@@ -1,7 +1,7 @@
 /*
  * BeastMain.java
  *
- * Copyright (c) 2002-2015 Alexei Drummond, Andrew Rambaut and Marc Suchard
+ * Copyright (c) 2002-2018 Alexei Drummond, Andrew Rambaut and Marc Suchard
  *
  * This file is part of BEAST.
  * See the NOTICE file distributed with this work for additional
@@ -27,6 +27,7 @@ package dr.app.beast;
 
 import beagle.BeagleFlag;
 import beagle.BeagleInfo;
+import dr.app.checkpoint.BeastCheckpointer;
 import dr.app.plugin.Plugin;
 import dr.app.plugin.PluginLoader;
 import dr.app.util.Arguments;
@@ -93,7 +94,7 @@ public class BeastMain {
 
             FileReader fileReader = new FileReader(inputFile);
 
-            XMLParser parser = new BeastParser(new String[]{fileName}, additionalParsers, verbose, parserWarning, strictXML);
+            XMLParser parser = new BeastParser(new String[]{fileName}, additionalParsers, verbose, parserWarning, strictXML, version);
 
             if (consoleApp != null) {
                 consoleApp.parser = parser;
@@ -154,6 +155,10 @@ public class BeastMain {
                 }
             }
 
+            // Install the checkpointer. This creates a factory that returns
+            // appropriate savers and loaders according to the user's options.
+            new BeastCheckpointer();
+
             if (!useMC3) {
                 // just parse the file running all threads...
 
@@ -187,7 +192,7 @@ public class BeastMain {
                     // turn off all messages for subsequent reads of the file (they will be the same as the
                     // first time).
                     messageHandler.setLevel(Level.OFF);
-                    parser = new BeastParser(new String[]{fileName}, additionalParsers, verbose, parserWarning, strictXML);
+                    parser = new BeastParser(new String[]{fileName}, additionalParsers, verbose, parserWarning, strictXML, version);
 
                     chains[i] = (MCMC) parser.parse(fileReader, MCMC.class);
                     if (chains[i] == null) {
@@ -222,7 +227,8 @@ public class BeastMain {
                     dome.getMessage());
             throw new RuntimeException("Terminate");
         } catch (dr.xml.XMLParseException pxe) {
-            pxe.printStackTrace(System.err);
+            // Leave the printing of the stack trace until the end - too noisy otherwise
+            //pxe.printStackTrace(System.err);
             if (pxe.getMessage() != null && pxe.getMessage().equals("Unknown root document element, beauti")) {
                 infoLogger.severe("Error running file: " + fileName);
                 infoLogger.severe(
@@ -235,7 +241,7 @@ public class BeastMain {
 
             } else {
                 infoLogger.severe("Parsing error - poorly formed BEAST file, " + fileName + ":\n" +
-                        pxe.getMessage());
+                        pxe.getMessage() + "\n\nError thrown at: " + pxe.getStackTrace()[0] + "\n");
             }
             throw new RuntimeException("Terminate");
         } catch (RuntimeException rex) {
@@ -254,7 +260,7 @@ public class BeastMain {
                                 "values. This will result in Priors with zero probability.\n\n" +
                                 "The individual components of the posterior are as follows:\n" +
                                 rex.getMessage() + "\n" +
-                                "For more information go to <http://beast.bio.ed.ac.uk/>.");
+                                "For more information go to <http://beast.community>.");
             } else {
                 // This call never returns as another RuntimeException exception is raised by
                 // the error log handler???
@@ -330,17 +336,24 @@ public class BeastMain {
                         new Arguments.IntegerOption("errors", "Specify maximum number of numerical errors before stopping"),
                         new Arguments.IntegerOption("threads", "The number of computational threads to use (default auto)"),
                         new Arguments.Option("java", "Use Java only, no native implementations"),
+                        new Arguments.LongOption("tests", "The number of full evaluation tests to perform (default 1000)"),
                         new Arguments.RealOption("threshold", 0.0, Double.MAX_VALUE, "Full evaluation test threshold (default 0.1)"),
 
-                        new Arguments.Option("beagle_off", "Don't use the BEAGLE library"),
+                        new Arguments.Option("adaptation_off", "Don't adapt operator sizes"),
+                        new Arguments.RealOption("adaptation_target", 0.0, 1.0, "Target acceptance rate for adaptive operators (default 0.234)"),
+
                         new Arguments.Option("beagle", "Use BEAGLE library if available (default on)"),
                         new Arguments.Option("beagle_info", "BEAGLE: show information on available resources"),
                         new Arguments.StringOption("beagle_order", "order", "BEAGLE: set order of resource use"),
                         new Arguments.IntegerOption("beagle_instances", "BEAGLE: divide site patterns amongst instances"),
+                        new Arguments.StringOption("beagle_multipartition", new String[]{"auto", "on", "off"},
+                                false, "BEAGLE: use multipartition extensions if available (default auto)"),
                         new Arguments.Option("beagle_CPU", "BEAGLE: use CPU instance"),
                         new Arguments.Option("beagle_GPU", "BEAGLE: use GPU instance if available"),
                         new Arguments.Option("beagle_SSE", "BEAGLE: use SSE extensions if available"),
                         new Arguments.Option("beagle_SSE_off", "BEAGLE: turn off use of SSE extensions"),
+                        new Arguments.Option("beagle_threading_off", "BEAGLE: turn off auto threading for a CPU instance"),
+                        new Arguments.IntegerOption("beagle_thread_count", 1, Integer.MAX_VALUE, "BEAGLE: manually set number of threads for a CPU instance"),
                         new Arguments.Option("beagle_cuda", "BEAGLE: use CUDA parallization if available"),
                         new Arguments.Option("beagle_opencl", "BEAGLE: use OpenCL parallization if available"),
                         new Arguments.Option("beagle_single", "BEAGLE: use single precision if available"),
@@ -352,14 +365,19 @@ public class BeastMain {
                         new Arguments.LongOption("beagle_rescale", "BEAGLE: frequency of rescaling (dynamic scaling only)"),
                         new Arguments.Option("mpi", "Use MPI rank to label output"),
 
+                        new Arguments.StringOption("particles", "FOLDER", "Specify a folder of particle start states"),
+
                         new Arguments.IntegerOption("mc3_chains", 1, Integer.MAX_VALUE, "number of chains"),
                         new Arguments.RealOption("mc3_delta", 0.0, Double.MAX_VALUE, "temperature increment parameter"),
                         new Arguments.RealArrayOption("mc3_temperatures", -1, "a comma-separated list of the hot chain temperatures"),
-                        new Arguments.LongOption("mc3_swap", 1, Integer.MAX_VALUE, "frequency at which chains temperatures will be swapped"),
+                        new Arguments.IntegerOption("mc3_swap", 1, Integer.MAX_VALUE, "frequency at which chains temperatures will be swapped"),
 
-                        new Arguments.StringOption("load_dump", "FILENAME", "Specify a filename to load a dumped state from"),
-                        new Arguments.LongOption("dump_state", "Specify a state at which to write a dump file"),
-                        new Arguments.LongOption("dump_every", "Specify a frequency to write a dump file"),
+                        new Arguments.StringOption("load_state", "FILENAME", "Specify a filename to load a saved state from"),
+                        new Arguments.StringOption("save_stem", "FILENAME", "Specify a stem for the filenames to save states to"),
+                        new Arguments.LongOption("save_at", "Specify a state at which to save a state file"),
+                        new Arguments.LongOption("save_every", "Specify a frequency to save the state file"),
+                        new Arguments.StringOption("save_state", "FILENAME", "Specify a filename to save state to"),
+                        new Arguments.Option("force_resume", "Force resuming from a saved state"),
 
                         new Arguments.StringOption("citations_file", "FILENAME", "Specify a filename to write a citation list to"),
 
@@ -367,6 +385,13 @@ public class BeastMain {
                         new Arguments.Option("help", "Print this information and stop"),
                 });
 
+        int[] versionNumbers = BeagleInfo.getVersionNumbers();
+        if (versionNumbers.length != 0 && versionNumbers[0] >= 3 && versionNumbers[1] >= 1) {
+            arguments.addOption("beagle_auto",
+                    "BEAGLE: automatically select fastest resource for analysis",
+                    "beagle_info");
+        };
+
         int argumentCount = 0;
 
         StringBuilder commandLine = new StringBuilder();
@@ -403,10 +428,16 @@ public class BeastMain {
         List<String> additionalParsers = new ArrayList<String>();
 
         final boolean verbose = arguments.hasOption("verbose");
-        final boolean parserWarning = arguments.hasOption("warnings"); // if dev, then auto turn on, otherwise default to turn off
+        if (verbose) {
+            System.setProperty("verbose_output", Boolean.toString(true));
+        }
+
+        final boolean warnings = arguments.hasOption("warnings"); // if dev, then auto turn on, otherwise default to turn off
+        if (warnings) {
+            System.setProperty("show_warnings", Boolean.toString(true));
+        }
+
         final boolean strictXML = arguments.hasOption("strict");
-        final boolean window = arguments.hasOption("window");
-        final boolean options = arguments.hasOption("options") || (argumentCount == 0);
         final boolean working = arguments.hasOption("working");
         String fileNamePrefix = null;
         boolean allowOverwrite = arguments.hasOption("overwrite");
@@ -415,60 +446,83 @@ public class BeastMain {
         long seed = MathUtils.getSeed();
         boolean useJava = false;
 
-        if (arguments.hasOption("threshold")) {
-            double evaluationThreshold = arguments.getRealOption("threshold");
-            System.setProperty("mcmc.evaluation.threshold", Double.toString(evaluationThreshold));
-        }
-
         int threadCount = -1;
 
-        if (arguments.hasOption("java")) {
-            useJava = true;
-        }
-
-        if (arguments.hasOption("prefix")) {
-            fileNamePrefix = arguments.getStringOption("prefix");
-        }
-
-        // ============= MC^3 settings =============
-
-        int chainCount = 1;
-        if (arguments.hasOption("mc3_chains")) {
-            chainCount = arguments.getIntegerOption("mc3_chains");
-        } else if (arguments.hasOption("mc3_temperatures")) {
-            chainCount = 1 + arguments.getRealArrayOption("mc3_temperatures").length;
-        }
-
-        double delta = DEFAULT_DELTA;
-        if (arguments.hasOption("mc3_delta")) {
-            if (arguments.hasOption("mc3_temperatures")) {
-                System.err.println("Either the -mc3_delta or the -mc3_temperatures option should be used, not both");
-                System.err.println();
-                printUsage(arguments);
-                System.exit(1);
-            }
-            delta = arguments.getRealOption("mc3_delta");
-        }
-
-        double[] chainTemperatures = new double[chainCount];
-        chainTemperatures[0] = 1.0;
-        if (arguments.hasOption("mc3_temperatures")) {
-            double[] hotChainTemperatures = arguments.getRealArrayOption("mc3_temperatures");
-            assert hotChainTemperatures.length == chainCount - 1;
-
-            System.arraycopy(hotChainTemperatures, 0, chainTemperatures, 1, chainCount - 1);
-        } else {
-            for (int i = 1; i < chainCount; i++) {
-                chainTemperatures[i] = 1.0 / (1.0 + (delta * i));
-            }
-        }
+        boolean usingSMC = false;
 
+        boolean usingMC3 = false;
+        double[] chainTemperatures = null;
         int swapChainsEvery = DEFAULT_SWAP_CHAIN_EVERY;
-        if (arguments.hasOption("mc3_swap")) {
-            swapChainsEvery = arguments.getIntegerOption("mc3_swap");
+
+        if (arguments.hasOption("particles")) {
+            System.setProperty("smc.particle_folder", arguments.getStringOption("particles"));
+            usingSMC = true;
+
+            System.setProperty("mcmc.evaluation.count", Long.toString(0));
         }
 
-        boolean useMC3 = chainCount > 1;
+        // smc option is always run without GUI.
+        final boolean window = !usingSMC && arguments.hasOption("window");
+        final boolean options = !usingSMC && (arguments.hasOption("options") || (argumentCount == 0));
+
+        if (!usingSMC) {
+            if (arguments.hasOption("tests")) {
+                long fullEvaluationCount = arguments.getLongOption("tests");
+                System.setProperty("mcmc.evaluation.count", Long.toString(fullEvaluationCount));
+            }
+
+            if (arguments.hasOption("threshold")) {
+                double fullEvaluationThreshold = arguments.getRealOption("threshold");
+                System.setProperty("mcmc.evaluation.threshold", Double.toString(fullEvaluationThreshold));
+            }
+
+            if (arguments.hasOption("java")) {
+                useJava = true;
+            }
+
+            if (arguments.hasOption("prefix")) {
+                fileNamePrefix = arguments.getStringOption("prefix");
+            }
+
+            // ============= MC^3 settings =============
+
+            int chainCount = 1;
+            if (arguments.hasOption("mc3_chains")) {
+                chainCount = arguments.getIntegerOption("mc3_chains");
+            } else if (arguments.hasOption("mc3_temperatures")) {
+                chainCount = 1 + arguments.getRealArrayOption("mc3_temperatures").length;
+            }
+
+            double delta = DEFAULT_DELTA;
+            if (arguments.hasOption("mc3_delta")) {
+                if (arguments.hasOption("mc3_temperatures")) {
+                    System.err.println("Either the -mc3_delta or the -mc3_temperatures option should be used, not both");
+                    System.err.println();
+                    printUsage(arguments);
+                    System.exit(1);
+                }
+                delta = arguments.getRealOption("mc3_delta");
+            }
+
+            chainTemperatures = new double[chainCount];
+            chainTemperatures[0] = 1.0;
+            if (arguments.hasOption("mc3_temperatures")) {
+                double[] hotChainTemperatures = arguments.getRealArrayOption("mc3_temperatures");
+                assert hotChainTemperatures.length == chainCount - 1;
+
+                System.arraycopy(hotChainTemperatures, 0, chainTemperatures, 1, chainCount - 1);
+            } else {
+                for (int i = 1; i < chainCount; i++) {
+                    chainTemperatures[i] = 1.0 / (1.0 + (delta * i));
+                }
+            }
+
+            if (arguments.hasOption("mc3_swap")) {
+                swapChainsEvery = arguments.getIntegerOption("mc3_swap");
+            }
+
+            usingMC3 = chainCount > 1;
+        }
 
         // ============= BEAGLE settings =============
         long beagleFlags = 0;
@@ -476,8 +530,11 @@ public class BeastMain {
         boolean beagleShowInfo = arguments.hasOption("beagle_info");
 
         // if any beagle flag is specified then use beagle...
-        boolean useBeagle = !arguments.hasOption("beagle_off");
+        //final boolean useBeagle = true;
 
+        if (arguments.hasOption("beagle_auto")) {
+            System.setProperty("beagle.resource.auto", Boolean.TRUE.toString());
+        }
         if (arguments.hasOption("beagle_CPU")) {
             beagleFlags |= BeagleFlag.PROCESSOR_CPU.getMask();
         }
@@ -492,6 +549,21 @@ public class BeastMain {
         }
         if (!arguments.hasOption("beagle_SSE_off")) {
             beagleFlags |= BeagleFlag.VECTOR_SSE.getMask();
+        } else {
+            beagleFlags |= BeagleFlag.VECTOR_NONE.getMask();
+        }
+        if (arguments.hasOption("beagle_threading_off")) {
+            beagleFlags |= BeagleFlag.THREADING_NONE.getMask();
+        } else {
+            beagleFlags |= BeagleFlag.THREADING_CPP.getMask();
+        }
+        if (arguments.hasOption("beagle_thread_count")) {
+            int beagleThreadCount = arguments.getIntegerOption("beagle_thread_count");
+            if (beagleThreadCount == 1) {
+                beagleFlags &= ~BeagleFlag.THREADING_CPP.getMask();
+                beagleFlags |= BeagleFlag.THREADING_NONE.getMask();
+            }
+            System.setProperty("beagle.thread.count", Integer.toString(arguments.getIntegerOption("beagle_thread_count")));
         }
 //        if (arguments.hasOption("beagle_double")) {
 //            beagleFlags |= BeagleFlag.PRECISION_DOUBLE.getMask();
@@ -525,6 +597,15 @@ public class BeastMain {
             System.setProperty("beagle.rescale", Long.toString(arguments.getLongOption("beagle_rescale")));
         }
 
+        if (arguments.hasOption("beagle_multipartition")) {
+            // attempt to force the use/non-use of the multipartition extensions, otherwise auto
+            if (arguments.getStringOption("beagle_multipartition").toLowerCase().equals("on")) {
+                System.setProperty("beagle.multipartition.extensions", Boolean.TRUE.toString());
+            } else if (arguments.getStringOption("beagle_multipartition").toLowerCase().equals("off")) {
+                System.setProperty("beagle.multipartition.extensions", Boolean.FALSE.toString());
+            }
+        }
+
         // ============= Other settings =============
         if (arguments.hasOption("threads")) {
             // threadCount defaults to -1 unless the user specifies an option
@@ -545,42 +626,68 @@ public class BeastMain {
             }
         }
 
-        if (arguments.hasOption("load_dump")) {
-            String debugStateFile = arguments.getStringOption("load_dump");
-            System.setProperty(MCMC.LOAD_DUMP_FILE, debugStateFile);
+        if (arguments.hasOption("adaptation_off")) {
+            System.setProperty("mcmc.use_adaptation", Boolean.FALSE.toString());
+        }
+        if (arguments.hasOption("adaptation_target")) {
+            System.setProperty("adaptation_target",
+                    Double.toString(arguments.getRealOption("mcmc.adaptation_target")));
         }
 
-        if (arguments.hasOption("dump_state")) {
-            long debugWriteState = arguments.getLongOption("dump_state");
-            System.setProperty(MCMC.DUMP_STATE, Long.toString(debugWriteState));
-        }
+        if (!usingSMC) {
+            // ignore these other options
 
-        if (arguments.hasOption("dump_every")) {
-            long debugWriteEvery = arguments.getLongOption("dump_every");
-            System.setProperty(MCMC.DUMP_EVERY, Long.toString(debugWriteEvery));
-        }
-
-        if (arguments.hasOption("citations_file")) {
-            String debugStateFile = arguments.getStringOption("citations_file");
-            System.setProperty("citations.filename", debugStateFile);
-        }
-
-        if (useMPI) {
-            String[] nullArgs = new String[0];
-            try {
-                BeastMPI.Init(nullArgs);
-            } catch (Exception e) {
-                throw new RuntimeException("Unable to access MPI.");
+            if (arguments.hasOption("load_state")) {
+                String stateFile = arguments.getStringOption("load_state");
+                System.setProperty(BeastCheckpointer.LOAD_STATE_FILE, stateFile);
             }
-            int rank = BeastMPI.COMM_WORLD.Rank();
-            System.setProperty("mpi.rank.postfix", String.valueOf(rank));
 
-        }
+            if (arguments.hasOption("save_at")) {
+                long saveAt = arguments.getLongOption("save_at");
+                System.setProperty(BeastCheckpointer.SAVE_STATE_AT, Long.toString(saveAt));
+            }
 
-        String rankProp = System.getProperty("mpi.rank.postfix");
-        if (rankProp != null) {
-            int rank = Integer.valueOf(rankProp);
-            seed = updateSeedByRank(seed, rank);
+            if (arguments.hasOption("save_every")) {
+                long saveEvery = arguments.getLongOption("save_every");
+                System.setProperty(BeastCheckpointer.SAVE_STATE_EVERY, Long.toString(saveEvery));
+            }
+
+            if (arguments.hasOption("save_state")) {
+                String stateFile = arguments.getStringOption("save_state");
+                System.setProperty(BeastCheckpointer.SAVE_STATE_FILE, stateFile);
+            }
+
+            if (arguments.hasOption("save_stem")) {
+                String stemName = arguments.getStringOption("save_stem");
+                System.setProperty(BeastCheckpointer.SAVE_STEM, stemName);
+            }
+
+            if (arguments.hasOption("force_resume")) {
+                System.setProperty("force.resume", Boolean.TRUE.toString());
+            }
+
+            if (arguments.hasOption("citations_file")) {
+                String debugStateFile = arguments.getStringOption("citations_file");
+                System.setProperty("citations.filename", debugStateFile);
+            }
+
+            if (useMPI) {
+                String[] nullArgs = new String[0];
+                try {
+                    BeastMPI.Init(nullArgs);
+                } catch (Exception e) {
+                    throw new RuntimeException("Unable to access MPI.");
+                }
+                int rank = BeastMPI.COMM_WORLD.Rank();
+                System.setProperty("mpi.rank.postfix", String.valueOf(rank));
+
+            }
+
+            String rankProp = System.getProperty("mpi.rank.postfix");
+            if (rankProp != null) {
+                int rank = Integer.valueOf(rankProp);
+                seed = updateSeedByRank(seed, rank);
+            }
         }
 
         int maxErrorCount = 0;
@@ -628,9 +735,11 @@ public class BeastMain {
 
             String titleString = "<html>" +
                     "<div style=\"font: HelveticaNeue, Helvetica, Arial, sans-serif\">" +
-                    "<p style=\"font-weight: 100; font-size: 42px\">BEAST</p>" +
-                    "<p style=\"font-weight: 200; font-size: 12px\">Bayesian Evolutionary Analysis Sampling Trees</p>" +
-                    "<p style=\"font-weight: 300; font-size: 11px\">Version " + version.getVersionString() + ", " + version.getDateString() + "</p>" +
+                    "<div style=\"font-weight: 100; font-size: 42px\">BEAST</div>" +
+                    "<div style=\"font-weight: 200; font-size: 11px\">Bayesian Evolutionary Analysis Sampling Trees</div>" +
+                    "<div style=\"font-weight: 300; font-size: 10px\">Version " + version.getVersionString() + ", " + version.getDateString() + "</div>" +
+                    "<div style=\"font-weight: 300; font-size: 10px\"><a href=\"" + version.getBuildString() + "\">" +
+                    version.getBuildString() + "</a></div>" +
                     "</div></html>";
             javax.swing.Icon icon = IconUtils.getIcon(BeastMain.class, "images/beast.png");
 
@@ -639,7 +748,7 @@ public class BeastMain {
             dialog.setAllowOverwrite(allowOverwrite);
             dialog.setSeed(seed);
 
-            dialog.setUseBeagle(useBeagle);
+            //dialog.setUseBeagle(useBeagle);
 
             if (BeagleFlag.PROCESSOR_GPU.isSet(beagleFlags)) {
                 dialog.setPreferBeagleGPU();
@@ -662,28 +771,25 @@ public class BeastMain {
             seed = dialog.getSeed();
             threadCount = dialog.getThreadPoolSize();
 
-            useBeagle = dialog.useBeagle();
-            if (useBeagle) {
-                beagleShowInfo = dialog.showBeagleInfo();
-                if (dialog.preferBeagleCPU()) {
-                    beagleFlags |= BeagleFlag.PROCESSOR_CPU.getMask();
-                }
-                if (dialog.preferBeagleSSE()) {
-                    beagleFlags |= BeagleFlag.VECTOR_SSE.getMask();
-                } else {
-                    beagleFlags &= ~BeagleFlag.VECTOR_SSE.getMask();
-                }
-                if (dialog.preferBeagleGPU()) {
-                    beagleFlags |= BeagleFlag.PROCESSOR_GPU.getMask();
-                }
-                if (dialog.preferBeagleDouble()) {
-                    beagleFlags |= BeagleFlag.PRECISION_DOUBLE.getMask();
-                }
-                if (dialog.preferBeagleSingle()) {
-                    beagleFlags |= BeagleFlag.PRECISION_SINGLE.getMask();
-                }
-                System.setProperty("beagle.scaling", dialog.scalingScheme());
+            beagleShowInfo = dialog.showBeagleInfo();
+            if (dialog.preferBeagleCPU()) {
+                beagleFlags |= BeagleFlag.PROCESSOR_CPU.getMask();
             }
+            if (dialog.preferBeagleSSE()) {
+                beagleFlags |= BeagleFlag.VECTOR_SSE.getMask();
+            } else {
+                beagleFlags &= ~BeagleFlag.VECTOR_SSE.getMask();
+            }
+            if (dialog.preferBeagleGPU()) {
+                beagleFlags |= BeagleFlag.PROCESSOR_GPU.getMask();
+            }
+            if (dialog.preferBeagleDouble()) {
+                beagleFlags |= BeagleFlag.PRECISION_DOUBLE.getMask();
+            }
+            if (dialog.preferBeagleSingle()) {
+                beagleFlags |= BeagleFlag.PRECISION_SINGLE.getMask();
+            }
+            System.setProperty("beagle.scaling", dialog.scalingScheme());
 
             inputFile = dialog.getInputFile();
             if (!beagleShowInfo && inputFile == null) {
@@ -693,15 +799,17 @@ public class BeastMain {
 
         }
 
-        if (useBeagle) {
-            BeagleInfo.printVersionInformation();
+        BeagleInfo.printVersionInformation();
 
-            if (BeagleInfo.getVersion().startsWith("1.")) {
-                System.err.println("WARNING: You are currenly using BEAGLE v1.x. For best performance and compatibility\n" +
-                        "with models in BEAST, please upgrade to BEAGLE v2.x at http://github.com/beagle-dev/beagle-lib/\n");
-            }
+        if (BeagleInfo.getVersion().startsWith("1.")) {
+            System.err.println("WARNING: You are currenly using BEAGLE v1.x. For best performance and compatibility\n" +
+                    "with models in BEAST, please upgrade to BEAGLE v3.x at http://github.com/beagle-dev/beagle-lib/\n");
+        } else if (BeagleInfo.getVersion().startsWith("2.")) {
+            System.err.println("WARNING: You are currenly using BEAGLE v2.x. For best performance and compatibility\n" +
+                    "with models in BEAST, please upgrade to BEAGLE v3.x at http://github.com/beagle-dev/beagle-lib/\n");
         }
 
+
         if (beagleShowInfo) {
             BeagleInfo.printResourceList();
             return;
@@ -756,9 +864,7 @@ public class BeastMain {
             System.setProperty("log.allow.overwrite", "true");
         }
 
-        if (useBeagle) {
-            additionalParsers.add("beagle");
-        }
+        additionalParsers.add("beagle");
 
         if (beagleFlags != 0) {
             System.setProperty("beagle.preferred.flags", Long.toString(beagleFlags));
@@ -771,14 +877,14 @@ public class BeastMain {
 
         MathUtils.setSeed(seed);
 
-        System.out.println();
         System.out.println("Random number seed: " + seed);
-        System.out.println();
 
         try {
-            new BeastMain(inputFile, consoleApp, maxErrorCount, verbose, parserWarning, strictXML, additionalParsers, useMC3, chainTemperatures, swapChainsEvery);
+            new BeastMain(inputFile, consoleApp, maxErrorCount, verbose, warnings, strictXML, additionalParsers,
+                    usingMC3, chainTemperatures, swapChainsEvery);
         } catch (RuntimeException rte) {
-            rte.printStackTrace(System.err);
+            // The stack trace here is not useful
+//            rte.printStackTrace(System.err);
             if (window) {
                 System.out.println();
                 System.out.println("BEAST has terminated with an error. Please select QUIT from the menu.");
