@@ -30,17 +30,17 @@ import dr.app.beauti.options.*;
 import dr.app.beauti.util.XMLWriter;
 import dr.evolution.datatype.DataType;
 import dr.evomodel.branchratemodel.BranchRateModel;
-import dr.evomodel.sitemodel.GammaSiteModel;
-import dr.evomodel.sitemodel.SiteModel;
+import dr.oldevomodel.sitemodel.GammaSiteModel;
+import dr.oldevomodel.sitemodel.SiteModel;
 import dr.evomodel.tree.TreeModel;
-import dr.evomodelxml.MSSD.ALSSiteModelParser;
-import dr.evomodelxml.MSSD.ALSTreeLikelihoodParser;
+import dr.oldevomodelxml.MSSD.ALSSiteModelParser;
+import dr.oldevomodelxml.MSSD.ALSTreeLikelihoodParser;
 import dr.evomodelxml.branchratemodel.DiscretizedBranchRatesParser;
 import dr.evomodelxml.branchratemodel.RandomLocalClockModelParser;
 import dr.evomodelxml.branchratemodel.StrictClockBranchRatesParser;
-import dr.evomodelxml.sitemodel.GammaSiteModelParser;
-import dr.evomodelxml.substmodel.MutationDeathModelParser;
-import dr.evomodelxml.treelikelihood.TreeLikelihoodParser;
+import dr.oldevomodelxml.sitemodel.GammaSiteModelParser;
+import dr.oldevomodelxml.substmodel.MutationDeathModelParser;
+import dr.oldevomodelxml.treelikelihood.TreeLikelihoodParser;
 import dr.evoxml.AlignmentParser;
 import dr.evoxml.MutationDeathTypeParser;
 import dr.evoxml.SitePatternsParser;
@@ -291,7 +291,7 @@ public class DolloComponentGenerator extends BaseComponentGenerator {
                         + BranchRateModel.BRANCH_RATES);
                 break;
             case UNCORRELATED:
-                writer.writeIDref(DiscretizedBranchRatesParser.DISCRETIZED_BRANCH_RATES, options.noDuplicatedPrefix(clockModel.getPrefix(), treeModel.getPrefix())
+                writer.writeIDref(DiscretizedBranchRatesParser.DISCRETIZED_BRANCH_RATES, clockModel.getPrefix()
                         + BranchRateModel.BRANCH_RATES);
                 break;
             case RANDOM_LOCAL_CLOCK:
