@@ -1,7 +1,7 @@
 /*
  * MarginalLikelihoodEstimationComponentFactory.java
  *
- * Copyright (C) 2002-2013 Alexei Drummond, Andrew Rambaut and Marc Suchard
+ * Copyright (c) 2002-2015 Alexei Drummond, Andrew Rambaut and Marc Suchard
  *
  * This file is part of BEAST.
  * See the NOTICE file distributed with this work for additional
@@ -26,8 +26,6 @@
 package dr.app.beauti.components.marginalLikelihoodEstimation;
 
 import dr.app.beauti.components.ComponentFactory;
-import dr.app.beauti.components.sequenceerror.SequenceErrorModelComponentGenerator;
-import dr.app.beauti.components.sequenceerror.SequenceErrorModelComponentOptions;
 import dr.app.beauti.generator.ComponentGenerator;
 import dr.app.beauti.options.BeautiOptions;
 import dr.app.beauti.options.ComponentOptions;
