@@ -1,7 +1,7 @@
 /*
  * MarginalLikelihoodEstimationOptions.java
  *
- * Copyright (C) 2002-2013 Alexei Drummond, Andrew Rambaut and Marc Suchard
+ * Copyright (c) 2002-2015 Alexei Drummond, Andrew Rambaut and Marc Suchard
  *
  * This file is part of BEAST.
  * See the NOTICE file distributed with this work for additional
@@ -25,22 +25,21 @@
 
 package dr.app.beauti.components.marginalLikelihoodEstimation;
 
-import dr.app.beauti.options.*;
-import dr.app.beauti.types.OperatorType;
-import dr.app.beauti.types.PriorScaleType;
-import dr.app.beauti.types.SequenceErrorType;
+import dr.app.beauti.options.ComponentOptions;
+import dr.app.beauti.options.ModelOptions;
+import dr.app.beauti.options.Operator;
+import dr.app.beauti.options.Parameter;
 
-import java.util.HashMap;
 import java.util.List;
-import java.util.Map;
 
 /**
  * @author Andrew Rambaut
+ * @author Guy Baele
  * @version $Id$
  */
 public class MarginalLikelihoodEstimationOptions implements ComponentOptions {
 
-    MarginalLikelihoodEstimationOptions() {
+    public MarginalLikelihoodEstimationOptions() {
     }
 
     @Override
@@ -62,13 +61,19 @@ public class MarginalLikelihoodEstimationOptions implements ComponentOptions {
     public void selectOperators(ModelOptions modelOptions, List<Operator> ops) {
         // nothing to do
     }
+
     //MLE options
     public boolean performMLE = false;
+    public boolean performMLEGSS = false;
+    public boolean printOperatorAnalysis = false;
     public int pathSteps = 100;
     public int mleChainLength = 1000000;
     public int mleLogEvery = 1000;
-    public String mleFileName = "MLE.log";
+    public String mleFileName = "mle.log";
+    public String mleResultFileName = "mle.result.log";
     public String pathScheme = "betaquantile";
+    //public String choiceParameterWorkingPrior = "normal";
+    public String choiceTreeWorkingPrior = "Product of exponential distributions";
     public double schemeParameter = 0.30;
 
 }
\ No newline at end of file
