@@ -1,3 +1,28 @@
+/*
+ * SequenceErrorModelComponentGenerator.java
+ *
+ * Copyright (c) 2002-2015 Alexei Drummond, Andrew Rambaut and Marc Suchard
+ *
+ * This file is part of BEAST.
+ * See the NOTICE file distributed with this work for additional
+ * information regarding copyright ownership and licensing.
+ *
+ * BEAST is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ *  BEAST is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with BEAST; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301  USA
+ */
+
 package dr.app.beauti.components.sequenceerror;
 
 import dr.app.beauti.generator.BaseComponentGenerator;
@@ -6,8 +31,8 @@ import dr.app.beauti.options.BeautiOptions;
 import dr.app.beauti.types.SequenceErrorType;
 import dr.app.beauti.util.XMLWriter;
 import dr.evolution.alignment.HypermutantAlignment;
-import dr.evomodel.treelikelihood.HypermutantErrorModel;
-import dr.evomodelxml.treelikelihood.SequenceErrorModelParser;
+import dr.evomodel.tipstatesmodel.HypermutantErrorModel;
+import dr.evomodelxml.tipstatesmodel.SequenceErrorModelParser;
 import dr.evoxml.HypermutantAlignmentParser;
 import dr.inference.model.ParameterParser;
 import dr.inference.model.StatisticParser;
