@@ -83,8 +83,6 @@ public class DataPanel extends BeautiPanel implements Exportable {
 
 //    ShowAction showAction = new ShowAction();
 
-    public JCheckBox useStarBEASTCheck = new JCheckBox("Use species tree ancestral reconstruction (*BEAST) Heled & Drummond 2010 ");
-
     SelectModelDialog selectModelDialog = null;
     SelectClockDialog selectClockDialog = null;
     SelectTreeDialog selectTreeDialog = null;
@@ -108,22 +106,14 @@ public class DataPanel extends BeautiPanel implements Exportable {
 
         TableColumn col = dataTable.getColumnModel().getColumn(5);
         ComboBoxRenderer comboBoxRenderer = new ComboBoxRenderer();
-        comboBoxRenderer.putClientProperty("JComboBox.isTableCellEditor", Boolean.TRUE);
         col.setCellRenderer(comboBoxRenderer);
 
-//        col = dataTable.getColumnModel().getColumn(5);
-//        comboBoxRenderer = new ComboBoxRenderer();
-//        comboBoxRenderer.putClientProperty("JComboBox.isTableCellEditor", Boolean.TRUE);
-//        col.setCellRenderer(comboBoxRenderer);
-
         col = dataTable.getColumnModel().getColumn(6);
         comboBoxRenderer = new ComboBoxRenderer();
-        comboBoxRenderer.putClientProperty("JComboBox.isTableCellEditor", Boolean.TRUE);
         col.setCellRenderer(comboBoxRenderer);
 
         col = dataTable.getColumnModel().getColumn(7);
         comboBoxRenderer = new ComboBoxRenderer();
-        comboBoxRenderer.putClientProperty("JComboBox.isTableCellEditor", Boolean.TRUE);
         col.setCellRenderer(comboBoxRenderer);
 
         TableEditorStopper.ensureEditingStopWhenTableLosesFocus(dataTable);
@@ -141,6 +131,7 @@ public class DataPanel extends BeautiPanel implements Exportable {
                 }
             }
         });
+//        dataTable.setFocusable(false);
 
         scrollPane = new JScrollPane(dataTable,
                 JScrollPane.VERTICAL_SCROLLBAR_ALWAYS,
@@ -151,6 +142,7 @@ public class DataPanel extends BeautiPanel implements Exportable {
         toolBar1.setFloatable(false);
         toolBar1.setOpaque(false);
         toolBar1.setLayout(new BoxLayout(toolBar1, BoxLayout.X_AXIS));
+        toolBar1.setBorder(BorderFactory.createEmptyBorder());
 
         JButton button = new JButton(unlinkModelsAction);
         unlinkModelsAction.setEnabled(false);
@@ -186,12 +178,6 @@ public class DataPanel extends BeautiPanel implements Exportable {
         PanelUtils.setupComponent(button);
         toolBar1.add(button);
 
-        // too crowded on the toolbar  - just double click to show
-//            button = new JButton(showAction);
-//            showAction.setEnabled(false);
-//            PanelUtils.setupComponent(button);
-//            toolBar1.add(button);
-
         ActionPanel actionPanel1 = new ActionPanel(false);
         actionPanel1.setAddAction(importDataAction);
         actionPanel1.setRemoveAction(removeDataAction);
@@ -212,31 +198,18 @@ public class DataPanel extends BeautiPanel implements Exportable {
         PanelUtils.setupComponent(button);
         controlPanel1.add(button);
 
-        JPanel panel1 = new JPanel(new BorderLayout());
-        panel1.setOpaque(false);
-        panel1.add(useStarBEASTCheck, BorderLayout.NORTH);
-        panel1.add(toolBar1, BorderLayout.SOUTH);
+        //JPanel panel1 = new JPanel(new BorderLayout());
+        //panel1.setOpaque(false);
+        //panel1.add(useStarBEASTCheck, BorderLayout.NORTH);
+        //panel1.add(toolBar1, BorderLayout.SOUTH);
 
         setOpaque(false);
         setBorder(new BorderUIResource.EmptyBorderUIResource(new Insets(12, 12, 12, 12)));
         setLayout(new BorderLayout(0, 0));
-        add(panel1, BorderLayout.NORTH);
-//        add(toolBar1, BorderLayout.NORTH);
+        add(toolBar1, BorderLayout.NORTH);
         add(scrollPane, BorderLayout.CENTER);
         add(controlPanel1, BorderLayout.SOUTH);
 
-        useStarBEASTCheck.setEnabled(false);
-        useStarBEASTCheck.setToolTipText(STARBEASTOptions.CITATION);
-        useStarBEASTCheck.addActionListener(new java.awt.event.ActionListener() {
-            public void actionPerformed(ActionEvent e) {
-                if (!frame.setupStarBEAST(useStarBEASTCheck.isSelected())) {
-                    useStarBEASTCheck.setSelected(false); // go back to unchecked
-                }
-
-                dataTableModel.fireTableDataChanged();
-            }
-        });
-
     }
 
     private void showAlignment() {
@@ -284,7 +257,7 @@ public class DataPanel extends BeautiPanel implements Exportable {
     }
 
     private void fireDataChanged() {
-        options.updatePartitionAllLinks();
+        // options.updatePartitionAllLinks();
         frame.setDirty();
     }
 
@@ -297,7 +270,6 @@ public class DataPanel extends BeautiPanel implements Exportable {
 
         col = dataTable.getColumnModel().getColumn(7);
         col.setCellEditor(new DefaultCellEditor(new JComboBox(options.getPartitionTreeModels().toArray())));
-
     }
 
     public class ComboBoxCellEditor extends DefaultCellEditor {
@@ -347,7 +319,7 @@ public class DataPanel extends BeautiPanel implements Exportable {
         unlinkTreesAction.setEnabled(canUnlink);
         linkTreesAction.setEnabled(canLink);
 
-        viewPartitionAction.setEnabled(options.dataPartitions.size() > 1 && hasSelection);
+        viewPartitionAction.setEnabled(options.dataPartitions.size() > 0 && hasSelection);
     }
 
     public void setOptions(BeautiOptions options) {
@@ -357,9 +329,8 @@ public class DataPanel extends BeautiPanel implements Exportable {
         modelsChanged();
 
         boolean taxaAvailable = options.taxonList != null && options.taxonList.getTaxonCount() > 0;
-        boolean traitAvailable = options.traits != null && options.traits.size() > 0 && (!options.useStarBEAST);
+        boolean traitAvailable = options.traits != null && options.traits.size() > 0;
 
-        useStarBEASTCheck.setEnabled(taxaAvailable);
         createTraitPartitionAction.setEnabled(traitAvailable);
 
         dataTableModel.fireTableDataChanged();
@@ -387,8 +358,6 @@ public class DataPanel extends BeautiPanel implements Exportable {
         if (options.dataPartitions.size() == 0) {
             // all data partitions removed so reset the taxa
             options.reset();
-            useStarBEASTCheck.setSelected(false);
-            frame.setupStarBEAST(false);
             frame.statusLabel.setText("");
             frame.setAllOptions();
             frame.getExportAction().setEnabled(false);
@@ -452,7 +421,7 @@ public class DataPanel extends BeautiPanel implements Exportable {
         return true;
     }
 
-    public void unlinkModels() {
+    public void unlinkSubstitutionModels() {
         int[] selRows = dataTable.getSelectedRows();
         for (int row : selRows) {
             AbstractPartitionData partition = options.dataPartitions.get(row);
@@ -470,7 +439,7 @@ public class DataPanel extends BeautiPanel implements Exportable {
         repaint();
     }
 
-    public void linkModels() {
+    public void linkSubstitutionModels() {
         int[] selRows = dataTable.getSelectedRows();
         List<AbstractPartitionData> selectedPartitionData = new ArrayList<AbstractPartitionData>();
         DataType dateType = null;
@@ -520,16 +489,19 @@ public class DataPanel extends BeautiPanel implements Exportable {
         repaint();
     }
 
-    public void unlinkClocks() { // reuse previous PartitionTreePrior
+    public void unlinkClockModels() { // reuse previous PartitionTreePrior
         int[] selRows = dataTable.getSelectedRows();
         for (int row : selRows) {
             AbstractPartitionData partition = options.dataPartitions.get(row);
 
-            PartitionClockModel model = partition.getPartitionClockModel();
-            if (!model.getName().equals(partition.getName())) {
-                PartitionClockModel newModel = new PartitionClockModel(options, partition.getName(), model);
-                partition.setPartitionClockModel(newModel);
+            PartitionClockModel clockModel = partition.getPartitionClockModel();
+            if (!clockModel.getName().equals(partition.getName())) {
+                clockModel = new PartitionClockModel(options, partition.getName(), clockModel);
+                partition.setPartitionClockModel(clockModel);
             }
+
+            // Clock models need to refer to the same tree as the data (many to one relationship).
+            clockModel.setPartitionTreeModel(partition.getPartitionTreeModel());
         }
 
         modelsChanged();
@@ -538,16 +510,27 @@ public class DataPanel extends BeautiPanel implements Exportable {
         repaint();
     }
 
-    public void linkClocks() { // keep previous PartitionTreePrior for reuse
+    public void linkClockModels() {
         int[] selRows = dataTable.getSelectedRows();
 
         List<AbstractPartitionData> selectedPartitionData = new ArrayList<AbstractPartitionData>();
         for (int row : selRows) {
             AbstractPartitionData partition = options.dataPartitions.get(row);
 
-            if (!selectedPartitionData.contains(partition))
+            if (!selectedPartitionData.contains(partition)) {
                 selectedPartitionData.add(partition);
+            }
         }
+
+        if (selectedPartitionData.size() > 1) {
+            if (!options.hasIdenticalTaxa(selectedPartitionData)) {
+                String errMsg = "To share a clock model, partitions need to have identical taxa.";
+                JOptionPane.showMessageDialog(this, errMsg, "Unsuppoted Configuration", JOptionPane.ERROR_MESSAGE);
+                return;
+            }
+        }
+
+
         Object[] modelArray = options.getPartitionClockModels(selectedPartitionData).toArray();
 
         if (selectClockDialog == null) {
@@ -556,13 +539,16 @@ public class DataPanel extends BeautiPanel implements Exportable {
 
         int result = selectClockDialog.showDialog(modelArray);
         if (result != JOptionPane.CANCEL_OPTION) {
-            PartitionClockModel model = selectClockDialog.getModel();
+            PartitionClockModel clockModel = selectClockDialog.getModel();
             if (selectClockDialog.getMakeCopy()) {
-                model.setName(selectClockDialog.getName());
+                clockModel.setName(selectClockDialog.getName());
             }
 
             for (AbstractPartitionData partition : selectedPartitionData) {
-                partition.setPartitionClockModel(model);
+                partition.setPartitionClockModel(clockModel);
+
+                // Clock models need to refer to the same tree as the data (many to one relationship).
+                partition.setPartitionTreeModel(clockModel.getPartitionTreeModel());
             }
         }
 
@@ -572,23 +558,30 @@ public class DataPanel extends BeautiPanel implements Exportable {
         repaint();
     }
 
-    public void unlinkTrees() { // reuse previous PartitionTreePrior
+    public void unlinkTreeModels() { // reuse previous PartitionTreePrior
         int[] selRows = dataTable.getSelectedRows();
         for (int row : selRows) {
             AbstractPartitionData partition = options.dataPartitions.get(row);
 
-            PartitionTreeModel model = partition.getPartitionTreeModel();
-            if (!model.getName().equals(partition.getName()) && partition.getTraits() == null) {// not a trait
-                PartitionTreeModel newTree = new PartitionTreeModel(options, partition.getName(), model);
-
-                // this prevents partition not broken, and used for unsharing tree prior only,
-                // because sharing uses shareSameTreePrior, unsharing uses getPartitionTreePrior
-//                newTree.setPartitionTreePrior(newPrior); // important
-
-                partition.setPartitionTreeModel(newTree);
+            PartitionTreeModel treeModel = partition.getPartitionTreeModel();
+            if (!treeModel.getName().equals(partition.getName()) && partition.getTraits() == null) {// not a trait
+                treeModel = new PartitionTreeModel(options, partition.getName(), treeModel);
+                partition.setPartitionTreeModel(treeModel);
             }
+
+            // Clock models need to refer to the same tree as the data (many to one relationship).
+            // When unlinking trees, the clocks must also be unlinked. Perhaps a dialog is need
+            // to say this? The parameters of the clocks could be linked in the priors panel.
+            PartitionClockModel clockModel = partition.getPartitionClockModel();
+            if (!clockModel.getName().equals(partition.getName())) {
+                clockModel = new PartitionClockModel(options, partition.getName(), clockModel);
+                partition.setPartitionClockModel(clockModel);
+            }
+
+            clockModel.setPartitionTreeModel(treeModel);
         }
 
+
         options.linkTreePriors(frame.getCurrentPartitionTreePrior());
 
         modelsChanged();
@@ -597,7 +590,7 @@ public class DataPanel extends BeautiPanel implements Exportable {
         repaint();
     }
 
-    public void linkTrees() { // keep previous PartitionTreePrior for reuse
+    public void linkTreeModels() { // keep previous PartitionTreePrior for reuse
         int[] selRows = dataTable.getSelectedRows();
 
         List<AbstractPartitionData> selectedPartitionData = new ArrayList<AbstractPartitionData>();
@@ -613,7 +606,7 @@ public class DataPanel extends BeautiPanel implements Exportable {
                 String errMsg = "To share a tree, partitions need to have identical taxa.";
                 if (selectedPartitionData.get(0).getDataType().getType() == DataType.MICRO_SAT)
                     errMsg += "\nThe data must be all diploid or all haploid when you want to link the tree.";
-                JOptionPane.showMessageDialog(this, errMsg, "Illegal Configuration", JOptionPane.ERROR_MESSAGE);
+                JOptionPane.showMessageDialog(this, errMsg, "Unsuppoted Configuration", JOptionPane.ERROR_MESSAGE);
                 return;
             }
         }
@@ -626,20 +619,26 @@ public class DataPanel extends BeautiPanel implements Exportable {
 
         int result = selectTreeDialog.showDialog(treeArray);
         if (result != JOptionPane.CANCEL_OPTION) {
-            PartitionTreeModel model = selectTreeDialog.getTree();
+            PartitionTreeModel treeModel = selectTreeDialog.getTree();
             if (selectTreeDialog.getMakeCopy()) {
-                model.setName(selectTreeDialog.getName());
+                treeModel.setName(selectTreeDialog.getName());
             }
-            PartitionTreePrior prior = model.getPartitionTreePrior();
+            PartitionTreePrior prior = treeModel.getPartitionTreePrior();
             options.linkTreePriors(prior);
 
             for (AbstractPartitionData partition : selectedPartitionData) {
-                partition.setPartitionTreeModel(model);
+                partition.setPartitionTreeModel(treeModel);
+
+                // Clock models need to refer to the same tree as the data (many to one relationship).
+                // Make sure the clock model for this partition refers to the same tree as the partition.
+                PartitionClockModel clockModel = partition.getPartitionClockModel();
+                clockModel.setPartitionTreeModel(treeModel);
+
             }
 
             for (Taxa taxa : options.taxonSets) { // Issue 454: all the taxon sets are deleted when link/unlink tree
                 PartitionTreeModel prevModel = options.taxonSetsTreeModel.get(taxa);
-                if (prevModel != model) options.taxonSetsTreeModel.put(taxa, model);
+                if (prevModel != treeModel) options.taxonSetsTreeModel.put(taxa, treeModel);
             }
         }
 
@@ -650,9 +649,9 @@ public class DataPanel extends BeautiPanel implements Exportable {
     }
 
     public void unlinkAll() {
-        unlinkModels();
-        unlinkClocks();
-        unlinkTrees();
+        unlinkSubstitutionModels();
+        unlinkClockModels();
+        unlinkTreeModels();
     }
 
     class DataTableModel extends AbstractTableModel {
@@ -802,7 +801,7 @@ public class DataPanel extends BeautiPanel implements Exportable {
         }
 
         public void actionPerformed(ActionEvent ae) {
-            unlinkModels();
+            unlinkSubstitutionModels();
         }
     }
 
@@ -814,7 +813,7 @@ public class DataPanel extends BeautiPanel implements Exportable {
         }
 
         public void actionPerformed(ActionEvent ae) {
-            linkModels();
+            linkSubstitutionModels();
         }
     }
 
@@ -825,7 +824,7 @@ public class DataPanel extends BeautiPanel implements Exportable {
         }
 
         public void actionPerformed(ActionEvent ae) {
-            unlinkClocks();
+            unlinkClockModels();
         }
     }
 
@@ -837,7 +836,7 @@ public class DataPanel extends BeautiPanel implements Exportable {
         }
 
         public void actionPerformed(ActionEvent ae) {
-            linkClocks();
+            linkClockModels();
         }
     }
 
@@ -848,7 +847,7 @@ public class DataPanel extends BeautiPanel implements Exportable {
         }
 
         public void actionPerformed(ActionEvent ae) {
-            unlinkTrees();
+            unlinkTreeModels();
         }
     }
 
@@ -860,7 +859,7 @@ public class DataPanel extends BeautiPanel implements Exportable {
         }
 
         public void actionPerformed(ActionEvent ae) {
-            linkTrees();
+            linkTreeModels();
         }
     }
 
