@@ -31,9 +31,12 @@ import dr.app.beauti.options.BeautiOptions;
 import dr.app.beauti.options.PartitionTreeModel;
 import dr.app.beauti.util.XMLWriter;
 import dr.evolution.datatype.DataType;
+import dr.evomodel.tree.TMRCAStatistic;
 import dr.evomodel.tree.TreeModel;
 import dr.evomodelxml.coalescent.OldCoalescentSimulatorParser;
 import dr.evomodelxml.tree.MicrosatelliteSamplerTreeModelParser;
+import dr.evomodelxml.tree.TMRCAStatisticParser;
+import dr.evomodelxml.tree.TreeLengthStatisticParser;
 import dr.evomodelxml.tree.TreeModelParser;
 import dr.evoxml.MicrosatellitePatternParser;
 import dr.evoxml.UPGMATreeParser;
@@ -60,9 +63,9 @@ public class TreeModelGenerator extends Generator {
      */
     void writeTreeModel(PartitionTreeModel model, XMLWriter writer) {
 
-        setModelPrefix(model.getPrefix());
+        String prefix = model.getPrefix();
 
-        final String treeModelName = modelPrefix + TreeModel.TREE_MODEL; // treemodel.treeModel or treeModel
+        final String treeModelName = prefix + TreeModel.TREE_MODEL; // treemodel.treeModel or treeModel
 
         writer.writeComment("Generate a tree model");
         writer.writeTag(TreeModel.TREE_MODEL, new Attribute.Default<String>(XMLParser.ID, treeModelName), false);
@@ -71,13 +74,13 @@ public class TreeModelGenerator extends Generator {
 
         switch (model.getStartingTreeType()) {
             case USER:
-                writer.writeIDref("tree", modelPrefix + STARTING_TREE);
+                writer.writeIDref("tree", prefix + STARTING_TREE);
                 break;
             case UPGMA:
-                writer.writeIDref(UPGMATreeParser.UPGMA_TREE, modelPrefix + STARTING_TREE);
+                writer.writeIDref(UPGMATreeParser.UPGMA_TREE, prefix + STARTING_TREE);
                 break;
             case RANDOM:
-                writer.writeIDref(OldCoalescentSimulatorParser.COALESCENT_TREE, modelPrefix + STARTING_TREE);
+                writer.writeIDref(OldCoalescentSimulatorParser.COALESCENT_TREE, prefix + STARTING_TREE);
                 break;
             default:
                 throw new IllegalArgumentException("Unknown StartingTreeType");
@@ -85,7 +88,7 @@ public class TreeModelGenerator extends Generator {
 
         writer.writeOpenTag(TreeModelParser.ROOT_HEIGHT);
         writer.writeTag(ParameterParser.PARAMETER,
-                new Attribute.Default<String>(XMLParser.ID, treeModelName + "." + OldCoalescentSimulatorParser.ROOT_HEIGHT), true);
+                new Attribute.Default<String>(XMLParser.ID, treeModelName + "." + TreeModelParser.ROOT_HEIGHT), true);
         writer.writeCloseTag(TreeModelParser.ROOT_HEIGHT);
 
 
@@ -182,6 +185,25 @@ public class TreeModelGenerator extends Generator {
 //            writer.writeCloseTag(CompoundParameter.COMPOUND_PARAMETER);
 //        }
 
+        writer.writeComment("Statistic for sum of the branch lengths of the tree (tree length)");
+        writer.writeTag(TreeLengthStatisticParser.TREE_LENGTH_STATISTIC,
+                new Attribute[]{
+                        new Attribute.Default<String>(XMLParser.ID, prefix + "treeLength"),
+                }, false);
+        writer.writeIDref(TreeModel.TREE_MODEL, treeModelName);
+        writer.writeCloseTag(TreeLengthStatisticParser.TREE_LENGTH_STATISTIC);
+
+        if (model.hasTipCalibrations()) {
+            writer.writeComment("Statistic for time of most recent common ancestor of tree");
+            writer.writeTag(TMRCAStatisticParser.TMRCA_STATISTIC,
+                    new Attribute[]{
+                            new Attribute.Default<String>(XMLParser.ID, prefix + "age(root)"),
+                            new Attribute.Default<String>(TMRCAStatisticParser.ABSOLUTE, "true")
+                    }, false);
+            writer.writeIDref(TreeModel.TREE_MODEL, treeModelName);
+            writer.writeCloseTag(TMRCAStatisticParser.TMRCA_STATISTIC);
+        }
+
         if (model.getDataType().getType() == DataType.MICRO_SAT) {
             for (AbstractPartitionData partitionData : options.getDataPartitions(model)) {
                 writer.writeComment("Generate a microsatellite tree model");
@@ -196,7 +218,7 @@ public class TreeModelGenerator extends Generator {
                 writer.writeOpenTag(MicrosatelliteSamplerTreeModelParser.INTERNAL_VALUES);
                 writer.writeTag(ParameterParser.PARAMETER, new Attribute[]{
                         new Attribute.Default<String>(XMLParser.ID, partitionData.getName() + "." +
-                               MicrosatelliteSamplerTreeModelParser.TREE_MICROSATELLITE_SAMPLER_MODEL + ".internalNodesParameter"),
+                                MicrosatelliteSamplerTreeModelParser.TREE_MICROSATELLITE_SAMPLER_MODEL + ".internalNodesParameter"),
                         new Attribute.Default<Integer>(ParameterParser.DIMENSION, model.getDimension())}, true);
                 writer.writeCloseTag(MicrosatelliteSamplerTreeModelParser.INTERNAL_VALUES);
 
