@@ -31,12 +31,13 @@ import dr.app.beauti.BeautiPanel;
 import dr.app.beauti.components.marginalLikelihoodEstimation.MLEDialog;
 import dr.app.beauti.components.marginalLikelihoodEstimation.MLEGSSDialog;
 import dr.app.beauti.components.marginalLikelihoodEstimation.MarginalLikelihoodEstimationOptions;
+import dr.app.beauti.options.AbstractPartitionData;
 import dr.app.beauti.options.BeautiOptions;
 import dr.app.beauti.options.PartitionTreeModel;
-import dr.app.beauti.options.STARBEASTOptions;
 import dr.app.beauti.util.PanelUtils;
 import dr.app.gui.components.WholeNumberField;
 import dr.app.util.OSType;
+import dr.evolution.datatype.DataType;
 import dr.evolution.datatype.Microsatellite;
 import jam.panels.OptionsPanel;
 
@@ -63,10 +64,10 @@ public class MCMCPanel extends BeautiPanel {
 
     JCheckBox samplePriorCheckBox = new JCheckBox("Sample from prior only - create empty alignment");
     JComboBox performMLECombo = new JComboBox(new String[] {"None", "path sampling/stepping-stone sampling", "generalized stepping-stone sampling"});
-//    JCheckBox performMLE = new JCheckBox("Perform marginal likelihood estimation (MLE) using path sampling/stepping-stone sampling");
+    //    JCheckBox performMLE = new JCheckBox("Perform marginal likelihood estimation (MLE) using path sampling/stepping-stone sampling");
     JButton buttonMLE = new JButton("Settings");
     //    JCheckBox performMLEGSS = new JCheckBox("Perform marginal likelihood estimation (MLE) using generalized stepping-stone sampling");
-  //  JButton buttonMLEGSS = new JButton("Settings");
+    //  JButton buttonMLEGSS = new JButton("Settings");
 
     public static final String DEFAULT_FILE_NAME_STEM = "untitled";
     JTextField fileNameStemField = new JTextField(DEFAULT_FILE_NAME_STEM);
@@ -74,7 +75,7 @@ public class MCMCPanel extends BeautiPanel {
     private JCheckBox addTxt = new JCheckBox("Add .txt suffix");
 
     JTextArea logFileNameField = new JTextArea(DEFAULT_FILE_NAME_STEM + ".log");
-    JTextArea treeFileNameField = new JTextArea(DEFAULT_FILE_NAME_STEM + "." + STARBEASTOptions.TREE_FILE_NAME);
+    JTextArea treeFileNameField = new JTextArea(DEFAULT_FILE_NAME_STEM + ".trees");
 //    JCheckBox allowOverwriteLogCheck = new JCheckBox("Allow to overwrite the existing log file");
 
 //    JCheckBox mapTreeLogCheck = new JCheckBox("Create tree file containing the MAP tree:");
@@ -289,6 +290,22 @@ public class MCMCPanel extends BeautiPanel {
                     buttonMLE.setEnabled(true);
                     updateMLEFileNameStem();
                 } else if (performMLECombo.getSelectedIndex() == 2) {
+                    // Generalized stepping-stone sampling
+                    for (AbstractPartitionData partition : options.getDataPartitions()) {
+                        if (partition.getDataType().getType() != DataType.NUCLEOTIDES) {
+                            JOptionPane.showMessageDialog(frame,
+                                    "Generalized stepping-stone sampling is not currently\n" +
+                                            "compatible with substitution models other than those\n" +
+                                            "for nucleotide data. \n\n" +
+                                            "Use path sampling/stepping-stone sampling instead",
+                                    "Warning",
+                                    JOptionPane.WARNING_MESSAGE);
+
+                            performMLECombo.setSelectedIndex(1);
+                            return;
+
+                        }
+                    }
                     mleOptions.performMLE = false;
                     mleOptions.performMLEGSS = true;
                     //set to true because product of exponentials is the default option
@@ -311,7 +328,7 @@ public class MCMCPanel extends BeautiPanel {
                 int result = -1;
 
                 if (performMLECombo.getSelectedIndex() == 1) {
-                   result  = mleDialog.showDialog();
+                    result  = mleDialog.showDialog();
                 } else if (performMLECombo.getSelectedIndex() == 2) {
                     result = mleGssDialog.showDialog();
                 }
@@ -408,17 +425,10 @@ public class MCMCPanel extends BeautiPanel {
                 options.substTreeFileName.add(treeFileName);
             }
         }
-
-        if (options.useStarBEAST) {
-            treeFileName = options.fileNameStem + "." + options.starBEASTOptions.SPECIES_TREE_FILE_NAME;
-            if (addTxt.isSelected()) treeFileName = treeFileName + ".txt";
-            options.treeFileName.add(treeFileName);
-            //TODO: species sub tree
-        }
     }
 
     private String getTreeFileName(String treeName) {
-        return options.fileNameStem + "." + treeName + STARBEASTOptions.TREE_FILE_NAME;
+        return options.fileNameStem + "." + treeName + "trees";
     }
 
     private String displayTreeList(List<String> treeList) {
@@ -528,7 +538,7 @@ public class MCMCPanel extends BeautiPanel {
 //            fileNameStemField.setText(fileNameStem);
 //            fileNameStemField.setEnabled(false);
             logFileNameField.setText(DEFAULT_FILE_NAME_STEM + ".log");
-            treeFileNameField.setText(DEFAULT_FILE_NAME_STEM + "." + STARBEASTOptions.TREE_FILE_NAME);
+            treeFileNameField.setText(DEFAULT_FILE_NAME_STEM + ".trees");
 //            mapTreeLogCheck.setEnabled(false);
 //            mapTreeFileNameField.setEnabled(false);
 //            mapTreeFileNameField.setText("untitled");
