@@ -25,9 +25,9 @@
 
 package dr.app.beauti.options;
 
-import cern.colt.bitvector.QuickBitVector;
 import dr.app.beauti.types.PriorScaleType;
 import dr.app.beauti.types.PriorType;
+import dr.evolution.util.Taxa;
 import dr.math.distributions.Distribution;
 
 import java.io.Serializable;
@@ -67,6 +67,8 @@ public class Parameter implements Serializable {
     public final boolean isNonNegative;
     public final boolean isZeroOne;
     public final boolean isCached;
+    public final boolean isAdaptiveMultivariateCompatible;
+    public boolean isMaintainedSum;
     public boolean isCalibratedYule = false;
 //    public final double lower;
 //    public final double upper;
@@ -78,6 +80,10 @@ public class Parameter implements Serializable {
     public final boolean isPriorFixed;
     public PriorType priorType;
 
+    private Parameter parent;
+
+    private Taxa taxonSet = null;
+
     public double getInitial() {
         return initial;
     }
@@ -89,6 +95,8 @@ public class Parameter implements Serializable {
     // Editable fields
     private boolean isFixed;
     private double initial;
+    public double maintainedSum;
+    public double dimension;
     public boolean isTruncated;
     public double truncationUpper;
     public double truncationLower;
@@ -120,14 +128,21 @@ public class Parameter implements Serializable {
         private boolean isCMTCRate = false;
         private boolean isNonNegative = false;
         private boolean isZeroOne = false;
+        private boolean isMaintainedSum = false;
         private boolean isStatistic = false;
         private boolean isCached = false;
 
         private PartitionOptions options = null;
 
+        private Taxa taxonSet = null;
+
         private PriorType priorType = PriorType.NONE_TREE_PRIOR;
         private boolean isPriorFixed = false;
 
+        private boolean isAdaptiveMultivariateCompatible = false;
+
+        private double maintainedSum = 1.0;
+        private double dimension = 1;
         private double initial = Double.NaN;
         //        private double upper = Double.NaN;
 //        private double lower = Double.NaN;
@@ -163,12 +178,16 @@ public class Parameter implements Serializable {
             isCMTCRate = source.isCMTCRate;
             isNonNegative = source.isNonNegative;
             isZeroOne = source.isZeroOne;
+            isMaintainedSum = source.isMaintainedSum;
             isStatistic = source.isStatistic;
             isCached = source.isCached;
             options = source.options;
             priorType = source.priorType;
             isPriorFixed = source.isPriorFixed;
+            isAdaptiveMultivariateCompatible = source.isAdaptiveMultivariateCompatible;
             initial = source.initial;
+            dimension = source.dimension;
+            maintainedSum = source.maintainedSum;
             isTruncated = source.isTruncated;
             truncationUpper = source.truncationUpper;
             truncationLower = source.truncationLower;
@@ -195,6 +214,17 @@ public class Parameter implements Serializable {
             return this;
         }
 
+        public Builder dimension(int dimension) {
+            this.dimension = dimension;
+            return this;
+        }
+
+        public Builder maintainedSum(double maintainedSum) {
+            this.maintainedSum = maintainedSum;
+            this.isMaintainedSum = true;
+            return this;
+        }
+
         public Builder taxaId(String taxaId) {
             this.taxaId = taxaId;
             return this;
@@ -220,6 +250,10 @@ public class Parameter implements Serializable {
             return this;
         }
 
+        public Builder taxonSet(Taxa taxonSet) {
+            this.taxonSet = taxonSet;
+            return this;
+        }
         public Builder prior(PriorType priorType) {
             this.priorType = priorType;
             return this;
@@ -252,6 +286,17 @@ public class Parameter implements Serializable {
             return this;
         }
 
+        public Builder isMaintainedSum(boolean isMaintainedMean) {
+            this.isMaintainedSum = isMaintainedMean;
+            return this;
+        }
+
+        public Builder isAdaptiveMultivariateCompatible(boolean isAdaptiveMultivariateCompatible) {
+            this.isAdaptiveMultivariateCompatible = isAdaptiveMultivariateCompatible;
+            return this;
+        }
+
+
         public Builder isCMTCRate(boolean isCMTCRate) {
             this.isCMTCRate = isCMTCRate;
             return this;
@@ -340,6 +385,8 @@ public class Parameter implements Serializable {
         description = builder.description;
         scaleType = builder.scaleType;
         initial = builder.initial;
+        maintainedSum = builder.maintainedSum;
+        dimension = builder.dimension;
         taxaId = builder.taxaId;
         isNodeHeight = builder.isNodeHeight;
         isStatistic = builder.isStatistic;
@@ -352,7 +399,12 @@ public class Parameter implements Serializable {
         isCMTCRate = builder.isCMTCRate;
         isNonNegative = builder.isNonNegative;
         isZeroOne = builder.isZeroOne;
+        isMaintainedSum = builder.isMaintainedSum;
         isPriorFixed = builder.isPriorFixed;
+        isAdaptiveMultivariateCompatible = builder.isAdaptiveMultivariateCompatible;
+
+        taxonSet = builder.taxonSet;
+        
 //        upper = builder.upper;
 //        lower = builder.lower;
         isTruncated = builder.isTruncated;
@@ -373,6 +425,10 @@ public class Parameter implements Serializable {
     }
 
     //+++++++++++++++++++++++++++++++++++++++++++++++++++++
+    public String getPrefix() {
+        return prefix;
+    }
+
     public void setPrefix(String prefix) {
         this.prefix = prefix;
     }
@@ -412,7 +468,7 @@ public class Parameter implements Serializable {
 
     public String getDescription() {
         if (taxaId != null && options != null) {
-            return description + " on tree " + options.getName();
+            return description + " " + taxaId + " on tree " + options.getName();
         }
         return description;
     }
@@ -443,6 +499,15 @@ public class Parameter implements Serializable {
         this.options = options;
     }
 
+    public Taxa getTaxonSet() {
+        return taxonSet;
+    }
+
+    public void setTaxonSet(Taxa taxonSet) {
+        this.taxonSet = taxonSet;
+    }
+
+
     public void setPriorEdited(boolean priorEdited) {
         this.priorEdited = priorEdited;
     }
@@ -467,7 +532,7 @@ public class Parameter implements Serializable {
     public double getLowerBound() {
         double lower = Double.NEGATIVE_INFINITY;
 
-        if (priorType == PriorType.UNIFORM_PRIOR) {
+        if (priorType == PriorType.UNIFORM_PRIOR || priorType == PriorType.DISCRETE_UNIFORM_PRIOR) {
             lower = uniformLower;
         }
 
@@ -491,7 +556,7 @@ public class Parameter implements Serializable {
             }
         }
 
-        if (priorType == PriorType.UNIFORM_PRIOR) {
+        if (priorType == PriorType.UNIFORM_PRIOR || priorType == PriorType.DISCRETE_UNIFORM_PRIOR) {
             upper = uniformUpper;
         }
 
@@ -512,7 +577,7 @@ public class Parameter implements Serializable {
         }
     }
 
-    public boolean isMeanInRealSpace() {
+    public boolean isInRealSpace() {
         return meanInRealSpace;
     }
 
@@ -542,7 +607,16 @@ public class Parameter implements Serializable {
         this.dimensionWeight = dimensionWeight;
     }
 
+    public void setParent(Parameter parent) {
+        this.parent = parent;
+    }
+
+    public Parameter getParent() {
+        return parent;
+    }
+
     public void addSubParameter(Parameter parameter) {
+        parameter.setParent(this);
         subParameters.add(parameter);
     }
 
