@@ -48,42 +48,28 @@ public class TreeModelOptions extends ModelOptions {
     public TreeModelOptions(BeautiOptions options) {
         this.options = options;
 
-        initGlobalTreeModelParaAndOpers();
+        initModelParametersAndOpererators();
     }
 
-    private void initGlobalTreeModelParaAndOpers() {
+    @Override
+    public void initModelParametersAndOpererators() {
 
     }
 
-    /**
-     * return a list of parameters that are required
-     *
-     * @param params the parameter list
-     */
-    public void selectParameters(List<Parameter> params) {
-
+    @Override
+    public List<Parameter> selectParameters(List<Parameter> params) {
+        return params;
     }
 
-    /**
-     * return a list of operators that are required
-     *
-     * @param ops the operator list
-     */
-    public void selectOperators(List<Operator> ops) {
-
+    @Override
+    public List<Operator> selectOperators(List<Operator> ops) {
+        return ops;
     }
 
-    /////////////////////////////////////////////////////////////
-//    public double getRandomStartingTreeInitialRootHeight(PartitionTreeModel model) {
-//    	Parameter rootHeight = model.getParameter("treeModel.rootHeight");
-//
-//    	if (rootHeight.priorType != PriorType.NONE_TREE_PRIOR) {
-//    		return rootHeight.initial;
-//    	} else {
-//    		return calculateMeanDistance(model.getDataPartitions());
-//    	}
-//
-//    }
+    @Override
+    public String getPrefix() {
+        return null;
+    }
 
     public double getExpectedAvgBranchLength(double rootHeight) {
         double sum = 0;
@@ -97,6 +83,9 @@ public class TreeModelOptions extends ModelOptions {
     }
 
     public int isNodeCalibrated(PartitionTreeModel treeModel) {
+        if (treeModel == null) {
+            return -1;
+        }
         if (isNodeCalibrated(treeModel.getParameter("treeModel.rootHeight"))) {
             return 0; // root node
         } else if (options.getKeysFromValue(options.taxonSetsTreeModel, treeModel).size() > 0) {
@@ -111,14 +100,13 @@ public class TreeModelOptions extends ModelOptions {
         }
     }
 
-    public boolean isNodeCalibrated(Parameter para) {
-        return (para.taxaId != null && hasProperPriorOn(para)) // param.taxa != null is TMRCA
-                || (para.getBaseName().endsWith("treeModel.rootHeight") && hasProperPriorOn(para));
+    public boolean isNodeCalibrated(Parameter parameter) {
+        return (parameter.taxaId != null && hasProperPriorOn(parameter)) // param.taxa != null is TMRCA
+                || (parameter.getBaseName().endsWith("treeModel.rootHeight") && hasProperPriorOn(parameter));
     }
 
     private boolean hasProperPriorOn(Parameter para) {
         return para.priorType == PriorType.EXPONENTIAL_PRIOR
-//                || para.priorType == PriorType.TRUNC_NORMAL_PRIOR
                 || (para.priorType == PriorType.UNIFORM_PRIOR && para.uniformLower > 0 && para.uniformUpper < Double.POSITIVE_INFINITY)
                 || para.priorType == PriorType.LAPLACE_PRIOR
                 || para.priorType == PriorType.NORMAL_PRIOR
