@@ -26,15 +26,12 @@
 package dr.app.beauti.tipdatepanel;
 
 import dr.app.beauti.options.DateGuesser;
-import dr.app.beauti.options.STARBEASTOptions;
 import dr.app.beauti.util.TextUtil;
 import dr.app.gui.components.RealNumberField;
 import jam.mac.Utils;
 import jam.panels.OptionsPanel;
 
 
-import java.io.*;
-import javax.swing.filechooser.FileNameExtensionFilter;
 import javax.swing.*;
 import javax.swing.border.EmptyBorder;
 import java.awt.*;
@@ -66,8 +63,6 @@ public class GuessDatesDialog {
 
     private JFrame frame;
 
-    private File loadFile;
-
     private final OptionsPanel optionPanel;
 
     private final JRadioButton orderRadio = new JRadioButton("Defined just by its order", true);
@@ -96,7 +91,7 @@ public class GuessDatesDialog {
     private final RealNumberField offset2Text = new RealNumberField();
 
     private final JTextField dateFormatText = new JTextField(16);
-    private String description = "Guess Dates for Taxa";
+    private String description = "Extract dates from taxon labels";
 
     private final int defaultDelimitRadioOption;
     private final int defaultOrderCombo;
@@ -248,14 +243,18 @@ public class GuessDatesDialog {
         group.add(calendar2Radio);
         ItemListener listener = new ItemListener() {
             public void itemStateChanged(ItemEvent e) {
-                offsetCheck.setEnabled(numericalRadio.isSelected());
-                offsetText.setEnabled(numericalRadio.isSelected() && offsetCheck.isSelected());
-                unlessCheck.setEnabled(numericalRadio.isSelected() && offsetCheck.isSelected());
-                unlessText.setEnabled(numericalRadio.isSelected() && offsetCheck.isSelected() && unlessCheck.isSelected());
-                offset2Label.setEnabled(numericalRadio.isSelected() && offsetCheck.isSelected() && unlessCheck.isSelected());
-                offset2Text.setEnabled(numericalRadio.isSelected() && offsetCheck.isSelected() && unlessCheck.isSelected());
-                dateFormatLabel.setEnabled(calendarRadio.isSelected());
-                dateFormatText.setEnabled(calendarRadio.isSelected());
+                boolean nrs = numericalRadio.isSelected();
+                boolean ocs = offsetCheck.isSelected();
+                boolean ucs = unlessCheck.isSelected();
+                boolean crs = calendarRadio.isSelected();
+                offsetCheck.setEnabled(nrs);
+                offsetText.setEnabled(nrs && ocs);
+                unlessCheck.setEnabled(nrs && ocs);
+                unlessText.setEnabled(nrs && ocs && ucs);
+                offset2Label.setEnabled(nrs && ocs && ucs);
+                offset2Text.setEnabled(nrs && ocs && ucs);
+                dateFormatLabel.setEnabled(crs);
+                dateFormatText.setEnabled(crs);
 
             }
         };
@@ -263,6 +262,22 @@ public class GuessDatesDialog {
         calendarRadio.addItemListener(listener);
         calendar2Radio.addItemListener(listener);
 
+        offsetCheck.setSelected(defaultOffsetCheckOption);
+        offsetText.setText(defaultOffsetText);
+        unlessCheck.setSelected(defaultUnlessCheckOption);
+        unlessText.setText(defaultUnlessText);
+        offset2Text.setText(defaultOffset2Text);
+
+        dateFormatText.setText(defaultDateFormatText);
+
+        orderCombo.setSelectedIndex(defaultOrderCombo);
+        prefixText.setText(defaultPrefixText);
+        regexText.setText(defaultRegexText);
+
+        orderCombo.setSelectedIndex(defaultOrderCombo);
+        prefixText.setText(defaultPrefixText);
+        regexText.setText(defaultRegexText);
+
         // set from preferences defaults...
         switch (defaultDelimitRadioOption) {
             case 0: orderRadio.setSelected(true); break;
@@ -272,10 +287,6 @@ public class GuessDatesDialog {
             default: throw new IllegalArgumentException("unknown radio option");
         }
 
-        orderCombo.setSelectedIndex(defaultOrderCombo);
-        prefixText.setText(defaultPrefixText);
-        regexText.setText(defaultRegexText);
-
         switch (defaultParseRadioOption) {
             case 0: numericalRadio.setSelected(true); break;
             case 1: calendarRadio.setSelected(true); break;
@@ -283,13 +294,6 @@ public class GuessDatesDialog {
             default: throw new IllegalArgumentException("unknown radio option");
         }
 
-        offsetCheck.setSelected(defaultOffsetCheckOption);
-        offsetText.setText(defaultOffsetText);
-        unlessCheck.setSelected(defaultUnlessCheckOption);
-        unlessText.setText(defaultUnlessText);
-        offset2Text.setText(defaultOffset2Text);
-
-        dateFormatText.setText(defaultDateFormatText);
     }
 
     public int showDialog() {
