@@ -28,17 +28,16 @@ package dr.app.beauti.tipdatepanel;
 import dr.app.beauti.BeautiFrame;
 import dr.app.beauti.BeautiPanel;
 import dr.app.beauti.components.tipdatesampling.TipDateSamplingComponentOptions;
-import dr.app.beauti.options.BeautiOptions;
-import dr.app.beauti.options.ClockModelGroup;
-import dr.app.beauti.options.DateGuesser;
-import dr.app.beauti.options.GuessDatesException;
+import dr.app.beauti.options.*;
 import dr.app.beauti.types.TipDateSamplingType;
 import dr.app.beauti.util.PanelUtils;
 import dr.app.gui.table.DateCellEditor;
 import dr.app.gui.table.TableEditorStopper;
 import dr.app.gui.table.TableSorter;
 import dr.evolution.util.*;
+import dr.evolution.util.Date;
 import dr.evoxml.util.DateUnitsType;
+import dr.util.DataTable;
 import jam.framework.Exportable;
 import jam.table.HeaderRenderer;
 import jam.table.TableRenderer;
@@ -46,15 +45,22 @@ import jam.table.TableRenderer;
 import javax.swing.*;
 import javax.swing.event.ListSelectionEvent;
 import javax.swing.event.ListSelectionListener;
+import javax.swing.filechooser.FileNameExtensionFilter;
 import javax.swing.plaf.BorderUIResource;
 import javax.swing.table.AbstractTableModel;
 import java.awt.*;
 import java.awt.event.*;
-import java.util.EnumSet;
+import java.io.File;
+import java.io.FileNotFoundException;
+import java.io.FileReader;
+import java.io.IOException;
+import java.util.*;
+import java.util.List;
 
 /**
  * @author Andrew Rambaut
  * @author Alexei Drummond
+ * @author Tommy Lam
  * @version $Id: DataPanel.java,v 1.17 2006/09/05 13:29:34 rambaut Exp $
  */
 public class TipDatesPanel extends BeautiPanel implements Exportable {
@@ -64,38 +70,43 @@ public class TipDatesPanel extends BeautiPanel implements Exportable {
      */
     private static final long serialVersionUID = 5283922195494563924L;
 
-    JScrollPane scrollPane = new JScrollPane();
-    JTable dataTable = null;
-    DataTableModel dataTableModel = null;
+    private JScrollPane scrollPane = new JScrollPane();
+    private JTable dataTable = null;
+    private DataTableModel dataTableModel = null;
 
-    SetDatesAction setDatesAction = new SetDatesAction();
-    ClearDatesAction clearDatesAction = new ClearDatesAction();
-    GuessDatesAction guessDatesAction = new GuessDatesAction();
+    private SetDatesAction setDatesAction = new SetDatesAction();
+    private ClearDatesAction clearDatesAction = new ClearDatesAction();
+    private GuessDatesAction guessDatesAction = new GuessDatesAction();
+    private ImportDatesAction importDatesAction = new ImportDatesAction();
 
-    SetPrecisionAction setPrecisionAction = new SetPrecisionAction();
+    private SetUncertaintyAction setUncertaintyAction = new SetUncertaintyAction();
 
-    JCheckBox usingTipDates = new JCheckBox("Use tip dates");
-    JCheckBox specifyOriginDate = new JCheckBox("Specify origin date:");
-    JTextField originDateText = new JTextField(20);
-    JLabel originDateLabel = new JLabel("");
+    private JCheckBox usingTipDates = new JCheckBox("Use tip dates");
+    private JCheckBox specifyOriginDate = new JCheckBox("Specify origin date:");
+    private JTextField originDateText = new JTextField(20);
+    private JLabel originDateLabel = new JLabel("");
 
-    JComboBox unitsCombo = new JComboBox(EnumSet.range(DateUnitsType.YEARS, DateUnitsType.DAYS).toArray());
-    JComboBox directionCombo = new JComboBox(EnumSet.range(DateUnitsType.FORWARDS, DateUnitsType.BACKWARDS).toArray());
+    final JLabel unitsLabel;
+    final JLabel tipDateSamplingLabel;
+    final JLabel tipDateTaxonSetLabel;
+
+    private JComboBox unitsCombo = new JComboBox(EnumSet.range(DateUnitsType.YEARS, DateUnitsType.DAYS).toArray());
+    private JComboBox directionCombo = new JComboBox(EnumSet.range(DateUnitsType.FORWARDS, DateUnitsType.BACKWARDS).toArray());
 
     //    JComboBox tipDateSamplingCombo = new JComboBox( TipDateSamplingType.values() );
-    JComboBox tipDateSamplingCombo = new JComboBox(new TipDateSamplingType[] {
+    private JComboBox tipDateSamplingCombo = new JComboBox(new TipDateSamplingType[] {
             TipDateSamplingType.NO_SAMPLING,
             TipDateSamplingType.SAMPLE_INDIVIDUALLY,
 //            TipDateSamplingType.SAMPLE_JOINT,
             TipDateSamplingType.SAMPLE_PRECISION
     });
-    JComboBox tipDateTaxonSetCombo = new JComboBox();
+    private JComboBox tipDateTaxonSetCombo = new JComboBox();
 
-    BeautiFrame frame = null;
+    private BeautiFrame frame = null;
 
-    BeautiOptions options = null;
+    private BeautiOptions options = null;
 
-    double[] heights = null;
+    private double[] heights = null;
 
     private GuessDatesDialog guessDatesDialog = null;
     private SetValueDialog dateValueDialog = null;
@@ -158,12 +169,17 @@ public class TipDatesPanel extends BeautiPanel implements Exportable {
         JToolBar toolBar1 = new JToolBar();
         toolBar1.setFloatable(false);
         toolBar1.setOpaque(false);
+        toolBar1.setBorder(BorderFactory.createEmptyBorder());
 
         toolBar1.setLayout(new FlowLayout(java.awt.FlowLayout.LEFT, 0, 0));
         JButton button = new JButton(guessDatesAction);
         PanelUtils.setupComponent(button);
         toolBar1.add(button);
 
+        button = new JButton(importDatesAction);
+        PanelUtils.setupComponent(button);
+        toolBar1.add(button);
+
         button = new JButton(setDatesAction);
         PanelUtils.setupComponent(button);
         toolBar1.add(button);
@@ -172,25 +188,28 @@ public class TipDatesPanel extends BeautiPanel implements Exportable {
         PanelUtils.setupComponent(button);
         toolBar1.add(button);
 
-        button = new JButton(setPrecisionAction);
+        button = new JButton(setUncertaintyAction);
         PanelUtils.setupComponent(button);
         toolBar1.add(button);
 
-        toolBar1.add(new JToolBar.Separator(new Dimension(12, 12)));
-        final JLabel unitsLabel = new JLabel("Dates specified as ");
-        toolBar1.add(unitsLabel);
-        toolBar1.add(unitsCombo);
-        toolBar1.add(directionCombo);
-
         JToolBar toolBar3 = new JToolBar();
         toolBar3.setFloatable(false);
         toolBar3.setOpaque(false);
+        toolBar3.setBorder(BorderFactory.createEmptyBorder());
 
         toolBar3.setLayout(new FlowLayout(java.awt.FlowLayout.LEFT, 0, 0));
 
+        unitsLabel = new JLabel("Dates as:");
+        toolBar3.add(unitsLabel);
+        toolBar3.add(unitsCombo);
+        toolBar3.add(directionCombo);
+
+        toolBar3.add(new JToolBar.Separator(new Dimension(12, 12)));
+
         toolBar3.add(specifyOriginDate);
         toolBar3.add(originDateText);
         toolBar3.add(originDateLabel);
+
         JPanel panel2 = new JPanel();
         panel2.setLayout(new BoxLayout(panel2, BoxLayout.PAGE_AXIS));
         panel2.setOpaque(false);
@@ -206,6 +225,7 @@ public class TipDatesPanel extends BeautiPanel implements Exportable {
         JToolBar toolBar2 = new JToolBar();
         toolBar2.setFloatable(false);
         toolBar2.setOpaque(false);
+        toolBar2.setBorder(BorderFactory.createEmptyBorder());
 
         toolBar2.setLayout(new FlowLayout(java.awt.FlowLayout.LEFT, 0, 0));
 
@@ -216,11 +236,11 @@ public class TipDatesPanel extends BeautiPanel implements Exportable {
 //        substitutionRateField.setToolTipText("<html>Enter the substitution rate here.</html>");
 //        substitutionRateField.setEnabled(true);
 
-        final JLabel tipDateSamplingLabel = new JLabel("Tip date sampling:");
+        tipDateSamplingLabel = new JLabel("Tip date sampling:");
         toolBar2.add(tipDateSamplingLabel);
         toolBar2.add(tipDateSamplingCombo);
 
-        final JLabel tipDateTaxonSetLabel = new JLabel("Apply to taxon set:");
+        tipDateTaxonSetLabel = new JLabel("Apply to taxon set:");
         toolBar2.add(tipDateTaxonSetLabel);
         toolBar2.add(tipDateTaxonSetCombo);
 
@@ -262,45 +282,21 @@ public class TipDatesPanel extends BeautiPanel implements Exportable {
                 }
         );
 
-        clearDatesAction.setEnabled(false);
-        guessDatesAction.setEnabled(false);
-        setDatesAction.setEnabled(false);
-        setPrecisionAction.setEnabled(false);
-        directionCombo.setEnabled(false);
-        unitsLabel.setEnabled(false);
-        unitsCombo.setEnabled(false);
-        scrollPane.setEnabled(false);
-        dataTable.setEnabled(false);
-        tipDateSamplingLabel.setEnabled(false);
-        tipDateSamplingCombo.setEnabled(false);
-        tipDateTaxonSetLabel.setEnabled(false);
-        tipDateTaxonSetCombo.setEnabled(false);
-        specifyOriginDate.setEnabled(false);
-        originDateText.setEnabled(false);
-        originDateLabel.setEnabled(false);
-
         usingTipDates.addItemListener(new ItemListener() {
-            public void itemStateChanged(ItemEvent ev) {
+            @Override
+            public void itemStateChanged(ItemEvent e) {
                 boolean enabled = usingTipDates.isSelected();
-                clearDatesAction.setEnabled(enabled);
-                guessDatesAction.setEnabled(enabled);
-                setDatesAction.setEnabled(enabled);
-                setPrecisionAction.setEnabled(enabled);
-                unitsLabel.setEnabled(enabled);
-                unitsCombo.setEnabled(enabled);
-                directionCombo.setEnabled(enabled);
-                scrollPane.setEnabled(enabled);
-                dataTable.setEnabled(enabled);
-                tipDateSamplingCombo.setEnabled(enabled);
-                tipDateSamplingLabel.setEnabled(enabled);
-                specifyOriginDate.setEnabled(enabled);
-                originDateText.setEnabled(enabled && specifyOriginDate.isSelected());
-                originDateLabel.setEnabled(enabled && specifyOriginDate.isSelected());
+
+                options.useTipDates = enabled;
+
+                setEnableComponents(enabled);
 
                 if (options.taxonList != null) timeScaleChanged();
             }
         });
 
+        setEnableComponents(false);
+
         ItemListener listener = new ItemListener() {
             public void itemStateChanged(ItemEvent ev) {
                 timeScaleChanged();
@@ -310,6 +306,27 @@ public class TipDatesPanel extends BeautiPanel implements Exportable {
         directionCombo.addItemListener(listener);
     }
 
+    private void setEnableComponents(boolean enabled) {
+        clearDatesAction.setEnabled(enabled);
+        guessDatesAction.setEnabled(enabled);
+        importDatesAction.setEnabled(enabled);
+        setDatesAction.setEnabled(enabled);
+        setUncertaintyAction.setEnabled(enabled);
+        unitsLabel.setEnabled(enabled);
+        unitsCombo.setEnabled(enabled);
+        directionCombo.setEnabled(enabled);
+        scrollPane.setEnabled(enabled);
+        dataTable.setEnabled(enabled);
+        tipDateSamplingCombo.setEnabled(enabled);
+        tipDateSamplingLabel.setEnabled(enabled);
+        tipDateTaxonSetCombo.setEnabled(enabled);
+        tipDateTaxonSetLabel.setEnabled(enabled);
+
+        specifyOriginDate.setEnabled(enabled);
+        originDateText.setEnabled(enabled && specifyOriginDate.isSelected());
+        originDateLabel.setEnabled(enabled && specifyOriginDate.isSelected());
+    }
+
     public final void timeScaleChanged() {
         Units.Type units = Units.Type.YEARS;
         switch ((DateUnitsType) unitsCombo.getSelectedItem()) {
@@ -332,7 +349,7 @@ public class TipDatesPanel extends BeautiPanel implements Exportable {
 
             Date newDate = createDate(d, units, backwards, 0.0);
 
-            newDate.setPrecision(date.getPrecision());
+            newDate.setUncertainty(date.getUncertainty());
 
             options.taxonList.getTaxon(i).setDate(newDate);
         }
@@ -358,9 +375,9 @@ public class TipDatesPanel extends BeautiPanel implements Exportable {
 
         calculateHeights();
 
-        if (options.clockModelOptions.isTipCalibrated()) { // todo correct?
-            for (ClockModelGroup clockModelGroup : options.clockModelOptions.getClockModelGroups()) {
-                options.clockModelOptions.tipTimeCalibration(clockModelGroup);
+        if (options.useTipDates) {
+            for (PartitionTreeModel treeModel : options.getPartitionTreeModels()) {
+                treeModel.setTipCalibrations(true);
             }
         }
 
@@ -379,13 +396,11 @@ public class TipDatesPanel extends BeautiPanel implements Exportable {
     public void setOptions(BeautiOptions options) {
         this.options = options;
 
-        setupTable();
-
         unitsCombo.setSelectedItem(options.datesUnits);
         directionCombo.setSelectedItem(options.datesDirection);
 
         calculateHeights();
-        usingTipDates.setSelected(options.clockModelOptions.isTipCalibrated());
+        usingTipDates.setSelected(options.useTipDates);
 
         dataTableModel.fireTableDataChanged();
 
@@ -400,6 +415,8 @@ public class TipDatesPanel extends BeautiPanel implements Exportable {
         if (item != null) {
             tipDateTaxonSetCombo.setSelectedItem(item);
         }
+
+        setupTable();
     }
 
     private void setupTable() {
@@ -431,7 +448,7 @@ public class TipDatesPanel extends BeautiPanel implements Exportable {
         // nothing to do
     }
 
-    public void setDates() {
+    private void setDates() {
         if (options.taxonList == null) { // validation of check empty taxonList
             return;
         }
@@ -482,7 +499,7 @@ public class TipDatesPanel extends BeautiPanel implements Exportable {
         } while (result < 0);
     }
 
-    public void setPrecisions() {
+    private void setPrecisions() {
         if (options.taxonList == null) { // validation of check empty taxonList
             return;
         }
@@ -521,7 +538,7 @@ public class TipDatesPanel extends BeautiPanel implements Exportable {
 
             if (selRows.length > 0) {
                 for (int row : selRows) {
-                    options.taxonList.getTaxon(row).getDate().setPrecision(value);
+                    options.taxonList.getTaxon(row).getDate().setUncertainty(value);
                 }
             } else {
                 for (Taxon taxon : options.taxonList) {
@@ -533,7 +550,7 @@ public class TipDatesPanel extends BeautiPanel implements Exportable {
         } while (result < 0);
     }
 
-    public void clearDates() {
+    private void clearDates() {
         for (int i = 0; i < options.taxonList.getTaxonCount(); i++) {
             java.util.Date origin = new java.util.Date(0);
 
@@ -549,7 +566,7 @@ public class TipDatesPanel extends BeautiPanel implements Exportable {
         dataTableModel.fireTableDataChanged();
     }
 
-    public void guessDates() {
+    private void guessDates() {
 
         if (guessDatesDialog == null) {
             guessDatesDialog = new GuessDatesDialog(frame);
@@ -558,9 +575,9 @@ public class TipDatesPanel extends BeautiPanel implements Exportable {
         int[] selRows = dataTable.getSelectedRows();
 
         if (selRows.length > 0) {
-            guessDatesDialog.setDescription("Guess date values for selected taxa");
+            guessDatesDialog.setDescription("Parse date values for selected taxa");
         } else {
-            guessDatesDialog.setDescription("Guess date values for all taxa");
+            guessDatesDialog.setDescription("Parse date values for all taxa");
         }
 
 
@@ -575,9 +592,7 @@ public class TipDatesPanel extends BeautiPanel implements Exportable {
         guesser.guessDates = true;
         guessDatesDialog.setupGuesser(guesser);
 
-        String warningMessage = null;
-
-            if (selRows.length > 0) {
+        if (selRows.length > 0) {
             Taxa selectedTaxa = new Taxa();
 
             for (int row : selRows) {
@@ -589,12 +604,125 @@ public class TipDatesPanel extends BeautiPanel implements Exportable {
             guesser.guessDates(options.taxonList);
         }
 
-        if (warningMessage != null) {
-            JOptionPane.showMessageDialog(this, "Warning: some dates may not be set correctly - \n" + warningMessage,
-                    "Error guessing dates",
-                    JOptionPane.WARNING_MESSAGE);
+        // adjust the dates to the current timescale...
+        timeScaleChanged();
+
+        dataTableModel.fireTableDataChanged();
+    }
+
+    private void importDates() {
+
+        File[] files = frame.selectImportFiles("Import Dates File...", false, new FileNameExtensionFilter[]{
+                new FileNameExtensionFilter("Tab-delimited text files", "txt", "tab", "dat")});
+
+        DataTable<String[]> dataTable;
+
+        if (files != null && files.length != 0) {
+            try {
+                // Load the file as a table
+                dataTable = DataTable.Text.parse(new FileReader(files[0]), true, true, true, false);
+
+            } catch (FileNotFoundException fnfe) {
+                JOptionPane.showMessageDialog(this, "Unable to open file: File not found",
+                        "Unable to open file",
+                        JOptionPane.ERROR_MESSAGE);
+                return;
+            } catch (IOException ioe) {
+                JOptionPane.showMessageDialog(this, "Unable to read file: " + ioe.getMessage(),
+                        "Unable to read file",
+                        JOptionPane.ERROR_MESSAGE);
+                return;
+            } catch (Exception ex) {
+                ex.printStackTrace(System.err);
+                JOptionPane.showMessageDialog(this, "Fatal exception: " + ex,
+                        "Error reading file",
+                        JOptionPane.ERROR_MESSAGE);
+                ex.printStackTrace();
+                return;
+            }
+        } else {
+            return;
         }
 
+        if (dataTable.getColumnCount() == 0) {
+            // expecting at least 2 columns - labels and dates
+            JOptionPane.showMessageDialog(frame,
+                    "Expecting a tab delimited file with at\n" +
+                            "least 2 columns (taxon labels and dates).",
+                    "Incompatible values", JOptionPane.ERROR_MESSAGE);
+            return;
+        }
+
+        String[] columnLabels = dataTable.getColumnLabels();
+        String[] taxonNames = dataTable.getRowLabels();
+
+        if (columnLabels.length < 2) {
+            // only one column so leave it
+            return;
+        }
+
+        boolean hasColumnHeadings = options.taxonList.getTaxonIndex(columnLabels[0]) < 0;
+
+        // assume the second column contains the dates
+        int dateColumn = 0;
+
+        if (hasColumnHeadings && columnLabels.length > 1) {
+            List<Integer> dateColumns = new ArrayList<Integer>();
+
+            // see if there is a column labelled 'dates' or something
+            for (int i = 1; i < dataTable.getColumnCount(); i++) {
+                if (columnLabels[i].toLowerCase().contains("date")) {
+                    dateColumns.add(i - 1);
+                }
+            }
+
+            if (dateColumns.size() > 0) {
+                // if there are multiple date column possibilities, take the first
+                // @todo - allow the user to select the column to use
+                dateColumn = dateColumns.get(0);
+            }
+        }
+
+        Map<Taxon, String> taxonDateMap = new HashMap<Taxon, String>();
+
+        String[] values = dataTable.getColumn(dateColumn);
+
+        if (!hasColumnHeadings) {
+            final int index = options.taxonList.getTaxonIndex(columnLabels[0]);
+            if (index >= 0) {
+                taxonDateMap.put(options.taxonList.getTaxon(index), columnLabels[dateColumn + 1]);
+            }
+        }
+
+        int j = 0;
+        for (final String taxonName : taxonNames) {
+
+            final int index = options.taxonList.getTaxonIndex(taxonName);
+            if (index >= 0) {
+                taxonDateMap.put(options.taxonList.getTaxon(index), values[j]);
+            }
+            j++;
+        }
+
+        if (guessDatesDialog == null) {
+            guessDatesDialog = new GuessDatesDialog(frame);
+        }
+
+        guessDatesDialog.setDescription("Parse date values from file");
+
+        int result = guessDatesDialog.showDialog(true);
+
+        if (result == -1 || result == JOptionPane.CANCEL_OPTION) {
+            return;
+        }
+
+        DateGuesser guesser = options.dateGuesser;
+
+        guesser.guessDates = true;
+        guessDatesDialog.setupGuesser(guesser);
+
+        guesser.guessDates(options.taxonList, taxonDateMap);
+
         // adjust the dates to the current timescale...
         timeScaleChanged();
 
@@ -607,7 +735,7 @@ public class TipDatesPanel extends BeautiPanel implements Exportable {
          */
         private static final long serialVersionUID = -7281309694753868635L;
 
-        public SetDatesAction() {
+        SetDatesAction() {
             super("Set Dates");
             setToolTipText("Use this tool to set sampling date values for the selected taxa");
         }
@@ -623,7 +751,7 @@ public class TipDatesPanel extends BeautiPanel implements Exportable {
          */
         private static final long serialVersionUID = -7281309694753868635L;
 
-        public ClearDatesAction() {
+        ClearDatesAction() {
             super("Clear Dates");
             setToolTipText("Use this tool to remove sampling dates from each taxon");
         }
@@ -639,9 +767,9 @@ public class TipDatesPanel extends BeautiPanel implements Exportable {
          */
         private static final long serialVersionUID = 8514706149822252033L;
 
-        public GuessDatesAction() {
-            super("Guess Dates");
-            setToolTipText("Use this tool to guess the sampling dates from the taxon labels");
+        GuessDatesAction() {
+            super("Parse Dates");
+            setToolTipText("Use this tool to parse the sampling dates from the taxon labels");
         }
 
         public void actionPerformed(ActionEvent ae) {
@@ -649,15 +777,31 @@ public class TipDatesPanel extends BeautiPanel implements Exportable {
         }
     }
 
-    public class SetPrecisionAction extends AbstractAction {
+    public class ImportDatesAction extends AbstractAction {
+        /**
+         *
+         */
+        private static final long serialVersionUID = 8514706149822252033L;
+
+        ImportDatesAction() {
+            super("Import Dates");
+            setToolTipText("Use this tool to import the sampling dates from a file");
+        }
+
+        public void actionPerformed(ActionEvent ae) {
+            importDates();
+        }
+    }
+
+    public class SetUncertaintyAction extends AbstractAction {
         /**
          *
          */
         private static final long serialVersionUID = -7281309694753868639L;
 
-        public SetPrecisionAction() {
-            super("Set Precision");
-            setToolTipText("Use this tool to set precision values for the selected taxa");
+        SetUncertaintyAction() {
+            super("Set Uncertainty");
+            setToolTipText("Use this tool to set uncertainty in the date for the selected taxa");
         }
 
         public void actionPerformed(ActionEvent ae) {
@@ -706,7 +850,7 @@ public class TipDatesPanel extends BeautiPanel implements Exportable {
          *
          */
         private static final long serialVersionUID = -6707994233020715574L;
-        String[] columnNames = {"Name", "Date", "Precision", "Height"};
+        String[] columnNames = {"Name", "Date", "Uncertainty", "Height"};
 
         public DataTableModel() {
         }
@@ -736,7 +880,7 @@ public class TipDatesPanel extends BeautiPanel implements Exportable {
                     }
                 case 2:
                     if (date != null) {
-                        return date.getPrecision();
+                        return date.getUncertainty();
                     } else {
                         return "-";
                     }
@@ -765,7 +909,7 @@ public class TipDatesPanel extends BeautiPanel implements Exportable {
                 if (date != null) {
                     double d = (Double) aValue;
                     if (d >= 0.0) {
-                        date.setPrecision(d);
+                        date.setUncertainty(d);
                     }
                 }
             }
@@ -791,25 +935,25 @@ public class TipDatesPanel extends BeautiPanel implements Exportable {
         }
 
         public String toString() {
-            StringBuffer buffer = new StringBuffer();
+            StringBuilder sb = new StringBuilder();
 
-            buffer.append(getColumnName(0));
+            sb.append(getColumnName(0));
             for (int j = 1; j < getColumnCount(); j++) {
-                buffer.append("\t");
-                buffer.append(getColumnName(j));
+                sb.append("\t");
+                sb.append(getColumnName(j));
             }
-            buffer.append("\n");
+            sb.append("\n");
 
             for (int i = 0; i < getRowCount(); i++) {
-                buffer.append(getValueAt(i, 0));
+                sb.append(getValueAt(i, 0));
                 for (int j = 1; j < getColumnCount(); j++) {
-                    buffer.append("\t");
-                    buffer.append(getValueAt(i, j));
+                    sb.append("\t");
+                    sb.append(getValueAt(i, j));
                 }
-                buffer.append("\n");
+                sb.append("\n");
             }
 
-            return buffer.toString();
+            return sb.toString();
         }
     }
 }
