@@ -69,7 +69,7 @@ public class PartitionTreePriorPanel extends OptionsPanel {
     private JComboBox gmrfBayesianSkyrideCombo = new JComboBox(EnumSet.range(TreePriorParameterizationType.UNIFORM_SKYRIDE,
             TreePriorParameterizationType.TIME_AWARE_SKYRIDE).toArray());
 
-    private JComboBox skyGridPointsCombo = new JComboBox(new Integer[]{10, 20, 50, 100});
+    private WholeNumberField skyGridPointsField = new WholeNumberField(2, Integer.MAX_VALUE);
     private RealNumberField skyGridInterval = new RealNumberField(0.0, Double.MAX_VALUE);
 
 //    private JComboBox skyGridCombo = new JComboBox(EnumSet.range())
@@ -96,20 +96,26 @@ public class PartitionTreePriorPanel extends OptionsPanel {
         this.partitionTreePrior = parTreePrior;
         this.treesPanel = parent;
 
-        setTreePriorChoices(false, false, false);
+        setTreePriorChoices(false, false);
         PanelUtils.setupComponent(treePriorCombo);
         treePriorCombo.setMaximumRowCount(10); // to show Calibrated Yule
         treePriorCombo.addItemListener(new ItemListener() {
             public void itemStateChanged(ItemEvent ev) {
+
                 if (treePriorCombo.getSelectedItem() != null) {
-                    partitionTreePrior.setNodeHeightPrior((TreePriorType) treePriorCombo.getSelectedItem());
                     setupPanel();
+
+                    partitionTreePrior.setNodeHeightPrior((TreePriorType) treePriorCombo.getSelectedItem());
                     parent.fireTreePriorsChanged();
                 }
             }
         });
 
         PanelUtils.setupComponent(parameterizationCombo);
+        parameterizationCombo.setToolTipText("<html>" +
+                "Select the parameterization of growth rate to use for<br>" +
+                "the parametric coalescent model. This does not affect<br>" +
+                "nature of the model but may assist with mixing.<html>");
         parameterizationCombo.addItemListener(new ItemListener() {
             public void itemStateChanged(ItemEvent ev) {
                 partitionTreePrior.setParameterization((TreePriorParameterizationType) parameterizationCombo.getSelectedItem());
@@ -125,6 +131,11 @@ public class PartitionTreePriorPanel extends OptionsPanel {
 //        });
 
         PanelUtils.setupComponent(groupCountField);
+        groupCountField.setToolTipText("<html>" +
+                "Set the number of groups to be used in the Skyline model<br>" +
+                "It will affect the resolution of the reconstruction. This<br>" +
+                "should be set at fewer than the number of nodes in the<br>" +
+                "tree.<html>");
         groupCountField.addKeyListener(new java.awt.event.KeyAdapter() {
             public void keyTyped(java.awt.event.KeyEvent ev) {
                 // move to here?
@@ -133,6 +144,11 @@ public class PartitionTreePriorPanel extends OptionsPanel {
         });
 
         PanelUtils.setupComponent(skyGridInterval);
+        skyGridInterval.setToolTipText("<html>" +
+                "This sets the time interval over which the change-points<br>" +
+                "of the Skygrid are placed. It is measured relative to the<br>" +
+                "most recent tip and should be commensurate with the predicted<br>" +
+                "age of the tree.<html>");
         skyGridInterval.addKeyListener(new java.awt.event.KeyAdapter() {
             public void keyTyped(java.awt.event.KeyEvent ev) {
             }
@@ -163,21 +179,31 @@ public class PartitionTreePriorPanel extends OptionsPanel {
             }
         });
 
-        PanelUtils.setupComponent(skyGridPointsCombo);
-        skyGridPointsCombo.addItemListener(new ItemListener() {
-            public void itemStateChanged(ItemEvent itemEvent) {
-                partitionTreePrior.setSkyGridCount((Integer) skyGridPointsCombo.getSelectedItem());
-                parent.fireTreePriorsChanged();
+//        PanelUtils.setupComponent(skyGridPointsCombo);
+//        skyGridPointsCombo.addItemListener(new ItemListener() {
+//            public void itemStateChanged(ItemEvent itemEvent) {
+//                partitionTreePrior.setSkyGridCount((Integer) skyGridPointsCombo.getSelectedItem());
+//                parent.fireTreePriorsChanged();
+//            }
+//        });
+        PanelUtils.setupComponent(skyGridPointsField);
+        skyGridPointsField.setToolTipText("<html>" +
+                "This sets number of population size parameters for<br>" +
+                "the Skygrid. This determines the number of transition-points<br>" +
+                "at which the population size changes. The last one spans to<br>" +
+                "infinite time.<html>");
+        skyGridPointsField.addKeyListener(new java.awt.event.KeyAdapter() {
+            public void keyTyped(java.awt.event.KeyEvent ev) {
             }
         });
 
         PanelUtils.setupComponent(populationSizeCombo);
         populationSizeCombo.addItemListener(new ItemListener() {
-            public void itemStateChanged(ItemEvent ev) {
-                partitionTreePrior.setPopulationSizeModel((PopulationSizeModelType) populationSizeCombo.getSelectedItem());
-                parent.fireTreePriorsChanged();
-            }
-        }
+                                                public void itemStateChanged(ItemEvent ev) {
+                                                    partitionTreePrior.setPopulationSizeModel((PopulationSizeModelType) populationSizeCombo.getSelectedItem());
+                                                    parent.fireTreePriorsChanged();
+                                                }
+                                            }
         );
 
 //        PanelUtils.setupComponent(calibrationCorrectionCombo);
@@ -190,9 +216,8 @@ public class PartitionTreePriorPanel extends OptionsPanel {
 //        );
 //	        samplingProportionField.addKeyListener(keyListener);
 
-        // need it not setupPanel(), because it contains required setSelectedItem()
-        // to make Tree prior panel displayed properly when link/unlink tree prior
         setOptions();
+        setupPanel();
     }
 
     private void setupPanel() {
@@ -212,134 +237,115 @@ public class PartitionTreePriorPanel extends OptionsPanel {
         String calYule = "Heled J, Drummond AJ (2011), Syst Biol, doi: 10.1093/sysbio/syr087 [Calibrated Yule]";
         String citation;
 
-        if (treePriorCombo.getSelectedItem() == TreePriorType.SPECIES_YULE
-                || treePriorCombo.getSelectedItem() == TreePriorType.SPECIES_YULE_CALIBRATION
-                || treePriorCombo.getSelectedItem() == TreePriorType.SPECIES_BIRTH_DEATH) { //*BEAST
-            addComponentWithLabel("Species Tree Prior:", treePriorCombo);
-            addComponentWithLabel("Population Size Model:", populationSizeCombo);
-            addLabel("Note: *BEAST only needs to select the prior for species tree.");
+        String citationCoalescent = "Kingman JFC (1982) Stoch Proc Appl 13, 235-248 [Constant Coalescent].";
 
-            if (treePriorCombo.getSelectedItem() == TreePriorType.SPECIES_YULE_CALIBRATION) {
-//                addComponentWithLabel("Calibration Correction Type:", calibrationCorrectionCombo);
-                citation = calYule;
-                addComponentWithLabel("Citation:", citationText);
-                citationText.setText(citation);
-            }
+        addComponentWithLabel("Tree Prior:", treePriorCombo);
 
-        } else { // non *BEAST
+        if (!treesPanel.linkTreePriorCheck.isEnabled()) {
+            treesPanel.updateLinkTreePriorEnablility();
+        }
 
-            String citationCoalescent = "Kingman JFC (1982) Stoch Proc Appl 13, 235-248 [Constant Coalescent].";
+        switch ((TreePriorType) treePriorCombo.getSelectedItem()) {
+            case CONSTANT:
+                citation = citationCoalescent;
+                break;
 
-            addComponentWithLabel("Tree Prior:", treePriorCombo);
+            case EXPONENTIAL:
+            case LOGISTIC:
+            case EXPANSION:
+                addComponentWithLabel("Parameterization for growth:", parameterizationCombo);
+                partitionTreePrior.setParameterization((TreePriorParameterizationType) parameterizationCombo.getSelectedItem());
 
-            if (!treesPanel.linkTreePriorCheck.isEnabled()) {
-                treesPanel.updateLinkTreePriorEnablility();
-            }
-
-            switch ((TreePriorType) treePriorCombo.getSelectedItem()) {
-                case CONSTANT:
-                    citation = citationCoalescent;
-                    break;
-
-                case EXPONENTIAL:
-                case LOGISTIC:
-                case EXPANSION:
-                    addComponentWithLabel("Parameterization for growth:", parameterizationCombo);
-                    partitionTreePrior.setParameterization((TreePriorParameterizationType) parameterizationCombo.getSelectedItem());
-
-                    citation = //citationCoalescent +  "\n" +
-                            "Griffiths RC, Tavare S (1994) Phil Trans R Soc Lond B Biol Sci 344, 403-410 [Parametric Coalescent].";
+                citation = //citationCoalescent +  "\n" +
+                        "Griffiths RC, Tavare S (1994) Phil Trans R Soc Lond B Biol Sci 344, 403-410 [Parametric Coalescent].";
 //                        + "\nDrummond AJ, Rambaut A, Shapiro B, Pybus OG (2005) Mol Biol Evol 22, 1185-1192.";
-                    break;
+                break;
 
-                case SKYLINE:
-                    groupCountField.setColumns(6);
-                    addComponentWithLabel("Number of groups:", groupCountField);
-                    addComponentWithLabel("Skyline Model:", bayesianSkylineCombo);
+            case SKYLINE:
+                groupCountField.setColumns(6);
+                addComponentWithLabel("Number of groups:", groupCountField);
+                addComponentWithLabel("Skyline Model:", bayesianSkylineCombo);
 
-                    citation = //citationCoalescent + "\n" +
-                            "Drummond AJ, Rambaut A, Shapiro B, Pybus OG (2005) Mol Biol Evol 22, 1185-1192 [Skyline Coalescent].";
-                    break;
+                citation = //citationCoalescent + "\n" +
+                        "Drummond AJ, Rambaut A, Shapiro B, Pybus OG (2005) Mol Biol Evol 22, 1185-1192 [Skyline Coalescent].";
+                break;
 
-                case EXTENDED_SKYLINE:
-                    addComponentWithLabel("Model Type:", extendedBayesianSkylineCombo);
-                    treesPanel.linkTreePriorCheck.setSelected(true);
-                    treesPanel.linkTreePriorCheck.setEnabled(false);
-                    treesPanel.updateShareSameTreePriorChanged();
+            case EXTENDED_SKYLINE:
+                addComponentWithLabel("Model Type:", extendedBayesianSkylineCombo);
+                treesPanel.linkTreePriorCheck.setSelected(true);
+                treesPanel.linkTreePriorCheck.setEnabled(false);
+                treesPanel.updateShareSameTreePriorChanged();
 
-                    citation = //citationCoalescent + "\n" +
-                            "Heled J, Drummond AJ (2008) BMC Evol Biol 8, 289 [Extended Skyline Coalescent].";
-                    break;
+                citation = //citationCoalescent + "\n" +
+                        "Heled J, Drummond AJ (2008) BMC Evol Biol 8, 289 [Extended Skyline Coalescent].";
+                break;
 
-                case GMRF_SKYRIDE:
-                    addComponentWithLabel("Smoothing:", gmrfBayesianSkyrideCombo);
-                    treesPanel.linkTreePriorCheck.setSelected(true);
-                    treesPanel.linkTreePriorCheck.setEnabled(false);
-                    //For GMRF, one tree prior has to be associated to one tree model. The validation is in BeastGenerator.checkOptions()
-                    addLabel("<html>For the Skyride, tree model/tree prior combination not implemented by BEAST. "
-                            + "The Skyride is only available for a single tree<br>model partition in this release. "
-                            + "Please try the Skygrid or link all tree models." + "</html>");
+            case GMRF_SKYRIDE:
+                addComponentWithLabel("Smoothing:", gmrfBayesianSkyrideCombo);
+                treesPanel.linkTreePriorCheck.setSelected(true);
+                treesPanel.linkTreePriorCheck.setEnabled(false);
+                //For GMRF, one tree prior has to be associated to one tree model. The validation is in BeastGenerator.checkOptions()
+                addLabel("<html>For the Skyride, tree model/tree prior combination not implemented by BEAST. "
+                        + "The Skyride is only available for a single tree<br>model partition in this release. "
+                        + "Please try the Skygrid or link all tree models." + "</html>");
 
-                    citation = //citationCoalescent + "\n" +
-                            "Minin VN, Bloomquist EW, Suchard MA (2008) Mol Biol Evol 25, 1459-1471 [Skyride Coalescent].";
-                    break;
+                citation = //citationCoalescent + "\n" +
+                        "Minin VN, Bloomquist EW, Suchard MA (2008) Mol Biol Evol 25, 1459-1471 [Skyride Coalescent].";
+                break;
 
-                case SKYGRID:
-                    skyGridInterval.setColumns(6);
-                    addComponentWithLabel("# parameters ( = # grid-points + 1):", skyGridPointsCombo);
-                    addComponentWithLabel("Time at last point:", skyGridInterval);
-                    addLabel("It is advisable to set this cut-off time commensurate with the expected root height for optimal model interpretability.");
-                    treesPanel.linkTreePriorCheck.setSelected(true);
-                    treesPanel.linkTreePriorCheck.setEnabled(false);
-                    treesPanel.updateShareSameTreePriorChanged();
+            case SKYGRID:
+                skyGridPointsField.setColumns(6);
+                addComponentWithLabel("Number of parameters:", skyGridPointsField);
+                skyGridInterval.setColumns(6);
+                addComponentWithLabel("Time at last transition point:", skyGridInterval);
+                treesPanel.linkTreePriorCheck.setSelected(true);
+                treesPanel.linkTreePriorCheck.setEnabled(false);
+                treesPanel.updateShareSameTreePriorChanged();
 
-                    citation = //citationCoalescent + "\n" +
-                            "Gill MS, Lemey P, Faria NR, Rambaut A, Shapiro B, Suchard MA (2013) Mol Biol Evol 30, 713-724 [SkyGrid Coalescent].";
-                    break;
+                citation = //citationCoalescent + "\n" +
+                        "Gill MS, Lemey P, Faria NR, Rambaut A, Shapiro B, Suchard MA (2013) Mol Biol Evol 30, 713-724 [SkyGrid Coalescent].";
+                break;
 
-                case YULE:
-                    citation = "Gernhard T (2008) J Theor Biol 253, 769-778 [Yule Process]." +
-                            "\nYule GU (1925) Phil Trans R Soc Lond B Biol Sci 213, 21-87 [Yule Process].";
-                    break;
+            case YULE:
+                citation = "Gernhard T (2008) J Theor Biol 253, 769-778 [Yule Process]." +
+                        "\nYule GU (1925) Phil Trans R Soc Lond B Biol Sci 213, 21-87 [Yule Process].";
+                break;
 
-                case YULE_CALIBRATION:
+            case YULE_CALIBRATION:
 //                    addComponentWithLabel("Calibration Correction Type:", calibrationCorrectionCombo);
-                    citation = calYule;
-                    break;
+                citation = calYule;
+                break;
 
-                case BIRTH_DEATH:
-                    citation = BirthDeathModelParser.getCitation();
-                    break;
+            case BIRTH_DEATH:
+                citation = BirthDeathModelParser.getCitation();
+                break;
 
-                case BIRTH_DEATH_INCOMPLETE_SAMPLING:
-                    citation = BirthDeathModelParser.getCitationRHO();
-                    break;
+            case BIRTH_DEATH_INCOMPLETE_SAMPLING:
+                citation = BirthDeathModelParser.getCitationRHO();
+                break;
 
-                case BIRTH_DEATH_SERIAL_SAMPLING:
-                    citation = BirthDeathSerialSamplingModelParser.getCitationPsiOrg();
-                    break;
+            case BIRTH_DEATH_SERIAL_SAMPLING:
+                citation = BirthDeathSerialSamplingModelParser.getCitationPsiOrg();
+                break;
 
-                case BIRTH_DEATH_BASIC_REPRODUCTIVE_NUMBER:
-                    citation = BirthDeathSerialSamplingModelParser.getCitationRT();
-                    break;
+            case BIRTH_DEATH_BASIC_REPRODUCTIVE_NUMBER:
+                citation = BirthDeathSerialSamplingModelParser.getCitationRT();
+                break;
 
-                default:
-                    throw new RuntimeException("No such tree prior has been specified so cannot refer to it");
-            }
+            default:
+                throw new RuntimeException("No such tree prior has been specified so cannot refer to it");
+        }
 
-            if (treesPanel.options.maximumTipHeight > 0)
-                citation = citation
+        if (treesPanel.options.maximumTipHeight > 0)
+            citation = citation
 //                    + "\n" +
 //                    "Rodrigo AG, Felsenstein J (1999) in Molecular Evolution of HIV (Crandall K), pp. 233-272 [Serially Sampled Data]."
-                        + "\n" +
-                        "Drummond AJ, Nicholls GK, Rodrigo AG, Solomon W (2002) Genetics 161, 1307-1320 [Serially Sampled Data].";
+                    + "\n" +
+                    "Drummond AJ, Nicholls GK, Rodrigo AG, Solomon W (2002) Genetics 161, 1307-1320 [Serially Sampled Data].";
+
+        addComponentWithLabel("Citation:", citationText);
+        citationText.setText(citation);
 
-            addComponentWithLabel("Citation:", citationText);
-            citationText.setText(citation);
-        }
-//        getOptions();
-//
-//        treesPanel.treeModelPanels.get(treesPanel.currentTreeModel).setOptions();
         for (PartitionTreeModel model : treesPanel.treeModelPanels.keySet()) {
             if (model != null) {
                 treesPanel.treeModelPanels.get(model).setOptions();
@@ -347,16 +353,17 @@ public class PartitionTreePriorPanel extends OptionsPanel {
             }
         }
 
-//        createTreeAction.setEnabled(options != null && options.dataPartitions.size() > 0);
-
-//        fireTableDataChanged();
-
         validate();
         repaint();
     }
 
     public void setOptions() {
 
+        if (settingOptions) {
+            // make sure we don't go all recursive
+            return;
+        }
+
         if (partitionTreePrior == null) {
             return;
         }
@@ -375,16 +382,24 @@ public class PartitionTreePriorPanel extends OptionsPanel {
 
         gmrfBayesianSkyrideCombo.setSelectedItem(partitionTreePrior.getSkyrideSmoothing());
 
-        skyGridPointsCombo.setSelectedItem(partitionTreePrior.getSkyGridCount());
+//        skyGridPointsCombo.setSelectedItem(partitionTreePrior.getSkyGridCount());
+        skyGridPointsField.setValue(partitionTreePrior.getSkyGridCount());
 
         double initialCutOff = partitionTreePrior.getOptions().getPartitionTreeModels().get(0).getInitialRootHeight();
         final double arbitraryScalar = 1.0;
         initialCutOff = roundToSignificantFigures(arbitraryScalar * initialCutOff, 2);
 
-        skyGridInterval.setValue(
-                partitionTreePrior.getSkyGridInterval() == -1.0 ?
-                        initialCutOff : partitionTreePrior.getSkyGridInterval()
-        );
+        skyGridInterval.setAllowEmpty(true);
+
+        if (Double.isNaN(partitionTreePrior.getSkyGridInterval())) {
+            if (initialCutOff > 0.0) {
+                skyGridInterval.setValue(initialCutOff);
+            } else {
+                skyGridInterval.setText((Double)null);
+            }
+        } else {
+            skyGridInterval.setValue(partitionTreePrior.getSkyGridInterval());
+        }
 
         populationSizeCombo.setSelectedItem(partitionTreePrior.getPopulationSizeModel());
 
@@ -425,8 +440,12 @@ public class PartitionTreePriorPanel extends OptionsPanel {
             }
         } else if (partitionTreePrior.getNodeHeightPrior() == TreePriorType.SKYGRID) {
             Double interval = skyGridInterval.getValue();
-            // TODO is != null check necessary like above?
-            partitionTreePrior.setSkyGridInterval(interval);
+            if (interval != null) {
+                partitionTreePrior.setSkyGridInterval(interval);
+            } else {
+                partitionTreePrior.setSkyGridInterval(Double.NaN);
+            }
+            partitionTreePrior.setSkyGridCount(skyGridPointsField.getValue());
         } else if (partitionTreePrior.getNodeHeightPrior() == TreePriorType.BIRTH_DEATH) {
 //            Double samplingProportion = samplingProportionField.getValue();
 //            if (samplingProportion != null) {
@@ -436,53 +455,34 @@ public class PartitionTreePriorPanel extends OptionsPanel {
 //            }
         }
 
-//        partitionTreePrior.setParameterization(parameterizationCombo.getSelectedIndex());
-//        partitionTreePrior.setSkylineModel(bayesianSkylineCombo.getSelectedIndex());
-//        partitionTreePrior.setExtendedSkylineModel(((VariableDemographicModel.Type) extendedBayesianSkylineCombo.getSelectedItem()).toString());
-//
-//        partitionTreePrior.setSkyrideSmoothing(gmrfBayesianSkyrideCombo.getSelectedIndex());
-        // the taxon list may not exist yet... this should be set when generating...
-//        partitionTreePrior.skyrideIntervalCount = partitionTreePrior.taxonList.getTaxonCount() - 1;
-
     }
 
-//    public void setMicrosatelliteTreePrior() {
-//        treePriorCombo.removeAllItems();
-//        treePriorCombo.addItem(TreePriorType.CONSTANT);
-//    }
-
-    public void setTreePriorChoices(boolean isStartBEAST, boolean isMultiLocus, boolean isTipCalibrated) {
+    public void setTreePriorChoices(boolean isMultiLocus, boolean isTipCalibrated) {
         TreePriorType type = (TreePriorType) treePriorCombo.getSelectedItem();
         treePriorCombo.removeAllItems();
 
-        if (isStartBEAST) {
-            for (TreePriorType treePriorType : EnumSet.range(TreePriorType.SPECIES_YULE, TreePriorType.SPECIES_BIRTH_DEATH)) {
-                treePriorCombo.addItem(treePriorType);
-            }
 
-        } else {
-
-            for (TreePriorType treePriorType : EnumSet.range(TreePriorType.CONSTANT, TreePriorType.BIRTH_DEATH_SERIAL_SAMPLING)) {
-                treePriorCombo.addItem(treePriorType);
-            }
-
-            // REMOVED due to unresolved issues with model
-            // treePriorCombo.addItem(TreePriorType.BIRTH_DEATH_BASIC_REPRODUCTIVE_NUMBER);
-
-
-            // would be much better to disable these rather than removing them
-            if (isMultiLocus) {
-                treePriorCombo.removeItem(TreePriorType.SKYLINE);
-            }
-
-            if (isTipCalibrated) {
-                // remove models that require contemporaneous tips...
-                treePriorCombo.removeItem(TreePriorType.YULE);
-                treePriorCombo.removeItem(TreePriorType.YULE_CALIBRATION);
-                treePriorCombo.removeItem(TreePriorType.BIRTH_DEATH);
-                treePriorCombo.removeItem(TreePriorType.BIRTH_DEATH_INCOMPLETE_SAMPLING);
-            }
+        for (TreePriorType treePriorType : EnumSet.range(TreePriorType.CONSTANT, TreePriorType.BIRTH_DEATH_SERIAL_SAMPLING)) {
+            treePriorCombo.addItem(treePriorType);
         }
+
+        // REMOVED due to unresolved issues with model
+        // treePriorCombo.addItem(TreePriorType.BIRTH_DEATH_BASIC_REPRODUCTIVE_NUMBER);
+
+
+        // would be much better to disable these rather than removing them
+        if (isMultiLocus) {
+            treePriorCombo.removeItem(TreePriorType.SKYLINE);
+        }
+
+        if (isTipCalibrated) {
+            // remove models that require contemporaneous tips...
+            treePriorCombo.removeItem(TreePriorType.YULE);
+            treePriorCombo.removeItem(TreePriorType.YULE_CALIBRATION);
+            treePriorCombo.removeItem(TreePriorType.BIRTH_DEATH);
+            treePriorCombo.removeItem(TreePriorType.BIRTH_DEATH_INCOMPLETE_SAMPLING);
+        }
+
         // this makes sure treePriorCombo selects correct prior
         treePriorCombo.setSelectedItem(type);
         if (treePriorCombo.getSelectedItem() == null) {
