@@ -128,7 +128,7 @@ public class TreesPanel extends BeautiPanel implements Exportable {
 
         treeModelPanelParent = new JPanel(new FlowLayout(FlowLayout.LEFT));
         treeModelPanelParent.setOpaque(false);
-        treeModelBorder = new javax.swing.border.TitledBorder("Tree Model");
+        treeModelBorder = new TitledBorder(null, "Tree Model", TitledBorder.DEFAULT_JUSTIFICATION, TitledBorder.ABOVE_TOP);
         treeModelPanelParent.setBorder(treeModelBorder);
 
         JScrollPane scrollPane2 = new JScrollPane(treeModelPanelParent, JScrollPane.VERTICAL_SCROLLBAR_AS_NEEDED, JScrollPane.HORIZONTAL_SCROLLBAR_NEVER);
@@ -138,7 +138,7 @@ public class TreesPanel extends BeautiPanel implements Exportable {
 
         treePriorPanelParent = new JPanel(new FlowLayout(FlowLayout.LEFT));
         treePriorPanelParent.setOpaque(false);
-        treePriorBorder = new TitledBorder("Tree Prior");
+        treePriorBorder = new TitledBorder(null, "Tree Prior", TitledBorder.DEFAULT_JUSTIFICATION, TitledBorder.ABOVE_TOP);
         treePriorPanelParent.setBorder(treePriorBorder);
 
         JPanel panel3 = new JPanel(new FlowLayout(FlowLayout.LEFT));
@@ -178,15 +178,13 @@ public class TreesPanel extends BeautiPanel implements Exportable {
         } else {
             options.unLinkTreePriors(currentTreeModel);
         }
-        setCurrentModelAndPrior(currentTreeModel); // this is important to make panel refreshing
+        updateTreePriorBorder();
 
         fireTreePriorsChanged();
     }
 
     private void updateTreePriorBorder() {
-        if (options.useStarBEAST) {
-            treePriorBorder.setTitle("Species tree prior used to start all gene tree models");
-        } else if (options.isShareSameTreePrior()) {
+        if (options.isShareSameTreePrior()) {
             treePriorBorder.setTitle("Tree prior shared by all tree models");
         } else {
             treePriorBorder.setTitle("Tree Prior - " + currentTreeModel.getPartitionTreePrior().getName());
@@ -195,46 +193,10 @@ public class TreesPanel extends BeautiPanel implements Exportable {
     }
 
     public void fireTreePriorsChanged() {
-        options.updatePartitionAllLinks();
+//        options.updatePartitionAllLinks();
         frame.setDirty();
     }
 
-    public void updatePriorPanelForSpeciesAnalysis() {
-        if (options.useStarBEAST) linkTreePriorCheck.setSelected(true); // not to set false if non-*BEAST
-        updateShareSameTreePriorChanged();
-
-        if (currentTreeModel.getPartitionTreePrior() != null) treePriorPanelParent.removeAll();
-
-        if (options.getPartitionTreePriors().size() > 0) {
-
-            if (options.useStarBEAST) {
-
-                options.getPartitionTreePriors().get(0).setNodeHeightPrior(TreePriorType.SPECIES_YULE);
-
-            } else {
-//                if (options.hasData() && options.contains(Microsatellite.INSTANCE)) {
-//                    linkTreePriorCheck.setEnabled(false);
-//                } else {
-//                    linkTreePriorCheck.setEnabled(true);
-//                }
-
-                options.getPartitionTreePriors().get(0).setNodeHeightPrior(TreePriorType.CONSTANT);
-            }
-
-            PartitionTreePriorPanel p = new PartitionTreePriorPanel(options.getPartitionTreePriors().get(0), this);
-
-            treePriorPanels.put(options.getPartitionTreePriors().get(0), p);
-
-            for (PartitionTreeModel model : options.getPartitionTreeModels()) {
-                if (model != null && treeModelPanels.get(model) != null) treeModelPanels.get(model).setupPanel();
-
-            }
-            treePriorPanelParent.add(p);
-        }
-        updateTreePriorBorder();
-        repaint();
-    }
-
     private void selectionChanged() {
         int selRow = treesTable.getSelectedRow();
 
@@ -309,7 +271,7 @@ public class TreesPanel extends BeautiPanel implements Exportable {
 
     public void updateLinkTreePriorEnablility() {
         boolean selected = !(options.getPartitionTreeModels().size() < 2
-                || options.contains(Microsatellite.INSTANCE) || options.useStarBEAST);
+                || options.contains(Microsatellite.INSTANCE));
 
         linkTreePriorCheck.setEnabled(selected);
     }
@@ -331,8 +293,8 @@ public class TreesPanel extends BeautiPanel implements Exportable {
         for (PartitionTreePrior prior : options.getPartitionTreePriors()) {
             PartitionTreePriorPanel ptpp = treePriorPanels.get(prior);
             if (ptpp != null) {
-                ptpp.setTreePriorChoices(options.useStarBEAST, options.getPartitionTreeModels().size() > 1,
-                        options.clockModelOptions.isTipCalibrated());
+                ptpp.setTreePriorChoices(options.getPartitionTreeModels().size() > 1,
+                        options.useTipDates);
                 // setTreePriorChoices should be always before setOptions
                 ptpp.setOptions();
 //                    if (options.contains(Microsatellite.INSTANCE)) {
@@ -447,20 +409,9 @@ public class TreesPanel extends BeautiPanel implements Exportable {
         }
 
         public boolean isCellEditable(int row, int col) {
-            boolean editable;
-
-            switch (col) {
-                case 0:// name
-                    editable = true;
-                    break;
-                default:
-                    editable = false;
-            }
-
-            return editable;
+            return false;
         }
 
-
         public String getColumnName(int column) {
             return columnNames[column];
         }
