@@ -41,6 +41,7 @@ public enum PriorType {
     NONE_IMPROPER("Infinite Uniform (Improper)", true, false, false),
     NONE_FIXED("Fixed value", true, false, false),
     UNIFORM_PRIOR("Uniform", true, false, false),
+    DISCRETE_UNIFORM_PRIOR("Discrete Uniform", true, false, false),
     EXPONENTIAL_PRIOR("Exponential", true, true, true),
     LAPLACE_PRIOR("Laplace", true, true, true),
     NORMAL_PRIOR("Normal", true, true, true),
@@ -54,7 +55,7 @@ public enum PriorType {
     LOGNORMAL_HPM_PRIOR("Lognormal HPM", true, false, false),
     NORMAL_HPM_PRIOR("Normal HPM", true, false, false),
     LINKED_PARAMETER("Linked Parameter", false, false, false),
-    POISSON_PRIOR("Poisson", true, false, false);
+    POISSON_PRIOR("Poisson", false, false, false);
 
     PriorType(final String name, final boolean isInitializable, final boolean isTruncatable, final boolean isPlottable) {
         this.name = name;
@@ -159,6 +160,13 @@ public enum PriorType {
             case UNDEFINED:
                 buffer.append("Not yet specified");
                 break;
+            case DISCRETE_UNIFORM_PRIOR:
+                buffer.append("Uniform [");
+                buffer.append(NumberUtil.formatDecimal(lower, 10, 6));
+                buffer.append(", ");
+                buffer.append(NumberUtil.formatDecimal(upper, 10, 6));
+                buffer.append("]");
+                break;
             case UNIFORM_PRIOR:
                 if (!parameter.isDiscrete) { // && !param.isStatistic) {
                     buffer.append("Uniform [");
@@ -191,7 +199,7 @@ public enum PriorType {
                 break;
             case LOGNORMAL_PRIOR:
                 buffer.append("LogNormal [");
-                if (parameter.isMeanInRealSpace()) buffer.append("R");
+                if (parameter.isInRealSpace()) buffer.append("R");
                 buffer.append(NumberUtil.formatDecimal(parameter.mean, 10, 6));
                 buffer.append(", ");
                 buffer.append(NumberUtil.formatDecimal(parameter.stdev, 10, 6));
@@ -261,7 +269,7 @@ public enum PriorType {
 
         if (parameter.priorType == NONE_FIXED) {
             buffer.append(", value=").append(NumberUtil.formatDecimal(parameter.getInitial(), 10, 6));
-        } else if (parameter.priorType.isInitializable && parameter.getInitial() != Double.NaN) {
+        } else if (parameter.priorType.isInitializable && !Double.isNaN(parameter.getInitial())) {
             buffer.append(", initial=").append(NumberUtil.formatDecimal(parameter.getInitial(), 10, 6));
         }
 
@@ -356,6 +364,18 @@ public enum PriorType {
                     LOGNORMAL_HPM_PRIOR,
                     NORMAL_HPM_PRIOR};
         }
+        if (parameter.isMaintainedSum) {
+            return new PriorType[]{
+                    NONE_FIXED,
+                    NONE_IMPROPER,
+                    DIRICHLET_PRIOR,
+                    UNIFORM_PRIOR,
+                    EXPONENTIAL_PRIOR,
+                    NORMAL_PRIOR,
+                    LOGNORMAL_PRIOR,
+                    GAMMA_PRIOR,
+                    INVERSE_GAMMA_PRIOR};
+        }
         if (parameter.isZeroOne) {
             return new PriorType[]{
                     NONE_FIXED,
@@ -381,6 +401,7 @@ public enum PriorType {
                     ONE_OVER_X_PRIOR};
         }
 
+
         // just a continuous parameter
         return new PriorType[]{
                 NONE_FIXED,
