@@ -43,10 +43,7 @@ public enum TreePriorType {
     BIRTH_DEATH("Speciation: Birth-Death Process"),
     BIRTH_DEATH_INCOMPLETE_SAMPLING("Speciation: Birth-Death Incomplete Sampling"),
     BIRTH_DEATH_SERIAL_SAMPLING("Speciation: Birth-Death Serially Sampled"),
-    BIRTH_DEATH_BASIC_REPRODUCTIVE_NUMBER("Epidemiology: Birth-Death Basic Reproductive Number"),
-    SPECIES_YULE("Species Tree: Yule Process"),
-    SPECIES_YULE_CALIBRATION("Species Tree: Calibrated Yule"),
-    SPECIES_BIRTH_DEATH("Species Tree: Birth-Death Process");
+    BIRTH_DEATH_BASIC_REPRODUCTIVE_NUMBER("Epidemiology: Birth-Death Basic Reproductive Number");
 
     TreePriorType(String name) {
         this.name = name;
