@@ -52,6 +52,8 @@ import javax.swing.JOptionPane;
 import javax.swing.JTabbedPane;
 import javax.swing.SwingUtilities;
 
+import dr.evolution.datatype.HiddenDataType;
+import dr.evolution.tree.TreeUtils;
 import org.apache.commons.math.random.MersenneTwister;
 
 import dr.app.bss.test.AncestralSequenceTrait;
@@ -1296,7 +1298,12 @@ public class Utils {
 				if (state == gapFlag) {
 					sSeq.append(dataType.getCode(dataType.getGapState()));
 				} else {
-					sSeq.append(dataType.getCode(seq[i]));
+					if(dataType instanceof HiddenDataType){
+						sSeq.append(dataType.getCode(seq[i] %
+								(dataType.getStateCount()/((HiddenDataType) dataType).getHiddenClassCount())));
+					}else{
+						sSeq.append(dataType.getCode(seq[i]));
+					}
 				}// END: gap check
 
 			}// END: replications loop
@@ -1426,10 +1433,10 @@ public class Utils {
 				sequencesMap, dataType);
 		TreeTraitProvider[] treeTraitProviders = new TreeTraitProvider[] { ancestralSequence };
 
-		Tree.Utils.newick(treeModel, //
+		TreeUtils.newick(treeModel, //
 				treeModel.getRoot(), //
 				useTipLabels, //
-				Tree.BranchLengthType.LENGTHS_AS_TIME, //
+				TreeUtils.BranchLengthType.LENGTHS_AS_TIME, //
 				format, //
 				null, //
 				treeTraitProviders, //
