@@ -32,17 +32,19 @@ import java.util.ArrayList;
 import java.util.LinkedHashMap;
 import java.util.Locale;
 
-import dr.app.beagle.evomodel.branchmodel.HomogeneousBranchModel;
-import dr.app.beagle.evomodel.branchmodel.RandomBranchModel;
-import dr.app.beagle.evomodel.sitemodel.GammaSiteRateModel;
-import dr.app.beagle.evomodel.substmodel.EmpiricalAminoAcidModel;
-import dr.app.beagle.evomodel.substmodel.FrequencyModel;
-import dr.app.beagle.evomodel.substmodel.GY94CodonModel;
-import dr.app.beagle.evomodel.substmodel.HKY;
-import dr.app.beagle.evomodel.substmodel.MG94CodonModel;
-import dr.app.beagle.evomodel.substmodel.SubstitutionModel;
-import dr.app.beagle.evomodel.treelikelihood.BeagleTreeLikelihood;
-import dr.app.beagle.evomodel.treelikelihood.PartialsRescalingScheme;
+import dr.evolution.tree.TreeUtils;
+import dr.evomodel.branchmodel.HomogeneousBranchModel;
+import dr.evomodel.branchmodel.RandomBranchModel;
+import dr.evomodel.siteratemodel.GammaSiteRateModel;
+import dr.evomodel.substmodel.EmpiricalRateMatrix;
+import dr.evomodel.substmodel.FrequencyModel;
+import dr.evomodel.substmodel.aminoacid.Blosum62;
+import dr.evomodel.substmodel.aminoacid.EmpiricalAminoAcidModel;
+import dr.evomodel.substmodel.codon.GY94CodonModel;
+import dr.evomodel.substmodel.nucleotide.HKY;
+import dr.evomodel.substmodel.codon.MG94CodonModel;
+import dr.evomodel.treelikelihood.BeagleTreeLikelihood;
+import dr.evomodel.treelikelihood.PartialsRescalingScheme;
 import dr.app.beagle.tools.BeagleSequenceSimulator;
 import dr.app.beagle.tools.Partition;
 import dr.app.bss.Utils;
@@ -67,8 +69,6 @@ import dr.evolution.util.Taxon;
 import dr.evolution.util.Units;
 import dr.evomodel.branchratemodel.BranchRateModel;
 import dr.evomodel.branchratemodel.DefaultBranchRateModel;
-import dr.evomodel.substmodel.Blosum62;
-import dr.evomodel.substmodel.EmpiricalRateMatrix;
 import dr.evomodel.tree.TreeModel;
 import dr.inference.model.Parameter;
 import dr.math.MathUtils;
@@ -207,10 +207,10 @@ public class BeagleSeqSimTest {
 			NumberFormat format = NumberFormat.getNumberInstance(Locale.ENGLISH);
 			boolean useTipLabels = true;
 
-			Tree.Utils.newick(treeModel, //
+			TreeUtils.newick(treeModel, //
 					treeModel.getRoot(), //
 					useTipLabels, //
-					Tree.BranchLengthType.LENGTHS_AS_TIME, //
+					TreeUtils.BranchLengthType.LENGTHS_AS_TIME, //
 					format, //
 					null, //
 					treeTraitProviders, //
