@@ -40,7 +40,10 @@ public class JChartPanel extends JPanel implements Printable {
 	private static final long serialVersionUID = -737128752110140264L;
 	public JChartPanel(JChart chart, String title, String xAxisTitle, String yAxisTitle) {
 
-		setOpaque(false);
+	    this.chart = chart;
+
+	    setOpaque(false);
+	    
 		ChartLayout layout = new ChartLayout(4, 4);
 		setLayout(layout);
 		if (chart != null) {
@@ -52,6 +55,10 @@ public class JChartPanel extends JPanel implements Printable {
 		setYAxisTitle(yAxisTitle);
 	}
 
+	public JChart getChart() {
+	    return chart;
+    }
+
 	public void setTitle(String title) {
 
 		if (titleLabel != null) {
@@ -141,7 +148,9 @@ public class JChartPanel extends JPanel implements Printable {
 		}
 	}
 
-	private JLabel titleLabel = null;
+    private final JChart chart;
+
+    private JLabel titleLabel = null;
 	private JLabel xAxisLabel = null;
 	private JLabel yAxisLabel = null;
 }
