@@ -50,13 +50,13 @@ public interface Plot {
 
     // These constants are used for automatic scaling to select exactly
     // where the axis starts and stops.
-    static public final int NO_MARK = 0;
-    static public final int POINT_MARK = 1;
-    static public final int CROSS_MARK = 2;
-    static public final int PLUS_MARK = 3;
-    static public final int CIRCLE_MARK = 4;
-    static public final int SQUARE_MARK = 5;
-    static public final int DIAMOND_MARK = 6;
+    int NO_MARK = 0;
+    int POINT_MARK = 1;
+    int CROSS_MARK = 2;
+    int PLUS_MARK = 3;
+    int CIRCLE_MARK = 4;
+    int SQUARE_MARK = 5;
+    int DIAMOND_MARK = 6;
 
     /**
      * Set axes
@@ -119,7 +119,7 @@ public interface Plot {
      * Paint actual plot
      */
     void paintPlot(Graphics2D g2, double xScale, double yScale,
-                   double xOffset, double yOffset);
+                   double xOffset, double yOffset, int plotNumber, int plotCount);
 
     /**
      * Set name
@@ -131,6 +131,16 @@ public interface Plot {
      */
     String getName();
 
+    int getPlotNumber();
+
+    void setPlotNumber(int plotNumber);
+
+    double getXLocation();
+
+    double getYLocation();
+
+    void setLocation(double x, double y);
+
     /**
      * A point on the plot has been clicked
      */
@@ -150,6 +160,10 @@ public interface Plot {
 
     Variate getYData();
 
+    void setChart(JChart chart);
+
+    JChart getChart();
+
     public interface Listener {
 
         void pointClicked(double x, double y, boolean isShiftDown);
@@ -191,7 +205,9 @@ public interface Plot {
      * <p/>
      * Description:	An abstract base class for plots
      */
-    public abstract class AbstractPlot implements Plot {
+    abstract class AbstractPlot implements Plot {
+
+        private JChart chart = null;
 
         protected Axis xAxis, yAxis;
         protected Variate.N xData = null;
@@ -208,12 +224,13 @@ public interface Plot {
         protected Paint markPaint = Color.black;
         protected Paint markFillPaint = Color.black;
 
-        private final Rectangle2D bounds = null;
-
-        private double xScale, yScale, xOffset, yOffset;
+        protected double xScale, yScale, xOffset, yOffset;
 
         private String name;
 
+        private int plotNumber = -1, plotCount = -1;
+        private double xLocation = 0, yLocation = 0;
+
         private Set<Integer> selectedPoints = new HashSet<Integer>();
 
         /**
@@ -237,6 +254,13 @@ public interface Plot {
             setData(xData, yData);
         }
 
+        public JChart getChart() {
+            return chart;
+        }
+
+        public void setChart(JChart chart) {
+            this.chart = chart;
+        }
 
         /**
          * Set data
@@ -280,6 +304,28 @@ public interface Plot {
             setupAxis(xAxis, yAxis, xData, yData);
         }
 
+        public int getPlotNumber() {
+            return plotNumber;
+        }
+
+        public void setPlotNumber(int plotNumber) {
+            this.plotNumber = plotNumber;
+        }
+
+        public double getXLocation() {
+            return xLocation;
+        }
+
+        public double getYLocation() {
+            return yLocation;
+        }
+
+        @Override
+        public void setLocation(double x, double y) {
+            xLocation = x;
+            yLocation = y;
+        }
+
         /**
          * Set up the axis with some data
          */
@@ -431,8 +477,8 @@ public interface Plot {
          * Transform a chart co-ordinates into a drawing co-ordinates
          */
         protected double transformX(double value) {
-            double tx = xAxis.transform(value);
-            if (tx == Double.NaN || tx == Double.NEGATIVE_INFINITY) {
+            double tx = xAxis.transform(value + xLocation);
+            if (Double.isNaN(tx) || tx == Double.NEGATIVE_INFINITY) {
                 return Double.NEGATIVE_INFINITY;
             }
             return ((tx - xAxis.transform(xAxis.getMinAxis())) * xScale) + xOffset;
@@ -442,8 +488,8 @@ public interface Plot {
          * Transform a chart co-ordinates into a drawing co-ordinates
          */
         protected double transformY(double value) {
-            double ty = yAxis.transform(value);
-            if (ty == Double.NaN || ty == Double.NEGATIVE_INFINITY) {
+            double ty = yAxis.transform(value + yLocation);
+            if (Double.isNaN(ty) || ty == Double.NEGATIVE_INFINITY) {
                 return Double.NEGATIVE_INFINITY;
             }
             return ((ty - yAxis.transform(yAxis.getMinAxis())) * yScale) + yOffset;
@@ -455,7 +501,7 @@ public interface Plot {
         protected double untransformX(double value) {
 
             return xAxis.untransform(
-                    xAxis.transform(xAxis.getMinAxis()) + ((value - xOffset) / xScale));
+                    xAxis.transform(xAxis.getMinAxis()) + ((value - xOffset) / xScale)) - xLocation;
         }
 
         /**
@@ -464,7 +510,7 @@ public interface Plot {
         protected double untransformY(double value) {
 
             return yAxis.untransform(
-                    yAxis.transform(yAxis.getMinAxis()) + ((value - yOffset) / yScale));
+                    yAxis.transform(yAxis.getMinAxis()) + ((value - yOffset) / yScale)) - yLocation;
         }
 
         /**
@@ -477,15 +523,9 @@ public interface Plot {
         }
 
         /**
-         * Draw a rectangle transforming co-ordinates to each axis
+         * Draw a rectangle directly (no transformation)
          */
-        protected void drawRect(Graphics2D g2, double x1, double y1, double x2, double y2) {
-
-            float tx1 = (float) transformX(x1);
-            float ty1 = (float) transformY(y1);
-            float tx2 = (float) transformX(x2);
-            float ty2 = (float) transformY(y2);
-
+        protected void drawRect(Graphics2D g2, float tx1, float ty1, float tx2, float ty2) {
             GeneralPath path = new GeneralPath();
             path.moveTo(tx1, ty1);
             path.lineTo(tx1, ty2);
@@ -497,14 +537,9 @@ public interface Plot {
         }
 
         /**
-         * Fill a rectangle transforming co-ordinates to each axis
+         * Fill a rectangle directly (no transformation)
          */
-        protected void fillRect(Graphics2D g2, double x1, double y1, double x2, double y2) {
-
-            float tx1 = (float) transformX(x1);
-            float ty1 = (float) transformY(y1);
-            float tx2 = (float) transformX(x2);
-            float ty2 = (float) transformY(y2);
+        protected void fillRect(Graphics2D g2, float tx1, float ty1, float tx2, float ty2) {
 
             GeneralPath path = new GeneralPath();
             path.moveTo(tx1, ty1);
@@ -516,11 +551,36 @@ public interface Plot {
             g2.fill(path);
         }
 
+        /**
+         * Draw a rectangle transforming co-ordinates to each axis
+         */
+        protected void drawRect(Graphics2D g2, double x1, double y1, double x2, double y2) {
+
+            float tx1 = (float) transformX(x1);
+            float ty1 = (float) transformY(y1);
+            float tx2 = (float) transformX(x2);
+            float ty2 = (float) transformY(y2);
+            drawRect(g2, tx1, ty1, tx2, ty2);
+        }
+
+        /**
+         * Fill a rectangle transforming co-ordinates to each axis
+         */
+        protected void fillRect(Graphics2D g2, double x1, double y1, double x2, double y2) {
+
+            float tx1 = (float) transformX(x1);
+            float ty1 = (float) transformY(y1);
+            float tx2 = (float) transformX(x2);
+            float ty2 = (float) transformY(y2);
+            fillRect(g2, tx1, ty1, tx2, ty2);
+        }
+
         /**
          * Paint actual plot
          */
+        @Override
         public void paintPlot(Graphics2D g2, double xScale, double yScale,
-                              double xOffset, double yOffset) {
+                              double xOffset, double yOffset, int plotNumber, int plotCount) {
             if (xAxis == null || yAxis == null)
                 return;
 
@@ -529,11 +589,12 @@ public interface Plot {
             this.xOffset = xOffset;
             this.yOffset = yOffset;
 
-            // variable is assigned to itself
-            //this.bounds = bounds;
+            this.plotNumber = plotNumber;
+            this.plotCount = plotCount;
 
-            if (xData != null && yData != null && xData.getCount() > 0)
+            if (hasData()) {
                 paintData(g2, xData, yData);
+            }
         }
 
         /**
@@ -541,6 +602,10 @@ public interface Plot {
          */
         abstract protected void paintData(Graphics2D g2, Variate.N xData, Variate.N yData);
 
+        protected boolean hasData() {
+            return (xData != null && yData != null && xData.getCount() > 0);
+        }
+
         /**
          * A point on the plot has been clicked
          */
