@@ -39,7 +39,6 @@ import dr.evolution.tree.Tree;
 import dr.inference.trace.LogFileTraces;
 import dr.inference.trace.TraceException;
 import dr.util.DataTable;
-import dr.xml.XMLParseException;
 import jam.framework.DocumentFrame;
 import jam.framework.Exportable;
 
@@ -276,12 +275,12 @@ public class MapperFrame extends DocumentFrame implements MapperFileMenuHandler
                 in.getProgressMonitor().setMillisToDecideToPopup(0);
                 in.getProgressMonitor().setMillisToPopup(0);
 
-                final Reader reader = new InputStreamReader(in);
+//                final Reader reader = new InputStreamReader(in);
 
                 Thread readThread = new Thread() {
                     public void run() {
                         try {
-                            traces.loadTraces(reader);
+                            traces.loadTraces(in);
 
                             EventQueue.invokeLater(
                                     new Runnable() {
@@ -345,8 +344,8 @@ public class MapperFrame extends DocumentFrame implements MapperFileMenuHandler
                 public void run() {
                     try {
                         for (final LogFileTraces traces : tracesArray) {
-                            final Reader reader = new FileReader(traces.getFile());
-                            traces.loadTraces(reader);
+//                            final Reader reader = new FileReader(traces.getFile());
+                            traces.loadTraces();
 
                             EventQueue.invokeLater(
                                     new Runnable() {
