@@ -33,10 +33,10 @@ import dr.evolution.sequence.Sequence;
 import dr.evolution.tree.*;
 import dr.evolution.util.*;
 import dr.evomodel.branchratemodel.*;
-import dr.evomodel.sitemodel.GammaSiteModel;
-import dr.evomodel.sitemodel.SiteModel;
-import dr.evomodel.substmodel.FrequencyModel;
-import dr.evomodel.substmodel.HKY;
+import dr.oldevomodel.sitemodel.GammaSiteModel;
+import dr.oldevomodel.sitemodel.SiteModel;
+import dr.oldevomodel.substmodel.FrequencyModel;
+import dr.oldevomodel.substmodel.HKY;
 import dr.inference.model.Parameter;
 import dr.math.MathUtils;
 import dr.xml.*;
@@ -380,7 +380,7 @@ public class RecomboGen {
         //************************************************************************
 
         public String getParserDescription() {
-            return "A SequenceSimulator that generates random sequences for a given tree, sitemodel and branch rate model";
+            return "A SequenceSimulator that generates random sequences for a given tree, siteratemodel and branch rate model";
         }
 
         public Class getReturnType() {
