@@ -36,11 +36,11 @@ import dr.evolution.tree.NodeRef;
 import dr.evolution.tree.Tree;
 import dr.evomodel.branchratemodel.BranchRateModel;
 import dr.evomodel.branchratemodel.DefaultBranchRateModel;
-import dr.evomodel.sitemodel.GammaSiteModel;
-import dr.evomodel.sitemodel.SiteModel;
-import dr.evomodel.substmodel.FrequencyModel;
-import dr.evomodel.substmodel.HKY;
-import dr.evomodel.substmodel.SubstitutionEpochModel;
+import dr.oldevomodel.sitemodel.GammaSiteModel;
+import dr.oldevomodel.sitemodel.SiteModel;
+import dr.oldevomodel.substmodel.FrequencyModel;
+import dr.oldevomodel.substmodel.HKY;
+import dr.oldevomodel.substmodel.SubstitutionEpochModel;
 import dr.inference.model.Parameter;
 import dr.math.MathUtils;
 import dr.xml.*;
@@ -318,7 +318,7 @@ public class SequenceSimulator {
         //************************************************************************
 
         public String getParserDescription() {
-            return "A SequenceSimulator that generates random sequences for a given tree, sitemodel and branch rate model";
+            return "A SequenceSimulator that generates random sequences for a given tree, siteratemodel and branch rate model";
         }
 
         public Class getReturnType() {
