@@ -28,11 +28,11 @@ package dr.app.tempest;
 import dr.app.beauti.options.DateGuesser;
 import dr.app.beauti.tipdatepanel.GuessDatesDialog;
 import dr.app.beauti.util.PanelUtils;
-import dr.evolution.util.Date;
-import dr.evolution.util.TimeScale;
-import dr.evolution.util.Units;
-import dr.evolution.util.TaxonList;
+import dr.app.util.OSType;
+import dr.app.util.Utils;
+import dr.evolution.util.*;
 import dr.app.gui.table.*;
+import dr.util.DataTable;
 import jam.framework.Exportable;
 import jam.table.HeaderRenderer;
 import dr.app.gui.table.TableEditorStopper;
@@ -41,12 +41,20 @@ import jam.table.TableRenderer;
 import javax.swing.*;
 import javax.swing.event.ListSelectionEvent;
 import javax.swing.event.ListSelectionListener;
+import javax.swing.filechooser.FileNameExtensionFilter;
 import javax.swing.plaf.BorderUIResource;
 import javax.swing.table.AbstractTableModel;
 import java.awt.*;
 import java.awt.event.ActionEvent;
 import java.awt.event.ItemEvent;
 import java.awt.event.ItemListener;
+import java.io.File;
+import java.io.FileNotFoundException;
+import java.io.FileReader;
+import java.io.IOException;
+import java.util.ArrayList;
+import java.util.HashMap;
+import java.util.Map;
 
 /**
  * @author Andrew Rambaut
@@ -64,6 +72,7 @@ public class SamplesPanel extends JPanel implements Exportable {
 
     ClearDatesAction clearDatesAction = new ClearDatesAction();
     GuessDatesAction guessDatesAction = new GuessDatesAction();
+    ImportDatesAction importDatesAction = new ImportDatesAction();
 
     JComboBox unitsCombo = new JComboBox(new String[]{"Years", "Months", "Days"});
     JComboBox directionCombo = new JComboBox(new String[]{"Since some time in the past", "Before the present"});
@@ -86,6 +95,7 @@ public class SamplesPanel extends JPanel implements Exportable {
 
         this.frame = parent;
 
+        frame.setImportAction(importDatesAction);
         dataTableModel = new DataTableModel();
         TableSorter sorter = new TableSorter(dataTableModel);
         dataTable = new JTable(sorter);
@@ -137,10 +147,13 @@ public class SamplesPanel extends JPanel implements Exportable {
         toolBar1.setOpaque(false);
 
         toolBar1.setLayout(new FlowLayout(FlowLayout.LEFT, 0, 0));
-        JButton button = new JButton(clearDatesAction);
+        JButton button = new JButton(importDatesAction);
         PanelUtils.setupComponent(button);
         toolBar1.add(button);
-        button = new JButton(guessDatesAction);
+         button = new JButton(guessDatesAction);
+        PanelUtils.setupComponent(button);
+        toolBar1.add(button);
+         button = new JButton(clearDatesAction);
         PanelUtils.setupComponent(button);
         toolBar1.add(button);
         toolBar1.add(new JToolBar.Separator(new Dimension(12, 12)));
@@ -189,7 +202,7 @@ public class SamplesPanel extends JPanel implements Exportable {
 
             Date newDate = createDate(d, units, backwards, 0.0);
 
-            newDate.setPrecision(date.getPrecision());
+            newDate.setUncertainty(date.getUncertainty());
 
             taxonList.getTaxon(i).setDate(newDate);
         }
@@ -285,6 +298,170 @@ public class SamplesPanel extends JPanel implements Exportable {
         dataTableModel.fireTableDataChanged();
     }
 
+    private Map<String, FileDialog> fileDialogs = new HashMap<String, FileDialog>();
+    private Map<String, JFileChooser> fileChoosers = new HashMap<String, JFileChooser>();
+    /**
+     * Use the native file dialog on the Mac because the Swing one is bad. On linux, the native
+     * one is bad. No preference on Windows.
+     * @param title
+     * @return
+     */
+    public File[] selectImportFiles(final String title, boolean multipleSelection, FileNameExtensionFilter[] fileNameExtensionFilters) {
+        if (Boolean.parseBoolean(System.getProperty("use.native.choosers", Boolean.toString(OSType.isMac())))) {
+            FileDialog importDialog = fileDialogs.get(title);
+            if (importDialog == null) {
+                importDialog = new FileDialog(frame, title, FileDialog.LOAD);
+                fileDialogs.put(title, importDialog);
+            }
+
+            importDialog.setVisible(true);
+            if (importDialog.getFile() != null) {
+                return new File[] { new File(importDialog.getDirectory(), importDialog.getFile()) };
+            }
+        } else {
+            JFileChooser importChooser = fileChoosers.get(title);
+            if (importChooser == null) {
+                importChooser = new JFileChooser(Utils.getCWD());
+
+                importChooser.setMultiSelectionEnabled(multipleSelection);
+                for (FileNameExtensionFilter fileNameExtensionFilter : fileNameExtensionFilters) {
+                    importChooser.setFileFilter(fileNameExtensionFilter);
+                }
+                importChooser.setDialogTitle(title);
+
+                fileChoosers.put(title, importChooser);
+            }
+
+            int returnVal = importChooser.showOpenDialog(this);
+            if (returnVal == JFileChooser.APPROVE_OPTION) {
+                if (importChooser.isMultiSelectionEnabled()) {
+                    return importChooser.getSelectedFiles();
+                } else {
+                    return new File[] { importChooser.getSelectedFile() };
+                }
+            }
+        }
+
+        return null;
+    }
+
+    private void importDates() {
+
+        File[] files = selectImportFiles("Import Dates File...", false, new FileNameExtensionFilter[]{
+                new FileNameExtensionFilter("Tab-delimited text files", "txt", "tab", "dat")});
+
+        DataTable<String[]> dataTable;
+
+        if (files != null && files.length != 0) {
+            try {
+                // Load the file as a table
+                dataTable = DataTable.Text.parse(new FileReader(files[0]), true, true, true, false);
+
+            } catch (FileNotFoundException fnfe) {
+                JOptionPane.showMessageDialog(this, "Unable to open file: File not found",
+                        "Unable to open file",
+                        JOptionPane.ERROR_MESSAGE);
+                return;
+            } catch (IOException ioe) {
+                JOptionPane.showMessageDialog(this, "Unable to read file: " + ioe.getMessage(),
+                        "Unable to read file",
+                        JOptionPane.ERROR_MESSAGE);
+                return;
+            } catch (Exception ex) {
+                ex.printStackTrace(System.err);
+                JOptionPane.showMessageDialog(this, "Fatal exception: " + ex,
+                        "Error reading file",
+                        JOptionPane.ERROR_MESSAGE);
+                ex.printStackTrace();
+                return;
+            }
+        } else {
+            return;
+        }
+
+        if (dataTable.getColumnCount() == 0) {
+            // expecting at least 2 columns - labels and dates
+            JOptionPane.showMessageDialog(frame,
+                    "Expecting a tab delimited file with at\n" +
+                            "least 2 columns (taxon labels and dates).",
+                    "Incompatible values", JOptionPane.ERROR_MESSAGE);
+            return;
+        }
+
+        String[] columnLabels = dataTable.getColumnLabels();
+        String[] taxonNames = dataTable.getRowLabels();
+
+        if (columnLabels.length < 2) {
+            // only one column so leave it
+            return;
+        }
+
+        boolean hasColumnHeadings = taxonList.getTaxonIndex(columnLabels[0]) < 0;
+
+        // assume the second column contains the dates
+        int dateColumn = 0;
+
+        if (hasColumnHeadings && columnLabels.length > 1) {
+            java.util.List<Integer> dateColumns = new ArrayList<Integer>();
+
+            // see if there is a column labelled 'dates' or something
+            for (int i = 1; i < dataTable.getColumnCount(); i++) {
+                if (columnLabels[i].toLowerCase().contains("date")) {
+                    dateColumns.add(i - 1);
+                }
+            }
+
+            if (dateColumns.size() > 0) {
+                // if there are multiple date column possibilities, take the first
+                // @todo - allow the user to select the column to use
+                dateColumn = dateColumns.get(0);
+            }
+        }
+
+        Map<Taxon, String> taxonDateMap = new HashMap<Taxon, String>();
+
+        String[] values = dataTable.getColumn(dateColumn);
+
+        if (!hasColumnHeadings) {
+            final int index = taxonList.getTaxonIndex(columnLabels[0]);
+            if (index >= 0) {
+                taxonDateMap.put(taxonList.getTaxon(index), columnLabels[dateColumn + 1]);
+            }
+        }
+
+        int j = 0;
+        for (final String taxonName : taxonNames) {
+
+            final int index = taxonList.getTaxonIndex(taxonName);
+            if (index >= 0) {
+                taxonDateMap.put(taxonList.getTaxon(index), values[j]);
+            }
+            j++;
+        }
+
+        if (guessDatesDialog == null) {
+            guessDatesDialog = new GuessDatesDialog(frame);
+        }
+
+        guessDatesDialog.setDescription("Parse date values from file");
+
+        int result = guessDatesDialog.showDialog(true);
+
+        if (result == -1 || result == JOptionPane.CANCEL_OPTION) {
+            return;
+        }
+
+        guesser.guessDates = true;
+        guessDatesDialog.setupGuesser(guesser);
+
+        guesser.guessDates(taxonList, taxonDateMap);
+
+        // adjust the dates to the current timescale...
+        timeScaleChanged();
+
+        dataTableModel.fireTableDataChanged();
+    }
+
     public class ClearDatesAction extends AbstractAction {
         /**
          *
@@ -308,8 +485,8 @@ public class SamplesPanel extends JPanel implements Exportable {
         private static final long serialVersionUID = 8514706149822252033L;
 
         public GuessDatesAction() {
-            super("Guess Dates");
-            setToolTipText("Use this tool to guess the sampling dates from the taxon labels");
+            super("Parse Dates");
+            setToolTipText("Use this tool to parse the sampling dates from the taxon labels");
         }
 
         public void actionPerformed(ActionEvent ae) {
@@ -317,6 +494,22 @@ public class SamplesPanel extends JPanel implements Exportable {
         }
     }
 
+    public class ImportDatesAction extends AbstractAction {
+        /**
+         *
+         */
+        private static final long serialVersionUID = 8514706149822252033L;
+
+        ImportDatesAction() {
+            super("Import Dates");
+            setToolTipText("Use this tool to import the sampling dates from a file");
+        }
+
+        public void actionPerformed(ActionEvent ae) {
+            importDates();
+        }
+    }
+
     private void calculateHeights() {
 
         maximumTipHeight = 0.0;
@@ -382,7 +575,7 @@ public class SamplesPanel extends JPanel implements Exportable {
                     }
                 case 2:
                     if (date != null) {
-                        return date.getPrecision();
+                        return date.getUncertainty();
                     } else {
                         return "-";
                     }
@@ -411,7 +604,7 @@ public class SamplesPanel extends JPanel implements Exportable {
                 if (date != null) {
                     double d = (Double) aValue;
                     if (d >= 0.0) {
-                        date.setPrecision(d);
+                        date.setUncertainty(d);
                     }
                 }
             }
