@@ -27,8 +27,8 @@ package dr.app.tempest;
 
 import dr.app.gui.chart.*;
 import dr.app.gui.util.LongTask;
-import dr.evolution.tree.NodeRef;
-import dr.evolution.tree.Tree;
+import dr.evolution.tree.*;
+import dr.evolution.tree.TreeUtils;
 import dr.evolution.util.TaxonList;
 import dr.math.MathUtils;
 import dr.stats.DiscreteStatistics;
@@ -392,7 +392,7 @@ public class TempestPanel extends JPanel implements Exportable {
             }
 
             Regression r = temporalRooting.getRootToTipRegression(currentTree);
-            NodeRef mrca = Tree.Utils.getCommonAncestorNode(currentTree, selectedTaxa);
+            NodeRef mrca = TreeUtils.getCommonAncestorNode(currentTree, selectedTaxa);
             double mrcaDistance1 = temporalRooting.getRootToTipDistance(currentTree, mrca);
             double mrcaTime1 = r.getX(mrcaDistance1);
             if (tree.isExternal(mrca)) {
@@ -493,7 +493,7 @@ public class TempestPanel extends JPanel implements Exportable {
                 tabbedPane.setEnabledAt(2, true);
             }
 
-            RootedTree jtree = Tree.Utils.asJeblTree(currentTree);
+            RootedTree jtree = dr.evolution.tree.TreeUtils.asJeblTree(currentTree);
 
             List<Color> colours = new ArrayList<Color>();
             for (Node tip : jtree.getExternalNodes()) {
@@ -510,7 +510,7 @@ public class TempestPanel extends JPanel implements Exportable {
                 }
 
                 rootToTipChart.removeAllPlots();
-                NumericalDensityPlot dp = new NumericalDensityPlot(values, 20, null);
+                NumericalDensityPlot dp = new NumericalDensityPlot(values, 20);
                 dp.setLineColor(new Color(9, 70, 15));
 
                 double yOffset = (Double) dp.getYData().getMax() / 2;
