@@ -1,7 +1,7 @@
 /*
- * TreeAnnotator.java
+ * AntigenicPlotter.java
  *
- * Copyright (C) 2002-2006 Alexei Drummond and Andrew Rambaut
+ * Copyright (c) 2002-2015 Alexei Drummond, Andrew Rambaut and Marc Suchard
  *
  * This file is part of BEAST.
  * See the NOTICE file distributed with this work for additional
@@ -107,7 +107,7 @@ public class AntigenicPlotter {
             traces.loadTraces();
 
             if (burnin == -1) {
-                burnin = traces.getMaxState() / 10;
+                burnin = (int) (traces.getMaxState() / 10);
             }
 
             traces.setBurnIn(burnin);
