@@ -26,16 +26,12 @@
 package dr.app.tools;
 
 import dr.app.beast.BeastVersion;
-import dr.app.phylogeography.tools.DiscreteTreeToKML;
 import dr.app.util.Arguments;
 import dr.evolution.io.Importer;
 import dr.evolution.io.NewickImporter;
 import dr.evolution.io.NexusImporter;
 import dr.evolution.io.TreeImporter;
-import dr.evolution.tree.FlexibleTree;
-import dr.evolution.tree.MutableTree;
-import dr.evolution.tree.NodeRef;
-import dr.evolution.tree.Tree;
+import dr.evolution.tree.*;
 import dr.evolution.util.TaxonList;
 import dr.geo.contouring.ContourMaker;
 import dr.geo.contouring.ContourPath;
@@ -123,7 +119,7 @@ public class TreeAnnotator {
      * @throws IOException
      */
     public TreeAnnotator(final int burninTrees,
-                         final int burninStates,
+                         final long burninStates,
                          HeightsSummary heightsOption,
                          double posteriorLimit,
                          double[] hpd2D,
@@ -150,26 +146,26 @@ public class TreeAnnotator {
         progressStream.println("0              25             50             75            100");
         progressStream.println("|--------------|--------------|--------------|--------------|");
 
-        int stepSize = totalTrees / 60;
+        long stepSize = totalTrees / 60;
         if (stepSize < 1) stepSize = 1;
 
         if (targetOption != Target.USER_TARGET_TREE) {
             cladeSystem = new CladeSystem();
             FileReader fileReader = new FileReader(inputFileName);
-            TreeImporter importer = new NexusImporter(fileReader);
+            TreeImporter importer = new NexusImporter(fileReader, true);
             try {
                 totalTrees = 0;
                 while (importer.hasTree()) {
                     Tree tree = importer.importNextTree();
 
-                    int state = Integer.MAX_VALUE;
+                    long state = Long.MAX_VALUE;
 
                     if (burninStates > 0) {
                         // if burnin has been specified in states, try to parse it out...
                         String name = tree.getId().trim();
 
                         if (name != null && name.length() > 0 && name.startsWith("STATE_")) {
-                            state = Integer.parseInt(name.split("_")[1]);
+                            state = Long.parseLong(name.split("_")[1]);
                         }
                     }
 
@@ -376,7 +372,7 @@ public class TreeAnnotator {
 
         int counter = 0;
         int bestTreeNumber = 0;
-        TreeImporter importer = new NexusImporter(new FileReader(inputFileName));
+        TreeImporter importer = new NexusImporter(new FileReader(inputFileName), true);
         try {
             while (importer.hasTree()) {
                 Tree tree = importer.importNextTree();
@@ -1338,7 +1334,7 @@ public class TreeAnnotator {
                     "<p>Department of Computer Science, University of Auckland<br>" +
                     "<a href=\"mailto:alexei@cs.auckland.ac.nz\">alexei@cs.auckland.ac.nz</a></p>" +
                     "<p>Part of the BEAST package:<br>" +
-                    "<a href=\"http://beast.bio.ed.ac.uk/\">http://beast.bio.ed.ac.uk/</a></p>" +
+                    "<a href=\"http://beast.community\">http://beast.community</a></p>" +
                     "</center></html>";
 
             new ConsoleApplication(nameString, aboutString, icon, true);
@@ -1355,7 +1351,7 @@ public class TreeAnnotator {
                 return;
             }
 
-            int burninStates = dialog.getBurninStates();
+            long burninStates = dialog.getBurninStates();
             int burninTrees = dialog.getBurninTrees();
             double posteriorLimit = dialog.getPosteriorLimit();
             double[] hpd2D = {0.80};
@@ -1413,7 +1409,7 @@ public class TreeAnnotator {
                         //new Arguments.StringOption("target", new String[] { "maxclade", "maxtree" }, false, "an option of 'maxclade' or 'maxtree'"),
                         new Arguments.StringOption("heights", new String[]{"keep", "median", "mean", "ca"}, false,
                                 "an option of 'keep' (default), 'median', 'mean' or 'ca'"),
-                        new Arguments.IntegerOption("burnin", "the number of states to be considered as 'burn-in'"),
+                        new Arguments.LongOption("burnin", "the number of states to be considered as 'burn-in'"),
                         new Arguments.IntegerOption("burninTrees", "the number of trees to be considered as 'burn-in'"),
                         new Arguments.RealOption("limit", "the minimum posterior probability for a node to be annotated"),
                         new Arguments.StringOption("target", "target_file_name", "specifies a user target tree to be annotated"),
@@ -1454,10 +1450,10 @@ public class TreeAnnotator {
             }
         }
 
-        int burninStates = -1;
+        long burninStates = -1;
         int burninTrees = -1;
         if (arguments.hasOption("burnin")) {
-            burninStates = arguments.getIntegerOption("burnin");
+            burninStates = arguments.getLongOption("burnin");
         }
         if (arguments.hasOption("burninTrees")) {
             burninTrees = arguments.getIntegerOption("burninTrees");
@@ -1534,7 +1530,7 @@ public class TreeAnnotator {
         if (reportStepSize < 1) reportStepSize = 1;
 
         final FileReader fileReader = new FileReader(inputFileName);
-        final NexusImporter importer = new NexusImporter(fileReader);
+        final NexusImporter importer = new NexusImporter(fileReader, true);
 
         // this call increments the clade counts and it shouldn't
         // this is remedied with removeClades call after while loop below
@@ -1566,7 +1562,7 @@ public class TreeAnnotator {
             final Tree tree = importer.importNextTree();
 
             if (counter >= burnin) {
-                Tree.Utils.preOrderTraversalList(tree, postOrderList);
+                TreeUtils.preOrderTraversalList(tree, postOrderList);
                 cladeSystem.getTreeCladeCodes(tree, ctree);
                 for (int k = 0; k < nClades; ++k) {
                     int j = postOrderList[k];
