@@ -27,6 +27,7 @@ package dr.app.treestat.statistics;
 
 import dr.evolution.tree.NodeRef;
 import dr.evolution.tree.Tree;
+import dr.evolution.tree.TreeUtils;
 import dr.evolution.util.TaxonList;
 
 import java.util.Set;
@@ -56,10 +57,10 @@ public class CladeMRCAAttributeStatistic extends AbstractTreeSummaryStatistic {
             node = tree.getRoot();
         } else {
             try {
-                Set<String> leafSet = Tree.Utils.getLeavesForTaxa(tree, taxonList);
-                node = Tree.Utils.getCommonAncestorNode(tree, leafSet);
+                Set<String> leafSet = TreeUtils.getLeavesForTaxa(tree, taxonList);
+                node = TreeUtils.getCommonAncestorNode(tree, leafSet);
                 if (node == null) throw new RuntimeException("No clade found that contains " + leafSet);
-            } catch (Tree.MissingTaxonException e) {
+            } catch (TreeUtils.MissingTaxonException e) {
                 throw new RuntimeException("Missing taxon!");
             }
         }
