@@ -202,7 +202,7 @@ public class Patterns implements PatternList {
                 addPattern(pattern, 1.0);
             }
         }
-
+        areUnique = siteList.areUnique();
     }
 
     /**
@@ -237,7 +237,7 @@ public class Patterns implements PatternList {
                 addPattern(pattern, patternList.getPatternWeight(i));
             }
         }
-
+        areUnique = patternList.areUnique();
     }
 
     /**
@@ -431,6 +431,11 @@ public class Patterns implements PatternList {
         return patterns[patternIndex];
     }
 
+    @Override
+    public double[][] getUncertainPattern(int patternIndex) {
+        throw new UnsupportedOperationException("uncertain patterns not implemented yet");
+    }
+
     /**
      * @return state at (taxonIndex, patternIndex)
      */
@@ -438,6 +443,11 @@ public class Patterns implements PatternList {
         return patterns[patternIndex][taxonIndex];
     }
 
+    @Override
+    public double[] getUncertainPatternState(int taxonIndex, int patternIndex) {
+        throw new UnsupportedOperationException("uncertain patterns not implemented yet");
+    }
+
     /**
      * Gets the weight of a site pattern
      */
@@ -470,7 +480,12 @@ public class Patterns implements PatternList {
 
     @Override
     public boolean areUnique() {
-        return true;
+        return areUnique;
+    }
+
+    @Override
+    public boolean areUncertain() {
+        return false;
     }
 
     // **************************************************************
@@ -594,4 +609,5 @@ public class Patterns implements PatternList {
         return taxonList.getTaxon(taxonIndex);
     }
 
+    private boolean areUnique = true;
 }
