@@ -36,6 +36,8 @@ import java.io.IOException;
 import java.io.Reader;
 import java.io.StringReader;
 import java.util.ArrayList;
+import java.util.HashMap;
+import java.util.Map;
 
 /**
  * Class for importing Newick tree file format
@@ -95,7 +97,17 @@ public class NewickImporter extends Importer implements TreeImporter {
 //				throw new BadFormatException("Expecting ';' after tree");
 //			}
 
-            return new FlexibleTree(root, false, true);
+            Map<Taxon, Integer> taxonNumberMap = null;
+            if (taxonList != null) {
+                taxonNumberMap = new HashMap<Taxon, Integer>();
+                int i = 0;
+                for (Taxon taxon : taxonList) {
+                    taxonNumberMap.put(taxon, i);
+                    i++;
+                }
+            }
+
+            return new FlexibleTree(root, false, true, taxonNumberMap);
 
         } catch (EOFException e) {
             throw new ImportException("incomplete tree");
@@ -227,16 +239,15 @@ public class NewickImporter extends Importer implements TreeImporter {
         // read the first child
         node.addChild(readBranch(taxonList));
 
-        // an internal node must have at least 2 children
         if (getLastDelimiter() != ',') {
-            throw new BadFormatException("Expecting ',' in tree, but got '" + (char) getLastDelimiter() + "'");
+            java.util.logging.Logger.getLogger("dr.evolution.io").warning("Internal node only has a single child.");
         }
 
-        // read subsequent children
-        do {
-            node.addChild(readBranch(taxonList));
 
-        } while (getLastDelimiter() == ',');
+        // read subsequent children
+        while (getLastDelimiter() == ',') {
+            node.addChild(readBranch(taxonList));
+        }
 
         // should have had a closing ')'
         if (getLastDelimiter() != ')') {
