@@ -42,7 +42,7 @@ import java.util.TimeZone;
 public class Date extends TimeScale implements Attribute { 
 
     public static final String DATE = "date";
-    private double precision = 0.0;
+    private double uncertainty = 0.0;
 
     /**
      * Constructor for relative to origin
@@ -268,11 +268,11 @@ public class Date extends TimeScale implements Attribute {
 
 	private NumberFormatter formatter = new NumberFormatter(5);
 
-    public void setPrecision(double precision) {
-        this.precision = precision;
+    public void setUncertainty(double uncertainty) {
+        this.uncertainty = uncertainty;
     }
 
-    public double getPrecision() {
-        return precision;
+    public double getUncertainty() {
+        return uncertainty;
     }
 }
