@@ -35,7 +35,6 @@ import dr.xml.*;
 import java.util.logging.Logger;
 
 
-import dr.inference.model.Bounds;
 import dr.inference.model.Parameter;
 
 
@@ -46,7 +45,7 @@ import dr.inference.model.Parameter;
  * Time: 11:15 PM
  * To change this template use File | Settings | File Templates.
  */
-public class CRPClusterRandomWalkOperator extends AbstractCoercableOperator {
+public class CRPClusterRandomWalkOperator extends AbstractAdaptableOperator {
 
 
 
@@ -62,7 +61,7 @@ public class CRPClusterRandomWalkOperator extends AbstractCoercableOperator {
     private double windowSize;
 
     public CRPClusterRandomWalkOperator( Parameter assignments, MatrixParameter virusLocations,double windowSize,   double weight){
-        super(CoercionMode.COERCION_ON);
+        super(AdaptationMode.ADAPTATION_ON);
 
         this.virusLocations=virusLocations;
         this.windowSize = windowSize;
@@ -73,7 +72,7 @@ public class CRPClusterRandomWalkOperator extends AbstractCoercableOperator {
     }
 
 
-    public double doOperation() throws OperatorFailedException {
+    public double doOperation() {
 
        int max = findMax(assignments);
 
@@ -182,23 +181,24 @@ public class CRPClusterRandomWalkOperator extends AbstractCoercableOperator {
 
 
 
-    public String getPerformanceSuggestion() {
-        return null;
+    public String getAdaptableParameterName() {
+        return "windowSize";
     }
 
 
 
+
     public String getOperatorName() {
         return CRP_CLUSTER_RW_OPERATOR;
     }
 
 
 
-    public double getCoercableParameter() {
+    public double getAdaptableParameter() {
         return Math.log(windowSize);
     }
 
-    public void setCoercableParameter(double value) {
+    public void setAdaptableParameter(double value) {
         windowSize = Math.exp(value);
     }
 
@@ -206,11 +206,6 @@ public class CRPClusterRandomWalkOperator extends AbstractCoercableOperator {
         return windowSize;
     }
 
-    public double getTargetAcceptanceProbability() {
-        return 0.234;
-    }
-
-
 
 
     public static dr.xml.XMLObjectParser PARSER = new dr.xml.AbstractXMLObjectParser() {
