@@ -1,3 +1,28 @@
+/*
+ * ContinuousAntigenicTraitLikelihood.java
+ *
+ * Copyright (c) 2002-2015 Alexei Drummond, Andrew Rambaut and Marc Suchard
+ *
+ * This file is part of BEAST.
+ * See the NOTICE file distributed with this work for additional
+ * information regarding copyright ownership and licensing.
+ *
+ * BEAST is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ *  BEAST is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with BEAST; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301  USA
+ */
+
 package dr.evomodel.antigenic;
 
 import dr.inference.model.*;
@@ -244,6 +269,7 @@ public class ContinuousAntigenicTraitLikelihood extends AntigenicTraitLikelihood
 
         initialize(
                 mdsDimension,
+                false,
                 mdsPrecision,
                 locationsParameter,
                 locationLabels,
@@ -495,19 +521,17 @@ public class ContinuousAntigenicTraitLikelihood extends AntigenicTraitLikelihood
         }
     };
 
+    @Override
+    public Citation.Category getCategory() {
+        return Citation.Category.TRAIT_MODELS;
+    }
+
+    @Override
+    public String getDescription() {
+        return "Bayesian Antigenic Cartography framework";
+    }
+
     public List<Citation> getCitations() {
-        List<Citation> citations = new ArrayList<Citation>();
-        citations.add(new Citation(
-                new Author[]{
-                        new Author("A", "Rambaut"),
-                        new Author("T", "Bedford"),
-                        new Author("P", "Lemey"),
-                        new Author("C", "Russell"),
-                        new Author("D", "Smith"),
-                        new Author("MA", "Suchard"),
-                },
-                Citation.Status.IN_PREPARATION
-        ));
-        return citations;
+        return Arrays.asList(CommonCitations.BEDFORD_2015_INTEGRATING);
     }
 }
