@@ -1,3 +1,28 @@
+/*
+ * DistanceDependentCRPGibbsOperator.java
+ *
+ * Copyright (c) 2002-2015 Alexei Drummond, Andrew Rambaut and Marc Suchard
+ *
+ * This file is part of BEAST.
+ * See the NOTICE file distributed with this work for additional
+ * information regarding copyright ownership and licensing.
+ *
+ * BEAST is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ *  BEAST is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with BEAST; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301  USA
+ */
+
 package dr.evomodel.antigenic;
 
 import java.util.logging.Logger;
@@ -7,12 +32,7 @@ import dr.inference.model.Parameter;
 import dr.inference.operators.GibbsOperator;
 import dr.inference.operators.MCMCOperator;
 import dr.inference.operators.SimpleMCMCOperator;
-import dr.math.GammaFunction;
 import dr.math.MathUtils;
-import dr.math.distributions.MultivariateNormalDistribution;
-import dr.math.distributions.WishartDistribution;
-import dr.math.matrixAlgebra.Matrix;
-import dr.math.matrixAlgebra.SymmetricMatrix;
 import dr.xml.*;
 
 
@@ -106,7 +126,7 @@ public class DistanceDependentCRPGibbsOperator extends SimpleMCMCOperator implem
 	    }
   */
 	    /**
-	     * change the parameter and return the hastings ratio.
+		 * change the parameter and return the hastings ratio.
 	     */
 	    public final double doOperation() {
 
