@@ -36,7 +36,7 @@ package dr.evomodel.arg.operators;
 
 import dr.evolution.tree.MutableTree;
 import dr.evolution.tree.NodeRef;
-import dr.evolution.tree.Tree;
+import dr.evolution.tree.TreeUtils;
 import dr.evomodel.arg.ARGModel;
 import dr.evomodel.arg.ARGModel.Node;
 import dr.evomodel.arg.ARGPartitionLikelihood;
@@ -44,10 +44,9 @@ import dr.evomodel.arg.ARGRatePrior;
 import dr.evomodelxml.tree.TreeModelParser;
 import dr.inference.model.CompoundParameter;
 import dr.inference.model.Parameter;
-import dr.inference.operators.AbstractCoercableOperator;
-import dr.inference.operators.CoercionMode;
+import dr.inference.operators.AbstractAdaptableOperator;
+import dr.inference.operators.AdaptationMode;
 import dr.inference.operators.MCMCOperator;
-import dr.inference.operators.OperatorFailedException;
 import dr.math.MathUtils;
 import dr.xml.*;
 
@@ -62,7 +61,7 @@ import java.util.logging.Logger;
  * @author Marc Suchard
  */
 
-public class ARGAddRemoveEventOperator extends AbstractCoercableOperator {
+public class ARGAddRemoveEventOperator extends AbstractAdaptableOperator {
 
     public static final String ADD_PROBABILITY = "addProbability";
     public static final String ARG_EVENT_OPERATOR = "ARGEventOperator";
@@ -87,7 +86,7 @@ public class ARGAddRemoveEventOperator extends AbstractCoercableOperator {
     private ARGRatePrior ratePrior;
 
 
-    //	private int mode = CoercableMCMCOperator.COERCION_OFF;
+    //	private int mode = AdaptableMCMCOperator.ADAPTATION_OFF;
     private CompoundParameter internalNodeParameters;
     private CompoundParameter internalAndRootNodeParameters;
     private CompoundParameter nodeRates;
@@ -95,7 +94,7 @@ public class ARGAddRemoveEventOperator extends AbstractCoercableOperator {
     private int tossSize = -1;
 
 
-    public ARGAddRemoveEventOperator(ARGModel arg, int weight, double size, CoercionMode mode,
+    public ARGAddRemoveEventOperator(ARGModel arg, int weight, double size, AdaptationMode mode,
                                      CompoundParameter param1,
                                      CompoundParameter param2,
                                      CompoundParameter param3,
@@ -153,7 +152,7 @@ public class ARGAddRemoveEventOperator extends AbstractCoercableOperator {
      *
      * @return the log-transformed hastings ratio
      */
-    public double doOperation() throws OperatorFailedException {
+    public double doOperation() {
         double logq = 0;
 
         try {
@@ -163,7 +162,7 @@ public class ARGAddRemoveEventOperator extends AbstractCoercableOperator {
                 logq = RemoveOperation() + size;
             }
         } catch (NoReassortmentEventException nree) {
-            throw new OperatorFailedException("");
+            throw new RuntimeException("");
         }
 
         assert !Double.isInfinite(logq) && !Double.isNaN(logq);
@@ -172,7 +171,7 @@ public class ARGAddRemoveEventOperator extends AbstractCoercableOperator {
         return logq;
     }
 
-    private double AddOperation() throws OperatorFailedException {
+    private double AddOperation() {
         double logHastings = 0;
 
 
@@ -798,7 +797,7 @@ public class ARGAddRemoveEventOperator extends AbstractCoercableOperator {
             arg.checkTreeIsValid();
         } catch (MutableTree.InvalidTreeException ite) {
             throw new RuntimeException(ite.toString() + "\n" + arg.toString()
-                    + "\n" + Tree.Utils.uniqueNewick(arg, arg.getRoot()));
+                    + "\n" + TreeUtils.uniqueNewick(arg, arg.getRoot()));
         }
 
         //Do all the backwards stuff now. :(
@@ -895,7 +894,7 @@ public class ARGAddRemoveEventOperator extends AbstractCoercableOperator {
     }
 
 
-    private double RemoveOperation() throws OperatorFailedException {
+    private double RemoveOperation() throws NoReassortmentEventException {
 
         double logHastings = 0;
 
@@ -1129,7 +1128,7 @@ public class ARGAddRemoveEventOperator extends AbstractCoercableOperator {
             arg.checkTreeIsValid();
         } catch (MutableTree.InvalidTreeException ite) {
             throw new RuntimeException(ite.toString() + "\n" + arg.toString()
-                    + "\n" + Tree.Utils.uniqueNewick(arg, arg.getRoot()));
+                    + "\n" + TreeUtils.uniqueNewick(arg, arg.getRoot()));
         }
 
         assert nodeCheck() : arg.toARGSummary();
@@ -1498,11 +1497,11 @@ public class ARGAddRemoveEventOperator extends AbstractCoercableOperator {
         this.size = size;
     }
 
-    public double getCoercableParameter() {
+    public double getAdaptableParameter() {
         return size;
     }
 
-    public void setCoercableParameter(double value) {
+    public void setAdaptableParameter(double value) {
         setSize(value);
     }
 
@@ -1510,6 +1509,11 @@ public class ARGAddRemoveEventOperator extends AbstractCoercableOperator {
         return size;
     }
 
+    @Override
+    public String getAdaptableParameterName() {
+        return null;
+    }
+
 //	public int getMode() {
 //		return mode;
 //	}
@@ -1518,21 +1522,6 @@ public class ARGAddRemoveEventOperator extends AbstractCoercableOperator {
         return 0.5;
     }
 
-
-    public String getPerformanceSuggestion() {
-        double prob = MCMCOperator.Utils.getAcceptanceProbability(this);
-//		double targetProb = getTargetAcceptanceProbability();
-
-//		double ws = OperatorUtils.optimizeWindowSize(getSize(), Double.MAX_VALUE, prob, targetProb);
-
-
-        if (prob < getMinimumGoodAcceptanceLevel()) {
-            return "Try setting addProbability closer to 0.5";
-        } else if (prob > getMaximumGoodAcceptanceLevel()) {
-            return "Try setting addProbability value closer to 0.5";
-        } else return "";
-    }
-
     public String getOperatorName() {
         return ARG_EVENT_OPERATOR;
     }
@@ -1549,16 +1538,16 @@ public class ARGAddRemoveEventOperator extends AbstractCoercableOperator {
 
         public Object parseXMLObject(XMLObject xo) throws XMLParseException {
 
-//			int mode = CoercableMCMCOperator.DEFAULT;
+//			int mode = AdaptableMCMCOperator.DEFAULT;
 //			if (xo.hasAttribute(AUTO_OPTIMIZE)) {
 //				if (xo.getBooleanAttribute(AUTO_OPTIMIZE)) {
-//					mode = CoercableMCMCOperator.COERCION_ON;
+//					mode = AdaptableMCMCOperator.ADAPTATION_ON;
 //				} else {
-//					mode = CoercableMCMCOperator.COERCION_OFF;
+//					mode = AdaptableMCMCOperator.ADAPTATION_OFF;
 //				}
 //			}
 
-            CoercionMode mode = CoercionMode.parseMode(xo);
+            AdaptationMode mode = AdaptationMode.parseMode(xo);
 
             ARGModel treeModel = (ARGModel) xo.getChild(ARGModel.class);
 
@@ -1641,7 +1630,7 @@ public class ARGAddRemoveEventOperator extends AbstractCoercableOperator {
         }
     };
 
-    private class NoReassortmentEventException extends OperatorFailedException {
+    private class NoReassortmentEventException extends Exception {
         public NoReassortmentEventException(String message) {
             super(message);
         }
