@@ -51,8 +51,8 @@ import java.util.ArrayList;
  * @author Alexei Drummond
  * @version $Id: ARGSubtreeSlideOperator.java,v 1.1.2.2 2006/11/06 01:38:30 msuchard Exp $
  */
-public class ARGSubtreeSlideOperator extends AbstractCoercableOperator {
-//		SimpleMCMCOperator implements CoercableMCMCOperator {
+public class ARGSubtreeSlideOperator extends AbstractAdaptableOperator {
+//		SimpleMCMCOperator implements AdaptableMCMCOperator {
 
 	public static final String SUBTREE_SLIDE = "argSubtreeSlide";
 	//	public static final String
@@ -66,11 +66,11 @@ public class ARGSubtreeSlideOperator extends AbstractCoercableOperator {
 	private boolean swapRates;
 	private boolean swapTraits;
 	private boolean scaledDirichletBranches;
-//	private int mode = CoercableMCMCOperator.DEFAULT;
-//	CoercionMode model;
+//	private int mode = AdaptableMCMCOperator.DEFAULT;
+//	AdaptationMode model;
 
 	public ARGSubtreeSlideOperator(ARGModel tree, int weight, double size, boolean gaussian, boolean swapRates,
-	                               boolean swapTraits, boolean scaledDirichletBranches, CoercionMode mode) {
+	                               boolean swapTraits, boolean scaledDirichletBranches, AdaptationMode mode) {
 		super(mode);
 		this.tree = tree;
 		setWeight(weight);
@@ -114,7 +114,7 @@ public class ARGSubtreeSlideOperator extends AbstractCoercableOperator {
 	 *
 	 * @return the log-transformed hastings ratio
 	 */
-	public double doOperation() throws OperatorFailedException {
+	public double doOperation() {
 
 //		System.err.println("Starting Subtree Slide Operation.");
 		double logq = 0;
@@ -180,13 +180,13 @@ public class ARGSubtreeSlideOperator extends AbstractCoercableOperator {
 				if (tree.isRoot(newChild)) {
 
 					if (true) {
-                        tree.endTreeEdit();
+						tree.endTreeEdit();
 						try {
                             tree.checkTreeIsValid();
 						} catch (MutableTree.InvalidTreeException e) {
 							e.printStackTrace();  //To change body of catch statement use File | Settings | File Templates.
 						}
-						throw new OperatorFailedException("Temporarily disable re-rooting");
+						throw new RuntimeException("Temporarily disable re-rooting");
 					}
 
 					//Parameter rootParameter = ((Node)newChild).heightParameter;
@@ -276,7 +276,7 @@ public class ARGSubtreeSlideOperator extends AbstractCoercableOperator {
 
 				// if no valid destinations then return a failure
 				if (newChildren.size() == 0) //{ return Double.NEGATIVE_INFINITY; }
-					throw new OperatorFailedException("no valid destinations");
+					throw new RuntimeException("no valid destinations");
 
 				// pick a random parent/child destination edge uniformly from options
 				int childIndex = MathUtils.nextInt(newChildren.size());
@@ -308,7 +308,7 @@ public class ARGSubtreeSlideOperator extends AbstractCoercableOperator {
 				if (tree.isRoot(iP)) {
 					// new root is CiP, but root cannot be a reassortment
 					if (!tree.isBifurcation(CiP))
-						throw new OperatorFailedException("root cannot be a reassortment");
+						throw new RuntimeException("root cannot be a reassortment");
 					boolean doubly = tree.isBifurcationDoublyLinked(newParent);
 					tree.doubleRemoveChild(iP, CiP);
 					tree.doubleRemoveChild(newParent, newChild);
@@ -421,14 +421,14 @@ public class ARGSubtreeSlideOperator extends AbstractCoercableOperator {
 		// todo fix
 		// Reject all trees in which the root is doubly-
 		if (tree.isBifurcationDoublyLinked(tree.getRoot()))
-			throw new OperatorFailedException("invalid slide");
+			throw new RuntimeException("invalid slide");
 
 		// todo -- check all ARGTree.Roots
 		if (!tree.validRoot())
-			throw new OperatorFailedException("Roots are invalid");
+			throw new RuntimeException("Roots are invalid");
 
 		if (logq == Double.NEGATIVE_INFINITY)
-			throw new OperatorFailedException("invalid slide");
+			throw new RuntimeException("invalid slide");
 //		System.err.println("Ending Subtree Slide Operation.");
 		//System.err.println("logq = "+logq);
 		//  logq = 0;
@@ -436,7 +436,7 @@ public class ARGSubtreeSlideOperator extends AbstractCoercableOperator {
 
 		if (scaledDirichletBranches) {
 			if (oldTreeHeight != tree.getNodeHeight(tree.getRoot()))
-				throw new OperatorFailedException("Temporarily disabled."); // TODO calculate Hastings ratio
+				throw new RuntimeException("Temporarily disabled."); // TODO calculate Hastings ratio
 		}
 
 
@@ -547,11 +547,11 @@ public class ARGSubtreeSlideOperator extends AbstractCoercableOperator {
 		this.size = size;
 	}
 
-	public double getCoercableParameter() {
+	public double getAdaptableParameter() {
 		return Math.log(getSize());
 	}
 
-	public void setCoercableParameter(double value) {
+	public void setAdaptableParameter(double value) {
 		setSize(Math.exp(value));
 	}
 
@@ -563,22 +563,8 @@ public class ARGSubtreeSlideOperator extends AbstractCoercableOperator {
 //		return mode;
 //	}
 
-	public double getTargetAcceptanceProbability() {
-		return 0.234;
-	}
-
-
-	public String getPerformanceSuggestion() {
-		double prob = MCMCOperator.Utils.getAcceptanceProbability(this);
-		double targetProb = getTargetAcceptanceProbability();
-
-		double ws = OperatorUtils.optimizeWindowSize(getSize(), Double.MAX_VALUE, prob, targetProb);
-
-		if (prob < getMinimumGoodAcceptanceLevel()) {
-			return "Try decreasing size to about " + ws;
-		} else if (prob > getMaximumGoodAcceptanceLevel()) {
-			return "Try increasing size to about " + ws;
-		} else return "";
+	public String getAdaptableParameterName() {
+		return "size";
 	}
 
 	public String getOperatorName() {
@@ -597,7 +583,7 @@ public class ARGSubtreeSlideOperator extends AbstractCoercableOperator {
 			boolean swapTraits = false;
 			boolean scaledDirichletBranches = false;
 
-			CoercionMode mode = CoercionMode.parseMode(xo);
+			AdaptationMode mode = AdaptationMode.parseMode(xo);
 
 			if (xo.hasAttribute(SWAP_RATES)) {
 				swapRates = xo.getBooleanAttribute(SWAP_RATES);
