@@ -35,6 +35,7 @@ package dr.evomodel.arg.operators;
 
 import dr.evolution.tree.NodeRef;
 import dr.evolution.tree.Tree;
+import dr.evolution.tree.TreeUtils;
 import dr.evomodel.arg.ARGModel;
 import dr.evomodel.arg.ARGModel.Node;
 import dr.evomodelxml.tree.TreeModelParser;
@@ -53,8 +54,8 @@ import java.util.ArrayList;
  * @author Marc Suchard
  * @version $Id: ObsoleteARGAddRemoveEventOperator.java,v 1.18.2.4 2006/11/06 01:38:30 msuchard Exp $
  */
-public class ObsoleteARGAddRemoveEventOperator extends AbstractCoercableOperator {
-//		SimpleMCMCOperator implements CoercableMCMCOperator {
+public class ObsoleteARGAddRemoveEventOperator extends AbstractAdaptableOperator {
+//		SimpleMCMCOperator implements AdaptableMCMCOperator {
 
     public static final String SUBTREE_SLIDE = "addremoveARGEvent";
     public static final String SWAP_RATES = "swapRates";
@@ -74,14 +75,14 @@ public class ObsoleteARGAddRemoveEventOperator extends AbstractCoercableOperator
     private boolean isRecombination = false;
     //   private boolean swapRates;
     //   private boolean swapTraits;
-    //	private int mode = CoercableMCMCOperator.DEFAULT;
+    //	private int mode = AdaptableMCMCOperator.DEFAULT;
     private CompoundParameter internalNodeParameters;
     private CompoundParameter internalAndRootNodeParameters;
     private CompoundParameter nodeRates;
 //	private int maxTips = 1;
 
     public ObsoleteARGAddRemoveEventOperator(ARGModel arg, int weight, double size, boolean gaussian,
-                                             boolean swapRates, boolean swapTraits, CoercionMode mode,
+                                             boolean swapRates, boolean swapTraits, AdaptationMode mode,
                                              CompoundParameter param1,
                                              CompoundParameter param2,
                                              CompoundParameter param3,
@@ -109,7 +110,7 @@ public class ObsoleteARGAddRemoveEventOperator extends AbstractCoercableOperator
      *
      * @return the log-transformed hastings ratio
      */
-    public double doOperation() throws OperatorFailedException {
+    public double doOperation() {
 //		System.err.println("Starting AddRemove Operation");
 
         double logq = 0;
@@ -118,14 +119,14 @@ public class ObsoleteARGAddRemoveEventOperator extends AbstractCoercableOperator
                 logq = AddOperation();
             else
                 logq = RemoveOperation();
-        } catch (OperatorFailedException ofe) {
+        } catch (ARGOperatorFailedException ofe) {
             if (ofe.getMessage().compareTo("No reassortment nodes to remove.") != 0) {
                 System.err.println("Catch: " + ofe.getMessage());
 //            System.exit(-1);
             }
         }
         if (arg.isBifurcationDoublyLinked(arg.getRoot()))
-            throw new OperatorFailedException("trouble with double-rooted root");
+            throw new RuntimeException("trouble with double-rooted root");
         return logq;
     }
 
@@ -230,7 +231,7 @@ public class ObsoleteARGAddRemoveEventOperator extends AbstractCoercableOperator
         }
     */
 
-    private double RemoveOperation() throws OperatorFailedException {
+    private double RemoveOperation() throws ARGOperatorFailedException {
         double logq = 0;
 
 //	    System.err.println("Starting remove ARG operation.");
@@ -241,7 +242,7 @@ public class ObsoleteARGAddRemoveEventOperator extends AbstractCoercableOperator
 
         int totalPotentials = findCurrentReassortmentNodes(potentialNodes);
         if (totalPotentials == 0)
-            throw new OperatorFailedException("No reassortment nodes to remove.");
+            throw new ARGOperatorFailedException("No reassortment nodes to remove.");
         Node recNode = (Node) potentialNodes.get(MathUtils.nextInt(totalPotentials));
         logq += Math.log(totalPotentials);
 
@@ -287,7 +288,7 @@ public class ObsoleteARGAddRemoveEventOperator extends AbstractCoercableOperator
 //                    throw new RuntimeException(ite.toString() + "\n" + arg.toString()
 //                            + "\n" + Tree.Utils.uniqueNewick(arg, arg.getRoot()));
 //                }
-                throw new OperatorFailedException("Not reversible deletion.");
+                throw new ARGOperatorFailedException("Not reversible deletion.");
             }
             if (!recParent1.bifurcation || recParent1.isRoot()) { // One orientation is valid
                 recParent1 = recNode.rightParent;
@@ -420,7 +421,7 @@ public class ObsoleteARGAddRemoveEventOperator extends AbstractCoercableOperator
         System.err.println("Checking all internal nodes (" + n + ") via tree:");
         for (int i = 0; i < n; i++) {
             NodeRef node = arg.getInternalNode(i);
-            System.err.print(Tree.Utils.uniqueNewick(arg, node) + " ");
+            System.err.print(TreeUtils.uniqueNewick(arg, node) + " ");
             System.err.println(((Node) node).getHeight());
         }
     }
@@ -644,7 +645,7 @@ public class ObsoleteARGAddRemoveEventOperator extends AbstractCoercableOperator
     }
 
 
-    private double AddOperation() throws OperatorFailedException {
+    private double AddOperation() throws ARGOperatorFailedException {
         double logq = 0;
 
 //	    System.err.println("Starting add ARG operation. ... "+arg.getReassortmentNodeCount());
@@ -655,7 +656,7 @@ public class ObsoleteARGAddRemoveEventOperator extends AbstractCoercableOperator
         if (totalPotentials == 0) {
             System.err.println("Should never get here AA");
             System.exit(-1);
-            throw new OperatorFailedException("No more nodes to recombine.");
+            throw new ARGOperatorFailedException("No more nodes to recombine.");
         }
         Node recNode = (Node) potentialNodes.get(MathUtils
                 .nextInt(totalPotentials));
@@ -677,7 +678,7 @@ public class ObsoleteARGAddRemoveEventOperator extends AbstractCoercableOperator
 //            System.err.println("Should never get here AB");
 //            System.exit(-1);
 
-            throw new OperatorFailedException("no more attachment points for this recomb");
+            throw new ARGOperatorFailedException("no more attachment points for this recomb");
         }
         Node sisNode = (Node) attachments.get(MathUtils
                 .nextInt(totalAttachments));
@@ -934,11 +935,11 @@ public class ObsoleteARGAddRemoveEventOperator extends AbstractCoercableOperator
         this.size = size;
     }
 
-    public double getCoercableParameter() {
+    public double getAdaptableParameter() {
         return Math.log(getSize());
     }
 
-    public void setCoercableParameter(double value) {
+    public void setAdaptableParameter(double value) {
         setSize(Math.exp(value));
     }
 
@@ -946,26 +947,8 @@ public class ObsoleteARGAddRemoveEventOperator extends AbstractCoercableOperator
         return getSize();
     }
 
-//	public int getMode() {
-//		return mode;
-//	}
-
-    public double getTargetAcceptanceProbability() {
-        return 0.234;
-    }
-
-
-    public String getPerformanceSuggestion() {
-        double prob = MCMCOperator.Utils.getAcceptanceProbability(this);
-        double targetProb = getTargetAcceptanceProbability();
-
-        double ws = OperatorUtils.optimizeWindowSize(getSize(), Double.MAX_VALUE, prob, targetProb);
-
-        if (prob < getMinimumGoodAcceptanceLevel()) {
-            return "Try decreasing size to about " + ws;
-        } else if (prob > getMaximumGoodAcceptanceLevel()) {
-            return "Try increasing size to about " + ws;
-        } else return "";
+    public String getAdaptableParameterName() {
+        return "size";
     }
 
     public String getOperatorName() {
@@ -986,16 +969,16 @@ public class ObsoleteARGAddRemoveEventOperator extends AbstractCoercableOperator
             double singlePartitionProbability = 0.0;
             boolean isRecombination = false;
 
-//			int mode = CoercableMCMCOperator.DEFAULT;
+//			int mode = AdaptableMCMCOperator.DEFAULT;
 //			if (xo.hasAttribute(AUTO_OPTIMIZE)) {
 //				if (xo.getBooleanAttribute(AUTO_OPTIMIZE)) {
-//					mode = CoercableMCMCOperator.COERCION_ON;
+//					mode = AdaptableMCMCOperator.ADAPTATION_ON;
 //				} else {
-//					mode = CoercableMCMCOperator.COERCION_OFF;
+//					mode = AdaptableMCMCOperator.ADAPTATION_OFF;
 //				}
 //			}
 
-            CoercionMode mode = CoercionMode.parseMode(xo);
+            AdaptationMode mode = AdaptationMode.parseMode(xo);
 
             if (xo.hasAttribute(SINGLE_PARTITION)) {
                 singlePartitionProbability = xo.getDoubleAttribute(SINGLE_PARTITION);
