@@ -34,7 +34,7 @@
 package dr.evomodel.arg.operators;
 
 import dr.evolution.tree.NodeRef;
-import dr.evolution.tree.Tree;
+import dr.evolution.tree.TreeUtils;
 import dr.evomodel.arg.ARGModel;
 import dr.evomodel.arg.ARGModel.Node;
 import dr.evomodelxml.tree.TreeModelParser;
@@ -54,8 +54,8 @@ import java.util.ArrayList;
  * @version $Id: ObsoleteARGAddRemoveEventOperator.java,v 1.18.2.4 2006/11/06 01:38:30 msuchard Exp $
  */
 
-public class ObsoleteARGNewEventOperator extends AbstractCoercableOperator {
-//		SimpleMCMCOperator implements CoercableMCMCOperator {
+public class ObsoleteARGNewEventOperator extends AbstractAdaptableOperator {
+//		SimpleMCMCOperator implements AdaptableMCMCOperator {
 
     public static final String SUBTREE_SLIDE = "newARGEvent";
     public static final String SWAP_RATES = "swapRates";
@@ -75,14 +75,14 @@ public class ObsoleteARGNewEventOperator extends AbstractCoercableOperator {
     private boolean isRecombination = false;
     //   private boolean swapRates;
     //   private boolean swapTraits;
-    //	private int mode = CoercableMCMCOperator.DEFAULT;
+    //	private int mode = AdaptableMCMCOperator.DEFAULT;
     private CompoundParameter internalNodeParameters;
     private CompoundParameter internalAndRootNodeParameters;
     private CompoundParameter nodeRates;
 //	private int maxTips = 1;
 
     public ObsoleteARGNewEventOperator(ARGModel arg, int weight, double size, boolean gaussian,
-                                       boolean swapRates, boolean swapTraits, CoercionMode mode,
+                                       boolean swapRates, boolean swapTraits, AdaptationMode mode,
                                        CompoundParameter param1,
                                        CompoundParameter param2,
                                        CompoundParameter param3,
@@ -110,7 +110,7 @@ public class ObsoleteARGNewEventOperator extends AbstractCoercableOperator {
      *
      * @return the log-transformed hastings ratio
      */
-    public double doOperation() throws OperatorFailedException {
+    public double doOperation() {
 //		System.err.println("Starting AddRemove Operation");
 
         double logq = 0;
@@ -157,7 +157,7 @@ public class ObsoleteARGNewEventOperator extends AbstractCoercableOperator {
         return count;
     }
 
-    private double RemoveOperation() throws OperatorFailedException {
+    private double RemoveOperation() throws ARGOperatorFailedException {
         double logq = 0;
 
 //	    System.err.println("Starting remove ARG operation.");
@@ -169,7 +169,7 @@ public class ObsoleteARGNewEventOperator extends AbstractCoercableOperator {
 
         int totalPotentials = findPotentialNodesToRemove(potentialNodes);
         if (totalPotentials == 0)
-            throw new OperatorFailedException("No reassortment nodes to remove.");
+            throw new ARGOperatorFailedException("No reassortment nodes to remove.");
 //	    System.err.println("potentials exist!");
         Node recNode = (Node) potentialNodes.get(MathUtils.nextInt(totalPotentials));
 //        logq += Math.log(totalPotentials);
@@ -327,7 +327,7 @@ public class ObsoleteARGNewEventOperator extends AbstractCoercableOperator {
         System.err.println("Checking all internal nodes (" + n + ") via tree:");
         for (int i = 0; i < n; i++) {
             NodeRef node = arg.getInternalNode(i);
-            System.err.print(Tree.Utils.uniqueNewick(arg, node) + " ");
+            System.err.print(TreeUtils.uniqueNewick(arg, node) + " ");
             System.err.println(((Node) node).getHeight());
         }
     }
@@ -420,7 +420,7 @@ public class ObsoleteARGNewEventOperator extends AbstractCoercableOperator {
     }
 
 
-    private double AddOperation() throws OperatorFailedException {
+    private double AddOperation() throws ARGOperatorFailedException {
 
         double logq = 0;
 
@@ -625,11 +625,11 @@ public class ObsoleteARGNewEventOperator extends AbstractCoercableOperator {
         this.size = size;
     }
 
-    public double getCoercableParameter() {
+    public double getAdaptableParameter() {
         return Math.log(getSize());
     }
 
-    public void setCoercableParameter(double value) {
+    public void setAdaptableParameter(double value) {
         setSize(Math.exp(value));
     }
 
@@ -641,22 +641,8 @@ public class ObsoleteARGNewEventOperator extends AbstractCoercableOperator {
 //		return mode;
 //	}
 
-    public double getTargetAcceptanceProbability() {
-        return 0.234;
-    }
-
-
-    public String getPerformanceSuggestion() {
-        double prob = MCMCOperator.Utils.getAcceptanceProbability(this);
-        double targetProb = getTargetAcceptanceProbability();
-
-        double ws = OperatorUtils.optimizeWindowSize(getSize(), Double.MAX_VALUE, prob, targetProb);
-
-        if (prob < getMinimumGoodAcceptanceLevel()) {
-            return "Try decreasing size to about " + ws;
-        } else if (prob > getMaximumGoodAcceptanceLevel()) {
-            return "Try increasing size to about " + ws;
-        } else return "";
+    public String getAdaptableParameterName() {
+        return "size";
     }
 
     public String getOperatorName() {
@@ -677,14 +663,14 @@ public class ObsoleteARGNewEventOperator extends AbstractCoercableOperator {
             double singlePartitionProbability = 0.0;
             boolean isRecombination = false;
 
-            CoercionMode mode = CoercionMode.parseMode(xo);
+            AdaptationMode mode = AdaptationMode.parseMode(xo);
 
-//			int mode = CoercableMCMCOperator.DEFAULT;
+//			int mode = AdaptableMCMCOperator.DEFAULT;
 //			if (xo.hasAttribute(AUTO_OPTIMIZE)) {
 //				if (xo.getBooleanAttribute(AUTO_OPTIMIZE)) {
-//					mode = CoercableMCMCOperator.COERCION_ON;
+//					mode = AdaptableMCMCOperator.ADAPTATION_ON;
 //				} else {
-//					mode = CoercableMCMCOperator.COERCION_OFF;
+//					mode = AdaptableMCMCOperator.ADAPTATION_OFF;
 //				}
 //			}
 
