@@ -28,6 +28,7 @@ package dr.evomodel.branchratemodel;
 import dr.evolution.tree.NodeRef;
 import dr.evolution.tree.Tree;
 import dr.evolution.tree.TreeTrait;
+import dr.evolution.tree.TreeUtils;
 import dr.evolution.util.TaxonList;
 import dr.evomodel.tree.TreeModel;
 import dr.evomodelxml.branchratemodel.LocalClockModelParser;
@@ -72,8 +73,8 @@ public class LocalClockModel extends AbstractBranchRateModel implements Citable
 
     }
 
-    public void addExternalBranchClock(TaxonList taxonList, Parameter rateParameter, boolean isRelativeRate) throws Tree.MissingTaxonException {
-        Set<Integer> tips = Tree.Utils.getTipsForTaxa(treeModel, taxonList);
+    public void addExternalBranchClock(TaxonList taxonList, Parameter rateParameter, boolean isRelativeRate) throws TreeUtils.MissingTaxonException {
+        Set<Integer> tips = TreeUtils.getTipsForTaxa(treeModel, taxonList);
         LocalClock clock = new LocalClock(rateParameter, isRelativeRate, tips, ClockType.EXTERNAL);
         for (int i : tips) {
             localTipClocks.put(i, clock);
@@ -81,20 +82,20 @@ public class LocalClockModel extends AbstractBranchRateModel implements Citable
         addVariable(rateParameter);
     }
 
-    public void addCladeClock(TaxonList taxonList, Parameter rateParameter, boolean isRelativeRate, double stemProportion, boolean excludeClade) throws Tree.MissingTaxonException {
-        Set<Integer> tips = Tree.Utils.getTipsForTaxa(treeModel, taxonList);
-        BitSet tipBitSet = Tree.Utils.getTipsBitSetForTaxa(treeModel, taxonList);
+    public void addCladeClock(TaxonList taxonList, Parameter rateParameter, boolean isRelativeRate, double stemProportion, boolean excludeClade) throws TreeUtils.MissingTaxonException {
+        Set<Integer> tips = TreeUtils.getTipsForTaxa(treeModel, taxonList);
+        BitSet tipBitSet = TreeUtils.getTipsBitSetForTaxa(treeModel, taxonList);
         LocalClock clock = new LocalClock(rateParameter, isRelativeRate, tips, stemProportion, excludeClade);
         localCladeClocks.put(tipBitSet, clock);
         addVariable(rateParameter);
     }
 
-    public void addTrunkClock(TaxonList taxonList, Parameter rateParameter, Parameter indexParameter, boolean isRelativeRate) throws Tree.MissingTaxonException {
+    public void addTrunkClock(TaxonList taxonList, Parameter rateParameter, Parameter indexParameter, boolean isRelativeRate) throws TreeUtils.MissingTaxonException {
         if (trunkClock != null) {
             throw new RuntimeException("Trunk already defined for this LocalClockModel");
         }
 
-        List<Integer> tipList = new ArrayList<Integer>(Tree.Utils.getTipsForTaxa(treeModel, taxonList));
+        List<Integer> tipList = new ArrayList<Integer>(TreeUtils.getTipsForTaxa(treeModel, taxonList));
         trunkClock = new LocalClock(rateParameter, indexParameter, isRelativeRate, tipList, ClockType.TRUNK);
         addVariable(rateParameter);
         if (indexParameter != null) {
@@ -197,6 +198,10 @@ public class LocalClockModel extends AbstractBranchRateModel implements Citable
         return rate;
     }
 
+    /**
+     * Set up the map from node to clock.
+     * @param tree
+     */
     private void setupNodeClocks(final Tree tree) {
         if (updateNodeClocks) {
             nodeClockMap.clear();
@@ -212,6 +217,14 @@ public class LocalClockModel extends AbstractBranchRateModel implements Citable
 
     }
 
+    /**
+     * Traverse the tree getting bitsets for each node based on the tips below. If this
+     * bitset is in the localCladeClocks map then set that clock for all the nodes below.
+     * Pre-order traversal so shallowest clades are set first.
+     * @param tree
+     * @param node
+     * @param tips
+     */
     private void setupRateParameters(Tree tree, NodeRef node, BitSet tips) {
         LocalClock clock;
 
@@ -230,7 +243,7 @@ public class LocalClockModel extends AbstractBranchRateModel implements Citable
         }
 
         if (clock != null) {
-            setNodeClock(tree, node, clock, clock.getStemProportion(), clock.excludeClade());
+            setNodeClock(tree, node, clock, clock.excludeClade());
         }
     }
 
@@ -256,23 +269,30 @@ public class LocalClockModel extends AbstractBranchRateModel implements Citable
         }
 
         if (clock != null) {
-            setNodeClock(tree, node, clock, clock.getStemProportion(), clock.excludeClade());
+            setNodeClock(tree, node, clock, clock.excludeClade());
             return true;
         }
 
         return false;
     }
 
-    private void setNodeClock(Tree tree, NodeRef node, LocalClock localClock, double stemProportion, boolean excludeClade) {
+    /**
+     * Traverse down the clade, associating all the nodes with the specified clock.
+     * @param tree
+     * @param node
+     * @param localClock
+     * @param excludeClade
+     */
+    private void setNodeClock(Tree tree, NodeRef node, LocalClock localClock, boolean excludeClade) {
 
         if (!tree.isExternal(node) && !excludeClade) {
             for (int i = 0; i < tree.getChildCount(node); i++) {
                 NodeRef child = tree.getChild(node, i);
-                setNodeClock(tree, child, localClock, 1.0, false);
+                setNodeClock(tree, child, localClock, false);
             }
         }
 
-        if (stemProportion > 0.0 && !nodeClockMap.containsKey(node)) {
+        if (!nodeClockMap.containsKey(node)) {
             nodeClockMap.put(node, localClock);
         }
     }
