@@ -29,6 +29,12 @@ import dr.evolution.coalescent.CataclysmicDemographic;
 import dr.evolution.coalescent.DemographicFunction;
 import dr.evomodelxml.coalescent.CataclysmicDemographicModelParser;
 import dr.inference.model.Parameter;
+import dr.util.Author;
+import dr.util.Citable;
+import dr.util.Citation;
+
+import java.util.Collections;
+import java.util.List;
 
 /**
  * This class models an exponentially growing model that suffers a
@@ -39,20 +45,22 @@ import dr.inference.model.Parameter;
  * @author Andrew Rambaut
  * @version $Id: CataclysmicDemographicModel.java,v 1.6 2005/05/24 20:25:57 rambaut Exp $
  */
-public class CataclysmicDemographicModel extends DemographicModel {
+public class CataclysmicDemographicModel extends DemographicModel implements Citable {
 
     /**
      * Construct demographic model with default settings
      */
-    public CataclysmicDemographicModel(Parameter N0Parameter, Parameter N1Parameter, Parameter growthRateParameter, Parameter timeParameter, Type units) {
+    public CataclysmicDemographicModel(Parameter N0Parameter, Parameter N1Parameter, Parameter growthRateParameter, Parameter timeParameter,
+                Type units, boolean useSpike) {
 
-        this(CataclysmicDemographicModelParser.CATACLYSM_MODEL, N0Parameter, N1Parameter, growthRateParameter, timeParameter, units);
+        this(CataclysmicDemographicModelParser.CATACLYSM_MODEL, N0Parameter, N1Parameter, growthRateParameter, timeParameter, units, useSpike);
     }
 
     /**
      * Construct demographic model with default settings
      */
-    public CataclysmicDemographicModel(String name, Parameter N0Parameter, Parameter N1Parameter, Parameter growthRateParameter, Parameter timeParameter, Type units) {
+    public CataclysmicDemographicModel(String name, Parameter N0Parameter, Parameter secondParam, Parameter growthRateParameter,
+                Parameter timeParameter, Type units, boolean useSpike) {
 
         super(name);
 
@@ -62,9 +70,14 @@ public class CataclysmicDemographicModel extends DemographicModel {
         addVariable(N0Parameter);
         N0Parameter.addBounds(new Parameter.DefaultBounds(Double.POSITIVE_INFINITY, 0.0, 1));
 
-        this.N1Parameter = N1Parameter;
-        addVariable(N1Parameter);
-        N1Parameter.addBounds(new Parameter.DefaultBounds(Double.POSITIVE_INFINITY, 0.0, 1));
+        if (useSpike) {
+            this.N1Parameter = secondParam;
+            N1Parameter.addBounds(new Parameter.DefaultBounds(Double.POSITIVE_INFINITY, 0.0, 1));
+            addVariable(N1Parameter);
+        } else {
+            this.declineRateParameter = secondParam;
+            addVariable(declineRateParameter);
+        }
 
         this.growthRateParameter = growthRateParameter;
         addVariable(growthRateParameter);
@@ -95,10 +108,10 @@ public class CataclysmicDemographicModel extends DemographicModel {
           */ // ..collapse to...
 
         double t = timeParameter.getParameterValue(0);
-        double declineRate = Math.log(N1Parameter.getParameterValue(0)) / t;
+        double declineRate = (declineRateParameter == null) ? Math.log(N1Parameter.getParameterValue(0)) / t :
+                declineRateParameter.getParameterValue(0);
         cataclysm.setDeclineRate(declineRate);
 
-
         return cataclysm;
     }
 
@@ -110,5 +123,32 @@ public class CataclysmicDemographicModel extends DemographicModel {
     Parameter N1Parameter = null;
     Parameter growthRateParameter = null;
     Parameter timeParameter = null;
+    Parameter declineRateParameter = null;
     CataclysmicDemographic cataclysm = null;
+
+    @Override
+    public Citation.Category getCategory() {
+        return Citation.Category.TREE_PRIORS;
+    }
+
+    @Override
+    public String getDescription() {
+        return "Boom-Bust Coalescent";
+    }
+
+    @Override
+    public List<Citation> getCitations() {
+        return Collections.singletonList(CITATION);
+    }
+
+    public static Citation CITATION = new Citation(
+            new Author[]{
+                    new Author("B", "Shapiro"),
+                    new Author("", "et al.")
+            },
+            "Rise and fall of the Beringian steppe bison",
+            2004,
+            "Science",
+            306, 1561, 1565
+    );
 }
