@@ -29,6 +29,12 @@ import dr.evolution.coalescent.ConstLogistic;
 import dr.evolution.coalescent.DemographicFunction;
 import dr.evomodelxml.coalescent.ConstantLogisticModelParser;
 import dr.inference.model.Parameter;
+import dr.util.Author;
+import dr.util.Citable;
+import dr.util.Citation;
+
+import java.util.Collections;
+import java.util.List;
 
 /**
  * Logistic growth from a constant ancestral population size.
@@ -37,7 +43,7 @@ import dr.inference.model.Parameter;
  * @author Andrew Rambaut
  * @version $Id: ConstantLogisticModel.java,v 1.7 2005/04/11 11:24:39 alexei Exp $
  */
-public class ConstantLogisticModel extends DemographicModel {
+public class ConstantLogisticModel extends DemographicModel implements Citable {
 
     //
     // Public stuff
@@ -112,4 +118,30 @@ public class ConstantLogisticModel extends DemographicModel {
     private Parameter shapeParameter = null;
     private double alpha = 0.5;
     private ConstLogistic constLogistic = null;
+
+    @Override
+    public Citation.Category getCategory() {
+        return Citation.Category.TREE_PRIORS;
+    }
+
+    @Override
+    public String getDescription() {
+        return "Constant-Logistic Coalescent";
+    }
+
+    @Override
+    public List<Citation> getCitations() {
+        return Collections.singletonList(CITATION);
+    }
+
+    public static Citation CITATION = new Citation(
+            new Author[]{
+                    new Author("OG", "Pybus"),
+                    new Author("A", "Rambaut")
+            },
+            "GENIE: estimating demographic history from molecular phylogenies",
+            2001,
+            "Bioinformatics",
+            18, 1404, 1405
+    );
 }
