@@ -29,6 +29,12 @@ import dr.evolution.coalescent.DemographicFunction;
 import dr.evolution.coalescent.ExpConstExpDemographic;
 import dr.evomodelxml.coalescent.ExpConstExpDemographicModelParser;
 import dr.inference.model.Parameter;
+import dr.util.Author;
+import dr.util.Citable;
+import dr.util.Citation;
+
+import java.util.Collections;
+import java.util.List;
 
 /**
  * This class models a two growth-phase demographic with a plateau in the middle
@@ -37,7 +43,7 @@ import dr.inference.model.Parameter;
  * @author Andrew Rambaut
  * @version $Id: ExpConstExpDemographicModel.java,v 1.2 2006/08/18 07:44:25 alexei Exp $
  */
-public class ExpConstExpDemographicModel extends DemographicModel {
+public class ExpConstExpDemographicModel extends DemographicModel implements Citable {
 
     //
     // Public stuff
@@ -132,4 +138,30 @@ public class ExpConstExpDemographicModel extends DemographicModel {
     Parameter timeParameter = null;
     Parameter relTimeParameter = null;
     ExpConstExpDemographic expConstExp = null;
+
+    @Override
+    public Citation.Category getCategory() {
+        return Citation.Category.TREE_PRIORS;
+    }
+
+    @Override
+    public String getDescription() {
+        return "Exponential-Constant-Exponential Coalescent";
+    }
+
+    @Override
+    public List<Citation> getCitations() {
+        return Collections.singletonList(CITATION);
+    }
+
+    public static Citation CITATION = new Citation(
+            new Author[]{
+                    new Author("OG", "Pybus"),
+                    new Author("A", "Rambaut")
+            },
+            "GENIE: estimating demographic history from molecular phylogenies",
+            2001,
+            "Bioinformatics",
+            18, 1404, 1405
+    );
 }
