@@ -27,11 +27,13 @@ package dr.evomodel.coalescent.operators;
 
 import dr.evomodel.coalescent.GMRFMultilocusSkyrideLikelihood;
 import dr.evomodelxml.coalescent.operators.GMRFSkyrideBlockUpdateOperatorParser;
+import dr.inference.model.MatrixParameter;
 import dr.inference.model.Parameter;
 import dr.inference.operators.*;
 import dr.math.MathUtils;
 import no.uib.cipr.matrix.*;
 
+import java.util.List;
 import java.util.logging.Logger;
 
 /* A Metropolis-Hastings operator to update the log population sizes and precision parameter jointly under a Gaussian Markov random field prior
@@ -41,7 +43,9 @@ import java.util.logging.Logger;
  * @author Mandev Gill
  * @version $Id: GMRFMultilocusSkylineBlockUpdateOperator.java,v 1.5 2007/03/20 11:26:49 msuchard Exp $
  */
-public class GMRFMultilocusSkyrideBlockUpdateOperator extends AbstractCoercableOperator {
+public class GMRFMultilocusSkyrideBlockUpdateOperator extends AbstractAdaptableOperator {
+
+    private static boolean FAIL_SILENTLY = true;
 
     private double scaleFactor;
     private double lambdaScaleFactor;
@@ -53,19 +57,23 @@ public class GMRFMultilocusSkyrideBlockUpdateOperator extends AbstractCoercableO
     private Parameter popSizeParameter;
     private Parameter precisionParameter;
     private Parameter lambdaParameter;
+    private List<Parameter> betaParameter;
+    private List<MatrixParameter> covariates;
 
     GMRFMultilocusSkyrideLikelihood gmrfField;
 
     private double[] zeros;
 
     public GMRFMultilocusSkyrideBlockUpdateOperator(GMRFMultilocusSkyrideLikelihood gmrfLikelihood,
-                                          double weight, CoercionMode mode, double scaleFactor,
-                                          int maxIterations, double stopValue) {
+                                                    double weight, AdaptationMode mode, double scaleFactor,
+                                                    int maxIterations, double stopValue) {
         super(mode);
         gmrfField = gmrfLikelihood;
         popSizeParameter = gmrfLikelihood.getPopSizeParameter();
         precisionParameter = gmrfLikelihood.getPrecisionParameter();
         lambdaParameter = gmrfLikelihood.getLambdaParameter();
+        betaParameter = gmrfLikelihood.getBetaListParameter();
+        covariates = gmrfLikelihood.getCovariates();
 
         this.scaleFactor = scaleFactor;
         lambdaScaleFactor = 0.0;
@@ -174,13 +182,38 @@ public class GMRFMultilocusSkyrideBlockUpdateOperator extends AbstractCoercableO
 
         return returnValue;
     }
-   
-    public DenseVector newtonRaphson(double[] data1, double[] data2, DenseVector currentGamma, SymmTridiagMatrix proposedQ) throws OperatorFailedException {
-        return newNewtonRaphson(data1, data2, currentGamma, proposedQ, maxIterations, stopValue);
+
+    public DenseVector getZBeta(List<MatrixParameter> covariates, List<Parameter> beta){
+
+        DenseVector temporaryVect = new DenseVector(fieldLength);
+
+        // TODO: Update for covariateMatrix block as well !!!
+
+        if(covariates != null) {
+           // DenseVector currentBeta = new DenseVector(beta.getParameterValues());
+            DenseVector currentBeta = new DenseVector(beta.size());
+            for(int i =0; i < beta.size(); i++){
+                currentBeta.set(i, beta.get(i).getParameterValue(0));
+            }
+
+            for (int i = 0; i < covariates.size(); i++) {
+                for (int j = 0; j < covariates.get(i).getColumnDimension(); j++) {
+                    temporaryVect.set(j, covariates.get(i).getParameterValue(0, j) * currentBeta.get(i));
+                }
+            }
+            return temporaryVect;
+        }else{
+            return temporaryVect.zero();
+        }
+    }
+
+    public DenseVector newtonRaphson(double[] data1, double[] data2, DenseVector currentGamma,
+                                     SymmTridiagMatrix proposedQ, DenseVector ZBeta) {
+        return newNewtonRaphson(data1, data2, currentGamma, proposedQ, maxIterations, stopValue, ZBeta);
     }
 
     public static DenseVector newNewtonRaphson(double[] data1, double[] data2, DenseVector currentGamma, SymmTridiagMatrix proposedQ,
-                                               int maxIterations, double stopValue) throws OperatorFailedException {
+                                               int maxIterations, double stopValue, DenseVector ZBeta) {
 
         DenseVector iterateGamma = currentGamma.copy();
         DenseVector tempValue = currentGamma.copy();
@@ -188,23 +221,37 @@ public class GMRFMultilocusSkyrideBlockUpdateOperator extends AbstractCoercableO
         int numberIterations = 0;
 
 
-        while (gradient(data1, data2, iterateGamma, proposedQ).norm(Vector.Norm.Two) > stopValue) {
+        while (gradient(data1, data2, iterateGamma, proposedQ, ZBeta).norm(Vector.Norm.Two) > stopValue) {
            try {
-                jacobian(data2, iterateGamma, proposedQ).solve(gradient(data1, data2, iterateGamma, proposedQ), tempValue);
+                jacobian(data2, iterateGamma, proposedQ).solve(gradient(data1, data2, iterateGamma, proposedQ, ZBeta), tempValue);
            } catch (no.uib.cipr.matrix.MatrixNotSPDException e) {
-                Logger.getLogger("dr.evomodel.coalescent.operators.GMRFMultilocusSkyrideBlockUpdateOperator").fine("Newton-Raphson F");
-                throw new OperatorFailedException("");
-            } catch (no.uib.cipr.matrix.MatrixSingularException e) {
-                Logger.getLogger("dr.evomodel.coalescent.operators.GMRFMultilocusSkyrideBlockUpdateOperator").fine("Newton-Raphson F");
-                throw new OperatorFailedException("");
-            }     
+               if (FAIL_SILENTLY) {
+                   // this replicates the old behaviour of throwing an OperatorFailedException and rejecting the move.
+                   return null;
+               }
+               Logger.getLogger("dr.evomodel.coalescent.operators.GMRFMultilocusSkyrideBlockUpdateOperator").fine("Newton-Raphson F");
+               throw new RuntimeException("Newton Raphson algorithm did not converge within " + maxIterations + " step to a norm less than " + stopValue + "\n" +
+                       "Try starting BEAST with a more accurate initial tree.");
+           } catch (no.uib.cipr.matrix.MatrixSingularException e) {
+               if (FAIL_SILENTLY) {
+                   // this replicates the old behaviour of throwing an OperatorFailedException and rejecting the move.
+                   return null;
+               }
+               Logger.getLogger("dr.evomodel.coalescent.operators.GMRFMultilocusSkyrideBlockUpdateOperator").fine("Newton-Raphson F");
+               throw new RuntimeException("Newton Raphson algorithm did not converge within " + maxIterations + " step to a norm less than " + stopValue + "\n" +
+                       "Try starting BEAST with a more accurate initial tree.");
+            }
 
             iterateGamma.add(tempValue);
             numberIterations++;
 
             if (numberIterations > maxIterations) {
+                if (FAIL_SILENTLY) {
+                    // this replicates the old behaviour of throwing an OperatorFailedException and rejecting the move.
+                    return null;
+                }
                 Logger.getLogger("dr.evomodel.coalescent.operators.GMRFMultilocusSkyrideBlockUpdateOperator").fine("Newton-Raphson F");
-                throw new OperatorFailedException("Newton Raphson algorithm did not converge within " + maxIterations + " step to a norm less than " + stopValue + "\n" +
+                throw new RuntimeException("Newton Raphson algorithm did not converge within " + maxIterations + " step to a norm less than " + stopValue + "\n" +
                         "Try starting BEAST with a more accurate initial tree.");
             }
         }
@@ -214,12 +261,16 @@ public class GMRFMultilocusSkyrideBlockUpdateOperator extends AbstractCoercableO
 
     }
 
-    private static DenseVector gradient(double[] data1, double[] data2, DenseVector value, SymmTridiagMatrix Q) {
+    private static DenseVector gradient(double[] data1, double[] data2, DenseVector value,
+                                        SymmTridiagMatrix Q, DenseVector ZBeta) {
 
         DenseVector returnValue = new DenseVector(value.size());
+        DenseVector returnValueCov = new DenseVector(ZBeta.size());
         Q.mult(value, returnValue);
+        //check this
+        Q.mult(ZBeta, returnValueCov);
         for (int i = 0; i < value.size(); i++) {
-            returnValue.set(i, -returnValue.get(i) - data1[i] + data2[i] * Math.exp(-value.get(i)));
+            returnValue.set(i, -returnValue.get(i) +returnValueCov.get(i) - data1[i] + data2[i] * Math.exp(-value.get(i)));
         }
         return returnValue;
     }
@@ -233,7 +284,7 @@ public class GMRFMultilocusSkyrideBlockUpdateOperator extends AbstractCoercableO
         return jacobian;
     }
 
-    public double doOperation() throws OperatorFailedException {
+    public double doOperation() {
 
         double currentPrecision = precisionParameter.getParameterValue(0);
         double proposedPrecision = this.getNewPrecision(currentPrecision, scaleFactor);
@@ -262,16 +313,26 @@ public class GMRFMultilocusSkyrideBlockUpdateOperator extends AbstractCoercableO
         DenseVector diagonal1 = new DenseVector(fieldLength);
         DenseVector diagonal2 = new DenseVector(fieldLength);
         DenseVector diagonal3 = new DenseVector(fieldLength);
+        DenseVector ZBetaVector = getZBeta(covariates, betaParameter);
+        DenseVector QZBetaProp = new DenseVector(fieldLength);
+        DenseVector QZBetaCurrent = new DenseVector(fieldLength);
+        forwardQW.mult(ZBetaVector, QZBetaProp);
+        backwardQW.mult(ZBetaVector, QZBetaCurrent);
+
+        DenseVector modeForward = newtonRaphson(numCoalEv, wNative, currentGamma, proposedQ.copy(), ZBetaVector);
+
+        if (modeForward == null) {
+            // used to pass on an OperatorFailedException
+            return Double.NEGATIVE_INFINITY;
+        }
 
-        DenseVector modeForward = newtonRaphson(numCoalEv, wNative, currentGamma, proposedQ.copy());
-       
         for (int i = 0; i < fieldLength; i++) {
             diagonal1.set(i, wNative[i] * Math.exp(-modeForward.get(i)));
             diagonal2.set(i, modeForward.get(i) + 1);
 
             forwardQW.set(i, i, diagonal1.get(i) + forwardQW.get(i, i));
             //diagonal1.set(i, diagonal1.get(i) * diagonal2.get(i) - 1);
-            diagonal1.set(i, diagonal1.get(i) * diagonal2.get(i) - numCoalEv[i]);
+            diagonal1.set(i, QZBetaProp.get(i) + diagonal1.get(i) * diagonal2.get(i) - numCoalEv[i]);
         }
 
         forwardCholesky.factor(forwardQW.copy());
@@ -308,7 +369,12 @@ public class GMRFMultilocusSkyrideBlockUpdateOperator extends AbstractCoercableO
         diagonal2.zero();
         diagonal3.zero();
 
-        DenseVector modeBackward = newtonRaphson(numCoalEv, wNative, proposedGamma, currentQ.copy());
+        DenseVector modeBackward = newtonRaphson(numCoalEv, wNative, proposedGamma, currentQ.copy(), ZBetaVector);
+
+        if (modeBackward == null) {
+            // used to pass on an OperatorFailedException
+            return Double.NEGATIVE_INFINITY;
+        }
 
         for (int i = 0; i < fieldLength; i++) {
             diagonal1.set(i, wNative[i] * Math.exp(-modeBackward.get(i)));
@@ -316,7 +382,7 @@ public class GMRFMultilocusSkyrideBlockUpdateOperator extends AbstractCoercableO
 
             backwardQW.set(i, i, diagonal1.get(i) + backwardQW.get(i, i));
             //diagonal1.set(i, diagonal1.get(i) * diagonal2.get(i) - 1);
-            diagonal1.set(i, diagonal1.get(i) * diagonal2.get(i) - numCoalEv[i]);
+            diagonal1.set(i, QZBetaCurrent.get(i) + diagonal1.get(i) * diagonal2.get(i) - numCoalEv[i]);
         }
 
         backwardCholesky.factor(backwardQW.copy());
@@ -341,12 +407,12 @@ public class GMRFMultilocusSkyrideBlockUpdateOperator extends AbstractCoercableO
         return GMRFSkyrideBlockUpdateOperatorParser.BLOCK_UPDATE_OPERATOR;
     }
 
-    public double getCoercableParameter() {
+    public double getAdaptableParameter() {
 //        return Math.log(scaleFactor);
         return Math.sqrt(scaleFactor - 1);
     }
 
-    public void setCoercableParameter(double value) {
+    public void setAdaptableParameter(double value) {
 //        scaleFactor = Math.exp(value);
         scaleFactor = 1 + value * value;
     }
@@ -359,39 +425,8 @@ public class GMRFMultilocusSkyrideBlockUpdateOperator extends AbstractCoercableO
         return scaleFactor;
     }
 
-    public double getTargetAcceptanceProbability() {
-        return 0.234;
-    }
-
-    public double getMinimumAcceptanceLevel() {
-        return 0.1;
-    }
-
-    public double getMaximumAcceptanceLevel() {
-        return 0.4;
-    }
-
-    public double getMinimumGoodAcceptanceLevel() {
-        return 0.20;
-    }
-
-    public double getMaximumGoodAcceptanceLevel() {
-        return 0.30;
-    }
-
-    public final String getPerformanceSuggestion() {
-
-        double prob = MCMCOperator.Utils.getAcceptanceProbability(this);
-        double targetProb = getTargetAcceptanceProbability();
-        dr.util.NumberFormatter formatter = new dr.util.NumberFormatter(5);
-
-        double sf = OperatorUtils.optimizeWindowSize(scaleFactor, prob, targetProb);
-
-        if (prob < getMinimumGoodAcceptanceLevel()) {
-            return "Try setting scaleFactor to about " + formatter.format(sf);
-        } else if (prob > getMaximumGoodAcceptanceLevel()) {
-            return "Try setting scaleFactor to about " + formatter.format(sf);
-        } else return "";
+    public String getAdaptableParameterName() {
+        return "scaleFactor";
     }
 
 
