@@ -26,7 +26,6 @@
 package dr.evomodel.coalescent.structure;
 
 import dr.evolution.colouring.ColourSampler;
-import dr.inference.operators.OperatorFailedException;
 import dr.inference.operators.SimpleMCMCOperator;
 import dr.xml.*;
 
@@ -35,6 +34,7 @@ import dr.xml.*;
  *
  * @version $Id: TreeColouringOperator.java,v 1.8 2006/08/12 12:55:44 gerton Exp $
  */
+@Deprecated
 public class TreeColouringOperator extends SimpleMCMCOperator {
 
     public static final String TREE_COLOURING_OPERATOR = "treeColouringOperator";
@@ -63,7 +63,7 @@ public class TreeColouringOperator extends SimpleMCMCOperator {
      *
      * @return the hastings ratio
      */
-    public double doOperation() throws OperatorFailedException {
+    public double doOperation() {
 
         double logP = colouringModel.getTreeColouringWithProbability().getLogProbabilityDensity();
 
