@@ -28,7 +28,10 @@ package dr.evomodel.continuous;
 import dr.evolution.tree.*;
 import dr.evolution.util.Taxon;
 import dr.evomodel.branchratemodel.BranchRateModel;
+import dr.evomodel.branchratemodel.StrictClockBranchRates;
+import dr.evomodel.tree.TreeChangedEvent;
 import dr.evomodel.tree.TreeModel;
+import dr.evomodelxml.treedatalikelihood.ContinuousDataLikelihoodParser;
 import dr.evomodelxml.treelikelihood.TreeTraitParserUtilities;
 import dr.inference.distribution.MultivariateDistributionLikelihood;
 import dr.inference.loggers.LogColumn;
@@ -80,7 +83,7 @@ public abstract class AbstractMultivariateTraitLikelihood extends AbstractModelL
     public static final String OPTIMAL_TRAITS = "optimalTraits";
 
 //    public AbstractMultivariateTraitLikelihood(String traitName,
-//                                               MultivariateTraitTree treeModel,
+//                                               MutableTreeModel treeModel,
 //                                               MultivariateDiffusionModel diffusionModel,
 //                                               CompoundParameter traitParameter,
 //                                               List<Integer> missingIndices,
@@ -96,7 +99,7 @@ public abstract class AbstractMultivariateTraitLikelihood extends AbstractModelL
 //    }
 
     public AbstractMultivariateTraitLikelihood(String traitName,
-                                               MultivariateTraitTree treeModel,
+                                               MutableTreeModel treeModel,
                                                MultivariateDiffusionModel diffusionModel,
                                                CompoundParameter traitParameter,
                                                Parameter deltaParameter,
@@ -186,7 +189,7 @@ public abstract class AbstractMultivariateTraitLikelihood extends AbstractModelL
     }
 
 //    public AbstractMultivariateTraitLikelihood(String traitName,
-//                                               MultivariateTraitTree treeModel,
+//                                               MutableTreeModel treeModel,
 //                                               MultivariateDiffusionModel diffusionModel,
 //                                               CompoundParameter traitParameter,
 //                                               Parameter deltaParameter,
@@ -382,6 +385,13 @@ public abstract class AbstractMultivariateTraitLikelihood extends AbstractModelL
         }
     }
 
+    protected double rescaleLength(double length) {
+        if (scaleByTime) {
+            length /= treeLength;
+        }
+        return length;
+    }
+
     public double getRescaledBranchLengthForPrecision(NodeRef node) {
 
         double length = treeModel.getBranchLength(node);
@@ -394,9 +404,10 @@ public abstract class AbstractMultivariateTraitLikelihood extends AbstractModelL
             }
         }
 
-        if (scaleByTime) {
-            length /= treeLength;
-        }
+//        if (scaleByTime) {
+//            length /= treeLength;
+//        }
+        length = rescaleLength(length);
 
         if (deltaParameter != null && treeModel.isExternal(node)) {
             length += deltaParameter.getParameterValue(0);
@@ -421,6 +432,7 @@ public abstract class AbstractMultivariateTraitLikelihood extends AbstractModelL
 
         if (!cacheBranches) {
             likelihoodKnown = false;
+            updateRestrictedNodePartials = true;
             if (model == treeModel)
                 recalculateTreeLength();
             return;
@@ -434,11 +446,12 @@ public abstract class AbstractMultivariateTraitLikelihood extends AbstractModelL
         // ignoring object instance Parameter case
 
         else if (model == treeModel) {
-            if (object instanceof TreeModel.TreeChangedEvent) {
-                TreeModel.TreeChangedEvent event = (TreeModel.TreeChangedEvent) object;
+            if (object instanceof TreeChangedEvent) {
+                TreeChangedEvent event = (TreeChangedEvent) object;
                 if (event.isTreeChanged()) {
                     recalculateTreeLength();
                     updateAllNodes();
+                    updateRestrictedNodePartials = true;
                 } else if (event.isHeightChanged()) {
                     recalculateTreeLength();
                     if (useTreeLength || (scaleByTime && treeModel.isRoot(event.getNode())))
@@ -455,6 +468,7 @@ public abstract class AbstractMultivariateTraitLikelihood extends AbstractModelL
                     else {
                         updateNodeAndChildren(event.getNode());
                     }
+                    updateRestrictedNodePartials = true;
                 } else {
                     throw new RuntimeException("Unexpected TreeModel TreeChangedEvent occurring in AbstractMultivariateTraitLikelihood");
                 }
@@ -472,6 +486,9 @@ public abstract class AbstractMultivariateTraitLikelihood extends AbstractModelL
                 else
                     updateAllNodes(); // Probably an epoch model
             }
+        } else if (model instanceof RestrictedPartials) {
+            updateAllNodes();
+            updateRestrictedNodePartials = true;
         } else {
             throw new RuntimeException("Unknown componentChangedEvent");
         }
@@ -573,12 +590,13 @@ public abstract class AbstractMultivariateTraitLikelihood extends AbstractModelL
             storedValidLogLikelihoods = validLogLikelihoods;
             validLogLikelihoods = tmp2;
         }
+        updateRestrictedNodePartials = true; // TODO remove or cache?  Caching is still not working, see IMTL.restoreState()
     }
 
     protected void acceptState() {
     } // nothing to do
 
-    public MultivariateTraitTree getTreeModel() {
+    public MutableTreeModel getTreeModel() {
         return treeModel;
     }
 
@@ -733,9 +751,9 @@ public abstract class AbstractMultivariateTraitLikelihood extends AbstractModelL
         public Object parseXMLObject(XMLObject xo) throws XMLParseException {
 
             MultivariateDiffusionModel diffusionModel = (MultivariateDiffusionModel) xo.getChild(MultivariateDiffusionModel.class);
-            MultivariateTraitTree treeModel = (MultivariateTraitTree) xo.getChild(MultivariateTraitTree.class);
+            MutableTreeModel treeModel = (MutableTreeModel) xo.getChild(MutableTreeModel.class);
 
-            boolean cacheBranches = xo.getAttribute(CACHE_BRANCHES, false);
+            boolean cacheBranches = xo.getAttribute(CACHE_BRANCHES, true);
             boolean integrate = xo.getAttribute(INTEGRATE, false);
             boolean useTreeLength = xo.getAttribute(USE_TREE_LENGTH, false);
             boolean scaleByTime = xo.getAttribute(SCALE_BY_TIME, false);
@@ -745,20 +763,7 @@ public abstract class AbstractMultivariateTraitLikelihood extends AbstractModelL
 
             BranchRateModel rateModel = (BranchRateModel) xo.getChild(BranchRateModel.class);
 
-            List<BranchRateModel> driftModels = null;
-            if (xo.hasChildNamed(DRIFT_MODELS)) {
-                driftModels = new ArrayList<BranchRateModel>();
-                XMLObject cxo = xo.getChild(DRIFT_MODELS);
-                final int number = cxo.getChildCount();
-                if (number != diffusionModel.getPrecisionmatrix().length) {
-                    throw new XMLParseException("Wrong number of drift models (" + number + ") for a trait of" +
-                            " dimension " + diffusionModel.getPrecisionmatrix().length + " in " + xo.getId()
-                    );
-                }
-                for (int i = 0; i < number; ++i) {
-                    driftModels.add((BranchRateModel) cxo.getChild(i));
-                }
-            }
+            List<BranchRateModel> driftModels = parseDriftModels(xo, diffusionModel);
 
             List<BranchRateModel> optimalValues = null;
             BranchRateModel strengthOfSelection = null;
@@ -791,6 +796,8 @@ public abstract class AbstractMultivariateTraitLikelihood extends AbstractModelL
             List<Integer> missingIndices = returnValue.missingIndices;
             traitName = returnValue.traitName;
 
+            /* TODO Add partially integrated traits here */
+
             Model samplingDensity = null;
 
             if (xo.hasChildNamed(SAMPLING_DENSITY)) {
@@ -840,7 +847,9 @@ public abstract class AbstractMultivariateTraitLikelihood extends AbstractModelL
                 Logger.getLogger("dr.evomodel").info(sb.toString());
 
             }
-            
+
+            List<RestrictedPartials> restrictedPartialsList = parseRestrictedPartials(xo, integrate);
+
             AbstractMultivariateTraitLikelihood like;
 
             if (integrate) {
@@ -858,7 +867,7 @@ public abstract class AbstractMultivariateTraitLikelihood extends AbstractModelL
                     like = new SemiConjugateMultivariateTraitLikelihood(traitName, treeModel, diffusionModel,
                             traitParameter, missingIndices, cacheBranches,
                             scaleByTime, useTreeLength, rateModel, samplingDensity, reportAsMultivariate,
-                            rootDistribution, reciprocalRates);
+                            rootDistribution, reciprocalRates, restrictedPartialsList);
 
 //                    like = new DebugableIntegratedMultivariateTraitLikelihood(traitName, treeModel, diffusionModel,
 //                            traitParameter, missingIndices, cacheBranches,
@@ -890,7 +899,7 @@ public abstract class AbstractMultivariateTraitLikelihood extends AbstractModelL
                         like = new NonPhylogeneticMultivariateTraitLikelihood(traitName, treeModel, diffusionModel,
                                 traitParameter, deltaParameter, missingIndices, cacheBranches,
                                 scaleByTime, useTreeLength, rateModel, samplingDensity, reportAsMultivariate,
-                                mean, pseudoObservations, reciprocalRates, exchangeableTips);
+                                mean, pseudoObservations, restrictedPartialsList, reciprocalRates, exchangeableTips);
                     } else {
                         if (driftModels == null) {
                             if (strengthOfSelection == null) {
@@ -899,14 +908,14 @@ public abstract class AbstractMultivariateTraitLikelihood extends AbstractModelL
                                         scaleByTime, useTreeLength,
                                         rateModel, null, null, null,
                                         samplingDensity, reportAsMultivariate,
-                                        mean, pseudoObservations, reciprocalRates);
+                                        mean, restrictedPartialsList, pseudoObservations, reciprocalRates);
                             } else {
                                 like = new FullyConjugateMultivariateTraitLikelihood(traitName, treeModel, diffusionModel,
                                         traitParameter, deltaParameter, missingIndices, cacheBranches,
                                         scaleByTime, useTreeLength,
                                         rateModel, null, optimalValues, strengthOfSelection,
                                         samplingDensity, reportAsMultivariate,
-                                        mean, pseudoObservations, reciprocalRates);
+                                        mean, restrictedPartialsList,pseudoObservations, reciprocalRates);
                             }
                         } else {
                             like = new FullyConjugateMultivariateTraitLikelihood(traitName, treeModel, diffusionModel,
@@ -914,7 +923,7 @@ public abstract class AbstractMultivariateTraitLikelihood extends AbstractModelL
                                     scaleByTime, useTreeLength,
                                     rateModel, driftModels, null, null,
                                     samplingDensity, reportAsMultivariate,
-                                    mean, pseudoObservations, reciprocalRates);
+                                    mean, restrictedPartialsList, pseudoObservations, reciprocalRates);
                         }
                     }
                 }
@@ -940,7 +949,10 @@ public abstract class AbstractMultivariateTraitLikelihood extends AbstractModelL
                 like.check(check);
             }
 
+            boolean isRRW = (rateModel != null) && (!(rateModel instanceof StrictClockBranchRates));
+
             if (!xo.hasAttribute(TreeTraitParserUtilities.ALLOW_IDENTICAL) &&
+                    isRRW &&
                     utilities.hasIdenticalTraits(traitParameter, missingIndices, diffusionModel.getPrecisionmatrix().length)) {
                 throw new XMLParseException("For multivariate trait analyses, all trait values should be unique.\n" +
                         "Check data or add random noise using 'jitter' option.");
@@ -994,7 +1006,7 @@ public abstract class AbstractMultivariateTraitLikelihood extends AbstractModelL
                         new ElementRule(Taxon.class)
                 }, true),
                 new ElementRule(MultivariateDiffusionModel.class),
-                new ElementRule(MultivariateTraitTree.class),
+                new ElementRule(MutableTreeModel.class),
                 new ElementRule(BranchRateModel.class, true),
                 AttributeRule.newDoubleArrayRule("cut", true),
                 AttributeRule.newBooleanRule(REPORT_MULTIVARIATE, true),
@@ -1005,6 +1017,7 @@ public abstract class AbstractMultivariateTraitLikelihood extends AbstractModelL
                 AttributeRule.newIntegerRule(RANDOM_SAMPLE, true),
                 AttributeRule.newBooleanRule(IGNORE_PHYLOGENY, true),
                 AttributeRule.newBooleanRule(EXCHANGEABLE_TIPS, true),
+                AttributeRule.newBooleanRule(TreeTraitParserUtilities.SAMPLE_MISSING_TRAITS, true),
                 new ElementRule(Parameter.class, true),
                 TreeTraitParserUtilities.randomizeRules(true),
                 TreeTraitParserUtilities.jitterRules(true),
@@ -1014,6 +1027,7 @@ public abstract class AbstractMultivariateTraitLikelihood extends AbstractModelL
                 new ElementRule(DRIFT_MODELS, new XMLSyntaxRule[]{
                         new ElementRule(BranchRateModel.class, 1, Integer.MAX_VALUE),
                 }, true),
+                new ElementRule(RestrictedPartials.class, 0, Integer.MAX_VALUE),
         };
 
 
@@ -1022,7 +1036,59 @@ public abstract class AbstractMultivariateTraitLikelihood extends AbstractModelL
         }
     };
 
-    MultivariateTraitTree treeModel = null;
+
+    public static List<BranchRateModel> parseDriftModels(XMLObject xo,
+                                                         MultivariateDiffusionModel diffusionModel)
+            throws XMLParseException {
+
+        List<BranchRateModel> driftModels = null;
+
+        if (xo.hasChildNamed(DRIFT_MODELS)) {
+            driftModels = new ArrayList<BranchRateModel>();
+            XMLObject cxo = xo.getChild(DRIFT_MODELS);
+
+            final int number = cxo.getChildCount();
+
+            if (number != diffusionModel.getPrecisionmatrix().length) {
+                throw new XMLParseException("Wrong number of drift models (" + number + ") for a trait of" +
+                        " dimension " + diffusionModel.getPrecisionmatrix().length + " in " + xo.getId()
+                );
+            }
+
+            for (int i = 0; i < number; ++i) {
+                driftModels.add((BranchRateModel) cxo.getChild(i));
+            }
+
+        }
+        return driftModels;
+    }
+
+    public static List<RestrictedPartials> parseRestrictedPartials(XMLObject xo, boolean integrate)
+            throws XMLParseException {
+
+        List<RestrictedPartials> restrictedPartialsList = null;
+        for (int i = 0; i < xo.getChildCount(); ++i) {
+            Object cxo = xo.getChild(i);
+
+            if (cxo instanceof RestrictedPartials) {
+                if (!integrate) {
+                    throw new XMLParseException("Restricted partials are currently only implements" +
+                            "for integrated multivariate trait likelihood models");
+                }
+                if (restrictedPartialsList == null) {
+                    restrictedPartialsList = new ArrayList<RestrictedPartials>();
+                }
+                restrictedPartialsList.add((RestrictedPartials) cxo);
+            }
+        }
+        return restrictedPartialsList;
+    }
+
+    protected void addRestrictedPartials(RestrictedPartials restrictedPartials) {
+        throw new IllegalArgumentException("Not implemented for this model type");
+    }
+
+    MutableTreeModel treeModel = null;
     MultivariateDiffusionModel diffusionModel = null;
     String traitName = null;
     CompoundParameter traitParameter;
@@ -1062,5 +1128,8 @@ public abstract class AbstractMultivariateTraitLikelihood extends AbstractModelL
     protected int dimTrait;
     protected int dim;
 
+    protected boolean updateRestrictedNodePartials = true;
+    protected boolean savedUpdateRestrictedNodePartials;
+//    protected Map<BitSet, RestrictedPartials> restrictedPartialsMap;
 }
 
