@@ -25,9 +25,10 @@
 
 package dr.evomodel.continuous;
 
-import dr.app.beagle.evomodel.treelikelihood.MarkovJumpsBeagleTreeLikelihood;
+import dr.evolution.tree.MutableTreeModel;
+import dr.evolution.tree.TreeUtils;
+import dr.evomodel.treelikelihood.MarkovJumpsBeagleTreeLikelihood;
 import dr.app.util.Arguments;
-import dr.evolution.tree.MultivariateTraitTree;
 import dr.evolution.tree.NodeRef;
 import dr.evolution.tree.Tree;
 import dr.evolution.util.TaxonList;
@@ -42,13 +43,15 @@ import dr.geo.math.SphericalPolarCoordinates;
 import dr.inference.model.Statistic;
 import dr.math.distributions.MultivariateNormalDistribution;
 import dr.stats.DiscreteStatistics;
+import dr.stats.Regression;
 import dr.xml.*;
 import org.jdom.Element;
+import org.apache.commons.math.stat.ranking.NaturalRanking;
 
-import javax.swing.event.TreeModelListener;
-import javax.swing.plaf.basic.BasicInternalFrameTitlePane;
 import java.util.*;
 
+import static java.lang.Double.NaN;
+
 /**
  * @author Marc Suchard
  * @author Philippe Lemey
@@ -66,6 +69,10 @@ public class ContinuousDiffusionStatistic extends Statistic.Abstract {
     public static final String AVERAGE = "average";  // average over all branches
     public static final String WEIGHTED_AVERAGE = "weightedAverage"; // weighted average (=total distance/total time)
     public static final String COEFFICIENT_OF_VARIATION = "coefficientOfVariation"; // weighted average (=total distance/total time)
+    public static final String SPEARMAN = "spearman";
+    public static final String CORRELATION_COEFFICIENT = "correlationCoefficient";
+    public static final String DISTANCE_TIME_CORRELATION = "distanceTimeCorrelation";
+    public static final String R_SQUARED = "Rsquared";
     public static final String STATISTIC = "statistic";
     public static final String TRAIT = "trait";
     public static final String TRAIT2DAREA = "trait2Darea";
@@ -139,8 +146,9 @@ public class ContinuousDiffusionStatistic extends Statistic.Abstract {
         double maxBranchDistanceFromRoot = 0;
         double maxDistanceOverTimeFromRootWA = 0;  // can only be used when cumulative and not associated with discrete state (not based on the distances on the branches from the root up that point)
         double maxBranchDistanceOverTimeFromRootWA = 0;
-
         List<Double> rates = new ArrayList<Double>();
+        List<Double> distances = new ArrayList<Double>();
+        List<Double> times = new ArrayList<Double>();
         List<Double> traits = new ArrayList<Double>();
         List<double[]> traits2D = new ArrayList<double[]>();
         //double[] diffusionCoefficients =  null;
@@ -160,7 +168,7 @@ public class ContinuousDiffusionStatistic extends Statistic.Abstract {
         }
 
         for (AbstractMultivariateTraitLikelihood traitLikelihood : traitLikelihoods) {
-            MultivariateTraitTree tree = traitLikelihood.getTreeModel();
+            MutableTreeModel tree = traitLikelihood.getTreeModel();
             BranchRateModel branchRates = traitLikelihood.getBranchRateModel();
 
             String traitName = traitLikelihood.getTraitName();
@@ -176,7 +184,7 @@ public class ContinuousDiffusionStatistic extends Statistic.Abstract {
                     if  (branchset.equals(BranchSet.CLADE)){
                         try{
                             testNode = inClade(tree, node, taxonList);
-                        } catch (Tree.MissingTaxonException mte) {
+                        } catch (TreeUtils.MissingTaxonException mte) {
                             throw new RuntimeException(mte.toString());
                         }
                     }  else if (branchset.equals(BranchSet.BACKBONE)) {
@@ -185,7 +193,7 @@ public class ContinuousDiffusionStatistic extends Statistic.Abstract {
                         } else {
                             try{
                                 testNode = onAncestralPathTaxa(tree, node, taxonList);
-                            } catch (Tree.MissingTaxonException mte) {
+                            } catch (TreeUtils.MissingTaxonException mte) {
                                 throw new RuntimeException(mte.toString());
                             }
                         }
@@ -242,12 +250,17 @@ public class ContinuousDiffusionStatistic extends Statistic.Abstract {
 
                             double time;
                             if (stateString != null) {
-                                time = history.getStateTime(stateString);
-//                            System.out.println("tine before = "+(timeUp - timeLow)+", time after= "+time);
+                                if (!history.returnMismatch()){
+                                    time = history.getStateTime(stateString);
+                                } else {
+                                    time = NaN;
+                                }
+                              //System.out.println("time before = "+(timeUp - timeLow)+", time after= "+time);
                             } else {
                                 time = timeUp - timeLow;
                             }
                             treeLength += time;
+                            times.add(time);
 
                             //setting up continuous trait values for heights in discrete trait history
                             if (stateString != null) {
@@ -260,10 +273,15 @@ public class ContinuousDiffusionStatistic extends Statistic.Abstract {
                             if (useGreatCircleDistances && (trait.length == 2)) { // Great Circle distance
                                 double distance;
                                 if (stateString != null) {
-                                    distance = history.getStateGreatCircleDistance(stateString);
+                                    if (!history.returnMismatch()){
+                                        distance = history.getStateGreatCircleDistance(stateString);
+                                    } else {
+                                        distance = NaN;
+                                    }
                                 } else {
                                     distance = getGreatCircleDistance(traitLow, traitUp);
                                 }
+                                distances.add(distance);
 
                                 if (time > 0) {
                                     treeDistance += distance;
@@ -282,10 +300,17 @@ public class ContinuousDiffusionStatistic extends Statistic.Abstract {
                                     if (stateString != null) {
                                         double[] stateTimeDistance = getStateTimeAndDistanceFromRoot(tree, node, timeLow, traitLikelihood, traitName, traitLow, precision, branchRates, true);
                                         if (stateTimeDistance[0] > 0) {
-                                            maxDistanceFromRootCumulative = tempDistanceFromRootLow * (stateTimeDistance[0] / timeFromRoot);
-                                            maxDistanceOverTimeFromRootWA = maxDistanceFromRootCumulative / stateTimeDistance[0];
-                                            maxBranchDistanceFromRoot = stateTimeDistance[1];
-                                            maxBranchDistanceOverTimeFromRootWA = stateTimeDistance[1] / stateTimeDistance[0];
+                                            if (!history.returnMismatch()){
+                                                maxDistanceFromRootCumulative = tempDistanceFromRootLow * (stateTimeDistance[0] / timeFromRoot);
+                                                maxDistanceOverTimeFromRootWA = maxDistanceFromRootCumulative / stateTimeDistance[0];
+                                                maxBranchDistanceFromRoot = stateTimeDistance[1];
+                                                maxBranchDistanceOverTimeFromRootWA = stateTimeDistance[1] / stateTimeDistance[0];
+                                            } else {
+                                                maxDistanceFromRootCumulative = NaN;
+                                                maxDistanceOverTimeFromRootWA = NaN;
+                                                maxBranchDistanceFromRoot = NaN;
+                                                maxBranchDistanceOverTimeFromRootWA = NaN;
+                                            }
                                         }
                                     } else {
                                         maxDistanceFromRootCumulative = tempDistanceFromRootLow;
@@ -309,10 +334,15 @@ public class ContinuousDiffusionStatistic extends Statistic.Abstract {
                             } else {
                                 double distance;
                                 if (stateString != null) {
-                                    distance = history.getStateNativeDistance(stateString);
+                                    if (!history.returnMismatch()){
+                                        distance = history.getStateNativeDistance(stateString);
+                                    } else {
+                                        distance = NaN;
+                                    }
                                 } else {
                                     distance = getNativeDistance(traitLow, traitUp);
                                 }
+                                distances.add(distance);
 
                                 if (time > 0) {
                                     treeDistance += distance;
@@ -328,10 +358,17 @@ public class ContinuousDiffusionStatistic extends Statistic.Abstract {
                                     if (stateString != null) {
                                         double[] stateTimeDistance = getStateTimeAndDistanceFromRoot(tree, node, timeLow, traitLikelihood, traitName, traitLow, precision, branchRates, false);
                                         if (stateTimeDistance[0] > 0) {
-                                            maxDistanceFromRootCumulative = tempDistanceFromRoot * (stateTimeDistance[0] / timeFromRoot);
-                                            maxDistanceOverTimeFromRootWA = maxDistanceFromRootCumulative / stateTimeDistance[0];
-                                            maxBranchDistanceFromRoot = stateTimeDistance[1];
-                                            maxBranchDistanceOverTimeFromRootWA = stateTimeDistance[1] / stateTimeDistance[0];
+                                            if (!history.returnMismatch()){
+                                                maxDistanceFromRootCumulative = tempDistanceFromRoot * (stateTimeDistance[0] / timeFromRoot);
+                                                maxDistanceOverTimeFromRootWA = maxDistanceFromRootCumulative / stateTimeDistance[0];
+                                                maxBranchDistanceFromRoot = stateTimeDistance[1];
+                                                maxBranchDistanceOverTimeFromRootWA = stateTimeDistance[1] / stateTimeDistance[0];
+                                            } else {
+                                                maxDistanceFromRootCumulative = NaN;
+                                                maxDistanceOverTimeFromRootWA = NaN;
+                                                maxBranchDistanceFromRoot = NaN;
+                                                maxBranchDistanceOverTimeFromRootWA = NaN;
+                                            }
                                         }
                                     } else {
                                         maxDistanceFromRootCumulative = tempDistanceFromRoot;
@@ -409,7 +446,17 @@ public class ContinuousDiffusionStatistic extends Statistic.Abstract {
         }  else if (summaryStat == summaryStatistic.DIFFUSION_DISTANCE)  {
             return treeDistance;
             //DIFFUSION_TIME
-        }  else {
+        }  else if (summaryStat == summaryStatistic.DISTANCE_TIME_CORRELATION)  {
+            if (summaryMode == Mode.SPEARMAN) {
+                return getSpearmanRho(convertDoubles(times),convertDoubles(distances));
+            } else if (summaryMode == Mode.R_SQUARED) {
+                Regression r = new Regression(convertDoubles(times), convertDoubles(distances));
+                return r.getRSquared();
+            } else {
+                Regression r = new Regression(convertDoubles(times),convertDoubles(distances));
+                return r.getCorrelationCoefficient();
+            }
+         }  else {
             return treeLength;
         }
     }
@@ -552,6 +599,7 @@ public class ContinuousDiffusionStatistic extends Statistic.Abstract {
     public History setUpHistory(String historyString, int nodeState, int parentNodeState, double timeLow, double timeUp){
         double[] heights;
         String[] states;
+        boolean mismatch = false;
         if (historyString.equals("{}")){
             heights = new double[]{timeUp,timeLow};
             states = new String[]{getState(nodeState)};
@@ -585,16 +633,21 @@ public class ContinuousDiffusionStatistic extends Statistic.Abstract {
 
             //sanity check
             if (!jumpStrings[0][1].equals(getState(parentNodeState))){
-                System.out.println(jumpStrings[0][1]+"\t"+getState(parentNodeState));
-                System.err.println("mismatch in jump history and parent node state");
-                System.exit(-1);
+//                System.out.println(jumpStrings[0][1]+"\t"+getState(parentNodeState));
+                System.err.println("mismatch in jump history and parent node state, continuous diffusion statistic will return NaN");
+                mismatch = true;
+//                System.exit(-1);
             }
 
             //sanity check
             states[numberOfJumps] = jumpStrings[numberOfJumps-1][2];
             if (!jumpStrings[numberOfJumps-1][2].equals(getState(nodeState))){
-                System.err.println("mismatch in jump history and node state");
-                System.exit(-1);
+//                System.out.println(getState(parentNodeState));
+//                System.out.println(getState(nodeState));
+//                System.out.println(historyString);
+                System.err.println("mismatch in jump history and node state, continuous diffusion statistic will return NaN");
+                mismatch = true;
+//                System.exit(-1);
             }
 
             heights[0] = timeUp;
@@ -606,7 +659,7 @@ public class ContinuousDiffusionStatistic extends Statistic.Abstract {
 //            System.out.print(heights[q] +"\t"+ states[q] +"\t");
 //        }
 //        System.out.println(heights[states.length]+"\r");
-        return new History(heights,states);
+        return new History(heights,states,mismatch);
     }
 
     private String getState(int stateInt){
@@ -620,7 +673,7 @@ public class ContinuousDiffusionStatistic extends Statistic.Abstract {
         return returnString;
     }
 
-    public double[] getStateTimeAndDistanceFromRoot(MultivariateTraitTree tree, NodeRef node, double timeLow, AbstractMultivariateTraitLikelihood traitLikelihood, String traitName, double[] traitLow, double[] precision, BranchRateModel branchRates, boolean useGreatCircleDistance){
+    public double[] getStateTimeAndDistanceFromRoot(MutableTreeModel tree, NodeRef node, double timeLow, AbstractMultivariateTraitLikelihood traitLikelihood, String traitName, double[] traitLow, double[] precision, BranchRateModel branchRates, boolean useGreatCircleDistance){
 
         NodeRef nodeOfInterest = node;
 
@@ -660,7 +713,7 @@ public class ContinuousDiffusionStatistic extends Statistic.Abstract {
         return timeDistance;
     }
 
-    public double[] getTimeAndDistanceFromRoot(MultivariateTraitTree tree, NodeRef node, double timeLow, AbstractMultivariateTraitLikelihood traitLikelihood, String traitName, double[] traitLow, boolean useGreatCircleDistance){
+    public double[] getTimeAndDistanceFromRoot(MutableTreeModel tree, NodeRef node, double timeLow, AbstractMultivariateTraitLikelihood traitLikelihood, String traitName, double[] traitLow, boolean useGreatCircleDistance){
 
         NodeRef nodeOfInterest = node;
         double[] timeDistance = new double[]{0,0};
@@ -694,14 +747,14 @@ public class ContinuousDiffusionStatistic extends Statistic.Abstract {
     }
 
 
-    public boolean inClade(MultivariateTraitTree tree, NodeRef node, TaxonList taxonList) throws Tree.MissingTaxonException {
+    public boolean inClade(MutableTreeModel tree, NodeRef node, TaxonList taxonList) throws TreeUtils.MissingTaxonException {
 
         Set leafSubSet;
-        leafSubSet = Tree.Utils.getLeavesForTaxa(tree, taxonList);
-        NodeRef mrca = Tree.Utils.getCommonAncestorNode(tree, leafSubSet);
-        Set mrcaLeafSet =  Tree.Utils.getDescendantLeaves(tree,mrca);
+        leafSubSet = TreeUtils.getLeavesForTaxa(tree, taxonList);
+        NodeRef mrca = TreeUtils.getCommonAncestorNode(tree, leafSubSet);
+        Set mrcaLeafSet =  TreeUtils.getDescendantLeaves(tree,mrca);
 
-        Set nodeLeafSet =  Tree.Utils.getDescendantLeaves(tree,node);
+        Set nodeLeafSet =  TreeUtils.getDescendantLeaves(tree,node);
 
         if (!nodeLeafSet.isEmpty()){
             nodeLeafSet.removeAll(mrcaLeafSet);
@@ -714,14 +767,14 @@ public class ContinuousDiffusionStatistic extends Statistic.Abstract {
         }
         return false;
     }
-    private static boolean onAncestralPathTaxa(Tree tree, NodeRef node, TaxonList taxonList) throws Tree.MissingTaxonException {
+    private static boolean onAncestralPathTaxa(Tree tree, NodeRef node, TaxonList taxonList) throws TreeUtils.MissingTaxonException {
 
         if (tree.isExternal(node)) return false;
 
-        Set leafSet = Tree.Utils.getDescendantLeaves(tree, node);
+        Set leafSet = TreeUtils.getDescendantLeaves(tree, node);
         int size = leafSet.size();
 
-        Set targetSet = Tree.Utils.getLeavesForTaxa(tree, taxonList);
+        Set targetSet = TreeUtils.getLeavesForTaxa(tree, taxonList);
         leafSet.retainAll(targetSet);
 
         if (leafSet.size() > 0) {
@@ -729,7 +782,7 @@ public class ContinuousDiffusionStatistic extends Statistic.Abstract {
             // if all leaves below are in target then check just above.
             if (leafSet.size() == size) {
 
-                Set superLeafSet = Tree.Utils.getDescendantLeaves(tree, tree.getParent(node));
+                Set superLeafSet = TreeUtils.getDescendantLeaves(tree, tree.getParent(node));
                 superLeafSet.removeAll(targetSet);
 
                 // the branch is on ancestral path if the super tree has some non-targets in it
@@ -745,8 +798,8 @@ public class ContinuousDiffusionStatistic extends Statistic.Abstract {
 
         double maxDescendentTime = 0;
 
-        Set leafSet = Tree.Utils.getExternalNodes(tree, node);
-        Set nodeSet = Tree.Utils.getExternalNodes(tree, node);
+        Set leafSet = TreeUtils.getExternalNodes(tree, node);
+        Set nodeSet = TreeUtils.getExternalNodes(tree, node);
 
         Iterator iter = leafSet.iterator();
 
@@ -808,6 +861,34 @@ public class ContinuousDiffusionStatistic extends Statistic.Abstract {
         return totalArea;
     }
 
+    private static double[] convertDoubles(List<Double> doubles) {
+        double[] ret = new double[doubles.size()];
+        Iterator<Double> iterator = doubles.iterator();
+        int i = 0;
+        while(iterator.hasNext())
+        {
+            ret[i] = iterator.next();
+            i++;
+        }
+        return ret;
+    }
+
+    private static double getSpearmanRho(double[] data1, double[] data2){
+
+        double data1Ranks[] = new NaturalRanking().rank(data1);
+        double data2Ranks[] = new NaturalRanking().rank(data2);
+
+        int counter = 0;
+        double d_i = 0;
+        while(counter < data1Ranks.length){
+            d_i += Math.pow(data1Ranks[counter] -  data2Ranks[counter], 2);
+            counter ++;
+        }
+        return  (1 - (6*d_i)/(data1Ranks.length*(Math.pow(data1Ranks.length,2) - 1)));
+    }
+
+
+
 //    private int getStateInt(String state){
 //        int returnInt = -1;
 //        int counter = 0;
@@ -833,7 +914,10 @@ public class ContinuousDiffusionStatistic extends Statistic.Abstract {
         AVERAGE,
         WEIGHTED_AVERAGE,
         MEDIAN,
-        COEFFICIENT_OF_VARIATION
+        COEFFICIENT_OF_VARIATION,
+        SPEARMAN,
+        CORRELATION_COEFFICIENT,
+        R_SQUARED
     }
 
     enum summaryStatistic {
@@ -846,6 +930,7 @@ public class ContinuousDiffusionStatistic extends Statistic.Abstract {
         WAVEFRONT_DISTANCE,
         WAVEFRONT_DISTANCE_PHYLO,
         WAVEFRONT_RATE,
+        DISTANCE_TIME_CORRELATION
     }
 
     enum BranchSet {
@@ -870,20 +955,26 @@ public class ContinuousDiffusionStatistic extends Statistic.Abstract {
             String name = xo.getAttribute(NAME, xo.getId());
 
             boolean greatCircleDistances = xo.getAttribute(USE_GREATCIRCLEDISTANCES, false); // Default value is false
-            Mode averageMode;
+            Mode statMode;
             String mode = xo.getAttribute(MODE, WEIGHTED_AVERAGE);
 
             if (mode.equals(AVERAGE)) {
-                averageMode = Mode.AVERAGE;
+                statMode = Mode.AVERAGE;
             } else if (mode.equals(MEDIAN)) {
-                averageMode = Mode.MEDIAN;
+                statMode = Mode.MEDIAN;
             } else if (mode.equals(COEFFICIENT_OF_VARIATION)) {
-                averageMode = Mode.COEFFICIENT_OF_VARIATION;
+                statMode = Mode.COEFFICIENT_OF_VARIATION;
             } else if (mode.equals(WEIGHTED_AVERAGE)) {
-                averageMode = Mode.WEIGHTED_AVERAGE;
+                statMode = Mode.WEIGHTED_AVERAGE;
+            } else if (mode.equals(SPEARMAN)) {
+                statMode = Mode.SPEARMAN;
+            } else if (mode.equals(CORRELATION_COEFFICIENT)) {
+                statMode = Mode.CORRELATION_COEFFICIENT;
+            } else if (mode.equals(R_SQUARED)) {
+                statMode = Mode.R_SQUARED;
             } else {
                 System.err.println("Unknown mode: "+mode+". Reverting to weighted average for "+name);
-                averageMode = Mode.WEIGHTED_AVERAGE;
+                statMode = Mode.WEIGHTED_AVERAGE;
             }
 
             final double upperHeight = xo.getAttribute(HEIGHT_UPPER, Double.MAX_VALUE);
@@ -910,6 +1001,10 @@ public class ContinuousDiffusionStatistic extends Statistic.Abstract {
             int dimension = 1;
             if (statistic.equals(DIFFUSION_RATE)) {
                 summaryStat = summaryStatistic.DIFFUSION_RATE;
+                if (mode.equals(SPEARMAN) || mode.equals(R_SQUARED) || mode.equals(CORRELATION_COEFFICIENT)){
+                    System.err.println(name+": mode = "+mode+" ignored for "+DIFFUSION_TIME+", reverting to weighted average mode");
+                    statMode = Mode.WEIGHTED_AVERAGE;
+                }
             } else if (statistic.equals(DIFFUSION_TIME)) {
                 summaryStat = summaryStatistic.DIFFUSION_TIME;
                 if (!mode.equals(WEIGHTED_AVERAGE)) {
@@ -920,6 +1015,12 @@ public class ContinuousDiffusionStatistic extends Statistic.Abstract {
                 if (!mode.equals(WEIGHTED_AVERAGE)) {
                     System.err.println(name+": mode = "+mode+" ignored for "+DIFFUSION_DISTANCE);
                 }
+            } else if (statistic.equals(DISTANCE_TIME_CORRELATION)) {
+                summaryStat = summaryStatistic.DISTANCE_TIME_CORRELATION;
+                if (mode.equals(AVERAGE) || mode.equals(WEIGHTED_AVERAGE) || mode.equals(COEFFICIENT_OF_VARIATION) || mode.equals(MEDIAN)){
+                    System.err.println(name+": mode = "+mode+" ignored for "+DISTANCE_TIME_CORRELATION+", reverting to correlation coefficient mode");
+                    statMode = Mode.CORRELATION_COEFFICIENT;
+                }
             } else if (statistic.equals(WAVEFRONT_DISTANCE)) {
                 summaryStat = summaryStatistic.WAVEFRONT_DISTANCE;
                 if (!mode.equals(WEIGHTED_AVERAGE)) {
@@ -934,7 +1035,7 @@ public class ContinuousDiffusionStatistic extends Statistic.Abstract {
                 summaryStat = summaryStatistic.TRAIT;
                 if (mode.equals(WEIGHTED_AVERAGE)) {
                     System.err.println(name + ": mode = " + mode + " ignored for " + TRAIT + ", resorting to " + AVERAGE);
-                    averageMode = Mode.AVERAGE;
+                    statMode = Mode.AVERAGE;
                 }
                 if (upperHeight < Double.MAX_VALUE) {
                     System.err.println(name + ": only " + HEIGHT_LOWER + " or " + HEIGHT_LOWER_SERIE + " are relevant for " + TRAIT);
@@ -960,6 +1061,8 @@ public class ContinuousDiffusionStatistic extends Statistic.Abstract {
                 summaryStat = summaryStatistic.WAVEFRONT_RATE;
             } else if (statistic.equals(DIFFUSION_COEFFICIENT)) {
                 summaryStat = summaryStatistic.DIFFUSION_COEFFICIENT;
+            } else if (statistic.equals(DISTANCE_TIME_CORRELATION)) {
+                summaryStat = summaryStatistic.DISTANCE_TIME_CORRELATION;
             } else {
                 System.err.println(name+": unknown statistic: "+statistic+". Reverting to diffusion rate.");
                 summaryStat = summaryStatistic.DIFFUSION_RATE;
@@ -1059,7 +1162,7 @@ public class ContinuousDiffusionStatistic extends Statistic.Abstract {
 
 
 
-            return new ContinuousDiffusionStatistic(name, traitLikelihoods, greatCircleDistances, averageMode, summaryStat, upperHeight, lowerHeight, lowerHeights, cumulative, trueNoise, dimension, taxonList, branchset, backboneTime, stateString, mjtl);
+            return new ContinuousDiffusionStatistic(name, traitLikelihoods, greatCircleDistances, statMode, summaryStat, upperHeight, lowerHeight, lowerHeights, cumulative, trueNoise, dimension, taxonList, branchset, backboneTime, stateString, mjtl);
         }
 
         //************************************************************************
@@ -1118,10 +1221,12 @@ public class ContinuousDiffusionStatistic extends Statistic.Abstract {
         private double[] historyHeights;
         private String[] historyStates;
         private double[][] historyTraits;
+        private boolean mismatch;
 
-        public History(double historyHeights[], String historyStates[]) {
+        public History(double historyHeights[], String historyStates[], boolean mismatch) {
             this.historyHeights = historyHeights;
             this.historyStates = historyStates;
+            this.mismatch = mismatch;
         }
 
         public void truncateUpper(double time) {
@@ -1185,6 +1290,10 @@ public class ContinuousDiffusionStatistic extends Statistic.Abstract {
             return time;
         }
 
+        public boolean returnMismatch(){
+            return mismatch;
+        }
+
         private void setTraitsforHeights(double[] traitUp,  double[] traitLow, double[] precisionArray, double rate, boolean trueNoise){
             historyTraits = new double[historyHeights.length][2];
             for (int x = 0; x < historyHeights.length; x++){
