@@ -25,16 +25,13 @@
 
 package dr.evomodel.continuous;
 
-import dr.evolution.tree.MultivariateTraitTree;
+import dr.evolution.tree.MutableTreeModel;
 import dr.evolution.tree.NodeRef;
-import dr.evolution.tree.Tree;
+import dr.evolution.tree.TreeUtils;
 import dr.evomodel.branchratemodel.BranchRateModel;
-import dr.inference.model.CompoundParameter;
-import dr.inference.model.Model;
-import dr.inference.model.Parameter;
+import dr.inference.model.*;
 import dr.math.KroneckerOperation;
 import dr.math.distributions.MultivariateNormalDistribution;
-import dr.math.distributions.NormalDistribution;
 import dr.math.distributions.WishartSufficientStatistics;
 import dr.math.interfaces.ConjugateWishartStatisticsProvider;
 import dr.math.matrixAlgebra.IllegalDimension;
@@ -42,9 +39,7 @@ import dr.math.matrixAlgebra.Matrix;
 import dr.math.matrixAlgebra.Vector;
 import dr.xml.Reportable;
 
-import java.util.HashSet;
-import java.util.List;
-import java.util.Set;
+import java.util.*;
 
 /**
  * Integrated multivariate trait likelihood that assumes a fully-conjugate prior on the root.
@@ -53,37 +48,65 @@ import java.util.Set;
  *
  * @author Marc A. Suchard
  */
-public class FullyConjugateMultivariateTraitLikelihood extends IntegratedMultivariateTraitLikelihood implements ConjugateWishartStatisticsProvider, Reportable {
+public class FullyConjugateMultivariateTraitLikelihood extends IntegratedMultivariateTraitLikelihood
+        implements ConjugateWishartStatisticsProvider, GibbsSampleFromTreeInterface, Reportable {
+
+//    public FullyConjugateMultivariateTraitLikelihood(String traitName,
+//                                                     MutableTreeModel treeModel,
+//                                                     MultivariateDiffusionModel diffusionModel,
+//                                                     CompoundParameter traitParameter,
+//                                                     Parameter deltaParameter,
+//                                                     List<Integer> missingIndices,
+//                                                     boolean cacheBranches,
+//                                                     boolean scaleByTime,
+//                                                     boolean useTreeLength,
+//                                                     BranchRateModel rateModel,
+//                                                     Model samplingDensity,
+//                                                     boolean reportAsMultivariate,
+//                                                     double[] rootPriorMean,
+//                                                     double rootPriorSampleSize,
+//                                                     boolean reciprocalRates) {
+//
+//        super(traitName, treeModel, diffusionModel, traitParameter, deltaParameter, missingIndices, cacheBranches, scaleByTime,
+//                useTreeLength, rateModel, samplingDensity, reportAsMultivariate, reciprocalRates);
+//
+//        // fully-conjugate multivariate normal with own mean and prior sample size
+//        this.rootPriorMean = rootPriorMean;
+//        this.rootPriorSampleSize = rootPriorSampleSize;
+//
+//        priorInformationKnown = false;
+//    }
+//
+//
+//    public FullyConjugateMultivariateTraitLikelihood(String traitName,
+//                                                     MutableTreeModel treeModel,
+//                                                     MultivariateDiffusionModel diffusionModel,
+//                                                     CompoundParameter traitParameter,
+//                                                     Parameter deltaParameter,
+//                                                     List<Integer> missingIndices,
+//                                                     boolean cacheBranches,
+//                                                     boolean scaleByTime,
+//                                                     boolean useTreeLength,
+//                                                     BranchRateModel rateModel,
+//                                                     List<BranchRateModel> driftModels,
+//                                                     Model samplingDensity,
+//                                                     boolean reportAsMultivariate,
+//                                                     double[] rootPriorMean,
+//                                                     double rootPriorSampleSize,
+//                                                     boolean reciprocalRates) {
+//
+//        super(traitName, treeModel, diffusionModel, traitParameter, deltaParameter, missingIndices, cacheBranches, scaleByTime,
+//                useTreeLength, rateModel, driftModels, samplingDensity, reportAsMultivariate, reciprocalRates);
+//
+//        // fully-conjugate multivariate normal with own mean and prior sample size
+//        this.rootPriorMean = rootPriorMean;
+//        this.rootPriorSampleSize = rootPriorSampleSize;
+//
+//        priorInformationKnown = false;
+//    }
 
     public FullyConjugateMultivariateTraitLikelihood(String traitName,
-                                                     MultivariateTraitTree treeModel,
-                                                     MultivariateDiffusionModel diffusionModel,
-                                                     CompoundParameter traitParameter,
-                                                     Parameter deltaParameter,
-                                                     List<Integer> missingIndices,
-                                                     boolean cacheBranches,
-                                                     boolean scaleByTime,
-                                                     boolean useTreeLength,
-                                                     BranchRateModel rateModel,
-                                                     Model samplingDensity,
-                                                     boolean reportAsMultivariate,
-                                                     double[] rootPriorMean,
-                                                     double rootPriorSampleSize,
-                                                     boolean reciprocalRates) {
-
-        super(traitName, treeModel, diffusionModel, traitParameter, deltaParameter, missingIndices, cacheBranches, scaleByTime,
-                useTreeLength, rateModel, samplingDensity, reportAsMultivariate, reciprocalRates);
-
-        // fully-conjugate multivariate normal with own mean and prior sample size
-        this.rootPriorMean = rootPriorMean;
-        this.rootPriorSampleSize = rootPriorSampleSize;
-
-        priorInformationKnown = false;
-    }
-
-
-    public FullyConjugateMultivariateTraitLikelihood(String traitName,
-                                                     MultivariateTraitTree treeModel,
+                                                     MutableTreeModel treeModel,
                                                      MultivariateDiffusionModel diffusionModel,
                                                      CompoundParameter traitParameter,
                                                      Parameter deltaParameter,
@@ -93,42 +116,17 @@ public class FullyConjugateMultivariateTraitLikelihood extends IntegratedMultiva
                                                      boolean useTreeLength,
                                                      BranchRateModel rateModel,
                                                      List<BranchRateModel> driftModels,
-                                                     Model samplingDensity,
-                                                     boolean reportAsMultivariate,
-                                                     double[] rootPriorMean,
-                                                     double rootPriorSampleSize,
-                                                     boolean reciprocalRates) {
-
-        super(traitName, treeModel, diffusionModel, traitParameter, deltaParameter, missingIndices, cacheBranches, scaleByTime,
-                useTreeLength, rateModel, driftModels, samplingDensity, reportAsMultivariate, reciprocalRates);
-
-        // fully-conjugate multivariate normal with own mean and prior sample size
-        this.rootPriorMean = rootPriorMean;
-        this.rootPriorSampleSize = rootPriorSampleSize;
-
-        priorInformationKnown = false;
-    }
-
-    public FullyConjugateMultivariateTraitLikelihood(String traitName,
-                                                     MultivariateTraitTree treeModel,
-                                                     MultivariateDiffusionModel diffusionModel,
-                                                     CompoundParameter traitParameter,
-                                                     Parameter deltaParameter,
-                                                     List<Integer> missingIndices,
-                                                     boolean cacheBranches,
-                                                     boolean scaleByTime,
-                                                     boolean useTreeLength,
-                                                     BranchRateModel rateModel,
                                                      List<BranchRateModel> optimalValues,
                                                      BranchRateModel strengthOfSelection,
                                                      Model samplingDensity,
                                                      boolean reportAsMultivariate,
                                                      double[] rootPriorMean,
+                                                     List<RestrictedPartials> partials,
                                                      double rootPriorSampleSize,
                                                      boolean reciprocalRates) {
 
         super(traitName, treeModel, diffusionModel, traitParameter, deltaParameter, missingIndices, cacheBranches, scaleByTime,
-                useTreeLength, rateModel, optimalValues, strengthOfSelection, samplingDensity, reportAsMultivariate, reciprocalRates);
+                useTreeLength, rateModel, driftModels, optimalValues, strengthOfSelection, samplingDensity, partials, reportAsMultivariate, reciprocalRates);
 
         // fully-conjugate multivariate normal with own mean and prior sample size
         this.rootPriorMean = rootPriorMean;
@@ -138,6 +136,18 @@ public class FullyConjugateMultivariateTraitLikelihood extends IntegratedMultiva
     }
 
 
+    //TODO temporary function so everything will compile. Need to actually write this.
+    public FullyConjugateMultivariateTraitLikelihood semiClone(CompoundParameter traitParameter){
+        return this;
+    }
+
+//    public FullyConjugateMultivariateTraitLikelihood semiClone(CompoundParameter traitParameter){
+//        return new FullyConjugateMultivariateTraitLikelihood(this.traitName, this.treeModel, this.diffusionModel, traitParameter,
+//                this.deltaParameter, this.missingIndices, this.cacheBranches, this.scaleByTime, this.useTreeLength, this.getBranchRateModel(),
+//                this.optimalValues, this.strengthOfSelection, this.samplingDensity, this.reportAsMultivariate, this.rootPriorMean,
+//                this.rootPriorSampleSize, this.reciprocalRates);
+//    }
+
     public double getRescaledLengthToRoot(NodeRef nodeRef) {
 
         double length = 0;
@@ -225,6 +235,11 @@ public class FullyConjugateMultivariateTraitLikelihood extends IntegratedMultiva
         return wishartStatistics;
     }
 
+    @Override
+    public MatrixParameterInterface getPrecisionParameter() {
+        return diffusionModel.getPrecisionParameter();
+    }
+
 //    private double getLogPrecisionDetermination() {
 //        return Math.log(diffusionModel.getDeterminantPrecisionMatrix()) + dimTrait * Math.log(rootPriorSampleSize);
 //    }
@@ -237,9 +252,54 @@ public class FullyConjugateMultivariateTraitLikelihood extends IntegratedMultiva
         super.handleModelChangedEvent(model, object, index);
     }
 
+    @Override
+    protected void handleVariableChangedEvent(Variable variable, int index, Parameter.ChangeType type){
+        if(variable==traitParameter
+                &&(Parameter.ChangeType.ADDED==type || Parameter.ChangeType.REMOVED==type)
+                ){
+            dimKnown = false;
+            dim = traitParameter.getParameter(0).getDimension();
+            numData = dim / getDimTrait();
+            meanCache = new double[dim * treeModel.getNodeCount()];
+//            storedMeanCache = new double[meanCache.length];
+            drawnStates = new double[dim * treeModel.getNodeCount()];
+        }
+        PostPreKnown=false;
+        super.handleVariableChangedEvent(variable,index,type);
+    }
+
+    @Override
+    public void storeState() {
+        storedNumData = numData;
+        storedDim = dim;
+        super.storeState();
+        storedPostPreKnown=PostPreKnown;
+        storedDimKnown=dimKnown;
+        if(preP!=null)
+         System.arraycopy(preP, 0, storedPreP, 0,preP.length);
+        if(preMeans!=null){
+            for(int i = 0; i < preMeans.length; i++)
+                storedPreMeans[i] = preMeans[i].clone();
+        }
+
+    }
+
+    @Override
     public void restoreState() {
+        dim = storedDim;
+        numData = storedNumData;
+        drawnStates = new double[dim * treeModel.getNodeCount()];
         super.restoreState();
+        PostPreKnown=storedPostPreKnown;
         priorInformationKnown = false;
+        double[] tempPreP = storedPreP;
+        storedPreP = preP;
+        preP = tempPreP;
+        preMeans=storedPreMeans;
+        double[][] preMeansTemp = preMeans;
+        preMeans = storedPreMeans;
+        storedPreMeans = preMeansTemp;
+        dimKnown=storedDimKnown;
     }
 
     public void makeDirty() {
@@ -260,6 +320,172 @@ public class FullyConjugateMultivariateTraitLikelihood extends IntegratedMultiva
         return computeWishartStatistics;
     }
 
+    public void doPreOrderTraversal(NodeRef node) {
+
+        if(preP==null){
+            preP=new double[treeModel.getNodeCount()];
+            storedPreP=new double[treeModel.getNodeCount()];
+        }
+        if(!dimKnown){
+            preMeans=new double[treeModel.getNodeCount()][dim];
+            storedPreMeans=new double[treeModel.getNodeCount()][dim];
+            dimKnown=true;
+        }
+
+        final int thisNumber = node.getNumber();
+
+
+        if (treeModel.isRoot(node)) {
+            preP[thisNumber] = rootPriorSampleSize;
+            for (int j = 0; j < dim; j++) {
+                preMeans[thisNumber][j]
+                        = rootPriorMean[j % dimTrait];
+            }
+
+
+        } else {
+
+            final NodeRef parentNode = treeModel.getParent(node);
+            final NodeRef sibNode = getSisterNode(node);
+
+            final int parentNumber = parentNode.getNumber();
+            final int sibNumber = sibNode.getNumber();
+
+
+
+	/*
+
+			  if (treeModel.isRoot(parentNode)){
+				  //partial precisions
+				    final double precisionParent = rootPriorSampleSize;
+			        final double precisionSib = postP[sibNumber];
+			        final double thisPrecision=1/treeModel.getBranchLength(node);
+			        double tp= precisionParent + precisionSib;
+			        preP[thisNumber]= tp*thisPrecision/(tp+thisPrecision);
+
+			        //partial means
+
+			        for (int j =0; j<dim;j++){
+			        	preMeans[thisNumber][j] = (precisionParent*preMeans[parentNumber][j] + precisionSib*rootPriorMean[j])/(precisionParent+precisionSib);
+			        }
+
+			  }else{
+	*/
+            //partial precisions
+            final double precisionParent = preP[parentNumber];
+            final double precisionSib = upperPrecisionCache[sibNumber];
+            final double thisPrecision = 1 / getRescaledBranchLengthForPrecision(node);
+            double tp = precisionParent + precisionSib;
+            preP[thisNumber] = tp * thisPrecision / (tp + thisPrecision);
+
+            //partial means
+
+            for (int j = 0; j < dim; j++) {
+                preMeans[thisNumber][j] = (precisionParent * preMeans[parentNumber][j] + precisionSib * cacheHelper.getMeanCache()[sibNumber*dim+j]) / (precisionParent + precisionSib);
+            }
+        }
+
+        if (treeModel.isExternal(node)) {
+            return;
+        } else {
+            doPreOrderTraversal(treeModel.getChild(node, 0));
+            doPreOrderTraversal(treeModel.getChild(node, 1));
+
+        }
+
+    }
+
+    public NodeRef getSisterNode(NodeRef node) {
+        NodeRef sib0 = treeModel.getChild(treeModel.getParent(node), 0);
+        NodeRef sib1 = treeModel.getChild(treeModel.getParent(node), 1);
+
+
+        if (sib0 == node) {
+            return sib1;
+        } else return sib0;
+
+    }
+
+    public double[] getConditionalMean(int taxa){
+        setup();
+
+
+//            double[] answer=new double[getRootNodeTrait().length];
+
+        double[] mean = new double[dim];
+        for (int i = 0; i < dim; i++) {
+            mean[i] = preMeans[taxa][i];
+        }
+
+        return mean;
+    }
+
+    public double[][] getConditionalMeans(){
+        setup();
+
+
+//            double[] answer=new double[getRootNodeTrait().length];
+
+
+        return preMeans;
+    }
+
+    public double getPrecisionFactor(int taxa){
+        setup();
+        return preP[taxa];
+    }
+
+    public double[] getPrecisionFactors(){
+        setup();
+        return preP;
+    }
+
+    public double[][] getConditionalPrecision(int taxa){
+         setup();
+
+
+
+
+        double[][] precisionParam =diffusionModel.getPrecisionmatrix();
+//        double[][] answer=new double[getRootNodeTrait().length][ getRootNodeTrait().length];
+        double p = getPrecisionFactor(taxa);
+
+        double[][] thisP = new double[dim][dim];
+        for (int i = 0; i < getNumData(); i++) {
+            for (int j = 0; j < getDimTrait(); j++) {
+                for (int k = 0; k < getDimTrait(); k++) {
+//                System.out.println("P: "+p);
+//                System.out.println("I: "+i+", J: "+j+" value:"+precisionParam[i][j]);
+                    thisP[i * getDimTrait() + j][i * getDimTrait() + k] = p * precisionParam[j][k];
+
+                }
+            }
+        }
+
+        return thisP;
+
+    }
+
+    private void setup(){
+        if(!PostPreKnown){
+            double[][] traitPrecision = diffusionModel.getPrecisionmatrix();
+            double logDetTraitPrecision = Math.log(diffusionModel.getDeterminantPrecisionMatrix());
+
+            final boolean computeWishartStatistics = getComputeWishartSufficientStatistics();
+
+            if (computeWishartStatistics) {
+                wishartStatistics = new WishartSufficientStatistics(dimTrait);
+            }
+
+            // Use dynamic programming to compute conditional likelihoods at each internal node
+            postOrderTraverse(treeModel, treeModel.getRoot(), traitPrecision, logDetTraitPrecision, computeWishartStatistics);
+
+            doPreOrderTraversal(treeModel.getRoot());}
+        PostPreKnown=true;
+
+    }
+
+
     protected void checkLogLikelihood(double loglikelihood, double logRemainders,
                                       double[] conditionalRootMean, double conditionalRootPrecision,
                                       double[][] traitPrecision) {
@@ -319,13 +545,13 @@ public class FullyConjugateMultivariateTraitLikelihood extends IntegratedMultiva
 
             if (computeWishartStatistics) {
 
-                final double[][] outerProducts = wishartStatistics.getScaleMatrix();
+                final double[] outerProducts = wishartStatistics.getScaleMatrix();
 
                 final double weight = conditionalRootPrecision * rootPriorSampleSize * marginalVariance;
                 for (int i = 0; i < dimTrait; i++) {
                     final double diffi = conditionalRootMean[i] - rootPriorMean[i];
                     for (int j = 0; j < dimTrait; j++) {
-                        outerProducts[i][j] += diffi * weight * (conditionalRootMean[j] - rootPriorMean[j]);
+                        outerProducts[i * dimTrait + j] += diffi * weight * (conditionalRootMean[j] - rootPriorMean[j]);
                     }
                 }
                 wishartStatistics.incrementDf(1);
@@ -336,9 +562,9 @@ public class FullyConjugateMultivariateTraitLikelihood extends IntegratedMultiva
             square = x * x * treePrecisionMatrix[0][0] * marginalVariance;
 
             if (computeWishartStatistics) {
-                final double[][] outerProducts = wishartStatistics.getScaleMatrix();
+                final double[] outerProducts = wishartStatistics.getScaleMatrix();
                 final double y = conditionalRootMean[0] - rootPriorMean[0];
-                outerProducts[0][0] += y * y * conditionalRootPrecision * rootPriorSampleSize * marginalVariance;
+                outerProducts[0] += y * y * conditionalRootPrecision * rootPriorSampleSize * marginalVariance;
                 wishartStatistics.incrementDf(1);
             }
         }
@@ -387,19 +613,82 @@ public class FullyConjugateMultivariateTraitLikelihood extends IntegratedMultiva
     protected double[] rootPriorMean;
     protected double rootPriorSampleSize;
 
+    double[] preP;
+    double[][] preMeans;
+
+    double[] storedPreP;
+    double[][] storedPreMeans;
+
+    Boolean PostPreKnown=false;
+    Boolean storedPostPreKnown=false;
+
     private boolean priorInformationKnown = false;
     private double zBz; // Prior sum-of-squares contribution
 
+    private boolean dimKnown=false;
+    private boolean storedDimKnown=false;
+    private int storedDim;
+    private int storedNumData;
+
     protected boolean computeWishartStatistics = false;
     private double[] ascertainedData = null;
     private static final boolean DEBUG_ASCERTAINMENT = false;
 
+    private double vectorMin(double[] vec) {
+        double min = Double.MAX_VALUE;
+        for (int i = 0; i < vec.length; ++i) {
+            min = Math.min(min, vec[i]);
+        }
+        return min;
+    }
+
+    private double matrixMin(double[][] mat) {
+        double min = Double.MAX_VALUE;
+        for (int i = 0; i < mat.length; ++i) {
+            min = Math.min(min, vectorMin(mat[i]));
+        }
+        return min;
+    }
+
+    private double vectorMax(double[] vec) {
+        double max = - Double.MAX_VALUE;
+        for (int i = 0; i < vec.length; ++i) {
+            max = Math.max(max, vec[i]);
+        }
+        return max;
+    }
+
+    private double matrixMax(double[][] mat) {
+        double max = -Double.MAX_VALUE;
+        for (int i = 0; i < mat.length; ++i) {
+            max = Math.max(max, vectorMax(mat[i]));
+        }
+        return max;
+    }
+
+    private double vectorSum(double[] vec) {
+        double sum = 0.0;
+        for (int i = 0; i < vec.length; ++i) {
+            sum += vec[i];
+        }
+        return sum;
+    }
+
+    private double matrixSum(double[][] mat) {
+        double sum = 0.0;
+        for (int i = 0; i < mat.length; ++i) {
+            sum += vectorSum(mat[i]);
+        }
+        return sum;
+    }
+
     @Override
     public String getReport() {
         StringBuilder sb = new StringBuilder();
 //        sb.append(this.g)
 //        System.err.println("Hello");
         sb.append("Tree:\n");
+        sb.append(getId()).append("\t");
         sb.append(treeModel.toString());
         sb.append("\n\n");
 
@@ -411,19 +700,37 @@ public class FullyConjugateMultivariateTraitLikelihood extends IntegratedMultiva
 
         sb.append("Tree variance:\n");
         sb.append(new Matrix(treeVariance));
+        sb.append(matrixMin(treeVariance)).append("\t").append(matrixMax(treeVariance)).append("\t").append(matrixSum(treeVariance));
         sb.append("\n\n");
         sb.append("Trait variance:\n");
         sb.append(traitVariance);
         sb.append("\n\n");
-        sb.append("Joint variance:\n");
-        sb.append(new Matrix(jointVariance));
+//        sb.append("Joint variance:\n");
+//        sb.append(new Matrix(jointVariance));
+//        sb.append("\n\n");
+
+        sb.append("Tree dim: " + treeVariance.length + "\n");
+        sb.append("data dim: " + jointVariance.length);
         sb.append("\n\n");
 
         double[] data = new double[jointVariance.length];
         System.arraycopy(meanCache, 0, data, 0, jointVariance.length);
 
+        if (nodeToClampMap != null) {
+            int offset = treeModel.getExternalNodeCount() * getDimTrait();
+            for(Map.Entry<NodeRef, RestrictedPartials> clamps : nodeToClampMap.entrySet()) {
+                double[] partials = clamps.getValue().getPartials();
+                for (int i = 0; i < partials.length; ++i) {
+                    data[offset] = partials[i];
+                    ++offset;
+                }
+            }
+        }
+
         sb.append("Data:\n");
-        sb.append(new Vector(data));
+        sb.append(new Vector(data)).append("\n");
+        sb.append(data.length).append("\t").append(vectorMin(data)).append("\t").append(vectorMax(data)).append("\t").append(vectorSum(data));
+        sb.append(treeModel.getNodeTaxon(treeModel.getExternalNode(0)).getId());
         sb.append("\n\n");
 
         MultivariateNormalDistribution mvn = new MultivariateNormalDistribution(new double[data.length], new Matrix(jointVariance).inverse().toComponents());
@@ -431,10 +738,10 @@ public class FullyConjugateMultivariateTraitLikelihood extends IntegratedMultiva
         sb.append("logLikelihood: " + getLogLikelihood() + " == " + logDensity + "\n\n");
 
         final WishartSufficientStatistics sufficientStatistics = getWishartStatistics();
-        final double[][] outerProducts = sufficientStatistics.getScaleMatrix();
+        final double[] outerProducts = sufficientStatistics.getScaleMatrix();
 
         sb.append("Outer-products (DP):\n");
-        sb.append(new Matrix(outerProducts));
+        sb.append(new Vector(outerProducts));
         sb.append(sufficientStatistics.getDf() + "\n");
 
         Matrix treePrecision = new Matrix(treeVariance).inverse();
@@ -463,36 +770,82 @@ public class FullyConjugateMultivariateTraitLikelihood extends IntegratedMultiva
     }
 
 
-    private double[][] computeTreeVariance(boolean includeRoot) {
+    class NodeToRootDistance {
+        NodeRef node;
+        double distance;
+
+        NodeToRootDistance(NodeRef node, double distance) {
+            this.node = node;
+            this.distance = distance;
+        }
+    }
+
+    class NodeToRootDistanceList extends ArrayList<NodeToRootDistance> {
+
+        NodeToRootDistanceList(NodeToRootDistanceList parentList) {
+            super(parentList);
+        }
+
+        NodeToRootDistanceList() {
+            super();
+        }
+    }
+
+    private void addNodeToList(final NodeRef thisNode, NodeToRootDistanceList parentList, NodeToRootDistanceList[] tipLists) {
+
+        if (!treeModel.isRoot(thisNode)) {
+            double increment = getRescaledBranchLengthForPrecision(thisNode);
+            if (parentList.size() > 0) {
+                increment += parentList.get(parentList.size() - 1).distance;
+            }
+            parentList.add(new NodeToRootDistance(thisNode, increment));
+        }
+
+        if (treeModel.isExternal(thisNode)) {
+            tipLists[thisNode.getNumber()] =  parentList;
+        } else { // recurse
+            NodeToRootDistanceList shallowCopy = new NodeToRootDistanceList(parentList);
+            addNodeToList(treeModel.getChild(thisNode, 0), shallowCopy, tipLists);
+            addNodeToList(treeModel.getChild(thisNode, 1), parentList, tipLists);
+        }
+    }
+
+    private double getTimeBetweenNodeToRootLists(List<NodeToRootDistance> x, List<NodeToRootDistance> y) {
+        if (x.get(0) != y.get(0)) {
+            return 0.0;
+        }
+
+        int index = 1;
+        while (x.get(index) == y.get(index)) {
+            ++index;
+        }
+        return x.get(index - 1).distance;
+    }
+
+    public double[][] computeTreeVariance2(boolean includeRoot) {
+
         final int tipCount = treeModel.getExternalNodeCount();
         double[][] variance = new double[tipCount][tipCount];
 
-        for (int i = 0; i < tipCount; i++) {
+        NodeToRootDistanceList[] tipToRootDistances = new NodeToRootDistanceList[tipCount];
 
+        // Recurse down tree to generate lists
+        addNodeToList(treeModel.getRoot(), new NodeToRootDistanceList(), tipToRootDistances);
+
+        for (int i = 0; i < tipCount; ++i) {
             // Fill in diagonal
-            double marginalTime = getRescaledLengthToRoot(treeModel.getExternalNode(i));
+            List<NodeToRootDistance> iList = tipToRootDistances[i];
+            double marginalTime = iList.get(iList.size() - 1).distance;
             variance[i][i] = marginalTime;
 
-            // Fill in upper right triangle,
+            for (int j = i + 1; j < tipCount; ++j) {
+                List<NodeToRootDistance> jList = tipToRootDistances[j];
 
-            for (int j = i + 1; j < tipCount; j++) {
-                NodeRef mrca = findMRCA(i, j);
-                variance[i][j] = getRescaledLengthToRoot(mrca);
+                double time = getTimeBetweenNodeToRootLists(iList, jList);
+                variance[j][i] = variance[i][j] = time;
             }
         }
 
-        // Make symmetric
-        for (int i = 0; i < tipCount; i++) {
-            for (int j = i + 1; j < tipCount; j++) {
-                variance[j][i] = variance[i][j];
-            }
-        }
-
-        if (DEBUG) {
-            System.err.println("");
-            System.err.println("New tree conditional variance:\n" + new Matrix(variance));
-        }
-
         variance = removeMissingTipsInTreeVariance(variance); // Automatically prune missing tips
 
         if (DEBUG) {
@@ -508,6 +861,91 @@ public class FullyConjugateMultivariateTraitLikelihood extends IntegratedMultiva
             }
         }
 
+        return variance;
+
+    }
+
+    public double[][] computeTreeVariance(boolean includeRoot) {
+        final int tipCount = treeModel.getExternalNodeCount();
+        int length = tipCount;
+
+        boolean DO_CLAMP = true;
+        if (DO_CLAMP && nodeToClampMap != null) {
+            length += nodeToClampMap.size();
+        }
+//        System.exit(-1);
+
+        double[][] variance = new double[length][length];
+
+        for (int i = 0; i < tipCount; i++) {
+
+            // Fill in diagonal
+            double marginalTime = getRescaledLengthToRoot(treeModel.getExternalNode(i));
+            variance[i][i] = marginalTime;
+
+            // Fill in upper right triangle,
+
+            for (int j = i + 1; j < tipCount; j++) {
+                NodeRef mrca = findMRCA(i, j);
+                variance[i][j] = getRescaledLengthToRoot(mrca);
+            }
+        }
+
+        if (DO_CLAMP && nodeToClampMap != null) {
+            List<RestrictedPartials> partialsList = new ArrayList<RestrictedPartials>();
+            for (Map.Entry<NodeRef, RestrictedPartials> keySet : nodeToClampMap.entrySet()) {
+                partialsList.add(keySet.getValue());
+            }
+
+            for (int i = 0; i < partialsList.size(); ++i) {
+                RestrictedPartials partials = partialsList.get(i);
+                NodeRef node = partials.getNode();
+
+                variance[tipCount + i][tipCount + i] = getRescaledLengthToRoot(node) +
+                        1.0 / partials.getPriorSampleSize();
+
+                for (int j = 0; j < tipCount; ++j) {
+                    NodeRef friend = treeModel.getExternalNode(j);
+                    NodeRef mrca = TreeUtils.getCommonAncestor(treeModel, node, friend);
+                    variance[j][tipCount + i] = getRescaledLengthToRoot(mrca);
+
+                }
+
+                for (int j = 0; j < i; ++j) {
+                    NodeRef friend = partialsList.get(j).getNode();
+                    NodeRef mrca = TreeUtils.getCommonAncestor(treeModel, node, friend);
+                    variance[tipCount + j][tipCount + i] = getRescaledLengthToRoot(mrca);
+                }
+            }
+        }
+
+        // Make symmetric
+        for (int i = 0; i < length; i++) {
+            for (int j = i + 1; j < length; j++) {
+                variance[j][i] = variance[i][j];
+            }
+        }
+
+//        if (DEBUG) {
+//            System.err.println("");
+//            System.err.println("New tree conditional variance:\n" + new Matrix(variance));
+//        }
+//
+//        variance = removeMissingTipsInTreeVariance(variance); // Automatically prune missing tips
+//
+//        if (DEBUG) {
+//            System.err.println("");
+//            System.err.println("New tree (trimmed) conditional variance:\n" + new Matrix(variance));
+//        }
+
+        if (includeRoot) {
+            for (int i = 0; i < variance.length; ++i) {
+                for (int j = 0; j < variance[i].length; ++j) {
+                    variance[i][j] += 1.0 / getPriorSampleSize();
+                }
+            }
+        }
+
         return variance;
     }
 
@@ -515,7 +953,7 @@ public class FullyConjugateMultivariateTraitLikelihood extends IntegratedMultiva
         Set<String> leafNames = new HashSet<String>();
         leafNames.add(treeModel.getTaxonId(iTip));
         leafNames.add(treeModel.getTaxonId(jTip));
-        return Tree.Utils.getCommonAncestorNode(treeModel, leafNames);
+        return TreeUtils.getCommonAncestorNode(treeModel, leafNames);
     }
 
     private double[][] removeMissingTipsInTreeVariance(double[][] variance) {
