@@ -36,7 +36,9 @@ import dr.util.CommonCitations;
 import dr.xml.*;
 
 import java.util.ArrayList;
+import java.util.LinkedHashMap;
 import java.util.List;
+import java.util.Map;
 import java.util.logging.Logger;
 
 public class MultinomialLatentLiabilityLikelihood extends AbstractModelLikelihood implements LatentTruncation, Citable, SoftThresholdLikelihood {
@@ -308,11 +310,20 @@ public class MultinomialLatentLiabilityLikelihood extends AbstractModelLikelihoo
         }
     };
 
+    @Override
+    public Citation.Category getCategory() {
+        return Citation.Category.TRAIT_MODELS;
+    }
+
+    @Override
+    public String getDescription() {
+        return "Latent Liability model";
+    }
+
+    @Override
     public List<Citation> getCitations() {
         List<Citation> citations = new ArrayList<Citation>();
-        citations.add(
-                CommonCitations.SUCHARD_2012_LATENT
-        );
+        citations.add(CommonCitations.CYBIS_2015_ASSESSING);
         return citations;
     }
 
