@@ -36,9 +36,7 @@ import dr.util.CommonCitations;
 import dr.xml.*;
 
 import java.util.ArrayList;
-import java.util.LinkedHashMap;
 import java.util.List;
-import java.util.Map;
 import java.util.logging.Logger;
 
 
@@ -63,17 +61,11 @@ public class OrderedLatentLiabilityLikelihood extends AbstractModelLikelihood im
         this.thresholdParameter = thresholdParameter;
         this.numClasses = numClasses;
         this.isUnordered = isUnordered;
+        this.NAcode = setNAcode();
 
         addVariable(tipTraitParameter);
         addVariable(thresholdParameter);
 
-
-        for (int i=0; i<tipTraitParameter.getParameterCount();i++){
-            tipTraitParameter.getParameter(i).addBounds(new Parameter.DefaultBounds(Double.POSITIVE_INFINITY,Double.NEGATIVE_INFINITY, tipTraitParameter.getParameter(0).getDimension()));
-        }
-
-
-
         setTipDataValuesForAllNodes();
 
         StringBuilder sb = new StringBuilder();
@@ -83,39 +75,75 @@ public class OrderedLatentLiabilityLikelihood extends AbstractModelLikelihood im
         Logger.getLogger("dr.evomodel.continous").info(sb.toString());
     }
 
+    public CompoundParameter getTipTraitParameter() {
+        return tipTraitParameter;
+    }
+
+    public PatternList getPatternList() {
+        return patternList;
+    }
+
     private void setTipDataValuesForAllNodes() {
         if (tipData == null) {
             tipData = new int[treeModel.getExternalNodeCount()][patternList.getPatternCount()];
         }
-
         for (int i = 0; i < treeModel.getExternalNodeCount(); i++) {
             NodeRef node = treeModel.getExternalNode(i);
             String id = treeModel.getTaxonId(i);
             int index = patternList.getTaxonIndex(id);
             setTipDataValuesForNode(node, index);
 
-            System.err.println("\t For node: " + i + " with ID " + id + " you get taxon " + index + " with ID " + patternList.getTaxonId(index));
+            if (DEBUG) {
+                System.err.println("\t For node: " + i + " with ID " + id + " you get taxon " + index + " with ID " + patternList.getTaxonId(index));
+            }
+        }
 
+        if (DEBUG) {
+            Bounds<Double> bounds = tipTraitParameter.getBounds();
+            for (int i = 0; i < tipTraitParameter.getDimension(); ++i) {
+                double value = tipTraitParameter.getParameterValue(i);
+                if (value <= bounds.getLowerLimit(i) || value >= bounds.getUpperLimit(i)) {
+                    System.err.println("tipTrait error: " + i);
+                    System.exit(-1);
+                }
+            }
 
+            System.err.println("Setup bounds correctly");
         }
     }
 
     private void setTipDataValuesForNode(NodeRef node, int index) {
         // Set tip data values
-        int Nindex = node.getNumber();
-        //   if (index != indexFromPatternList) {
-        //       throw new RuntimeException("Need to figure out the indexing");
-        //  }
+        final int Nindex = node.getNumber();
+        final int dim = tipTraitParameter.getParameter(0).getDimension();
+
+        // TODO - This class appears to work for only binary data; how does it handle ordered-multistate data?
+
+        // boolean isBinary = patternList.getDataType() == TwoStates.INSTANCE;
+
+        double[] upperBounds = new double[dim];
+        double[] lowerBounds = new double[dim];
 
         for (int datum = 0; datum < patternList.getPatternCount(); ++datum) {
             tipData[Nindex][datum] = (int) patternList.getPattern(datum)[index];
-            if (DEBUG) {
-                Parameter oneTipTraitParameter = tipTraitParameter.getParameter(Nindex);
-                System.err.println("Data = " + tipData[Nindex][datum] + " : " + oneTipTraitParameter.getParameterValue(datum));
-
 
+            switch(tipData[Nindex][datum]) {
+                case 0:
+                    upperBounds[datum] = 0;
+                    lowerBounds[datum] = Double.NEGATIVE_INFINITY;
+                    break;
+                case 1:
+                    upperBounds[datum] = Double.POSITIVE_INFINITY;
+                    lowerBounds[datum] = 0;
+                    break;
+                default:
+                    upperBounds[datum] = Double.POSITIVE_INFINITY;
+                    lowerBounds[datum] = Double.NEGATIVE_INFINITY;
+                    break;
             }
         }
+
+        tipTraitParameter.getParameter(Nindex).addBounds(new Parameter.DefaultBounds(upperBounds,lowerBounds));
     }
 
     @Override
@@ -162,22 +190,20 @@ public class OrderedLatentLiabilityLikelihood extends AbstractModelLikelihood im
 
     @Override
     public void setPathParameter(double beta) {
-        pathParameter=beta;
+        pathParameter = beta;
     }
 
     @Override
     public double getLikelihoodCorrection() {
-        boolean valid=true;
+        boolean valid = true;
         for (int tip = 0; tip < tipData.length && valid; ++tip) {
             valid = validTraitForTip(tip);
 
         }
-        if(valid)
-        {
+        if (valid) {
             return 0;
-        }
-        else{
-            return 1/(1-pathParameter);
+        } else {
+            return -1 / (1 - pathParameter);
         }
     }
 
@@ -190,184 +216,135 @@ public class OrderedLatentLiabilityLikelihood extends AbstractModelLikelihood im
 
         for (int tip = 0; tip < tipData.length && valid; ++tip) {
             valid = validTraitForTip(tip);
-
-
         }
 
-
-
         if (valid) {
             return 0.0;
         } else {
-            if(pathParameter==1)
+            if (pathParameter == 1) {
                 return Double.NEGATIVE_INFINITY;
-            else{
-                return Math.log(1-pathParameter);
+            } else {
+                return Math.log(1 - pathParameter);
             }
         }
     }
 
+    public int[] getData(int tip) {
+        return tipData[tip];
+    }
+
+ 
+
     public boolean validTraitForTip(int tip) {
         boolean valid = true;
         Parameter oneTipTraitParameter = tipTraitParameter.getParameter(tip);
         int[] data = tipData[tip];
 
+        if (!isUnordered) {
 
-       if (!isUnordered){
+            int threshNum = 0;
 
+            for (int index = 0; index < data.length && valid; ++index) {
 
+                int datum = data[index];
+                double trait = oneTipTraitParameter.getParameterValue(index);
+                int dim = (int) numClasses.getParameterValue(index);
 
-
-        int threshNum = 0;
-
-        for (int index = 0; index < data.length && valid; ++index) {
-
-            int datum = data[index];
-            double trait = oneTipTraitParameter.getParameterValue(index);
-            int dim = (int) numClasses.getParameterValue(index);
-
-
-
-
-            if (dim == 1.0) {
-                valid = true;
-            } else if (dim == 2.0){
-                if (trait == 0) {
+                if (dim == 1.0) {
                     valid = true;
-                }
-                else if(datum>1){
-                    valid=true;
-                } else {
-                    boolean positive = trait > 0.0;
-                    if (positive) {
-                        valid = (datum == 1.0);
+                } else if (dim == 2.0) {
+                    if (trait == 0) {
+                        valid = true;
+                    } else if (datum > 1) {
+                        valid = true;
                     } else {
-                        valid = (datum == 0.0);
+                        boolean positive = trait > 0.0;
+                        if (positive) {
+                            valid = (datum == 1.0);
+                        } else {
+                            valid = (datum == 0.0);
+                        }
+                    }
+                } else {
+                    if (datum == 0) {
+                        valid = trait <= 0.0;
+                    } else if (datum == 1) {
+                        valid = (trait >= 0 &&
+                                trait <= thresholdParameter.getParameter(threshNum).getParameterValue(0));
+                    } else if (datum == (dim - 1)) {
+                        valid = trait >= thresholdParameter.getParameter(threshNum).getParameterValue(dim - 3);
+                    } else if (datum > (dim - 1)) {
+                        valid = true;
+                    } else {
+                        valid = (trait >= thresholdParameter.getParameter(threshNum).getParameterValue(datum - 2) &&
+                                trait <= thresholdParameter.getParameter(threshNum).getParameterValue(datum - 1));
                     }
-                }
-            } else {
-                if (datum == 0) {
-                    valid = trait <= 0.0;
-                } else if (datum == 1) {
-                    valid = (trait >= 0 &&
-                            trait <= thresholdParameter.getParameter(threshNum).getParameterValue(0));
-                } else if (datum == (dim - 1)) {
-                    valid = trait >= thresholdParameter.getParameter(threshNum).getParameterValue(dim - 3);
-                } else if (datum > (dim-1)) {
-                    valid=true;
-                }else {
-                    valid = (trait >= thresholdParameter.getParameter(threshNum).getParameterValue(datum - 2) &&
-                            trait <= thresholdParameter.getParameter(threshNum).getParameterValue(datum - 1));
-                }
 
-                threshNum++;
+                    threshNum++;
+                }
             }
+        } else {
+            int LLpointer = 0;
+
+            for (int index = 0; index < data.length && valid; ++index) {
+
+                int datum = data[index];
+                int dim = (int) numClasses.getParameterValue(index);
+
+
+
+                if(datum==NAcode){
+                    valid = true;
+
+                    if(dim==1) {
+                        LLpointer++;
+                    }else{
+                    LLpointer+= dim-1;
+                    }
+
+                }else{
+
+
+                if (dim == 1.0) {
+                    valid = true;
+                    LLpointer++;
+                } else if (dim == 2.0) {
+
+                    double trait = oneTipTraitParameter.getParameterValue(LLpointer);
+
+
+                    if (trait == 0) {
+                        valid = true;
+                    } else {
+
+
+                        boolean positive = trait > 0.0;
+                        if (positive) {
+                            valid = (datum == 1.0);
+                        } else {
+                            valid = (datum == 0.0);
+                        }
+                    }
+                    LLpointer++;
+                } else {
+                    double[] trait = new double[dim];
+                    trait[0] = 0.0;
+                    for (int l = 1; l < dim; l++) {
+                        trait[l] = oneTipTraitParameter.getParameterValue(LLpointer + l - 1);
+                    }
+
+                    valid = isMax(trait, datum);
+
+                    LLpointer += dim - 1;
+                }
+
+
+            } }
         }
-       }else{
-           int LLpointer = 0;
-
-           for (int index = 0; index < data.length && valid; ++index) {
-
-               int datum = data[index];
-               int dim = (int) numClasses.getParameterValue(index);
-
-
-               if (dim == 1.0) {
-                   valid = true;
-                   LLpointer++;
-               } else if (dim == 2.0) {
-
-                   double trait = oneTipTraitParameter.getParameterValue(LLpointer);
-
-
-                   if (trait == 0) {
-                       valid = true;
-                   } else {
-
-
-                       boolean positive = trait > 0.0;
-                       if (positive) {
-                           valid = (datum == 1.0);
-                       } else {
-                           valid = (datum == 0.0);
-                       }
-                   }
-                   LLpointer++;
-               } else {
-                   double[] trait = new double[dim];
-                   trait[0] = 0.0;
-                   for (int l=1; l<dim; l++){
-                       trait[l]=oneTipTraitParameter.getParameterValue(LLpointer+l-1);
-                   }
-
-                   valid=isMax(trait, datum);
-
-
-                   LLpointer += dim-1;
-
-
-               }
-           }
-       }
 
         return valid;
     }
 
-
-
-  /*
-    public boolean unorderedValidTraitForTip(int tip) {
-        boolean valid = true;
-        Parameter oneTipTraitParameter = tipTraitParameter.getParameter(tip);
-        int[] data = tipData[tip];
-        int LLpointer = 0;
-
-        for (int index = 0; index < data.length && valid; ++index) {
-
-            int datum = data[index];
-            int dim = (int) numClasses.getParameterValue(index);
-
-
-            if (dim == 1.0) {
-                valid = true;
-                LLpointer++;
-            } else if (dim == 2.0) {
-
-                double trait = oneTipTraitParameter.getParameterValue(LLpointer);
-
-
-                if (trait == 0) {
-                    valid = true;
-                } else {
-
-
-                    boolean positive = trait > 0.0;
-                    if (positive) {
-                        valid = (datum == 1.0);
-                    } else {
-                        valid = (datum == 0.0);
-                    }
-                }
-                LLpointer++;
-            } else {
-                double[] trait = new double[dim];
-                trait[0] = 0.0;
-                for (int l=1; l<dim; l++){
-                    trait[l]=oneTipTraitParameter.getParameterValue(LLpointer+l-1);
-                }
-
-                valid=isMax(trait, datum);
-
-
-                LLpointer += dim-1;
-
-
-            }
-        }
-        return valid;
-    }
-  */
-
     private boolean isMax(double[] trait, int datum) {
 
         boolean isMax = true;
@@ -382,8 +359,18 @@ public class OrderedLatentLiabilityLikelihood extends AbstractModelLikelihood im
     }
 
 
+    private int setNAcode(){
+        int dim = numClasses.getDimension();
+        int max=0;
+        for (int i=0; i<dim; i++){
+         int num = (int) numClasses.getParameterValue(i);
+         if (num>max){
+             max=num;
+         }
 
-
+        }
+        return max;
+    }
 
 
     public double getNormalizationConstant(Distribution working) {
@@ -398,6 +385,10 @@ public class OrderedLatentLiabilityLikelihood extends AbstractModelLikelihood im
             return constant;
         }
     };
+
+    public Boolean getOrdering() {
+        return isUnordered;
+    }
     // **************************************************************
     // XMLObjectParser
     // **************************************************************
@@ -408,8 +399,8 @@ public class OrderedLatentLiabilityLikelihood extends AbstractModelLikelihood im
         public final static String THRESHOLD_PARAMETER = "threshold";
         public final static String NUM_CLASSES = "numClasses";
         public static final String IS_UNORDERED = "isUnordered";
-        public final static String N_DATA="NData";
-        public final static String N_TRAITS="NTraits";
+        public final static String N_DATA = "NData";
+        public final static String N_TRAITS = "NTraits";
 
 
         public String getParserName() {
@@ -417,47 +408,54 @@ public class OrderedLatentLiabilityLikelihood extends AbstractModelLikelihood im
         }
 
         public Object parseXMLObject(XMLObject xo) throws XMLParseException {
-            int numData;
-            int dimTrait;
-            if(xo.hasAttribute(N_DATA)&&xo.hasAttribute(N_TRAITS)){
-                String numDataTemp=(String) xo.getAttribute(N_DATA);
-                String dimTraitTemp=(String) xo.getAttribute(N_TRAITS);
-                numData= Integer.parseInt(numDataTemp);
-                dimTrait= Integer.parseInt(dimTraitTemp);
-            }
-            else {
-                AbstractMultivariateTraitLikelihood traitLikelihood = (AbstractMultivariateTraitLikelihood)
-                        xo.getChild(AbstractMultivariateTraitLikelihood.class);
-                numData = traitLikelihood.getNumData();
-                dimTrait = traitLikelihood.getDimTrait();
-            }
-            PatternList patternList = (PatternList) xo.getChild(PatternList.class);
+
             TreeModel treeModel = (TreeModel) xo.getChild(TreeModel.class);
-            CompoundParameter tipTraitParameter = (CompoundParameter) xo.getElementFirstChild(TIP_TRAIT);
-            CompoundParameter thresholdParameter = (CompoundParameter) xo.getElementFirstChild(THRESHOLD_PARAMETER);
-            Parameter numClasses = (Parameter) xo.getElementFirstChild(NUM_CLASSES);
-            boolean isUnorderd = xo.getAttribute(IS_UNORDERED,false);
-
-
             int numTaxa = treeModel.getTaxonCount();
 
+            CompoundParameter tipTraitParameter = (CompoundParameter) xo.getElementFirstChild(TIP_TRAIT);
 
-
-
-                if (tipTraitParameter.getDimension() != numTaxa * numData * dimTrait) {
-                    throw new XMLParseException("Tip trait parameter is wrong dimension in latent liability model");
-                }
-
-            if (!isUnorderd){
-
-                if (patternList.getPatternCount() != numData * dimTrait) {
-                    throw new XMLParseException("Data is wrong dimension in latent liability model");
+            int numData;
+            int dimTrait;
+            if (xo.hasAttribute(N_DATA) && xo.hasAttribute(N_TRAITS)) {
+                String numDataTemp = (String) xo.getAttribute(N_DATA);
+                String dimTraitTemp = (String) xo.getAttribute(N_TRAITS);
+                numData = Integer.parseInt(numDataTemp);
+                dimTrait = Integer.parseInt(dimTraitTemp);
+            } else {
+                AbstractMultivariateTraitLikelihood traitLikelihood = (AbstractMultivariateTraitLikelihood)
+                        xo.getChild(AbstractMultivariateTraitLikelihood.class);
+                if (traitLikelihood != null) {
+                    numData = traitLikelihood.getNumData();
+                    dimTrait = traitLikelihood.getDimTrait();
+                } else {
+                    numData = 1;
+                    if (tipTraitParameter.getParameterCount() != numTaxa) {
+                        throw new XMLParseException("Tip trait parameter is wrong dimension");
+                    }
+                    dimTrait = tipTraitParameter.getDimension() / numTaxa;
                 }
             }
 
+            PatternList patternList = (PatternList) xo.getChild(PatternList.class);
 
+            CompoundParameter thresholdParameter = (CompoundParameter) xo.getElementFirstChild(THRESHOLD_PARAMETER);
+            Parameter numClasses = (Parameter) xo.getElementFirstChild(NUM_CLASSES);
+            boolean isUnorderd = xo.getAttribute(IS_UNORDERED, false);
+            
+            if (tipTraitParameter.getDimension() != numTaxa * numData * dimTrait) {
+                throw new XMLParseException("Tip trait parameter is wrong dimension in latent liability model");
+            }
 
-            return new OrderedLatentLiabilityLikelihood(treeModel, patternList, tipTraitParameter, thresholdParameter, numClasses,isUnorderd);
+            if (!isUnorderd) {
+
+                if (patternList.getPatternCount() != numData * dimTrait) {
+                    throw new XMLParseException("Data are wrong dimension in latent liability model. "
+                            + "Pattern count = " + patternList.getPatternCount() + ", while per-taxon parameter dimension = "
+                            + (numData * dimTrait));
+                }
+            }
+
+            return new OrderedLatentLiabilityLikelihood(treeModel, patternList, tipTraitParameter, thresholdParameter, numClasses, isUnorderd);
         }
 
         //************************************************************************
@@ -473,16 +471,17 @@ public class OrderedLatentLiabilityLikelihood extends AbstractModelLikelihood im
         }
 
         private final XMLSyntaxRule[] rules = {
-                new OrRule(
-                new ElementRule(AbstractMultivariateTraitLikelihood.class, "The model for the latent random variables"),
-                new AndRule(AttributeRule.newIntegerRule(N_DATA), AttributeRule.newIntegerRule(N_TRAITS))
-                        ),
+                new XORRule(
+                        new ElementRule(AbstractMultivariateTraitLikelihood.class, true),
+                        new AndRule(AttributeRule.newIntegerRule(N_DATA),
+                                AttributeRule.newIntegerRule(N_TRAITS))
+                ),
                 new ElementRule(TIP_TRAIT, CompoundParameter.class, "The parameter of tip locations from the tree"),
                 new ElementRule(THRESHOLD_PARAMETER, CompoundParameter.class, "The parameter with nonzero thershold values"),
                 new ElementRule(NUM_CLASSES, Parameter.class, "Number of multinomial classes in each dimention"),
-                new ElementRule(PatternList.class, "The binary tip data"),
+                new ElementRule(PatternList.class, "The binary/multinomial tip data"),
                 new ElementRule(TreeModel.class, "The tree model"),
-                AttributeRule.newBooleanRule(IS_UNORDERED,true),
+                AttributeRule.newBooleanRule(IS_UNORDERED, true),
         };
 
         public Class getReturnType() {
@@ -513,6 +512,7 @@ public class OrderedLatentLiabilityLikelihood extends AbstractModelLikelihood im
     private CompoundParameter thresholdParameter;
     public Parameter numClasses;
     private Parameter containsMissing;
+    private int NAcode;
 
     private boolean isUnordered = false;
     private int[][] tipData;
@@ -524,5 +524,9 @@ public class OrderedLatentLiabilityLikelihood extends AbstractModelLikelihood im
 
     private static final boolean DEBUG = false;
 
-    private double pathParameter=1;
+    private double pathParameter = 1;
+
+    public Parameter getThreshold() {
+        return thresholdParameter;
+    }
 }
\ No newline at end of file
