@@ -25,7 +25,7 @@
 
 package dr.evomodel.continuous;
 
-import dr.evolution.tree.MultivariateTraitTree;
+import dr.evolution.tree.MutableTreeModel;
 import dr.evolution.tree.NodeRef;
 import dr.evomodel.branchratemodel.BranchRateModel;
 import dr.inference.model.CompoundParameter;
@@ -45,7 +45,7 @@ import java.util.List;
 public class SemiConjugateMultivariateTraitLikelihood extends IntegratedMultivariateTraitLikelihood {
 
     public SemiConjugateMultivariateTraitLikelihood(String traitName,
-                                                    MultivariateTraitTree treeModel,
+                                                    MutableTreeModel treeModel,
                                                     MultivariateDiffusionModel diffusionModel,
                                                     CompoundParameter traitParameter,
                                                     List<Integer> missingIndices,
@@ -56,10 +56,11 @@ public class SemiConjugateMultivariateTraitLikelihood extends IntegratedMultivar
                                                     Model samplingDensity,
                                                     boolean reportAsMultivariate,
                                                     MultivariateNormalDistribution rootPrior,
-                                                    boolean reciprocalRates) {
+                                                    boolean reciprocalRates,
+                                                    List<RestrictedPartials> partials) {
 
         super(traitName, treeModel, diffusionModel, traitParameter, null, missingIndices, cacheBranches, scaleByTime,
-                useTreeLength, rateModel, null, null, null, samplingDensity, reportAsMultivariate, reciprocalRates);
+                useTreeLength, rateModel, null, null, null, samplingDensity, partials, reportAsMultivariate, reciprocalRates);
 
         setRootPrior(rootPrior); // Semi-conjugate multivariate normal with own mean and precision
     }
