@@ -27,10 +27,10 @@ package dr.evomodel.epidemiology.casetocase;
 
 import dr.evolution.tree.NodeRef;
 import dr.evolution.tree.Tree;
+import dr.evolution.tree.TreeUtils;
 import dr.evolution.util.Date;
 import dr.evolution.util.Taxon;
 import dr.evolution.util.TaxonList;
-import dr.evomodel.tree.TreeModel;
 import dr.inference.model.CompoundParameter;
 import dr.inference.model.Parameter;
 import dr.inference.model.ParameterParser;
@@ -289,7 +289,7 @@ public class PartitionedTreeModelParser extends AbstractXMLObjectParser {
 //        treeModel.setupHeightBounds();
         //System.err.println("done constructing treeModel");
 
-        Logger.getLogger("dr.evomodel").info("  initial tree topology = " + Tree.Utils.uniqueNewick(treeModel, treeModel.getRoot()));
+        Logger.getLogger("dr.evomodel").info("  initial tree topology = " + TreeUtils.uniqueNewick(treeModel, treeModel.getRoot()));
         Logger.getLogger("dr.evomodel").info("  tree height = " + treeModel.getNodeHeight(treeModel.getRoot()));
         return treeModel;
     }
@@ -297,7 +297,7 @@ public class PartitionedTreeModelParser extends AbstractXMLObjectParser {
     private void setPrecisionBounds(Parameter newParameter, Taxon taxon) {
         Date date = taxon.getDate();
         if (date != null) {
-            double precision = date.getPrecision();
+            double precision = date.getUncertainty();
             if (precision > 0.0) {
                 // taxon date not specified to exact value so add appropriate bounds
                 double upper = Taxon.getHeightFromDate(date);
