@@ -1,20 +1,42 @@
+/*
+ * TransmissionSubtreeSlideB.java
+ *
+ * Copyright (c) 2002-2015 Alexei Drummond, Andrew Rambaut and Marc Suchard
+ *
+ * This file is part of BEAST.
+ * See the NOTICE file distributed with this work for additional
+ * information regarding copyright ownership and licensing.
+ *
+ * BEAST is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ *  BEAST is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with BEAST; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301  USA
+ */
+
 package dr.evomodel.epidemiology.casetocase.operators;
 
 import dr.evolution.tree.NodeRef;
 import dr.evolution.tree.Tree;
 import dr.evomodel.epidemiology.casetocase.AbstractCase;
-import dr.evomodel.epidemiology.casetocase.AbstractOutbreak;
 import dr.evomodel.epidemiology.casetocase.BranchMapModel;
 import dr.evomodel.epidemiology.casetocase.CaseToCaseTreeLikelihood;
 import dr.evomodel.operators.AbstractTreeOperator;
 import dr.evomodel.tree.TreeModel;
-import dr.inference.model.Parameter;
 import dr.inference.operators.*;
 import dr.math.MathUtils;
 import dr.xml.*;
 
 import java.util.ArrayList;
-import java.util.HashMap;
 import java.util.List;
 
 /**
@@ -23,7 +45,7 @@ import java.util.List;
  * @author Matthew Hall
  *
  */
-public class TransmissionSubtreeSlideB extends AbstractTreeOperator implements CoercableMCMCOperator {
+public class TransmissionSubtreeSlideB extends AbstractTreeOperator implements AdaptableMCMCOperator {
 
     private CaseToCaseTreeLikelihood c2cLikelihood;
     private TreeModel tree;
@@ -32,7 +54,7 @@ public class TransmissionSubtreeSlideB extends AbstractTreeOperator implements C
     private final boolean swapInRandomRate;
     private final boolean swapInRandomTrait;
     private final boolean resampleInfectionTimes;
-    private CoercionMode mode = CoercionMode.DEFAULT;
+    private AdaptationMode mode = AdaptationMode.DEFAULT;
     private static final boolean DEBUG = false;
     public static final String TRANSMISSION_SUBTREE_SLIDE_B = "transmissionSubtreeSlideB";
     public static final String SWAP_RATES = "swapInRandomRate";
@@ -40,7 +62,7 @@ public class TransmissionSubtreeSlideB extends AbstractTreeOperator implements C
     public static final String TARGET_ACCEPTANCE = "targetAcceptance";
 
     public TransmissionSubtreeSlideB(CaseToCaseTreeLikelihood c2cLikelihood, double weight, double size,
-                                     boolean gaussian, boolean swapRates, boolean swapTraits,  CoercionMode mode,
+                                     boolean gaussian, boolean swapRates, boolean swapTraits,  AdaptationMode mode,
                                      boolean resampleInfectionTimes) {
         this.c2cLikelihood = c2cLikelihood;
         tree = c2cLikelihood.getTreeModel();
@@ -69,11 +91,11 @@ public class TransmissionSubtreeSlideB extends AbstractTreeOperator implements C
      *
      * @return the log-transformed hastings ratio
      */
-    public double doOperation() throws OperatorFailedException {
+    public double doOperation() {
 
 
         if(DEBUG){
-            c2cLikelihood.debugOutputTree("beforeTSSB.nex", false);
+            c2cLikelihood.outputTreeToFile("beforeTSSB.nex", false);
         }
 
 
@@ -81,9 +103,6 @@ public class TransmissionSubtreeSlideB extends AbstractTreeOperator implements C
 
         double logq;
 
-        final NodeRef root = tree.getRoot();
-        final double oldTreeHeight = tree.getNodeHeight(root);
-
         NodeRef i;
 
         // 1. choose a random eligible node avoiding root
@@ -190,7 +209,7 @@ public class TransmissionSubtreeSlideB extends AbstractTreeOperator implements C
                 // Randomly assign iP the partition of either its parent or the child that is not i, and adjust q
                 // appropriately
 
-                if(branchMap.get(PiP.getNumber())!=branchMap.get(CiP.getNumber())){
+                if(PiPCase != CiPCase){
                     logq += Math.log(0.5);
                 }
 
@@ -312,7 +331,7 @@ public class TransmissionSubtreeSlideB extends AbstractTreeOperator implements C
                 // Randomly assign iP the partition of either its parent or the child that is not i, and adjust q
                 // appropriately
 
-                if(PiP!=null && branchMap.get(PiP.getNumber())!=branchMap.get(CiP.getNumber())){
+                if(PiP!=null && PiPCase != CiPCase){
                     logq += Math.log(0.5);
                 }
 
@@ -327,13 +346,11 @@ public class TransmissionSubtreeSlideB extends AbstractTreeOperator implements C
                         newiPCase = newChildCase;
                     }
 
-
                     if(resampleInfectionTimes) {
                         //whichever we picked for iP, it's the new child's case whose infection branch is modified
                         // (even if this infection branch is iP's branch)
 
                         newChildCase.setInfectionBranchPosition(MathUtils.nextDouble());
-
                     }
 
                     logq += Math.log(2);
@@ -376,11 +393,12 @@ public class TransmissionSubtreeSlideB extends AbstractTreeOperator implements C
 
         }
 
-        if (logq == Double.NEGATIVE_INFINITY) throw new OperatorFailedException("invalid slide");
+        // just return -Inf: will reject move
+//        if (logq == Double.NEGATIVE_INFINITY) throw new OperatorFailedException("invalid slide");
 
         if (DEBUG) {
-            c2cLikelihood.checkPartitions();
-            c2cLikelihood.debugOutputTree("afterTSSB.nex", false);
+            c2cLikelihood.getTreeModel().checkPartitions();
+            c2cLikelihood.outputTreeToFile("afterTSSB.nex", false);
         }
 
 
@@ -432,11 +450,11 @@ public class TransmissionSubtreeSlideB extends AbstractTreeOperator implements C
         this.size = size;
     }
 
-    public double getCoercableParameter() {
+    public double getAdaptableParameter() {
         return Math.log(getSize());
     }
 
-    public void setCoercableParameter(double value) {
+    public void setAdaptableParameter(double value) {
         setSize(Math.exp(value));
     }
 
@@ -444,13 +462,39 @@ public class TransmissionSubtreeSlideB extends AbstractTreeOperator implements C
         return getSize();
     }
 
-    public CoercionMode getMode() {
+    public AdaptationMode getMode() {
         return mode;
     }
 
+    @Override
+    public double getTargetAcceptanceProbability() {
+        return AbstractAdaptableOperator.DEFAULT_ADAPTATION_TARGET;
+    }
 
+    @Override
+    public String getAdaptableParameterName() {
+        return "size";
+    }
+
+    public double getMinimumAcceptanceLevel() {
+        return MINIMUM_ACCEPTANCE_LEVEL;
+    }
+
+    public double getMaximumAcceptanceLevel() {
+        return MAXIMUM_ACCEPTANCE_LEVEL;
+    }
+
+    public double getMinimumGoodAcceptanceLevel() {
+        return MINIMUM_GOOD_ACCEPTANCE_LEVEL;
+    }
+
+    public double getMaximumGoodAcceptanceLevel() {
+        return MAXIMUM_GOOD_ACCEPTANCE_LEVEL;
+    }
+
+    @Override
     public String getPerformanceSuggestion() {
-        return "not implemented";
+        return "";
     }
 
     public String getOperatorName() {
@@ -466,12 +510,12 @@ public class TransmissionSubtreeSlideB extends AbstractTreeOperator implements C
             boolean swapRates = xo.getAttribute(SWAP_RATES, false);
             boolean swapTraits = xo.getAttribute(SWAP_TRAITS, false);
 
-            CoercionMode mode = CoercionMode.DEFAULT;
-            if (xo.hasAttribute(CoercableMCMCOperator.AUTO_OPTIMIZE)) {
-                if (xo.getBooleanAttribute(CoercableMCMCOperator.AUTO_OPTIMIZE)) {
-                    mode = CoercionMode.COERCION_ON;
+            AdaptationMode mode = AdaptationMode.DEFAULT;
+            if (xo.hasAttribute(AdaptableMCMCOperator.AUTO_OPTIMIZE)) {
+                if (xo.getBooleanAttribute(AdaptableMCMCOperator.AUTO_OPTIMIZE)) {
+                    mode = AdaptationMode.ADAPTATION_ON;
                 } else {
-                    mode = CoercionMode.COERCION_OFF;
+                    mode = AdaptationMode.ADAPTATION_OFF;
                 }
             }
 
@@ -496,7 +540,7 @@ public class TransmissionSubtreeSlideB extends AbstractTreeOperator implements C
             final boolean gaussian = xo.getBooleanAttribute("gaussian");
             TransmissionSubtreeSlideB operator = new TransmissionSubtreeSlideB(c2cL, weight, size, gaussian,
                     swapRates, swapTraits, mode, resampleInfectionTimes);
-            operator.setTargetAcceptanceProbability(targetAcceptance);
+//            operator.setTargetAcceptanceProbability(targetAcceptance);
 
             return operator;
         }
@@ -525,7 +569,7 @@ public class TransmissionSubtreeSlideB extends AbstractTreeOperator implements C
                 AttributeRule.newBooleanRule("gaussian"),
                 AttributeRule.newBooleanRule(SWAP_RATES, true),
                 AttributeRule.newBooleanRule(SWAP_TRAITS, true),
-                AttributeRule.newBooleanRule(CoercableMCMCOperator.AUTO_OPTIMIZE, true),
+                AttributeRule.newBooleanRule(AdaptableMCMCOperator.AUTO_OPTIMIZE, true),
                 AttributeRule.newBooleanRule(RESAMPLE_INFECTION_TIMES, true),
                 new ElementRule(CaseToCaseTreeLikelihood.class)
         };
