@@ -26,9 +26,9 @@
 package dr.evomodel.operators;
 
 import dr.evolution.alignment.Alignment;
-import dr.evomodel.sitemodel.CategorySampleModel;
+import dr.math.MathUtils;
+import dr.oldevomodel.sitemodel.CategorySampleModel;
 import dr.inference.model.Parameter;
-import dr.inference.operators.OperatorFailedException;
 import dr.inference.operators.SimpleMCMCOperator;
 import dr.xml.*;
 import org.w3c.dom.Document;
@@ -58,9 +58,9 @@ public class CategoryOperator extends SimpleMCMCOperator {
     /**
      * Alter the category of one site
      */
-    public final double doOperation() throws OperatorFailedException {
+    public final double doOperation() {
 
-        int randomSite = (int) (Math.random() * siteCount);
+        int randomSite = (int) (MathUtils.nextDouble() * siteCount);
 
         int currentCategory = (int) categoryParameter.getParameterValue(randomSite);
 
@@ -77,7 +77,7 @@ public class CategoryOperator extends SimpleMCMCOperator {
             }
         }
 
-        int newCategory = temp[(int) (Math.random() * temp.length)];
+        int newCategory = temp[(int) (MathUtils.nextDouble() * temp.length)];
 
         categoryParameter.setParameterValue(randomSite, newCategory);
         siteModel.addSitesInCategoryCount(newCategory);
