@@ -33,9 +33,7 @@ import dr.evolution.tree.Tree;
 import dr.evomodel.tree.TreeModel;
 import dr.evomodelxml.operators.GibbsPruneAndRegraftParser;
 import dr.inference.model.Likelihood;
-import dr.inference.operators.OperatorFailedException;
 import dr.inference.operators.SimpleMetropolizedGibbsOperator;
-import dr.inference.prior.Prior;
 import dr.math.MathUtils;
 
 import java.util.ArrayList;
@@ -45,6 +43,8 @@ import java.util.List;
  * @author Sebastian Hoehna
  *
  */
+// Cleaning out untouched stuff. Can be resurrected if needed
+@Deprecated
 public class GibbsPruneAndRegraft extends SimpleMetropolizedGibbsOperator {
 
 	private int MAX_DISTANCE = 10;
@@ -76,17 +76,15 @@ public class GibbsPruneAndRegraft extends SimpleMetropolizedGibbsOperator {
 	 * .Prior, dr.inference.model.Likelihood)
 	 */
 	@Override
-	public double doOperation(Prior prior, Likelihood likelihood)
-			throws OperatorFailedException {
+	public double doOperation(Likelihood likelihood) {
 		if (pruned) {
-			return prunedGibbsProposal(prior, likelihood);
+			return prunedGibbsProposal(likelihood);
 		} else {
-			return GibbsProposal(prior, likelihood);
+			return gibbsProposal(likelihood);
 		}
 	}
 
-	private double GibbsProposal(Prior prior, Likelihood likelihood)
-			throws OperatorFailedException {
+	private double gibbsProposal(Likelihood likelihood) {
 
 		final int nodeCount = tree.getNodeCount();
 		final NodeRef root = tree.getRoot();
@@ -104,8 +102,7 @@ public class GibbsPruneAndRegraft extends SimpleMetropolizedGibbsOperator {
 		final NodeRef iP = tree.getParent(i);
 		final double heightIP = tree.getNodeHeight(iP);
 		double sum = 0.0;
-		double backwardLikelihood = calculateTreeLikelihood(prior, likelihood,
-				tree);
+		double backwardLikelihood = calculateTreeLikelihood(likelihood, tree);
 		int offset = (int) -backwardLikelihood;
 		double backward = Math.exp(backwardLikelihood + offset);
 		final NodeRef oldBrother = getOtherChild(tree, iP, i);
@@ -120,8 +117,7 @@ public class GibbsPruneAndRegraft extends SimpleMetropolizedGibbsOperator {
 					secondNodeIndices.add(n);
 
 					pruneAndRegraft(tree, i, iP, j, jP);
-					double prob = Math.exp(calculateTreeLikelihood(prior,
-							likelihood, tree)
+					double prob = Math.exp(calculateTreeLikelihood(likelihood, tree)
 							+ offset);
 					probabilities.add(prob);
 					sum += prob;
@@ -135,11 +131,11 @@ public class GibbsPruneAndRegraft extends SimpleMetropolizedGibbsOperator {
 			// hack
 			// the proposals have such a small likelihood that they can be
 			// neglected
-			throw new OperatorFailedException(
+			throw new RuntimeException(
 					"Couldn't find another proposal with a decent likelihood.");
 		}
 
-		double ran = Math.random() * sum;
+		double ran = MathUtils.nextDouble() * sum;
 		int index = 0;
 		while (ran > 0.0) {
 			ran -= probabilities.get(index);
@@ -161,8 +157,7 @@ public class GibbsPruneAndRegraft extends SimpleMetropolizedGibbsOperator {
 		return hastingsRatio;
 	}
 
-	private double prunedGibbsProposal(Prior prior, Likelihood likelihood)
-			throws OperatorFailedException {
+	private double prunedGibbsProposal(Likelihood likelihood) {
 		final int nodeCount = tree.getNodeCount();
 		final NodeRef root = tree.getRoot();
 
@@ -183,7 +178,7 @@ public class GibbsPruneAndRegraft extends SimpleMetropolizedGibbsOperator {
 		final NodeRef iP = tree.getParent(i);
 		final double heightIP = tree.getNodeHeight(iP);
 		double sum = 0.0;
-		double backwardLikelihood = calculateTreeLikelihood(prior, likelihood,
+		double backwardLikelihood = calculateTreeLikelihood(likelihood,
 				tree);
 		int offset = (int) -backwardLikelihood;
 		double backward = Math.exp(backwardLikelihood + offset);
@@ -200,7 +195,7 @@ public class GibbsPruneAndRegraft extends SimpleMetropolizedGibbsOperator {
 					secondNodeIndices.add(n);
 
 					pruneAndRegraft(tree, i, iP, j, jP);
-					double prob = Math.exp(calculateTreeLikelihood(prior,
+					double prob = Math.exp(calculateTreeLikelihood(
 							likelihood, tree)
 							+ offset);
 					probabilities.add(prob);
@@ -216,11 +211,11 @@ public class GibbsPruneAndRegraft extends SimpleMetropolizedGibbsOperator {
 			// hack
 			// the proposals have such a small likelihood that they can be
 			// neglected
-			throw new OperatorFailedException(
+			throw new RuntimeException(
 					"Couldn't find another proposal with a decent likelihood.");
 		}
 
-		double ran = Math.random() * sum;
+		double ran = MathUtils.nextDouble() * sum;
 		int index = 0;
 		while (ran > 0.0) {
 			ran -= probabilities.get(index);
@@ -250,13 +245,13 @@ public class GibbsPruneAndRegraft extends SimpleMetropolizedGibbsOperator {
 						sumBackward += scores[n];
 					} else {
 						pruneAndRegraft(tree, i, iP, j, jP);
-						double prob = Math.exp(calculateTreeLikelihood(prior,
+						double prob = Math.exp(calculateTreeLikelihood(
 								likelihood, tree)
 								+ offset);
 						sumBackward += prob;
 
 						pruneAndRegraft(tree, i, iP, newBrother, newGrandfather);
-						evaluate(likelihood, prior, 1.0);
+						evaluate(likelihood, 1.0);
 					}
 				}
 			}
@@ -296,13 +291,12 @@ public class GibbsPruneAndRegraft extends SimpleMetropolizedGibbsOperator {
 		}
 	}
 
-	private double calculateTreeLikelihood(Prior prior, Likelihood likelihood,
+	private double calculateTreeLikelihood(Likelihood likelihood,
 			TreeModel tree) {
-		return evaluate(likelihood, prior, 1.0);
+		return evaluate(likelihood, 1.0);
 	}
 
-	private void pruneAndRegraft(TreeModel tree, NodeRef i, NodeRef iP,
-			NodeRef j, NodeRef jP) throws OperatorFailedException {
+	private void pruneAndRegraft(TreeModel tree, NodeRef i, NodeRef iP, NodeRef j, NodeRef jP) {
 		tree.beginTreeEdit();
 
 		// the grandfather
