@@ -33,9 +33,7 @@ import dr.evolution.tree.NodeRef;
 import dr.evolution.tree.Tree;
 import dr.evomodel.tree.TreeModel;
 import dr.inference.model.Likelihood;
-import dr.inference.operators.OperatorFailedException;
 import dr.inference.operators.SimpleMetropolizedGibbsOperator;
-import dr.inference.prior.Prior;
 import dr.math.MathUtils;
 
 import java.util.ArrayList;
@@ -45,6 +43,8 @@ import java.util.List;
  * @author Sebastian Hoehna
  *
  */
+// Cleaning out untouched stuff. Can be resurrected if needed
+@Deprecated
 public class GibbsSubtreeSwap extends SimpleMetropolizedGibbsOperator {
 
     private int MAX_DISTANCE = 10;
@@ -77,13 +77,12 @@ public class GibbsSubtreeSwap extends SimpleMetropolizedGibbsOperator {
         return 1;
     }
 
-    public double doOperation(Prior prior, Likelihood likelihood)
-            throws OperatorFailedException {
+    public double doOperation(Likelihood likelihood) {
 
         if( pruned ) {
-            return prunedWide(prior, likelihood);
+            return prunedWide(likelihood);
         } else {
-            return wide(prior, likelihood);
+            return wide(likelihood);
         }
     }
 
@@ -92,8 +91,7 @@ public class GibbsSubtreeSwap extends SimpleMetropolizedGibbsOperator {
      *
      * @throws InvalidTreeException
      */
-    public double wide(Prior prior, Likelihood likelihood)
-            throws OperatorFailedException {
+    public double wide(Likelihood likelihood) {
 
         final int nodeCount = tree.getNodeCount();
         final NodeRef root = tree.getRoot();
@@ -115,7 +113,7 @@ public class GibbsSubtreeSwap extends SimpleMetropolizedGibbsOperator {
         double heightIP = tree.getNodeHeight(iP);
         double heightI = tree.getNodeHeight(i);
         double sum = 0.0;
-        double backward = calculateTreeLikelihood(prior, likelihood, tree);
+        double backward = calculateTreeLikelihood(likelihood, tree);
         int offset = (int) -backward;
         backward = Math.exp(backward + offset);
         for(int n = 0; n < nodeCount; n++) {
@@ -128,7 +126,7 @@ public class GibbsSubtreeSwap extends SimpleMetropolizedGibbsOperator {
                     secondNodeIndices.add(n);
 
                     swap(tree, i, j, iP, jP);
-                    double prob = Math.exp(calculateTreeLikelihood(prior,
+                    double prob = Math.exp(calculateTreeLikelihood(
                             likelihood, tree)
                             + offset);
                     probabilities.add(prob);
@@ -143,7 +141,7 @@ public class GibbsSubtreeSwap extends SimpleMetropolizedGibbsOperator {
             // hack
             // the proposals have such a small likelihood that they can be
             // neglected
-            throw new OperatorFailedException(
+            throw new RuntimeException(
                     "Couldn't find another proposal with a decent likelihood.");
         }
 
@@ -176,7 +174,7 @@ public class GibbsSubtreeSwap extends SimpleMetropolizedGibbsOperator {
                         && (heightJ < tree.getNodeHeight(kP)) ) {
 
                     swap(tree, j, k, jP, kP);
-                    double prob = Math.exp(calculateTreeLikelihood(prior,
+                    double prob = Math.exp(calculateTreeLikelihood(
                             likelihood, tree)
                             + offset);
                     sumForward2 += prob;
@@ -200,7 +198,7 @@ public class GibbsSubtreeSwap extends SimpleMetropolizedGibbsOperator {
                         && (heightI < tree.getNodeHeight(jP)) ) {
 
                     swap(tree, i, j, iP, jP);
-                    double prob = Math.exp(calculateTreeLikelihood(prior,
+                    double prob = Math.exp(calculateTreeLikelihood(
                             likelihood, tree)
                             + offset);
                     sumBackward += prob;
@@ -226,7 +224,7 @@ public class GibbsSubtreeSwap extends SimpleMetropolizedGibbsOperator {
                         && (heightJ < tree.getNodeHeight(kP)) ) {
 
                     swap(tree, j, k, jP, kP);
-                    double prob = Math.exp(calculateTreeLikelihood(prior,
+                    double prob = Math.exp(calculateTreeLikelihood(
                             likelihood, tree)
                             + offset);
                     sumBackward2 += prob;
@@ -252,8 +250,7 @@ public class GibbsSubtreeSwap extends SimpleMetropolizedGibbsOperator {
      *
      * @throws InvalidTreeException
      */
-    public double prunedWide(Prior prior, Likelihood likelihood)
-            throws OperatorFailedException {
+    public double prunedWide(Likelihood likelihood) {
 
         final int nodeCount = tree.getNodeCount();
         final NodeRef root = tree.getRoot();
@@ -275,7 +272,7 @@ public class GibbsSubtreeSwap extends SimpleMetropolizedGibbsOperator {
         double heightIP = tree.getNodeHeight(iP);
         double heightI = tree.getNodeHeight(i);
         double sum = 0.0;
-        double backward = calculateTreeLikelihood(prior, likelihood, tree);
+        double backward = calculateTreeLikelihood(likelihood, tree);
         int offset = (int) -backward;
         backward = Math.exp(backward + offset);
         for(int n = 0; n < nodeCount; n++) {
@@ -289,7 +286,7 @@ public class GibbsSubtreeSwap extends SimpleMetropolizedGibbsOperator {
                     secondNodeIndices.add(n);
 
                     swap(tree, i, j, iP, jP);
-                    double prob = Math.exp(calculateTreeLikelihood(prior,
+                    double prob = Math.exp(calculateTreeLikelihood(
                             likelihood, tree)
                             + offset);
                     probabilities.add(prob);
@@ -304,7 +301,7 @@ public class GibbsSubtreeSwap extends SimpleMetropolizedGibbsOperator {
             // hack
             // the proposals have such a small likelihood that they can be
             // neglected
-            throw new OperatorFailedException(
+            throw new RuntimeException(
                     "Couldn't find another proposal with a decent likelihood.");
         }
 
@@ -335,7 +332,7 @@ public class GibbsSubtreeSwap extends SimpleMetropolizedGibbsOperator {
                         && getNodeDistance(kP, jP) <= MAX_DISTANCE ) {
 
                     swap(tree, j, k, jP, kP);
-                    double prob = Math.exp(calculateTreeLikelihood(prior,
+                    double prob = Math.exp(calculateTreeLikelihood(
                             likelihood, tree)
                             + offset);
                     sumForward2 += prob;
@@ -360,7 +357,7 @@ public class GibbsSubtreeSwap extends SimpleMetropolizedGibbsOperator {
                         && getNodeDistance(iP, jP) <= MAX_DISTANCE ) {
 
                     swap(tree, i, j, iP, jP);
-                    double prob = Math.exp(calculateTreeLikelihood(prior,
+                    double prob = Math.exp(calculateTreeLikelihood(
                             likelihood, tree)
                             + offset);
                     sumBackward += prob;
@@ -387,7 +384,7 @@ public class GibbsSubtreeSwap extends SimpleMetropolizedGibbsOperator {
                         && getNodeDistance(kP, jP) <= MAX_DISTANCE ) {
 
                     swap(tree, j, k, jP, kP);
-                    double prob = Math.exp(calculateTreeLikelihood(prior,
+                    double prob = Math.exp(calculateTreeLikelihood(
                             likelihood, tree)
                             + offset);
                     sumBackward2 += prob;
@@ -408,9 +405,9 @@ public class GibbsSubtreeSwap extends SimpleMetropolizedGibbsOperator {
         return hastingsRatio;
     }
 
-    private double calculateTreeLikelihood(Prior prior, Likelihood likelihood,
+    private double calculateTreeLikelihood(Likelihood likelihood,
                                            TreeModel tree) {
-        return evaluate(likelihood, prior, 1.0);
+        return evaluate(likelihood, 1.0);
         // return 0.0;
     }
 
@@ -430,8 +427,7 @@ public class GibbsSubtreeSwap extends SimpleMetropolizedGibbsOperator {
     }
 
     /* exchange subtrees whose root are i and j */
-    private TreeModel swap(TreeModel tree, NodeRef i, NodeRef j, NodeRef iP,
-                           NodeRef jP) throws OperatorFailedException {
+    private TreeModel swap(TreeModel tree, NodeRef i, NodeRef j, NodeRef iP, NodeRef jP) {
 
         tree.beginTreeEdit();
         tree.removeChild(iP, i);
