@@ -41,7 +41,9 @@ import java.util.*;
  *
  * @author Andrew Rambaut
  */
-public class NodeHeightScaleOperator extends AbstractCoercableOperator {
+// Cleaning out untouched stuff. Can be resurrected if needed
+@Deprecated
+public class NodeHeightScaleOperator extends AbstractAdaptableOperator {
 
     public static final String NODE_HEIGHT_SCALE_OPERATOR = "nodeHeightScaleOperator";
     public static final String SCALE_FACTOR = ScaleOperatorParser.SCALE_FACTOR;
@@ -53,7 +55,7 @@ public class NodeHeightScaleOperator extends AbstractCoercableOperator {
     private final Map<Double, Integer> intervals = new TreeMap<Double, Integer>();
     private Parameter nodeHeightParameter;
 
-    public NodeHeightScaleOperator(TreeModel tree, double scale, boolean scaleAll, CoercionMode mode) {
+    public NodeHeightScaleOperator(TreeModel tree, double scale, boolean scaleAll, AdaptationMode mode) {
 
         super(mode);
 
@@ -72,7 +74,7 @@ public class NodeHeightScaleOperator extends AbstractCoercableOperator {
     /**
      * scale the rates of a subtree and return the hastings ratio.
      */
-    public final double doOperation() throws OperatorFailedException {
+    public final double doOperation() {
 
         final double scale = (scaleFactor + (MathUtils.nextDouble() * ((1.0 / scaleFactor) - scaleFactor)));
 
@@ -170,11 +172,11 @@ public class NodeHeightScaleOperator extends AbstractCoercableOperator {
         return "nodeHeightScale";
     }
 
-    public double getCoercableParameter() {
+    public double getAdaptableParameter() {
         return Math.log(1.0 / scaleFactor - 1.0);
     }
 
-    public void setCoercableParameter(double value) {
+    public void setAdaptableParameter(double value) {
         scaleFactor = 1.0 / (Math.exp(value) + 1.0);
     }
 
@@ -186,37 +188,9 @@ public class NodeHeightScaleOperator extends AbstractCoercableOperator {
         return scaleFactor;
     }
 
-    public double getTargetAcceptanceProbability() {
-        return 0.234;
-    }
-
-    public double getMinimumAcceptanceLevel() {
-        return 0.1;
-    }
-
-    public double getMaximumAcceptanceLevel() {
-        return 0.4;
-    }
-
-    public double getMinimumGoodAcceptanceLevel() {
-        return 0.20;
-    }
-
-    public double getMaximumGoodAcceptanceLevel() {
-        return 0.30;
-    }
-
-    public final String getPerformanceSuggestion() {
-
-        double prob = Utils.getAcceptanceProbability(this);
-        double targetProb = getTargetAcceptanceProbability();
-        dr.util.NumberFormatter formatter = new dr.util.NumberFormatter(5);
-        double sf = OperatorUtils.optimizeScaleFactor(scaleFactor, prob, targetProb);
-        if (prob < getMinimumGoodAcceptanceLevel()) {
-            return "Try setting scaleFactor to about " + formatter.format(sf);
-        } else if (prob > getMaximumGoodAcceptanceLevel()) {
-            return "Try setting scaleFactor to about " + formatter.format(sf);
-        } else return "";
+    @Override
+    public String getAdaptableParameterName() {
+        return "scaleFactor";
     }
 
 
@@ -228,7 +202,7 @@ public class NodeHeightScaleOperator extends AbstractCoercableOperator {
 
         public Object parseXMLObject(XMLObject xo) throws XMLParseException {
 
-            CoercionMode mode = CoercionMode.parseMode(xo);
+            AdaptationMode mode = AdaptationMode.parseMode(xo);
 
             final double weight = xo.getDoubleAttribute(WEIGHT);
             final double scaleFactor = xo.getDoubleAttribute(SCALE_FACTOR);
