@@ -37,7 +37,7 @@ import dr.xml.*;
 /**
  * @author Marc Suchard
  */
-public class RandomWalkOnMapOperator extends AbstractCoercableOperator {
+public class RandomWalkOnMapOperator extends AbstractAdaptableOperator {
 
     public static final String OPERATOR_NAME = "randomWalkOnMapOperator";
     public static final String WINDOW_SIZE = "windowSize";
@@ -48,7 +48,7 @@ public class RandomWalkOnMapOperator extends AbstractCoercableOperator {
     public RandomWalkOnMapOperator(Parameter parameter,
                                    MapDiffusionModel mapModel,
                                    double windowSize,
-                                   double weight, CoercionMode mode) {
+                                   double weight, AdaptationMode mode) {
         super(mode);
         this.parameter = parameter;
         this.model = mapModel;
@@ -80,7 +80,7 @@ public class RandomWalkOnMapOperator extends AbstractCoercableOperator {
     /**
      * change the parameter and return the hastings ratio.
      */
-    public final double doOperation() throws OperatorFailedException {
+    public final double doOperation() {
 
         // a random dimension to perturb
 
@@ -102,7 +102,8 @@ public class RandomWalkOnMapOperator extends AbstractCoercableOperator {
 
         if (map != null) {
             if (!map.isValidPoint(newX, newY)) {
-                throw new OperatorFailedException("proposed value outside boundaries");
+//                throw new OperatorFailedException("proposed value outside boundaries");
+                return Double.NEGATIVE_INFINITY;
             }
         }
 
@@ -124,11 +125,11 @@ public class RandomWalkOnMapOperator extends AbstractCoercableOperator {
     }
 
 
-    public double getCoercableParameter() {
+    public double getAdaptableParameter() {
         return Math.log(windowSize);
     }
 
-    public void setCoercableParameter(double value) {
+    public void setAdaptableParameter(double value) {
         windowSize = Math.exp(value);
     }
 
@@ -136,38 +137,8 @@ public class RandomWalkOnMapOperator extends AbstractCoercableOperator {
         return windowSize;
     }
 
-    public double getTargetAcceptanceProbability() {
-        return 0.234;
-    }
-
-    public double getMinimumAcceptanceLevel() {
-        return 0.1;
-    }
-
-    public double getMaximumAcceptanceLevel() {
-        return 0.4;
-    }
-
-    public double getMinimumGoodAcceptanceLevel() {
-        return 0.20;
-    }
-
-    public double getMaximumGoodAcceptanceLevel() {
-        return 0.30;
-    }
-
-    public final String getPerformanceSuggestion() {
-
-        double prob = MCMCOperator.Utils.getAcceptanceProbability(this);
-        double targetProb = getTargetAcceptanceProbability();
-
-        double ws = OperatorUtils.optimizeWindowSize(windowSize, parameter.getParameterValue(0) * 2.0, prob, targetProb);
-
-        if (prob < getMinimumGoodAcceptanceLevel()) {
-            return "Try decreasing windowSize to about " + ws;
-        } else if (prob > getMaximumGoodAcceptanceLevel()) {
-            return "Try increasing windowSize to about " + ws;
-        } else return "";
+    public String getAdaptableParameterName() {
+        return "windowSize";
     }
 
     public static dr.xml.XMLObjectParser PARSER = new AbstractXMLObjectParser() {
@@ -179,7 +150,7 @@ public class RandomWalkOnMapOperator extends AbstractCoercableOperator {
 
         public Object parseXMLObject(XMLObject xo) throws XMLParseException {
 
-            CoercionMode mode = CoercionMode.parseMode(xo);
+            AdaptationMode mode = AdaptationMode.parseMode(xo);
 
             double weight = xo.getDoubleAttribute(WEIGHT);
             double windowSize = xo.getDoubleAttribute(WINDOW_SIZE);
