@@ -28,9 +28,8 @@ package dr.evomodel.operators;
 import dr.evolution.tree.NodeRef;
 import dr.evomodel.tree.TreeModel;
 import dr.evomodelxml.operators.RateScaleOperatorParser;
-import dr.inference.operators.AbstractCoercableOperator;
-import dr.inference.operators.CoercionMode;
-import dr.inference.operators.OperatorFailedException;
+import dr.inference.operators.AbstractAdaptableOperator;
+import dr.inference.operators.AdaptationMode;
 import dr.inference.operators.OperatorUtils;
 import dr.math.MathUtils;
 
@@ -42,13 +41,13 @@ import java.util.List;
  *
  * @author Michael Defoin Platel
  */
-public class RateScaleOperator extends AbstractCoercableOperator {
+public class RateScaleOperator extends AbstractAdaptableOperator {
 
     private TreeModel tree;
 
     private boolean noRoot;
 
-    public RateScaleOperator(TreeModel tree, double scale, boolean noRoot, CoercionMode mode) {
+    public RateScaleOperator(TreeModel tree, double scale, boolean noRoot, AdaptationMode mode) {
 
         super(mode);
 
@@ -62,7 +61,7 @@ public class RateScaleOperator extends AbstractCoercableOperator {
     /**
      * scale the rates of a subtree and return the hastings ratio.
      */
-    public final double doOperation() throws OperatorFailedException {
+    public final double doOperation() {
 
         final double scale = (scaleFactor + (MathUtils.nextDouble() * ((1.0 / scaleFactor) - scaleFactor)));
 
@@ -118,11 +117,11 @@ public class RateScaleOperator extends AbstractCoercableOperator {
         return "rateScale";
     }
 
-    public double getCoercableParameter() {
+    public double getAdaptableParameter() {
         return Math.log(1.0 / scaleFactor - 1.0);
     }
 
-    public void setCoercableParameter(double value) {
+    public void setAdaptableParameter(double value) {
         scaleFactor = 1.0 / (Math.exp(value) + 1.0);
     }
 
@@ -134,37 +133,8 @@ public class RateScaleOperator extends AbstractCoercableOperator {
         return scaleFactor;
     }
 
-    public double getTargetAcceptanceProbability() {
-        return 0.234;
-    }
-
-    public double getMinimumAcceptanceLevel() {
-        return 0.1;
-    }
-
-    public double getMaximumAcceptanceLevel() {
-        return 0.4;
-    }
-
-    public double getMinimumGoodAcceptanceLevel() {
-        return 0.20;
-    }
-
-    public double getMaximumGoodAcceptanceLevel() {
-        return 0.30;
-    }
-
-    public final String getPerformanceSuggestion() {
-
-        double prob = Utils.getAcceptanceProbability(this);
-        double targetProb = getTargetAcceptanceProbability();
-        dr.util.NumberFormatter formatter = new dr.util.NumberFormatter(5);
-        double sf = OperatorUtils.optimizeScaleFactor(scaleFactor, prob, targetProb);
-        if (prob < getMinimumGoodAcceptanceLevel()) {
-            return "Try setting scaleFactor to about " + formatter.format(sf);
-        } else if (prob > getMaximumGoodAcceptanceLevel()) {
-            return "Try setting scaleFactor to about " + formatter.format(sf);
-        } else return "";
+    public String getAdaptableParameterName() {
+        return "scaleFactor";
     }
 
     public String toString() {
