@@ -25,11 +25,7 @@
 
 package dr.evomodel.operators;
 
-import dr.evomodel.continuous.AbstractMultivariateTraitLikelihood;
 import dr.evomodel.continuous.IntegratedMultivariateTraitLikelihood;
-import dr.evomodel.treelikelihood.AbstractLikelihoodCore;
-import dr.evomodel.treelikelihood.TreeLikelihood;
-import dr.inference.operators.OperatorFailedException;
 import dr.inference.operators.SimpleMCMCOperator;
 import dr.math.MathUtils;
 import dr.xml.*;
@@ -50,7 +46,7 @@ public class TipTraitSwapOperator extends SimpleMCMCOperator {
     private int index1;
     private int index2;
 
-    public double doOperation() throws OperatorFailedException {
+    public double doOperation() {
 
         int tipCount = traitLikelihood.getTreeModel().getExternalNodeCount();
 
@@ -81,16 +77,6 @@ public class TipTraitSwapOperator extends SimpleMCMCOperator {
         swap(index1, index2);
     }
 
-    public String getPerformanceSuggestion() {
-        if (Utils.getAcceptanceProbability(this) < getMinimumAcceptanceLevel()) {
-            return "";
-        } else if (Utils.getAcceptanceProbability(this) > getMaximumAcceptanceLevel()) {
-            return "";
-        } else {
-            return "";
-        }
-    }
-
     public String getOperatorName() {
         return TIP_TRAIT_SWAP_OPERATOR;
     }
