@@ -27,11 +27,11 @@ package dr.evomodel.operators;
 
 import dr.evolution.tree.NodeRef;
 import dr.evolution.tree.Tree;
+import dr.evolution.tree.TreeUtils;
 import dr.evomodel.speciation.SpeciesBindings;
 import dr.evomodel.speciation.SpeciesTreeModel;
 import dr.evomodelxml.operators.TreeNodeSlideParser;
 import dr.inference.model.Parameter;
-import dr.inference.operators.OperatorFailedException;
 import dr.inference.operators.SimpleMCMCOperator;
 import dr.math.MathUtils;
 import jebl.util.FixedBitSet;
@@ -47,6 +47,8 @@ import java.util.Arrays;
  *  @author Joseph Heled
  *         Date: 29/05/2008
  */
+// Cleaning out untouched stuff. Can be resurrected if needed
+@Deprecated
 public class TreeNodeSlide extends SimpleMCMCOperator {
 
     private final SpeciesTreeModel tree;
@@ -84,14 +86,14 @@ public class TreeNodeSlide extends SimpleMCMCOperator {
         return TreeNodeSlideParser.TREE_NODE_REHEIGHT + "(" + tree.getId() + "," + species.getId() + ")";
     }
 
-    public double doOperation() throws OperatorFailedException {
+    public double doOperation() {
         operateOneNode(0.0);
         return 0;
     }
 
     private void ptree(SpeciesTreeModel tree, NodeRef[] order, int[] preOrderIndex) {
-        System.err.println(Tree.Utils.uniqueNewick(tree, tree.getRoot()));
-        System.err.println(Tree.Utils.newick(tree));
+        System.err.println(TreeUtils.uniqueNewick(tree, tree.getRoot()));
+        System.err.println(TreeUtils.newick(tree));
         ptreenode(tree, tree.getRoot(), preOrderIndex, "");
         for(NodeRef anOrder : order) {
             System.err.print(anOrder.getNumber() + " ");
@@ -116,7 +118,7 @@ public class TreeNodeSlide extends SimpleMCMCOperator {
        }
     }
 
-    public void operateOneNode(final double factor) throws OperatorFailedException {
+    public void operateOneNode(final double factor) {
 
 //            #print "operate: tree", ut.treerep(t)
      //   if( verbose)  System.out.println("  Mau at start: " + tree.getSimpleTree());
