@@ -27,6 +27,8 @@ package dr.evomodel.tree;
 
 import dr.evolution.tree.NodeRef;
 import dr.evolution.tree.Tree;
+import dr.evolution.tree.TreeUtils;
+import dr.evolution.util.Taxon;
 import dr.evolution.util.TaxonList;
 import dr.inference.model.Statistic;
 
@@ -39,14 +41,26 @@ import java.util.Set;
  * @author Andrew Rambaut
  * @version $Id: TMRCAStatistic.java,v 1.21 2005/07/11 14:06:25 rambaut Exp $
  */
-public class TMRCAStatistic extends Statistic.Abstract implements TreeStatistic {
+public class TMRCAStatistic extends TreeStatistic {
 
-    public TMRCAStatistic(String name, Tree tree, TaxonList taxa, boolean isRate, boolean forParent)
-            throws Tree.MissingTaxonException {
+    public TMRCAStatistic(String name, Tree tree, TaxonList taxa, boolean absoluteTime, boolean forParent)
+            throws TreeUtils.MissingTaxonException {
         super(name);
         this.tree = tree;
-        this.leafSet = Tree.Utils.getLeavesForTaxa(tree, taxa);
-        this.isRate = isRate;
+        if (absoluteTime && Taxon.getMostRecentDate() != null) {
+            isBackwards = Taxon.getMostRecentDate().isBackwards();
+            mostRecentTipTime = Taxon.getMostRecentDate().getAbsoluteTimeValue();
+        } else {
+            // give node heights or taxa don't have dates
+            mostRecentTipTime = Double.NaN;
+            isBackwards = false;
+        }
+        if (taxa != null) {
+            this.leafSet = TreeUtils.getLeavesForTaxa(tree, taxa);
+        } else {
+            // if no taxa are given then use the root of the tree
+            this.leafSet = null;
+        }
         this.forParent = forParent;
     }
 
@@ -67,19 +81,32 @@ public class TMRCAStatistic extends Statistic.Abstract implements TreeStatistic
      */
     public double getStatisticValue(int dim) {
 
-        NodeRef node = Tree.Utils.getCommonAncestorNode(tree, leafSet);
-        if (forParent && !tree.isRoot(node))
-            node = tree.getParent(node);       
+        NodeRef node;
+        if (leafSet != null) {
+            node = TreeUtils.getCommonAncestorNode(tree, leafSet);
+            if (forParent && !tree.isRoot(node)) {
+                node = tree.getParent(node);
+            }
+        } else {
+            node = tree.getRoot();
+        }
         if (node == null) throw new RuntimeException("No node found that is MRCA of " + leafSet);
-        if (isRate) {
-            return tree.getNodeRate(node);
+
+        if (!Double.isNaN(mostRecentTipTime)) {
+            if (isBackwards) {
+                return mostRecentTipTime + tree.getNodeHeight(node);
+            } else {
+                return mostRecentTipTime - tree.getNodeHeight(node);
+            }
+        } else {
+            return tree.getNodeHeight(node);
         }
-        return tree.getNodeHeight(node);
     }
 
     private Tree tree = null;
     private Set<String> leafSet = null;
-    private final boolean isRate;
+    private final double mostRecentTipTime;
+    private final boolean isBackwards;
     private final boolean forParent;
 
 }
