@@ -1,7 +1,7 @@
 /*
  * TreeModel.java
  *
- * Copyright (c) 2002-2015 Alexei Drummond, Andrew Rambaut and Marc Suchard
+ * Copyright (c) 2002-2017 Alexei Drummond, Andrew Rambaut and Marc Suchard
  *
  * This file is part of BEAST.
  * See the NOTICE file distributed with this work for additional
@@ -29,10 +29,7 @@ import dr.evolution.tree.*;
 import dr.evolution.util.MutableTaxonListListener;
 import dr.evolution.util.Taxon;
 import dr.inference.model.*;
-import dr.util.Attributable;
-import dr.util.Author;
-import dr.util.Citable;
-import dr.util.Citation;
+import dr.util.*;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 
@@ -45,7 +42,7 @@ import java.util.*;
  * @author Alexei Drummond
  * @version $Id: TreeModel.java,v 1.129 2006/01/05 17:55:47 rambaut Exp $
  */
-public class TreeModel extends AbstractModel implements MultivariateTraitTree, Citable {
+public class TreeModel extends AbstractModel implements MutableTreeModel, Keywordable, Citable {
 
     //
     // Public stuff
@@ -60,17 +57,18 @@ public class TreeModel extends AbstractModel implements MultivariateTraitTree, C
         nodeCount = 0;
         externalNodeCount = 0;
         internalNodeCount = 0;
+        isTreeRandom = true;
     }
 
     public TreeModel(Tree tree) {
-        this(TREE_MODEL, tree, false, false);
+        this(TREE_MODEL, tree, false, false, false);
     }
 
-    public TreeModel(String id, Tree tree) { this(id, tree, false); }
+    public TreeModel(String id, Tree tree) { this(id, tree, false, false); }
 
-    public TreeModel(String id, Tree tree, boolean fixHeights) {
+    public TreeModel(String id, Tree tree, boolean fixHeights, boolean fixTree) {
 
-        this(id, tree, false, fixHeights);
+        this(id, tree, false, fixHeights, fixTree);
         setId(id);
     }
 
@@ -78,7 +76,7 @@ public class TreeModel extends AbstractModel implements MultivariateTraitTree, C
       * Useful for constructing a TreeModel from a NEXUS file entry
       */
 
-    public TreeModel(String name, Tree tree, boolean copyAttributes, boolean fixHeights) {
+    public TreeModel(String name, Tree tree, boolean copyAttributes, boolean fixHeights, boolean fixTree) {
 
         super(name);
 
@@ -92,6 +90,8 @@ public class TreeModel extends AbstractModel implements MultivariateTraitTree, C
             MutableTree.Utils.correctHeightsForTips(binaryTree);
         }
 
+        this.isTreeRandom = !fixTree;
+
         // clone the node structure (this will create the individual parameters)
         Node node = new Node(binaryTree, binaryTree.getRoot());
 
@@ -109,7 +109,7 @@ public class TreeModel extends AbstractModel implements MultivariateTraitTree, C
         root = node;
 
         do {
-            node = (Node) Tree.Utils.postorderSuccessor(this, node);
+            node = (Node) TreeUtils.postorderSuccessor(this, node);
 
             if (node.isExternal()) {
                 node.number = i;
@@ -175,7 +175,10 @@ public class TreeModel extends AbstractModel implements MultivariateTraitTree, C
     /**
      * Push a tree changed event into the event stack.
      */
-    public void pushTreeChangedEvent(TreeChangedEvent event) {
+    public void pushTreeChangedEvent(dr.evomodel.tree.TreeChangedEvent event) {
+
+        if (!isTreeRandom) throw new IllegalStateException("Attempting state change in fixed tree");
+
         if (inEdit) {
             treeChangedEvents.add(event);
         } else {
@@ -202,7 +205,7 @@ public class TreeModel extends AbstractModel implements MultivariateTraitTree, C
     }
 
 
-    private final List<TreeChangedEvent> treeChangedEvents = new ArrayList<TreeChangedEvent>();
+    private final List<dr.evomodel.tree.TreeChangedEvent> treeChangedEvents = new ArrayList<dr.evomodel.tree.TreeChangedEvent>();
 
     public boolean hasRates() {
         return hasRates;
@@ -212,7 +215,7 @@ public class TreeModel extends AbstractModel implements MultivariateTraitTree, C
         return inEdit;
     }
 
-    public class TreeChangedEvent {
+    public class TreeChangedEvent implements dr.evomodel.tree.TreeChangedEvent {
         static final int CHANGE_IN_ALL_INTERNAL_NODES = -2;
 
         final Node node;
@@ -233,10 +236,12 @@ public class TreeModel extends AbstractModel implements MultivariateTraitTree, C
             this.index = index;
         }
 
+        @Override
         public int getIndex() {
             return index;
         }
 
+        @Override
         public Node getNode() {
             return node;
         }
@@ -249,10 +254,12 @@ public class TreeModel extends AbstractModel implements MultivariateTraitTree, C
             return parameter == null;
         }
 
+        @Override
         public boolean isNodeChanged() {
             return node != null;
         }
 
+        @Override
         public boolean isNodeParameterChanged() {
             return parameter != null;
         }
@@ -475,7 +482,7 @@ public class TreeModel extends AbstractModel implements MultivariateTraitTree, C
     /**
      * Set a new node as root node.
      */
-    public final void setRoot(NodeRef newRoot) {
+    public void setRoot(NodeRef newRoot) {
 
         if (!inEdit) throw new RuntimeException("Must be in edit transaction to call this method!");
 
@@ -514,7 +521,7 @@ public class TreeModel extends AbstractModel implements MultivariateTraitTree, C
     private Node oldRoot;
 
     public boolean beginTreeEdit() {
-        if (inEdit) throw new RuntimeException("Alreading in edit transaction mode!");
+        if (inEdit) throw new RuntimeException("Already in edit transaction mode!");
 
         oldRoot = root;
 
@@ -540,7 +547,7 @@ public class TreeModel extends AbstractModel implements MultivariateTraitTree, C
             }
         }
 
-        for (TreeChangedEvent treeChangedEvent : treeChangedEvents) {
+        for (dr.evomodel.tree.TreeChangedEvent treeChangedEvent : treeChangedEvents) {
             listenerHelper.fireModelChanged(this, treeChangedEvent);
         }
         treeChangedEvents.clear();
@@ -621,7 +628,7 @@ public class TreeModel extends AbstractModel implements MultivariateTraitTree, C
      * in the same way as this TreeModel is set up. This method is package
      * private.
      */
-    void copyNodeStructure(Node[] destination) {
+    private void copyNodeStructure(Node[] destination) {
 
         if (nodes.length != destination.length) {
             throw new IllegalArgumentException("Node arrays are of different lengths");
@@ -685,6 +692,145 @@ public class TreeModel extends AbstractModel implements MultivariateTraitTree, C
 
     }
 
+    /**
+     * Modifies the current tree by adopting the provided collection of edges
+     * @param edges Edges are provided as index: child number; parent: array entry
+     * @param nodeHeights Also sets the node heights to the provided values
+     * @param childOrder Array that contains whether a child node is left or right child
+     */
+    public void adoptTreeStructure(int[] edges, double[] nodeHeights, int[] childOrder, String[] taxaNames) {
+
+        int[] nodeMap = createNodeMap(taxaNames);
+
+        if (this.nodeCount != edges.length) {
+            throw new RuntimeException("Incorrect number of edges provided: " + edges.length + " versus " + this.nodeCount + " nodes.");
+        }
+
+        //first remove all the child nodes of the internal nodes
+        for (int i = this.externalNodeCount; i < this.nodeCount; i++) {
+            int childCount = nodes[i].getChildCount();
+            for (int j = 0; j < childCount; j++) {
+                nodes[i].removeChild(j);
+            }
+        }
+
+        //start with setting the external node heights
+        for (int i = 0; i < this.getExternalNodeCount(); i++) {
+            this.setNodeHeight(this.getExternalNode(nodeMap[i]), nodeHeights[i]);
+        }
+        //set the internal node heights
+        for (int i = 0; i < (this.getExternalNodeCount() - 1); i++) {
+            //No just restart counting, will fix later on in the code by adding additionalTaxa variable
+            this.setNodeHeight(this.getInternalNode(i), nodeHeights[this.getExternalNodeCount() + i]);
+        }
+
+        int newRootIndex = -1;
+        //now add the parent-child links again to ALL the nodes
+        for (int i = 0; i < edges.length; i++) {
+            if (edges[i] != -1) {
+                //make distinction between external nodes and internal nodes
+                if (i < this.getExternalNodeCount()) {
+                    //external node
+                    this.addChild(this.getNode(edges[i]), this.getExternalNode(nodeMap[i]));
+                    System.out.println("external: " + edges[i] + " > " + nodeMap[i]);
+                } else {
+                    //internal node
+                    this.addChild(this.getNode(edges[i]), this.getNode(i));
+                    System.out.println("internal: " + edges[i] + " > " + i);
+                }
+            } else {
+                newRootIndex = i;
+            }
+        }
+
+        //not possible to determine correct ordering of child nodes in the loop where they're being assigned
+        //hence perform possible swaps in a separate loop
+
+        for (int i = 0; i < edges.length; i++) {
+                if (edges[i] != -1) {
+                    if(i < this.externalNodeCount) {
+                        if (childOrder[i] == 0 && nodes[edges[i]].getChild(0) != nodes[nodeMap[i]]) {
+                            //swap child nodes
+                            Node childOne = nodes[edges[i]].removeChild(0);
+                            Node childTwo = nodes[edges[i]].removeChild(1);
+                            nodes[edges[i]].addChild(childTwo);
+                            nodes[edges[i]].addChild(childOne);
+                        }
+                    }else{
+                        if (childOrder[i] == 0 && nodes[edges[i]].getChild(0) != nodes[i]) {
+                            //swap child nodes
+                            Node childOne = nodes[edges[i]].removeChild(0);
+                            Node childTwo = nodes[edges[i]].removeChild(1);
+                            nodes[edges[i]].addChild(childTwo);
+                            nodes[edges[i]].addChild(childOne);
+                        }
+                    }
+                }
+
+        }
+
+        this.setRoot(nodes[newRootIndex]);
+    }
+
+    private int[] createNodeMap(String[] taxaNames) {
+
+        System.out.println("Creating a node mapping:");
+
+        int external = this.getExternalNodeCount();
+
+        int[] nodeMap = new int[external];
+        for (int i = 0; i < taxaNames.length; i++) {
+            for (int j = 0; j < external; j++) {
+                if (taxaNames[i].equals(this.getNodeTaxon(this.getExternalNode(j)).getId())) {
+                    //taxon found
+                    nodeMap[i] = j;
+                }
+            }
+        }
+        return nodeMap;
+    }
+
+    /**
+     * Imports trait information from a file
+     * @param edges Edges are provided as index: child number; parent: array entry
+     * @param traitModels List of TreeParameterModel object that contain trait information
+     * @param traitValues Values to be copied into the List of TreeParameterModel objects
+     */
+    public void adoptTraitData(int[] edges, ArrayList<TreeParameterModel> traitModels, double[][] traitValues, String[] taxaNames) {
+        int[] nodeMap = createNodeMap(taxaNames);
+        int index = 0;
+
+        for (TreeParameterModel tpm : traitModels) {
+
+            for (int i = 0; i < this.getRoot().getNumber(); i++) {
+                if (i < this.getExternalNodeCount()) {
+                        tpm.setNodeValue(this, this.getExternalNode(nodeMap[i]), traitValues[index][i]);
+                        System.out.println("Setting external node " + this.getExternalNode(nodeMap[i]) + " to " + traitValues[index][i]);
+
+                    } else {
+                        tpm.setNodeValue(this, this.getNode(i), traitValues[index][i]);
+                        System.out.println("Setting internal node " + this.getNode(i ) + " to " + traitValues[index][i]);
+                    }
+            }
+
+            // In TreeParameterModel, when this.getRoot.getNumber() and rootNodeNumber.getValue(0) are not equal,
+            // handleRootMove() will get called and move parameter/trait values to different indices.  Here, we
+            // preemptively move around trait values (if necessary) so that if handleRootMove() gets called, the
+            // trait values end up in the correct indices.
+            if(this.getRoot().getNumber() < edges.length-1){
+                tpm.setNodeValue(this, this.getNode(this.getRoot().getNumber()+1), traitValues[index][this.getNodeCount()-1]);
+               // System.out.println("Setting node " + this.getNode(this.getRoot().getNumber()+1) + " " + " to " + traitValues[index][this.getNodeCount()-1]);
+            }
+
+            for (int i = this.getRoot().getNumber()+2; i < edges.length; i++) {
+                    tpm.setNodeValue(this, this.getNode(i), traitValues[index][i-1]);
+                   // System.out.println("Setting node " + this.getNode(i ) + " to " + traitValues[index][i-1]);
+            }
+
+            index++;
+        }
+    }
+
     /**
      * Recursive algorithm to copy a proposed tree structure into the current treeModel.
      */
@@ -927,7 +1073,7 @@ public class TreeModel extends AbstractModel implements MultivariateTraitTree, C
      * @return a string containing a newick representation of the tree
      */
     public final String getNewick() {
-        return Tree.Utils.newick(this);
+        return TreeUtils.newick(this);
     }
 
     /**
@@ -1072,9 +1218,7 @@ public class TreeModel extends AbstractModel implements MultivariateTraitTree, C
                                                boolean rootNode, boolean internalNodes,
                                                boolean leafNodes, boolean firesTreeEvents) {
 
-        if (!rootNode && !internalNodes && !leafNodes) {
-            throw new IllegalArgumentException("At least one of rootNode, internalNodes or leafNodes must be true");
-        }
+        checkValidFlags(rootNode, internalNodes, leafNodes);
 
         CompoundParameter parameter = new CompoundParameter(name);
 
@@ -1097,6 +1241,47 @@ public class TreeModel extends AbstractModel implements MultivariateTraitTree, C
         return parameter;
     }
 
+    public Parameter createNodeTraitsParameterAsMatrix(String name, int dim, double[] initialValues,
+                                               boolean rootNode, boolean internalNodes,
+                                               boolean leafNodes, boolean firesTreeEvents) {
+
+        checkValidFlags(rootNode, internalNodes, leafNodes);
+
+        final int rowDim = dim;
+        final int colDim = (rootNode ? 1 : 0)
+                + (internalNodes ? internalNodeCount - 1 : 0)
+                + (leafNodes ? externalNodeCount : 0);
+
+        FastMatrixParameter parameter = new FastMatrixParameter(name, rowDim, colDim, 0.0);
+        parameter.addBounds(new Parameter.DefaultBounds(Double.POSITIVE_INFINITY, Double.NEGATIVE_INFINITY,
+                rowDim * colDim));
+
+        hasTraits = true;
+
+        int parameterIndex = 0;
+        for (int i = externalNodeCount; i < nodeCount; i++) {
+            if ((rootNode && nodes[i] == root) || (internalNodes && nodes[i] != root)) {
+                nodes[i].addTraitParameter(name, parameter.getParameter(parameterIndex), initialValues, firesTreeEvents);
+                ++parameterIndex;
+            }
+        }
+
+        for (int i = 0; i < externalNodeCount; i++) {
+            if (leafNodes) {
+                nodes[i].addTraitParameter(name, parameter.getParameter(parameterIndex), initialValues, firesTreeEvents);
+                ++parameterIndex;
+            }
+        }
+
+        return parameter;
+    }
+
+    private void checkValidFlags(boolean rootNode, boolean internalNodes, boolean leafNodes) {
+        if (!rootNode && !internalNodes && !leafNodes) {
+            throw new IllegalArgumentException("At least one of rootNode, internalNodes or leafNodes must be true");
+        }
+    }
+
     private void swapAllTraits(Node n1, Node n2) {
 
         for (Map.Entry<String, Parameter> entry : n1.traitParameters.entrySet()) {
@@ -1224,13 +1409,7 @@ public class TreeModel extends AbstractModel implements MultivariateTraitTree, C
                 } else {
                     rateParameter = new Parameter.Default(1.0);
                 }
-                if (isRoot()) {
-                    rateParameter.setId("root.rate");
-                } else if (isExternal()) {
-                    rateParameter.setId(getTaxonId(getNumber()) + ".rate");
-                } else {
-                    rateParameter.setId("node" + getNumber() + ".rate");
-                }
+                setParameterId("rate", rateParameter);
                 rateParameter.addBounds(new Parameter.DefaultBounds(Double.POSITIVE_INFINITY, 0.0, 1));
                 addVariable(rateParameter);
             }
@@ -1240,29 +1419,10 @@ public class TreeModel extends AbstractModel implements MultivariateTraitTree, C
             createTraitParameter(name, initialValues.length, initialValues, firesTreeEvents);
         }
 
-        public final void createTraitParameter(String name, int dim, double[] initialValues, boolean firesTreeEvents) {
-
+        public final void addTraitParameter(String name, Parameter trait, double[] initialValues, boolean firesTreeEvents) {
             if (!traitParameters.containsKey(name)) {
-
-                Parameter trait = new Parameter.Default(dim);
-                if (isRoot()) {
-                    trait.setId("root." + name);
-                } else if (isExternal()) {
-                    trait.setId(getTaxonId(getNumber()) + "." + name);
-                } else {
-                    trait.setId("node" + getNumber() + "." + name);
-                }
-                trait.addBounds(new Parameter.DefaultBounds(Double.POSITIVE_INFINITY, Double.NEGATIVE_INFINITY, dim));
-
-                if (initialValues != null && initialValues.length > 0) {
-                    for (int i = 0; i < dim; i++) {
-                        if (initialValues.length == dim) {
-                            trait.setParameterValue(i, initialValues[i]);
-                        } else {
-                            trait.setParameterValue(i, initialValues[0]);
-                        }
-                    }
-                }
+                setParameterId(name, trait);
+                setParameterValues(trait, trait.getDimension(), initialValues);
 
                 traitParameters.put(name, trait);
 
@@ -1272,6 +1432,46 @@ public class TreeModel extends AbstractModel implements MultivariateTraitTree, C
             }
         }
 
+        private void setParameterValues(Parameter parameter, int dim, double[] initialValues) {
+            if (initialValues != null && initialValues.length > 0) {
+                for (int i = 0; i < dim; i++) {
+                    if (initialValues.length == dim) {
+                        parameter.setParameterValue(i, initialValues[i]);
+                    } else {
+                        parameter.setParameterValue(i, initialValues[0]);
+                    }
+                }
+            }
+        }
+
+        public final void createTraitParameter(String name, int dim, double[] initialValues, boolean firesTreeEvents) {
+
+            if (!traitParameters.containsKey(name)) {
+
+                Parameter trait = new Parameter.Default(dim);
+                setParameterId(name, trait);
+                trait.addBounds(new Parameter.DefaultBounds(Double.POSITIVE_INFINITY, Double.NEGATIVE_INFINITY, dim));
+
+                setParameterValues(trait, dim, initialValues);
+
+                traitParameters.put(name, trait);
+
+                if (firesTreeEvents) {
+                    addVariable(trait);
+                }
+            }
+        }
+
+        private void setParameterId(String name, Parameter trait) {
+            if (isRoot()) {
+                trait.setId("root." + name);
+            } else if (isExternal()) {
+                trait.setId(getTaxonId(getNumber()) + "." + name);
+            } else {
+                trait.setId("node" + getNumber() + "." + name);
+            }
+        }
+
         public final double getHeight() {
             return heightParameter.getParameterValue(0);
         }
@@ -1452,6 +1652,22 @@ public class TreeModel extends AbstractModel implements MultivariateTraitTree, C
         private Parameter nodeHeightParameter = null;
     }
 
+    // ***********************************************************************
+    // Interface: Keywordable
+    // ***********************************************************************
+
+    @Override
+    public void addKeyword(String keyword) {
+        keywords.add(keyword);
+    }
+
+    @Override
+    public List<String> getKeywords() {
+        return keywords;
+    }
+
+    private final List<String> keywords = new ArrayList<String>();
+
     // ***********************************************************************
     // Private members
     // ***********************************************************************
@@ -1494,11 +1710,17 @@ public class TreeModel extends AbstractModel implements MultivariateTraitTree, C
     private boolean hasRates = false;
     private boolean hasTraits = false;
     private boolean isTipDateSampled = false;
+    private final boolean isTreeRandom;
 
     public boolean isTipDateSampled() {
         return isTipDateSampled;
     }
 
+    @Override
+    public boolean isVariable() {
+        return isTreeRandom;
+    }
+
     @Override
     public Citation.Category getCategory() {
         return Citation.Category.TREE_PRIORS;
