@@ -1,7 +1,7 @@
 /*
  * TreeParameterModel.java
  *
- * Copyright (c) 2002-2012 Alexei Drummond, Andrew Rambaut and Marc Suchard
+ * Copyright (c) 2002-2015 Alexei Drummond, Andrew Rambaut and Marc Suchard
  *
  * This file is part of BEAST.
  * See the NOTICE file distributed with this work for additional
@@ -25,10 +25,7 @@
 
 package dr.evomodel.tree;
 
-import dr.evolution.tree.NodeRef;
-import dr.evolution.tree.Tree;
-import dr.evolution.tree.TreeDoubleTraitProvider;
-import dr.evolution.tree.TreeTrait;
+import dr.evolution.tree.*;
 import dr.inference.model.AbstractModel;
 import dr.inference.model.Model;
 import dr.inference.model.Parameter;
@@ -45,14 +42,13 @@ import dr.inference.model.Variable;
  */
 public class TreeParameterModel extends AbstractModel implements TreeTrait<Double>, TreeDoubleTraitProvider {
 
-    protected final TreeModel tree;
+    protected final MutableTreeModel tree;
 
     // The tree parameter;
     private final Parameter parameter;
 
     // the index of the root node.
-    private int rootNodeNumber;
-    private int storedRootNodeNumber;
+    private final Parameter rootNodeNumber;
 
     private boolean includeRoot = false;
 
@@ -67,7 +63,7 @@ public class TreeParameterModel extends AbstractModel implements TreeTrait<Doubl
      * @param parameter   the parameter to keep in sync with tree topology moves.
      * @param includeRoot tree if the parameter includes a value associated with the root node.
      */
-    public TreeParameterModel(TreeModel tree, Parameter parameter, boolean includeRoot) {
+    public TreeParameterModel(MutableTreeModel tree, Parameter parameter, boolean includeRoot) {
         this(tree, parameter, includeRoot, Intent.NODE);
     }
 
@@ -79,7 +75,7 @@ public class TreeParameterModel extends AbstractModel implements TreeTrait<Doubl
      * @param parameter   the parameter to keep in sync with tree topology moves.
      * @param includeRoot tree if the parameter includes a value associated with the root node.
      */
-    public TreeParameterModel(TreeModel tree, Parameter parameter, boolean includeRoot, Intent intent) {
+    public TreeParameterModel(MutableTreeModel tree, Parameter parameter, boolean includeRoot, Intent intent) {
 
         super("treeParameterModel");
         this.tree = tree;
@@ -100,8 +96,9 @@ public class TreeParameterModel extends AbstractModel implements TreeTrait<Doubl
         addModel(tree);
         addVariable(parameter);
 
-        rootNodeNumber = tree.getRoot().getNumber();
-        storedRootNodeNumber = rootNodeNumber;
+        rootNodeNumber = new Parameter.Default(parameter.getId() + ".rootNodeNumber");
+        rootNodeNumber.setParameterValue(0, tree.getRoot().getNumber());
+        addVariable(rootNodeNumber);
     }
 
     public int getParameterSize() {
@@ -127,11 +124,11 @@ public class TreeParameterModel extends AbstractModel implements TreeTrait<Doubl
     }
 
     protected void storeState() {
-        storedRootNodeNumber = rootNodeNumber;
+        //rootNodeNumber.storeParameterValues();
     }
 
     protected void restoreState() {
-        rootNodeNumber = storedRootNodeNumber;
+        //rootNodeNumber.restoreParameterValues();
     }
 
     protected void acceptState() {
@@ -145,7 +142,7 @@ public class TreeParameterModel extends AbstractModel implements TreeTrait<Doubl
 
         assert (!tree.isRoot(node) || includeRoot) : "root node doesn't have a parameter value!";
 
-        assert tree.getRoot().getNumber() == rootNodeNumber :
+        assert !includeRoot || tree.getRoot().getNumber() == rootNodeNumber.getValue(0).intValue() :
                 "INTERNAL ERROR! node with number " + rootNodeNumber + " should be the root node.";
 
         int nodeNumber = node.getNumber();
@@ -157,7 +154,7 @@ public class TreeParameterModel extends AbstractModel implements TreeTrait<Doubl
 
         assert (!tree.isRoot(node) && !includeRoot) : "root node doesn't have a parameter value!";
 
-        assert tree.getRoot().getNumber() == rootNodeNumber :
+        assert tree.getRoot().getNumber() == rootNodeNumber.getValue(0).intValue() :
                 "INTERNAL ERROR! node with number " + rootNodeNumber + " should be the root node.";
 
         int nodeNumber = node.getNumber();
@@ -179,39 +176,42 @@ public class TreeParameterModel extends AbstractModel implements TreeTrait<Doubl
 
         if (!includeRoot) {
 
+            final int oldRootNodeNumber = rootNodeNumber.getValue(0).intValue();
             final int newRootNodeNumber = tree.getRoot().getNumber();
 
-            if (rootNodeNumber > newRootNodeNumber) {
+            if (oldRootNodeNumber != newRootNodeNumber) {
+                if (oldRootNodeNumber > newRootNodeNumber) {
 
-                final double oldValue = parameter.getParameterValue(newRootNodeNumber);
+                    final double oldValue = parameter.getParameterValue(newRootNodeNumber);
 
-                final int end = Math.min(parameter.getDimension() - 1, rootNodeNumber);
-                for (int i = newRootNodeNumber; i < end; i++) {
-                    parameter.setParameterValue(i, parameter.getParameterValue(i + 1));
+                    final int end = Math.min(parameter.getDimension() - 1, oldRootNodeNumber);
+                    for (int i = newRootNodeNumber; i < end; i++) {
+                        parameter.setParameterValue(i, parameter.getParameterValue(i + 1));
+                    }
+
+                    parameter.setParameterValue(end, oldValue);
+
+                } else if (oldRootNodeNumber < newRootNodeNumber) {
+
+                    final int end = Math.min(parameter.getDimension() - 1, newRootNodeNumber);
+
+                    final double oldValue = parameter.getParameterValue(end);
+
+                    for (int i = end; i > oldRootNodeNumber; i--) {
+                        parameter.setParameterValue(i, parameter.getParameterValue(i - 1));
+                    }
+
+                    parameter.setParameterValue(oldRootNodeNumber, oldValue);
                 }
-
-                parameter.setParameterValue(end, oldValue);
-
-            } else if (rootNodeNumber < newRootNodeNumber) {
-
-                final int end = Math.min(parameter.getDimension() - 1, newRootNodeNumber);
-
-                final double oldValue = parameter.getParameterValue(end);
-
-                for (int i = end; i > rootNodeNumber; i--) {
-                    parameter.setParameterValue(i, parameter.getParameterValue(i - 1));
-                }
-
-                parameter.setParameterValue(rootNodeNumber, oldValue);
+                rootNodeNumber.setParameterValue(0, newRootNodeNumber);
             }
-            rootNodeNumber = newRootNodeNumber;
         }
     }
 
     /**
      * @return the tree model that this parameter is synchronized with
      */
-    public TreeModel getTreeModel() {
+    public MutableTreeModel getTreeModel() {
         return tree;
     }
 
