@@ -27,6 +27,7 @@ package dr.evomodel.tree;
 
 import dr.evolution.tree.Tree;
 import dr.evolution.tree.TreeShape;
+import dr.evolution.tree.TreeUtils;
 import dr.inference.model.Statistic;
 
 
@@ -36,12 +37,12 @@ import dr.inference.model.Statistic;
  * @author Alexei Drummond
  * @version $Id: TreeShapeStatistic.java,v 1.4 2005/07/11 14:06:25 rambaut Exp $
  */
-public class TreeShapeStatistic extends Statistic.Abstract implements TreeStatistic {
+public class TreeShapeStatistic extends TreeStatistic {
 
     public TreeShapeStatistic(String name, TreeModel target) {
         super(name);
         this.target = target;
-        ultrametric = Tree.Utils.isUltrametric(target);
+        ultrametric = TreeUtils.isUltrametric(target);
     }
 
     public void setTree(Tree tree) {
