@@ -35,9 +35,9 @@ import dr.inference.model.Variable;
 import dr.util.Author;
 import dr.util.Citable;
 import dr.util.Citation;
+import dr.util.CommonCitations;
 
-import java.util.ArrayList;
-import java.util.List;
+import java.util.*;
 
 /**
  * @author Marc A. Suchard
@@ -105,17 +105,21 @@ public abstract class TreeTransform extends AbstractModel implements TreeTraitPr
 
     private final Helper treeTraits = new Helper();
 
-    public List<Citation> getCitations() {
-        List<Citation> citations = new ArrayList<Citation>();
-        citations.add(
-                new Citation(
-                        new Author[]{
-                                new Author("P", "Lemey"),
-                                new Author("MA", "Suchard"),
-                        },
-                        Citation.Status.IN_PREPARATION
-                ));
-        return citations;
+    @Override
+    public Citation.Category getCategory() {
+        return Citation.Category.TRAIT_MODELS;
     }
+
+    @Override
+    public String getDescription() {
+        return "Branch-specific phenotypic mixture model";
+    }
+
+    @Override
+    public List<Citation> getCitations() {
+        return Collections.singletonList(CommonCitations.VRANCKEN_2015_SIMULTANEOUSLY);
+    }
+
+
 }
 
