@@ -29,35 +29,26 @@ import dr.evolution.alignment.PatternList;
 import dr.evolution.datatype.DataType;
 import dr.evolution.tree.NodeRef;
 import dr.evomodel.tree.TreeModel;
-import dr.inference.model.AbstractModelLikelihood;
-import dr.inference.model.Model;
-import dr.inference.model.Parameter;
-import dr.inference.model.Variable;
+import dr.inference.model.*;
 import dr.xml.Reportable;
 
 /**
  * AbstractTreeLikelihood - a base class for likelihood calculators of sites on a tree.
  *
  * @author Andrew Rambaut
+ * @author Marc Suchard
  * @version $Id: AbstractTreeLikelihood.java,v 1.16 2005/06/07 16:27:39 alexei Exp $
  */
 
+@Deprecated // Switching to TreeDataLikelihood
 public abstract class AbstractTreeLikelihood extends AbstractModelLikelihood implements Reportable {
 
     protected static final boolean COUNT_TOTAL_OPERATIONS = true;
 
-    public AbstractTreeLikelihood(String name, PatternList patternList,
-                                  TreeModel treeModel) {
+    public AbstractTreeLikelihood(String name, TreeModel treeModel) {
 
         super(name);
 
-        this.patternList = patternList;
-        this.dataType = patternList.getDataType();
-        patternCount = patternList.getPatternCount();
-        stateCount = dataType.getStateCount();
-
-        patternWeights = patternList.getPatternWeights();
-
         this.treeModel = treeModel;
         addModel(treeModel);
 
@@ -70,92 +61,16 @@ public abstract class AbstractTreeLikelihood extends AbstractModelLikelihood imp
 
         likelihoodKnown = false;
 
+        hasInitialized = true;
     }
 
+
     /**
-     * Sets the partials from a sequence in an alignment.
-     */
-    protected final void setStates(LikelihoodCore likelihoodCore, PatternList patternList,
-                                   int sequenceIndex, int nodeIndex) {
-        int i;
-
-        int[] states = new int[patternCount];
-
-        for (i = 0; i < patternCount; i++) {
-
-            states[i] = patternList.getPatternState(sequenceIndex, i);
-        }
-
-        likelihoodCore.setNodeStates(nodeIndex, states);
-    }
-
-    public TreeModel getTreeModel() {
-        return treeModel;
-    }
-
-    /**
-     * Sets the partials from a sequence in an alignment.
-     */
-    protected final void setPartials(LikelihoodCore likelihoodCore, PatternList patternList,
-                                     int categoryCount,
-                                     int sequenceIndex, int nodeIndex) {
-        double[] partials = new double[patternCount * stateCount];
-
-        boolean[] stateSet;
-
-        int v = 0;
-        for (int i = 0; i < patternCount; i++) {
-
-            int state = patternList.getPatternState(sequenceIndex, i);
-            stateSet = dataType.getStateSet(state);
-
-            for (int j = 0; j < stateCount; j++) {
-                if (stateSet[j]) {
-                    partials[v] = 1.0;
-                } else {
-                    partials[v] = 0.0;
-                }
-                v++;
-            }
-        }
-
-        likelihoodCore.setNodePartials(nodeIndex, partials);
-    }
-
-    /**
-     * Sets the partials from a sequence in an alignment.
-     */
-    protected final void setMissingStates(LikelihoodCore likelihoodCore, int nodeIndex) {
-        int[] states = new int[patternCount];
-
-        for (int i = 0; i < patternCount; i++) {
-            states[i] = dataType.getGapState();
-        }
-
-        likelihoodCore.setNodeStates(nodeIndex, states);
-    }
-
-    /**
-     * Sets the partials from a sequence in an alignment.
-     */
-    protected final void setMissingPartials(LikelihoodCore likelihoodCore, int nodeIndex) {
-        double[] partials = new double[patternCount * stateCount];
-
-        int v = 0;
-        for (int i = 0; i < patternCount; i++) {
-            for (int j = 0; j < stateCount; j++) {
-                partials[v] = 1.0;
-                v++;
-            }
-        }
-
-        likelihoodCore.setNodePartials(nodeIndex, partials);
-    }
-
-    /**
-     * Set update flag for a node and its children
+     * Set update flag for a node only
      */
     protected void updateNode(NodeRef node) {
+        if (COUNT_TOTAL_OPERATIONS)
+            totalRateUpdateSingleCount++;
 
         updateNode[node.getNumber()] = true;
         likelihoodKnown = false;
@@ -165,9 +80,15 @@ public abstract class AbstractTreeLikelihood extends AbstractModelLikelihood imp
      * Set update flag for a node and its direct children
      */
     protected void updateNodeAndChildren(NodeRef node) {
+        if (COUNT_TOTAL_OPERATIONS)
+            totalRateUpdateSingleCount++;
+
         updateNode[node.getNumber()] = true;
 
         for (int i = 0; i < treeModel.getChildCount(node); i++) {
+            if (COUNT_TOTAL_OPERATIONS)
+                totalRateUpdateSingleCount++;
+
             NodeRef child = treeModel.getChild(node, i);
             updateNode[child.getNumber()] = true;
         }
@@ -178,6 +99,9 @@ public abstract class AbstractTreeLikelihood extends AbstractModelLikelihood imp
      * Set update flag for a node and all its descendents
      */
     protected void updateNodeAndDescendents(NodeRef node) {
+        if (COUNT_TOTAL_OPERATIONS)
+            totalRateUpdateSingleCount++;
+
         updateNode[node.getNumber()] = true;
 
         for (int i = 0; i < treeModel.getChildCount(node); i++) {
@@ -192,42 +116,15 @@ public abstract class AbstractTreeLikelihood extends AbstractModelLikelihood imp
      * Set update flag for all nodes
      */
     protected void updateAllNodes() {
+        if (COUNT_TOTAL_OPERATIONS)
+            totalRateUpdateAllCount++;
+
         for (int i = 0; i < nodeCount; i++) {
             updateNode[i] = true;
         }
         likelihoodKnown = false;
     }
 
-    /**
-     * Set update flag for a pattern
-     */
-    protected void updatePattern(int i) {
-        if (updatePattern != null) {
-            updatePattern[i] = true;
-        }
-        likelihoodKnown = false;
-    }
-
-    /**
-     * Set update flag for all patterns
-     */
-    protected void updateAllPatterns() {
-        if (updatePattern != null) {
-            for (int i = 0; i < patternCount; i++) {
-                updatePattern[i] = true;
-            }
-        }
-        likelihoodKnown = false;
-    }
-
-    public final double[] getPatternWeights() {
-        return patternWeights;
-    }
-
-    public final int getPatternCount() {
-        return patternCount;
-    }
-
     // **************************************************************
     // VariableListener IMPLEMENTATION
     // **************************************************************
@@ -241,6 +138,8 @@ public abstract class AbstractTreeLikelihood extends AbstractModelLikelihood imp
     // **************************************************************
 
     protected void handleModelChangedEvent(Model model, Object object, int index) {
+        if (COUNT_TOTAL_OPERATIONS)
+            totalModelChangedCount++;
         likelihoodKnown = false;
     }
 
@@ -273,12 +172,15 @@ public abstract class AbstractTreeLikelihood extends AbstractModelLikelihood imp
         return this;
     }
 
-    public final PatternList getPatternList() {
-        return patternList;
-    }
-
     public final double getLogLikelihood() {
+        if (COUNT_TOTAL_OPERATIONS)
+            totalGetLogLikelihoodCount++;
+        if (CompoundLikelihood.DEBUG_PARALLEL_EVALUATION) {
+            System.err.println((likelihoodKnown ? "lazy" : "evaluate"));
+        }
         if (!likelihoodKnown) {
+            if (COUNT_TOTAL_OPERATIONS)
+                totalCalculateLikelihoodCount++;
             logLikelihood = calculateLogLikelihood();
             likelihoodKnown = true;
         }
@@ -289,17 +191,34 @@ public abstract class AbstractTreeLikelihood extends AbstractModelLikelihood imp
      * Forces a complete recalculation of the likelihood next time getLikelihood is called
      */
     public void makeDirty() {
+        if (COUNT_TOTAL_OPERATIONS)
+            totalMakeDirtyCount++;
         likelihoodKnown = false;
         updateAllNodes();
-        updateAllPatterns();
+    }
+    
+    public boolean isLikelihoodKnown() {
+    	return likelihoodKnown;
     }
 
     protected abstract double calculateLogLikelihood();
 
     public String getReport() {
-        getLogLikelihood();
-        return getClass().getName() + "(" + logLikelihood + ") total operations = " + totalOperationCount;
-
+        if (hasInitialized) {
+            String rtnValue =  getClass().getName() + "(" + getLogLikelihood() + ")";
+            if (COUNT_TOTAL_OPERATIONS)
+             rtnValue += "\n  total operations = " + totalOperationCount +
+                         "\n  matrix updates = " + totalMatrixUpdateCount +
+                     "\n  model changes = " + totalModelChangedCount +
+                         "\n  make dirties = " + totalMakeDirtyCount +
+                         "\n  calculate likelihoods = " + totalCalculateLikelihoodCount +
+                         "\n  get likelihoods = " + totalGetLogLikelihoodCount +
+                         "\n  all rate updates = " + totalRateUpdateAllCount +
+                         "\n  partial rate updates = " + totalRateUpdateSingleCount;
+            return rtnValue;
+        } else {
+            return getClass().getName() + "(uninitialized)";
+        }
     }
 
     // **************************************************************
@@ -311,38 +230,11 @@ public abstract class AbstractTreeLikelihood extends AbstractModelLikelihood imp
      */
     protected TreeModel treeModel = null;
 
-    /**
-     * the patternList
-     */
-    protected PatternList patternList = null;
-
-    protected DataType dataType = null;
-
-    /**
-     * the pattern weights
-     */
-    protected double[] patternWeights;
-
-    /**
-     * the number of patterns
-     */
-    protected int patternCount;
-
-    /**
-     * the number of states in the data
-     */
-    protected int stateCount;
-
     /**
      * the number of nodes in the tree
      */
     protected int nodeCount;
 
-    /**
-     * Flags to specify which patterns are to be updated
-     */
-    protected boolean[] updatePattern = null;
-
     /**
      * Flags to specify which nodes are to be updated
      */
@@ -353,5 +245,15 @@ public abstract class AbstractTreeLikelihood extends AbstractModelLikelihood imp
     protected boolean likelihoodKnown = false;
     private boolean storedLikelihoodKnown = false;
 
+    protected boolean hasInitialized = false;
+
     protected int totalOperationCount = 0;
+    protected int totalMatrixUpdateCount = 0;
+    protected int totalGetLogLikelihoodCount = 0;
+    protected int totalModelChangedCount = 0;
+    protected int totalMakeDirtyCount = 0;
+    protected int totalCalculateLikelihoodCount = 0;
+    protected int totalRateUpdateAllCount = 0;
+    protected int totalRateUpdateSingleCount = 0;
+
 }
\ No newline at end of file
