@@ -65,7 +65,7 @@ public class ArbitraryBranchRatesParser extends AbstractXMLObjectParser {
 //            "Should have length = " + numBranches);
         }
 
-        Logger.getLogger("dr.evomodel").info("Using an scaled mixture of normals model.");
+        Logger.getLogger("dr.evomodel").info("\nUsing an scaled mixture of normals model.");
         Logger.getLogger("dr.evomodel").info("  rates = " + rateCategoryParameter.getDimension());
         Logger.getLogger("dr.evomodel").info("  NB: Make sure you have a prior on " + rateCategoryParameter.getId() + " and do not use this model in a treeLikelihood for sequence data");
         Logger.getLogger("dr.evomodel").info("  reciprocal = " + reciprocal);
