@@ -25,7 +25,7 @@
 
 package dr.evomodelxml.branchratemodel;
 
-import dr.evolution.tree.Tree;
+import dr.evolution.tree.TreeUtils;
 import dr.evolution.util.Taxa;
 import dr.evolution.util.TaxonList;
 import dr.evomodel.branchratemodel.BranchRateModel;
@@ -34,6 +34,8 @@ import dr.evomodel.tree.TreeModel;
 import dr.inference.model.Parameter;
 import dr.xml.*;
 
+import java.util.logging.Logger;
+
 /**
  */
 public class LocalClockModelParser extends AbstractXMLObjectParser {
@@ -98,7 +100,7 @@ public class LocalClockModelParser extends AbstractXMLObjectParser {
                     try {
                         localClockModel.addCladeClock(taxonList, rateParameter, relative, stemProportion, excludeClade);
 
-                    } catch (Tree.MissingTaxonException mte) {
+                    } catch (TreeUtils.MissingTaxonException mte) {
                         throw new XMLParseException("Taxon, " + mte + ", in " + getParserName() + " was not found in the tree.");
                     }
                 } else if (xoc.getName().equals(EXTERNAL_BRANCHES)) {
@@ -112,7 +114,7 @@ public class LocalClockModelParser extends AbstractXMLObjectParser {
                     try {
                         localClockModel.addExternalBranchClock(taxonList, rateParameter, relative);
 
-                    } catch (Tree.MissingTaxonException mte) {
+                    } catch (TreeUtils.MissingTaxonException mte) {
                         throw new XMLParseException("Taxon, " + mte + ", in " + getParserName() + " was not found in the tree.");
                     }
                 } else if (xoc.getName().equals(TRUNK)) {
@@ -130,7 +132,7 @@ public class LocalClockModelParser extends AbstractXMLObjectParser {
                     try {
                         localClockModel.addTrunkClock(taxonList, rateParameter, indexParameter, relative);
 
-                    } catch (Tree.MissingTaxonException mte) {
+                    } catch (TreeUtils.MissingTaxonException mte) {
                         throw new XMLParseException("Taxon, " + mte + ", in " + getParserName() + " was not found in the tree.");
                     }
                 }
@@ -138,7 +140,7 @@ public class LocalClockModelParser extends AbstractXMLObjectParser {
             }
         }
 
-        System.out.println("Using local clock branch rate model.");
+        Logger.getLogger("dr.evomodel").info("\nUsing local clock branch rate model.");
 
         return localClockModel;
     }
