@@ -36,7 +36,6 @@ public class ExchangeOperatorParser {
 
     public static final String NARROW_EXCHANGE = "narrowExchange";
     public static final String WIDE_EXCHANGE = "wideExchange";
-    public static final String INTERMEDIATE_EXCHANGE = "intermediateExchange";
 
     public static XMLObjectParser NARROW_EXCHANGE_OPERATOR_PARSER = new AbstractXMLObjectParser() {
         public String getParserName() {
@@ -73,42 +72,6 @@ public class ExchangeOperatorParser {
         };
     };
 
-    public static XMLObjectParser INTERMEDIATE_EXCHANGE_OPERATOR_PARSER = new AbstractXMLObjectParser() {
-        public String getParserName() {
-            return INTERMEDIATE_EXCHANGE;
-        }
-
-        public Object parseXMLObject(XMLObject xo) throws XMLParseException {
-
-            final TreeModel treeModel = (TreeModel) xo.getChild(TreeModel.class);
-            final double weight = xo.getDoubleAttribute(MCMCOperator.WEIGHT);
-            return new ExchangeOperator(ExchangeOperator.INTERMEDIATE, treeModel, weight);
-        }
-
-        // ************************************************************************
-        // AbstractXMLObjectParser implementation
-        // ************************************************************************
-
-        public String getParserDescription() {
-            return "This element represents an intermediate exchange operator. "
-                    + "This operator swaps two subtree random subtrees with a bias towards nearby subtrees.";
-        }
-
-        public Class getReturnType() {
-            return ExchangeOperator.class;
-        }
-
-        public XMLSyntaxRule[] getSyntaxRules() {
-            return rules;
-        }
-
-        private final XMLSyntaxRule[] rules = {
-                AttributeRule.newDoubleRule(MCMCOperator.WEIGHT),
-                new ElementRule(TreeModel.class)
-        };
-    };
-
-
     public static XMLObjectParser WIDE_EXCHANGE_OPERATOR_PARSER = new AbstractXMLObjectParser() {
         public String getParserName() {
             return WIDE_EXCHANGE;
