@@ -1,7 +1,7 @@
 /*
  * GTRParser.java
  *
- * Copyright (c) 2002-2015 Alexei Drummond, Andrew Rambaut and Marc Suchard
+ * Copyright (c) 2002-2016 Alexei Drummond, Andrew Rambaut and Marc Suchard
  *
  * This file is part of BEAST.
  * See the NOTICE file distributed with this work for additional
@@ -26,18 +26,23 @@
 package dr.evomodelxml.substmodel;
 
 import dr.evomodel.substmodel.FrequencyModel;
-import dr.evomodel.substmodel.GTR;
-import dr.evomodel.substmodel.SubstitutionModel;
+import dr.evomodel.substmodel.nucleotide.GTR;
+import dr.inference.model.Parameter;
 import dr.inference.model.Variable;
 import dr.xml.*;
 
+import static dr.evomodel.substmodel.nucleotide.GTR.*;
+
 /**
- * Parses an element from an DOM document into a DemographicModel. Recognises
- * ConstantPopulation and ExponentialGrowth.
+ * @author Alexei Drummond
+ * @author Andrew Rambaut
  */
 public class GTRParser extends AbstractXMLObjectParser {
     public static final String GTR_MODEL = "gtrModel";
 
+    public static final String FREQUENCIES = "frequencies";
+    public static final String RATES = "rates";
+
     public static final String A_TO_C = "rateAC";
     public static final String A_TO_G = "rateAG";
     public static final String A_TO_T = "rateAT";
@@ -45,52 +50,66 @@ public class GTRParser extends AbstractXMLObjectParser {
     public static final String C_TO_T = "rateCT";
     public static final String G_TO_T = "rateGT";
 
-    public static final String FREQUENCIES = "frequencies";
-
     public String getParserName() {
         return GTR_MODEL;
     }
 
     public Object parseXMLObject(XMLObject xo) throws XMLParseException {
 
-        XMLObject cxo = xo.getChild(FREQUENCIES);
-        FrequencyModel freqModel = (FrequencyModel) cxo.getChild(FrequencyModel.class);
+        FrequencyModel freqModel = (FrequencyModel) xo.getElementFirstChild(FREQUENCIES);
 
-        Variable rateACValue = null;
-        if (xo.hasChildNamed(A_TO_C)) {
-            rateACValue = (Variable) xo.getElementFirstChild(A_TO_C);
-        }
-        Variable rateAGValue = null;
-        if (xo.hasChildNamed(A_TO_G)) {
-            rateAGValue = (Variable) xo.getElementFirstChild(A_TO_G);
-        }
-        Variable rateATValue = null;
-        if (xo.hasChildNamed(A_TO_T)) {
-            rateATValue = (Variable) xo.getElementFirstChild(A_TO_T);
-        }
-        Variable rateCGValue = null;
-        if (xo.hasChildNamed(C_TO_G)) {
-            rateCGValue = (Variable) xo.getElementFirstChild(C_TO_G);
-        }
-        Variable rateCTValue = null;
-        if (xo.hasChildNamed(C_TO_T)) {
-            rateCTValue = (Variable) xo.getElementFirstChild(C_TO_T);
-        }
-        Variable rateGTValue = null;
-        if (xo.hasChildNamed(G_TO_T)) {
-            rateGTValue = (Variable) xo.getElementFirstChild(G_TO_T);
-        }
-        int countNull = 0;
-        if (rateACValue == null) countNull++;
-        if (rateAGValue == null) countNull++;
-        if (rateATValue == null) countNull++;
-        if (rateCGValue == null) countNull++;
-        if (rateCTValue == null) countNull++;
-        if (rateGTValue == null) countNull++;
+        Parameter rates = null;
 
-        if (countNull != 1)
-            throw new XMLParseException("Only five parameters may be specified in GTR, leave exactly one out, the others will be specifed relative to the one left out.");
-        return new GTR(rateACValue, rateAGValue, rateATValue, rateCGValue, rateCTValue, rateGTValue, freqModel);
+        if (xo.hasChildNamed(RATES)) {
+            rates = (Parameter) xo.getElementFirstChild(RATES);
+            rates.setDimensionNames(new String[] {
+                    rates.getId() + "." + A_TO_C,
+                    rates.getId() + "." + A_TO_G,
+                    rates.getId() + "." + A_TO_T,
+                    rates.getId() + "." + C_TO_G,
+                    rates.getId() + "." + C_TO_T,
+                    rates.getId() + "." + G_TO_T});
+
+            return new GTR(rates, freqModel);
+        } else {
+
+            Variable<Double> rateACVariable = null;
+            if (xo.hasChildNamed(A_TO_C)) {
+                rateACVariable = (Variable<Double>) xo.getElementFirstChild(A_TO_C);
+            }
+            Variable<Double> rateAGVariable = null;
+            if (xo.hasChildNamed(A_TO_G)) {
+                rateAGVariable = (Variable<Double>) xo.getElementFirstChild(A_TO_G);
+            }
+            Variable<Double> rateATVariable = null;
+            if (xo.hasChildNamed(A_TO_T)) {
+                rateATVariable = (Variable<Double>) xo.getElementFirstChild(A_TO_T);
+            }
+            Variable<Double> rateCGVariable = null;
+            if (xo.hasChildNamed(C_TO_G)) {
+                rateCGVariable = (Variable<Double>) xo.getElementFirstChild(C_TO_G);
+            }
+            Variable<Double> rateCTVariable = null;
+            if (xo.hasChildNamed(C_TO_T)) {
+                rateCTVariable = (Variable<Double>) xo.getElementFirstChild(C_TO_T);
+            }
+            Variable<Double> rateGTVariable = null;
+            if (xo.hasChildNamed(G_TO_T)) {
+                rateGTVariable = (Variable<Double>) xo.getElementFirstChild(G_TO_T);
+            }
+            int countNull = 0;
+            if (rateACVariable == null) countNull++;
+            if (rateAGVariable == null) countNull++;
+            if (rateATVariable == null) countNull++;
+            if (rateCGVariable == null) countNull++;
+            if (rateCTVariable == null) countNull++;
+            if (rateGTVariable == null) countNull++;
+
+            if (countNull != 1) {
+                throw new XMLParseException("Only five parameters may be specified in GTR, leave exactly one out, the others will be specifed relative to the one left out.");
+            }
+            return new GTR(rateACVariable, rateAGVariable, rateATVariable, rateCGVariable, rateCTVariable, rateGTVariable, freqModel);
+        }
     }
 
     //************************************************************************
@@ -119,7 +138,7 @@ public class GTRParser extends AbstractXMLObjectParser {
     }
 
     public Class getReturnType() {
-        return SubstitutionModel.class;
+        return GTR.class;
     }
 
     public XMLSyntaxRule[] getSyntaxRules() {
@@ -129,6 +148,8 @@ public class GTRParser extends AbstractXMLObjectParser {
     private final XMLSyntaxRule[] rules = {
             new ElementRule(FREQUENCIES,
                     new XMLSyntaxRule[]{new ElementRule(FrequencyModel.class)}),
+            new ElementRule(RATES,
+                    new XMLSyntaxRule[]{new ElementRule(Parameter.class)}, true),
             new ElementRule(A_TO_C,
                     new XMLSyntaxRule[]{new ElementRule(Variable.class)}, true),
             new ElementRule(A_TO_G,
@@ -142,6 +163,4 @@ public class GTRParser extends AbstractXMLObjectParser {
             new ElementRule(G_TO_T,
                     new XMLSyntaxRule[]{new ElementRule(Variable.class)}, true)
     };
-
-
 }
