@@ -25,7 +25,7 @@
 
 package dr.evomodelxml.tree;
 
-import dr.evolution.tree.Tree;
+import dr.evolution.tree.TreeUtils;
 import dr.evolution.util.Taxa;
 import dr.evolution.util.TaxonList;
 import dr.evomodel.tree.MRCATraitStatistic;
@@ -55,7 +55,7 @@ public class MRCATraitStatisticParser extends AbstractXMLObjectParser {
 
         try {
             return new MRCATraitStatistic(name, trait, tree, taxa);
-        } catch (Tree.MissingTaxonException mte) {
+        } catch (TreeUtils.MissingTaxonException mte) {
             throw new XMLParseException("Taxon, " + mte + ", in " + getParserName() + "was not found in the tree.");
         }
     }
