@@ -26,6 +26,7 @@
 package dr.evomodelxml.tree;
 
 import dr.evolution.tree.Tree;
+import dr.evolution.tree.TreeUtils;
 import dr.evolution.util.Taxa;
 import dr.evolution.util.TaxonList;
 import dr.evomodel.tree.ParsimonyStateStatistic;
@@ -58,7 +59,7 @@ public class ParsimonyStateStatisticParser extends AbstractXMLObjectParser {
 
         try {
             return new ParsimonyStateStatistic(name, tree, stateTaxa, mrcaTaxa);
-        } catch (Tree.MissingTaxonException mte) {
+        } catch (TreeUtils.MissingTaxonException mte) {
             throw new XMLParseException("Taxon, " + mte + ", in " + getParserName() + "was not found in the tree.");
         }
     }
