@@ -25,6 +25,7 @@
 
 package dr.evomodelxml.tree;
 
+import dr.evolution.tree.MutableTreeModel;
 import dr.evomodel.tree.*;
 import dr.inference.model.Parameter;
 import dr.xml.*;
@@ -49,7 +50,7 @@ public class TransformedTreeModelParser extends AbstractXMLObjectParser {
     public Object parseXMLObject(XMLObject xo) throws XMLParseException {
 
 
-        TreeModel tree = (TreeModel) xo.getChild(TreeModel.class);
+        MutableTreeModel tree = (MutableTreeModel) xo.getChild(MutableTreeModel.class);
         Parameter scale = (Parameter) xo.getChild(Parameter.class);
 
         String id = tree.getId();
@@ -70,6 +71,8 @@ public class TransformedTreeModelParser extends AbstractXMLObjectParser {
             transform = new ProgressiveScalarTreeTransform(scale);
         } else if (version.compareTo("branch") == 0) {
             transform = new ProgressiveScalarTreeTransform(tree, scale);
+        } else if (version.compareTo("ou") == 0) {
+            transform = new OuScalarTreeTransform(scale);
         } else {
             transform = new SingleScalarTreeTransform(scale);
         }
@@ -95,7 +98,7 @@ public class TransformedTreeModelParser extends AbstractXMLObjectParser {
 
     private final XMLSyntaxRule[] rules =
             new XMLSyntaxRule[]{
-                    new ElementRule(TreeModel.class),
+                    new ElementRule(MutableTreeModel.class),
                     new ElementRule(Parameter.class),
                     AttributeRule.newStringRule(VERSION, true),
             };
