@@ -26,6 +26,7 @@
 package dr.evomodelxml.tree;
 
 import dr.evolution.tree.Tree;
+import dr.evolution.tree.treemetrics.*;
 import dr.evomodel.tree.TreeMetricStatistic;
 import dr.inference.model.Statistic;
 import dr.xml.*;
@@ -37,7 +38,7 @@ public class TreeMetricStatisticParser extends AbstractXMLObjectParser {
     public static final String TREE_METRIC_STATISTIC = "treeMetricStatistic";
     public static final String TARGET = "target";
     public static final String REFERENCE = "reference";
-    public static final String METHOD = "method";
+    public static final String TYPE = "type";
 
     public String getParserName() {
         return TREE_METRIC_STATISTIC;
@@ -45,17 +46,53 @@ public class TreeMetricStatisticParser extends AbstractXMLObjectParser {
 
     public Object parseXMLObject(XMLObject xo) throws XMLParseException {
 
-        TreeMetricStatistic.Method m = TreeMetricStatistic.Method.TOPOLOGY;
-        if (xo.hasAttribute(METHOD)) {
-            final String s = xo.getStringAttribute(METHOD);
-            m = TreeMetricStatistic.Method.valueOf(s.toUpperCase());
+        TreeMetric.Type type = null;
+        if (xo.hasAttribute(TYPE)) {
+            final String s = xo.getStringAttribute(TYPE);
+            for (TreeMetric.Type t : TreeMetric.Type.values()) {
+                if (t.toString().toLowerCase().equals(s.toLowerCase())) {
+                    type = t;
+                    break;
+                }
+            }
+
+            if (type == null) {
+                throw new XMLParseException("Tree metric type, " + s + ", is not recognised");
+            }
         }
 
-        final String name = xo.getAttribute(Statistic.NAME, xo.hasId() ? xo.getId() : m.name());
+        final String name = xo.getAttribute(Statistic.NAME, xo.hasId() ? xo.getId() :
+                (type == null ? "topology" : type.toString()));
         final Tree target = (Tree) xo.getElementFirstChild(TARGET);
         final Tree reference = (Tree) xo.getElementFirstChild(REFERENCE);
 
-        return new TreeMetricStatistic(name, target, reference, m);
+        TreeMetric treeMetric = null;
+        if (type != null) {
+            switch (type) {
+                case ROBINSON_FOULDS:
+                    treeMetric = new RobinsonFouldsMetric();
+                    break;
+                case BRANCH_SCORE:
+                    treeMetric = new BranchScoreMetric();
+                    break;
+                case ROOTED_BRANCH_SCORE:
+                    treeMetric = new RootedBranchScoreMetric();
+                    break;
+                case CLADE_HEIGHT:
+                    treeMetric = new CladeHeightMetric();
+                    break;
+                case KENDALL_COLIJN:
+                    treeMetric = new KendallColijnPathDifferenceMetric(0.5);
+                    break;
+                case STEEL_PENNY:
+                    treeMetric = new SteelPennyPathDifferenceMetric();
+                    break;
+                default:
+                    throw new IllegalArgumentException("Unknown tree metric type");
+            }
+        }
+
+        return new TreeMetricStatistic(name, reference, target, treeMetric);
     }
 
     // ************************************************************************
@@ -81,8 +118,7 @@ public class TreeMetricStatisticParser extends AbstractXMLObjectParser {
             new StringAttributeRule(Statistic.NAME,
                     "A name for this statistic primarily for the purposes of logging",
                     true),
-            new StringAttributeRule(METHOD, "comparision method ("
-                    + TreeMetricStatistic.methodNames(",") + ")", true),
+            new StringAttributeRule(TYPE, "tree metric name", true),
             new ElementRule(TARGET, new XMLSyntaxRule[]{new ElementRule(
                     Tree.class)}),
             new ElementRule(REFERENCE, new XMLSyntaxRule[]{new ElementRule(
