@@ -1,7 +1,7 @@
 /*
  * TreeTraitParserUtilities.java
  *
- * Copyright (c) 2002-2015 Alexei Drummond, Andrew Rambaut and Marc Suchard
+ * Copyright (c) 2002-2016 Alexei Drummond, Andrew Rambaut and Marc Suchard
  *
  * This file is part of BEAST.
  * See the NOTICE file distributed with this work for additional
@@ -25,7 +25,8 @@
 
 package dr.evomodelxml.treelikelihood;
 
-import dr.evolution.tree.MultivariateTraitTree;
+import dr.evolution.tree.Tree;
+import dr.evomodel.continuous.StandardizeTraits;
 import dr.inference.model.*;
 import dr.math.MathUtils;
 import dr.xml.*;
@@ -36,8 +37,8 @@ import java.util.logging.Logger;
 /**
  * @author Marc A. Suchard
  */
-public class TreeTraitParserUtilities {
 
+public class TreeTraitParserUtilities {
 
     public static final String TRAIT_PARAMETER = "traitParameter";
     public static final String TRAIT_NAME = "traitName";
@@ -54,6 +55,10 @@ public class TreeTraitParserUtilities {
     public static final String WINDOW = "window";
     public static final String DUPLICATES = "duplicatesOnly";
     public static final String STANDARDIZE = "standardize";
+    public static final String SAMPLE_MISSING_TRAITS = "sampleMissingTraits";
+
+    public static final String LATENT_FROM = "latentFrom";
+    public static final String LATENT_TO = "latentTo";
 
     public void randomize(Parameter trait, double[] lower, double[] upper) {
         // Draws each dimension in each trait from U[lower, upper)
@@ -230,18 +235,23 @@ public class TreeTraitParserUtilities {
         public CompoundParameter traitParameter;
         public List<Integer> missingIndices;
         public String traitName;
+        public Parameter sampleMissingParameter;
+        public boolean useMissingIndices;
 
-        TraitsAndMissingIndices(CompoundParameter traitParameter, List<Integer> missingIndices, String traitName) {
+        TraitsAndMissingIndices(CompoundParameter traitParameter, List<Integer> missingIndices, String traitName,
+                                Parameter sampleMissingParameter, boolean useMissingIndices) {
             this.traitParameter = traitParameter;
             this.missingIndices = missingIndices;
             this.traitName = traitName;
+            this.sampleMissingParameter = sampleMissingParameter;
+            this.useMissingIndices = useMissingIndices;
         }
     }
 
     public TraitsAndMissingIndices parseTraitsFromTaxonAttributes(
             XMLObject xo,
             String inTraitName,
-            MultivariateTraitTree treeModel,
+            Tree treeModel,
             boolean integrateOutInternalStates) throws XMLParseException {
 
         XMLObject xoc = xo.getChild(TRAIT_PARAMETER);
@@ -253,6 +263,7 @@ public class TreeTraitParserUtilities {
 
         CompoundParameter traitParameter;
         List<Integer> missingIndices = null;
+        Parameter sampleMissingParameter = null;
 
         boolean isMatrixParameter = false;
         if (parameter instanceof MatrixParameter || parameter instanceof FastMatrixParameter) {
@@ -278,6 +289,10 @@ public class TreeTraitParserUtilities {
             Map<Integer, Integer> randomSample = null;
             traitName = xo.getStringAttribute(TRAIT_NAME);
 
+            StringBuilder warnings = new StringBuilder();
+            int warningLength = 0;
+            final int maxWarnings = 10;
+
             // Fill in attributeValues
             int taxonCount = treeModel.getTaxonCount();
             for (int i = 0; i < taxonCount; i++) {
@@ -338,17 +353,23 @@ public class TreeTraitParserUtilities {
                         if (randomSampleSizeFlag == -1 || randomSample.containsKey(j)) {
                             double value = Double.NaN;
                             if (oneValue.equals("NA") || oneValue.equals("?") ) {
-                                Logger.getLogger("dr.evomodel.continuous").info(
-                                        "Warning: Missing value in tip for taxon " + taxonName +
-                                                " (filling with 0 as starting value when sampling only)"   // See comment below
-                                );
+                                if (warningLength < maxWarnings) {
+                                    warnings.append(
+                                            "Warning: Missing value in tip for taxon " + taxonName +
+                                                    " (filling with 0 as starting value when sampling only)\n"   // See comment below
+                                    );
+                                    ++warningLength;
+                                }
                             } else {
                                 try {
                                     value = new Double(oneValue);
                                     if (Double.isNaN(value)) {
-                                        Logger.getLogger("dr.evomodel.continuous").info(
-                                                "Warning: Unrecognizable number " + oneValue + " for taxon " + taxonName
-                                        );
+                                        if (warningLength < maxWarnings) {
+                                            warnings.append(
+                                                    "Warning: Unrecognizable number " + oneValue + " for taxon " + taxonName + "\n"
+                                            );
+                                            ++warningLength;
+                                        }
                                     }
                                 } catch (NumberFormatException e) {
                                     throw new RuntimeException(e.getMessage());
@@ -369,6 +390,22 @@ public class TreeTraitParserUtilities {
                 }
             }
 
+            if (warningLength > 0) {
+                Logger.getLogger("dr.evomodel.continuous").info(warnings.toString());
+                if (warningLength == maxWarnings) {
+                    Logger.getLogger("dr.evomodel.continuous").info("Warning: only first " + maxWarnings + " trait warnings were displayed\n");
+                }
+            }
+
+            // Standardize
+            if (xo.getAttribute(STANDARDIZE, false) && traitParameter instanceof MatrixParameterInterface) {
+
+                StandardizeTraits st = new StandardizeTraits((MatrixParameterInterface) traitParameter);
+                String message = st.doStandardization(false);
+
+                Logger.getLogger("dr.evomodel.continous").info(message);
+            }
+
             // Find missing values
             double[] allValues = traitParameter.getParameterValues();
             missingIndices = new ArrayList<Integer>();
@@ -381,16 +418,38 @@ public class TreeTraitParserUtilities {
 
             if (xo.hasChildNamed(MISSING)) {
                 XMLObject cxo = xo.getChild(MISSING);
+
                 Parameter missingParameter = new Parameter.Default(allValues.length, 0.0);
                 for (int i : missingIndices) {
                     missingParameter.setParameterValue(i, 1.0);
                 }
+
+                if (cxo.hasAttribute(LATENT_FROM) && cxo.hasAttribute(LATENT_TO)) {
+                    int from = cxo.getIntegerAttribute(LATENT_FROM);
+                    int to = cxo.getIntegerAttribute(LATENT_TO);
+
+                    final int dimTrait = allValues.length / taxonCount;
+
+                    if (from < 1 || to < 1 || from > dimTrait || to > dimTrait) {
+                        throw new XMLParseException("Invalid latent dimension specification");
+                    }
+
+                    int index = 0;
+                    for (int taxon = 0; taxon < taxonCount; ++taxon) {
+                        for (int trait = from - 1; trait < to; ++trait) {
+                            missingParameter.setParameterValue(index + trait, 1.0);
+                        }
+                        index += dimTrait;
+                    }
+                }
+
                 missingParameter.addBounds(new Parameter.DefaultBounds(1.0, 0.0, allValues.length));
                 ParameterParser.replaceParameter(cxo, missingParameter);
+                sampleMissingParameter = missingParameter;
             }
 
             // Give warnings if trait exist for internal and root nodes when integrating them out
-            if (integrateOutInternalStates) {
+            if (false) {
                 int numTraits = traitParameter.getParameterCount();
                 if (numTraits != treeModel.getExternalNodeCount()) {
                     throw new XMLParseException(
@@ -403,12 +462,25 @@ public class TreeTraitParserUtilities {
                     if (parameterName.startsWith("node") || parameterName.startsWith("root")) {
                         throw new XMLParseException(
                                 "Internal/root node trait parameters are not allowed when " +
-                                        "using the integrated observed data multivariateTraitLikelihoood");
+                                        "using the integrated observed data likelihood");
                     }
                 }
             }
         }
-        return new TraitsAndMissingIndices(traitParameter, missingIndices, traitName);
+
+        boolean useMissingIndices = true;
+        if (xo.getAttribute(SAMPLE_MISSING_TRAITS, false) || xo.hasChildNamed(MISSING)) {
+//            missingIndices = new ArrayList<Integer>(); // return empty
+            useMissingIndices = false;
+
+        }
+
+        if (missingIndices == null || missingIndices.size() == 0) {
+            useMissingIndices = false;
+        }
+
+        return new TraitsAndMissingIndices(traitParameter, missingIndices, traitName,
+                sampleMissingParameter, useMissingIndices);
     }
 
     private Parameter getTraitParameterByName(CompoundParameter traits, String name) {
