@@ -117,6 +117,20 @@ public class InverseGammaDistributionModel extends AbstractModel implements Para
         }
     };
 
+    // *****************************************************************
+    // Interface DensityModel
+    // *****************************************************************
+
+    @Override
+    public double logPdf(double[] x) {
+        return logPdf(x[0]);
+    }
+
+    @Override
+    public Variable<Double> getLocationVariable() {
+        throw new UnsupportedOperationException("Not implemented");
+    }
+
     // *****************************************************************
     // Interface Model
     // *****************************************************************
