@@ -29,14 +29,13 @@ package dr.inference.distribution;
 import dr.inference.model.*;
 import dr.inference.model.Parameter;
 import dr.inferencexml.distribution.MomentDistributionModelParser;
-import dr.math.MathUtils;
 import dr.math.distributions.RandomGenerator;
 
 //@author Max Tolkoff
 public class MomentDistributionModel extends AbstractModelLikelihood implements ParametricMultivariateDistributionModel, RandomGenerator {
 
-    public MomentDistributionModel(Parameter mean, Parameter precision, Parameter cutoff, Parameter data) {
-        super(MomentDistributionModelParser.MOMENT_DISTRIBUTION_MODEL);
+    public MomentDistributionModel(String id, Parameter mean, Parameter precision, Parameter cutoff, Parameter data) {
+        super(id);
 
         this.mean=mean;
         this.precision=precision;
@@ -49,9 +48,14 @@ public class MomentDistributionModel extends AbstractModelLikelihood implements
         mean.addBounds(new Parameter.DefaultBounds(Double.POSITIVE_INFINITY, Double.NEGATIVE_INFINITY, 1));
         addVariable(precision);
 //        precision.addBounds(new Parameter.DefaultBounds(Double.POSITIVE_INFINITY, 0.0, 1));
-        this.cutoff=cutoff;  if(cutoff!=null){
-        addVariable(cutoff);
-        cutoff.addBounds(new Parameter.DefaultBounds(Double.POSITIVE_INFINITY, 0.0, cutoff.getDimension()));}
+        this.cutoff=cutoff;
+        if(cutoff!=null){
+            addVariable(cutoff);
+            int boundsDim;
+            if(cutoff.getBounds()!=null)
+                boundsDim = cutoff.getBounds().getBoundsDimension();
+            else boundsDim = cutoff.getDimension();
+            cutoff.addBounds(new Parameter.DefaultBounds(Double.POSITIVE_INFINITY, 0.0, boundsDim));}
         addVariable(data);
         this.data=data;
         untruncated=new NormalDistributionModel(mean, precision, true);
@@ -90,28 +94,34 @@ public class MomentDistributionModel extends AbstractModelLikelihood implements
             if(data.getDimension()!=cutoff.getDimension()){
                 throw new RuntimeException("Incorrect number of cutoffs");
             }
-        for (int i = 0; i <data.getDimension() ; i++) {
-            if (Math.sqrt(cutoff.getParameterValue(i)) - .0001 > Math.abs(data.getParameterValue(i)) && data.getParameterValue(i)!=0){
-//                System.out.println(i);
-//                System.out.println(cutoff.getParameterValue(i));
-//                System.out.println(data.getParameterValue(i));
-                return Double.NEGATIVE_INFINITY;                                                                          }
-            else if(data.getParameterValue(i)==0)
-                sum+=-1000-Math.log(precision.getParameterValue(0));
-            else
-                sum+=untruncated.logPdf(data.getParameterValue(i));//(2*untruncated.logPdf(cutoff.getParameterValue(i)));
-        }         }
+            for (int i = 0; i <data.getDimension() ; i++) {
+                if (Math.sqrt(cutoff.getParameterValue(i)) - .05 > Math.abs(data.getParameterValue(i)) && data.getParameterValue(i)!=0){
+                        return Double.NEGATIVE_INFINITY;                                                                          }
+                    else if(data.getParameterValue(i)==0){
+                        sum += 0;
+                }
+//                        sum+=-1000-Math.log(precision.getParameterValue(0));
+                    else {
+                        sum+=untruncated.logPdf(data.getParameterValue(i))
+                                + getNormalizingConstant(i)
+                                ;
+                        }
+            }
+        }
         else{
             for (int i = 0; i <data.getDimension() ; i++) {
-                sum+= untruncated.logPdf(data.getParameterValue(i))+2* StrictMath.log(data.getParameterValue(i))+StrictMath.log(precision.getParameterValue(0));
+                sum+= untruncated.logPdf(data.getParameterValue(i)) + 2 * StrictMath.log(Math.abs(data.getParameterValue(i))) + StrictMath.log(precision.getParameterValue(0));
             }
         }
         sumKnown=true;
         return sum;
-        //}
 
     }
 
+    public double getNormalizingConstant(int i){
+        return -Math.log(1 - (untruncated.cdf(Math.sqrt(cutoff.getParameterValue(i))) - untruncated.cdf(-Math.sqrt(cutoff.getParameterValue(i)))));
+    }
+
     @Override
     public double logPdf(double[] x) {
         return 0;
@@ -213,4 +223,14 @@ public class MomentDistributionModel extends AbstractModelLikelihood implements
         untruncatedKnown=false;
 
     }
+
+    // *****************************************************************
+    // Interface DensityModel
+    // *****************************************************************
+
+    @Override
+    public Variable<Double> getLocationVariable() {
+        throw new UnsupportedOperationException("Not implemented");
+    }
+
 }
