@@ -142,6 +142,20 @@ public class SkewNormalDistributionModel extends AbstractModel implements Parame
         throw new RuntimeException("Not implemented!");
     }
 
+    // *****************************************************************
+    // Interface DensityModel
+    // *****************************************************************
+
+    @Override
+    public double logPdf(double[] x) {
+        return logPdf(x[0]);
+    }
+
+    @Override
+    public Variable<Double> getLocationVariable() {
+        return location;
+    }
+
     // **************************************************************
     // Private instance variables
     // **************************************************************
