@@ -129,6 +129,20 @@ public class TwoPieceLocationScaleDistributionModel extends AbstractModel implem
         return logPdf(v);
     }
 
+    // *****************************************************************
+    // Interface DensityModel
+    // *****************************************************************
+
+    @Override
+    public double logPdf(double[] x) {
+        return logPdf(x[0]);
+    }
+
+    @Override
+    public Variable<Double> getLocationVariable() {
+        throw new UnsupportedOperationException("Not implemented");
+    }
+
     // *****************************************************************
     // Interface Model
     // *****************************************************************
