@@ -110,6 +110,21 @@ public class UniformDistributionModel extends AbstractModel implements Parametri
         }
     };
 
+    // *****************************************************************
+    // Interface DensityModel
+    // *****************************************************************
+
+    @Override
+    public double logPdf(double[] x) {
+        return logPdf(x[0]);
+    }
+
+    @Override
+    public Variable<Double> getLocationVariable() {
+        throw new UnsupportedOperationException("Not implemented");
+    }
+
+
     // *****************************************************************
     // Interface Model
     // *****************************************************************
