@@ -1,7 +1,7 @@
 /*
  * MarkovChain.java
  *
- * Copyright (c) 2002-2015 Alexei Drummond, Andrew Rambaut and Marc Suchard
+ * Copyright (c) 2002-2017 Alexei Drummond, Andrew Rambaut and Marc Suchard
  *
  * This file is part of BEAST.
  * See the NOTICE file distributed with this work for additional
@@ -31,10 +31,10 @@ import dr.inference.model.Likelihood;
 import dr.inference.model.Model;
 import dr.inference.model.PathLikelihood;
 import dr.inference.operators.*;
-import dr.inference.prior.Prior;
 
 import java.io.Serializable;
 import java.util.ArrayList;
+import java.util.Set;
 import java.util.logging.Logger;
 
 /**
@@ -49,7 +49,6 @@ import java.util.logging.Logger;
 public final class MarkovChain implements Serializable {
     private static final long serialVersionUID = 181L;
 
-
     private final static boolean DEBUG = false;
     private final static boolean PROFILE = true;
 
@@ -57,7 +56,6 @@ public final class MarkovChain implements Serializable {
 
     private final OperatorSchedule schedule;
     private final Acceptor acceptor;
-    private final Prior prior;
     private final Likelihood likelihood;
 
     private boolean pleaseStop = false;
@@ -65,7 +63,7 @@ public final class MarkovChain implements Serializable {
     private double bestScore, currentScore, initialScore;
     private long currentLength;
 
-    private boolean useCoercion = true;
+    private boolean useAdaptation = true;
 
     private final long fullEvaluationCount;
     private final int minOperatorCountForFullEvaluation;
@@ -73,17 +71,16 @@ public final class MarkovChain implements Serializable {
     private double evaluationTestThreshold = EVALUATION_TEST_THRESHOLD;
 
 
-    public MarkovChain(Prior prior, Likelihood likelihood,
+    public MarkovChain(Likelihood likelihood,
                        OperatorSchedule schedule, Acceptor acceptor,
                        long fullEvaluationCount, int minOperatorCountForFullEvaluation, double evaluationTestThreshold,
-                       boolean useCoercion) {
+                       boolean useAdaptation) {
 
         currentLength = 0;
-        this.prior = prior;
         this.likelihood = likelihood;
         this.schedule = schedule;
         this.acceptor = acceptor;
-        this.useCoercion = useCoercion;
+        this.useAdaptation = useAdaptation;
 
         this.fullEvaluationCount = fullEvaluationCount;
         this.minOperatorCountForFullEvaluation = minOperatorCountForFullEvaluation;
@@ -98,7 +95,7 @@ public final class MarkovChain implements Serializable {
             }
         }
 
-        currentScore = evaluate(likelihood, prior);
+        currentScore = evaluate(likelihood);
     }
 
     /**
@@ -118,10 +115,10 @@ public final class MarkovChain implements Serializable {
      *
      * @param length number of states to run the chain.
      */
-    public long runChain(long length, boolean disableCoerce) {
+    public long runChain(long length, boolean disableAdaptation) {
 
         likelihood.makeDirty();
-        currentScore = evaluate(likelihood, prior);
+        currentScore = evaluate(likelihood);
 
         long currentState = currentLength;
 
@@ -136,15 +133,6 @@ public final class MarkovChain implements Serializable {
         if (currentScore == Double.NEGATIVE_INFINITY) {
 
             // identify which component of the score is zero...
-            if (prior != null) {
-                double logPrior = prior.getLogPrior(likelihood.getModel());
-
-                if (logPrior == Double.NEGATIVE_INFINITY) {
-                    throw new IllegalArgumentException(
-                            "The initial model is invalid because one of the priors has zero probability.");
-                }
-            }
-
             String message = "The initial likelihood is zero";
             if (likelihood instanceof CompoundLikelihood) {
                 message += ": " + ((CompoundLikelihood) likelihood).getDiagnosis();
@@ -156,11 +144,15 @@ public final class MarkovChain implements Serializable {
             }
             throw new IllegalArgumentException(message);
         } else if (currentScore == Double.POSITIVE_INFINITY || Double.isNaN(currentScore)) {
-            String message = "A likelihood returned with a numerical error";
+            String message = "A likelihood returned with a numerical error (" + currentScore + ")";
             if (likelihood instanceof CompoundLikelihood) {
                 message += ": " + ((CompoundLikelihood) likelihood).getDiagnosis();
             } else {
                 message += ".";
+                Set<Likelihood> lSet = likelihood.getLikelihoodSet();
+                for (Likelihood l : lSet) {
+                    message += "\n  " + l.prettyName() + " = " + l.getLogLikelihood();
+                }
             }
             throw new IllegalArgumentException(message);
         }
@@ -215,25 +207,41 @@ public final class MarkovChain implements Serializable {
 
             logr[0] = -Double.MAX_VALUE;
 
-            try {
-                // The new model is proposed
-                // assert Profiler.startProfile("Operate");
+            long elaspedTime = 0;
+            if (PROFILE) {
+                elaspedTime = System.currentTimeMillis();
+            }
+
+            // The new model is proposed
+            // assert Profiler.startProfile("Operate");
 
                 if (DEBUG) {
+                    System.out.println("\n>> Iteration: " + currentState);
                     System.out.println("\n&& Operator: " + mcmcOperator.getOperatorName());
                 }
 
-                if (mcmcOperator instanceof GeneralOperator) {
-                    hastingsRatio = ((GeneralOperator) mcmcOperator).operate(prior, likelihood);
-                } else {
-                    hastingsRatio = mcmcOperator.operate();
-                }
+            if (mcmcOperator instanceof GeneralOperator) {
+                hastingsRatio = ((GeneralOperator) mcmcOperator).operate(likelihood);
+            } else {
+                hastingsRatio = mcmcOperator.operate();
+            }
 
-                // assert Profiler.stopProfile("Operate");
-            } catch (OperatorFailedException e) {
+            // assert Profiler.stopProfile("Operate");
+            if (hastingsRatio == Double.NEGATIVE_INFINITY) {
+                // Should the evaluation be short-cutted?
+                // Previously this was set to false if OperatorFailedException was thrown.
+                // Now a -Inf HR is returned.
                 operatorSucceeded = false;
             }
 
+            if (PROFILE) {
+                long duration = System.currentTimeMillis() - elaspedTime;
+                if (DEBUG) {
+                    System.out.println("Time: " + duration);
+                }
+                mcmcOperator.addEvaluationTime(duration);
+            }
+
             double score = Double.NaN;
             double deviation = Double.NaN;
 
@@ -253,7 +261,7 @@ public final class MarkovChain implements Serializable {
                 }
 
                 // The new model is evaluated
-                score = evaluate(likelihood, prior);
+                score = evaluate(likelihood);
 
                 if (PROFILE) {
                     long duration = System.currentTimeMillis() - elapsedTime;
@@ -271,6 +279,22 @@ public final class MarkovChain implements Serializable {
 
                 if (score == Double.NEGATIVE_INFINITY && mcmcOperator instanceof GibbsOperator) {
                     if (!(mcmcOperator instanceof GibbsIndependentNormalDistributionOperator) && !(mcmcOperator instanceof GibbsIndependentGammaOperator) && !(mcmcOperator instanceof GibbsIndependentCoalescentOperator) && !(mcmcOperator instanceof GibbsIndependentJointNormalGammaOperator)) {
+                        if (DEBUG) {
+                            if (likelihood instanceof CompoundLikelihood) {
+                                CompoundLikelihood cpl = (CompoundLikelihood) likelihood;
+                                System.out.println("\nDEBUG CompoundLikelihood:");
+                                for (Likelihood l : cpl.getLikelihoods()) {
+                                    if (l instanceof CompoundLikelihood) {
+                                        CompoundLikelihood l2 = (CompoundLikelihood)l;
+                                        for (Likelihood lTwo : l2.getLikelihoods()) {
+                                            System.out.println("\t" + lTwo.prettyName() + " = " + lTwo.getLogLikelihood());
+                                        }
+                                    }
+                                    System.out.println(l.prettyName() + " = " + l.getLogLikelihood());
+                                }
+                                System.out.println("Total likelihood = " + cpl.getLogLikelihood() + "\n");
+                            }
+                        }
                         Logger.getLogger("error").severe("State " + currentState + ": A Gibbs operator, " + mcmcOperator.getOperatorName() + ", returned a state with zero likelihood.");
                     }
                 }
@@ -284,6 +308,23 @@ public final class MarkovChain implements Serializable {
                         Logger.getLogger("error").severe("State "+currentState+": A likelihood returned with a numerical error.");
                     }
 
+                    if (DEBUG) {
+                        if (likelihood instanceof CompoundLikelihood) {
+                            CompoundLikelihood cpl = (CompoundLikelihood) likelihood;
+                            System.out.println("\nDEBUG CompoundLikelihood:");
+                            for (Likelihood l : cpl.getLikelihoods()) {
+                                if (l instanceof CompoundLikelihood) {
+                                    CompoundLikelihood l2 = (CompoundLikelihood) l;
+                                    for (Likelihood lTwo : l2.getLikelihoods()) {
+                                        System.out.println("\t" + lTwo.prettyName() + " = " + lTwo.getLogLikelihood());
+                                    }
+                                }
+                                System.out.println(l.prettyName() + " = " + l.getLogLikelihood());
+                            }
+                            System.out.println("Total likelihood = " + cpl.getLogLikelihood() + "\n");
+                        }
+                    }
+
                     // If the user has chosen to ignore this error then we transform it
                     // to a negative infinity so the state is rejected.
                     score = Double.NEGATIVE_INFINITY;
@@ -298,7 +339,7 @@ public final class MarkovChain implements Serializable {
                     // BEAST is aware of all changes that the operator induced.
 
                     likelihood.makeDirty();
-                    final double testScore = evaluate(likelihood, prior);
+                    final double testScore = evaluate(likelihood);
 
                     final String d2 = likelihood instanceof CompoundLikelihood ?
                             ((CompoundLikelihood) likelihood).getDiagnosis() : "";
@@ -340,7 +381,7 @@ public final class MarkovChain implements Serializable {
             } else {
                 if (DEBUG) {
                     System.out.println("** Move rejected: new score = " + score
-                            + ", old score = " + oldScore);
+                            + ", old score = " + oldScore + " (logr = " + logr[0] + ")");
                 }
 
                 mcmcOperator.reject();
@@ -355,7 +396,7 @@ public final class MarkovChain implements Serializable {
                     // that before the operation was made.
 
                     likelihood.makeDirty();
-                    final double testScore = evaluate(likelihood, prior);
+                    final double testScore = evaluate(likelihood);
 
                     final String d2 = likelihood instanceof CompoundLikelihood ?
                             ((CompoundLikelihood) likelihood).getDiagnosis() : "";
@@ -378,8 +419,8 @@ public final class MarkovChain implements Serializable {
             // assert Profiler.stopProfile("Restore");
 
 
-            if (!disableCoerce && mcmcOperator instanceof CoercableMCMCOperator) {
-                coerceAcceptanceProbability((CoercableMCMCOperator) mcmcOperator, logr[0]);
+            if (useAdaptation && !disableAdaptation && mcmcOperator instanceof AdaptableMCMCOperator) {
+                adaptAcceptanceProbability((AdaptableMCMCOperator) mcmcOperator, logr[0]);
             }
 
             if (usingFullEvaluation) {
@@ -416,10 +457,6 @@ public final class MarkovChain implements Serializable {
         // Profiler.report();
     }
 
-    public Prior getPrior() {
-        return prior;
-    }
-
     public Likelihood getLikelihood() {
         return likelihood;
     }
@@ -465,23 +502,13 @@ public final class MarkovChain implements Serializable {
     }
 
     public double evaluate() {
-        return evaluate(likelihood, prior);
+        return evaluate(likelihood);
     }
 
-    protected double evaluate(Likelihood likelihood, Prior prior) {
+    protected double evaluate(Likelihood likelihood) {
 
         double logPosterior = 0.0;
 
-        if (prior != null) {
-            final double logPrior = prior.getLogPrior(likelihood.getModel());
-
-            if (logPrior == Double.NEGATIVE_INFINITY) {
-                return Double.NEGATIVE_INFINITY;
-            }
-
-            logPosterior += logPrior;
-        }
-
         final double logLikelihood = likelihood.getLogLikelihood();
 
         if (Double.isNaN(logLikelihood)) {
@@ -502,10 +529,14 @@ public final class MarkovChain implements Serializable {
      * @param op   The operator
      * @param logr
      */
-    private void coerceAcceptanceProbability(CoercableMCMCOperator op, double logr) {
+    private void adaptAcceptanceProbability(AdaptableMCMCOperator op, double logr) {
 
-        if (isCoercable(op)) {
-            final double p = op.getCoercableParameter();
+        if (DEBUG) {
+            System.out.println("adaptAcceptanceProbability " + isAdaptable(op));
+        }
+
+        if (isAdaptable(op)) {
+            final double p = op.getAdaptableParameter();
 
             final double i = schedule.getOptimizationTransform(MCMCOperator.Utils.getOperationCount(op));
 
@@ -514,68 +545,53 @@ public final class MarkovChain implements Serializable {
             final double newp = p + ((1.0 / (i + 1.0)) * (Math.exp(logr) - target));
 
             if (newp > -Double.MAX_VALUE && newp < Double.MAX_VALUE) {
-                op.setCoercableParameter(newp);
+                op.setAdaptableParameter(newp);
+                if (DEBUG) {
+                    System.out.println("Setting coercable parameter: " + newp + " target: " + target + " logr: " + logr);
+                }
             }
         }
     }
 
-    private boolean isCoercable(CoercableMCMCOperator op) {
+    private boolean isAdaptable(AdaptableMCMCOperator op) {
 
-        return op.getMode() == CoercionMode.COERCION_ON
-                || (op.getMode() != CoercionMode.COERCION_OFF && useCoercion);
+        return op.getMode() == AdaptationMode.ADAPTATION_ON
+                || (op.getMode() != AdaptationMode.ADAPTATION_OFF && useAdaptation);
     }
 
     public void addMarkovChainListener(MarkovChainListener listener) {
-        listeners.add(listener);
+        if (listener != null) {
+            listeners.add(listener);
+        }
     }
 
     public void removeMarkovChainListener(MarkovChainListener listener) {
         listeners.remove(listener);
     }
 
-    public void addMarkovChainDelegate(MarkovChainDelegate delegate) {
-        delegates.add(delegate);
-    }
-
-    public void removeMarkovChainDelegate(MarkovChainDelegate delegate) {
-        delegates.remove(delegate);
-    }
-
 
     private void fireBestModel(long state, Model bestModel) {
 
         for (MarkovChainListener listener : listeners) {
-            listener.bestState(state, bestModel);
+            listener.bestState(state, this, bestModel);
         }
     }
 
     private void fireCurrentModel(long state, Model currentModel) {
         for (MarkovChainListener listener : listeners) {
-            listener.currentState(state, currentModel);
-        }
-
-        for (MarkovChainDelegate delegate : delegates) {
-            delegate.currentState(state);
+            listener.currentState(state, this, currentModel);
         }
     }
 
     private void fireFinished(long chainLength) {
 
         for (MarkovChainListener listener : listeners) {
-            listener.finished(chainLength);
-        }
-
-        for (MarkovChainDelegate delegate : delegates) {
-            delegate.finished(chainLength);
+            listener.finished(chainLength, this);
         }
     }
 
     private void fireEndCurrentIteration(long state) {
-        for (MarkovChainDelegate delegate : delegates) {
-            delegate.currentStateEnd(state);
-        }
     }
 
     private final ArrayList<MarkovChainListener> listeners = new ArrayList<MarkovChainListener>();
-    private final ArrayList<MarkovChainDelegate> delegates = new ArrayList<MarkovChainDelegate>();
 }
