@@ -41,8 +41,9 @@ public class MCMCOptions {
     private final long fullEvaluationCount;
     private final int minOperatorCountForFullEvaluation;
     private final double evaluationTestThreshold;
-    private final boolean coercion;
-    private final long coercionDelay;
+    private final boolean useAdaptation;
+    private final long adaptationDelay;
+    private final double adaptationTarget;
     private final double temperature;
 
     /**
@@ -50,7 +51,7 @@ public class MCMCOptions {
      * @param chainLength
      */
     public MCMCOptions(long chainLength) {
-        this(chainLength, 2000, 1, MarkovChain.EVALUATION_TEST_THRESHOLD, true, 0, 1.0);
+        this(chainLength, 2000, 1, MarkovChain.EVALUATION_TEST_THRESHOLD, true, 0, 0.234, 1.0);
     }
 
     /**
@@ -59,17 +60,20 @@ public class MCMCOptions {
      * @param fullEvaluationCount
      * @param minOperatorCountForFullEvaluation
      * @param evaluationTestThreshold
-     * @param coercion
-     * @param coercionDelay
+     * @param useAdaptation
+     * @param adaptationDelay
      * @param temperature
      */
-    public MCMCOptions(long chainLength, long fullEvaluationCount, int minOperatorCountForFullEvaluation, double evaluationTestThreshold, boolean coercion, long coercionDelay, double temperature) {
+    public MCMCOptions(long chainLength, long fullEvaluationCount, int minOperatorCountForFullEvaluation,
+                       double evaluationTestThreshold, boolean useAdaptation, long adaptationDelay, double adaptationTarget,
+                       double temperature) {
         this.chainLength = chainLength;
         this.fullEvaluationCount = fullEvaluationCount;
         this.minOperatorCountForFullEvaluation = minOperatorCountForFullEvaluation;
         this.evaluationTestThreshold = evaluationTestThreshold;
-        this.coercion = coercion;
-        this.coercionDelay = coercionDelay;
+        this.useAdaptation = useAdaptation;
+        this.adaptationDelay = adaptationDelay;
+        this.adaptationTarget = adaptationTarget;
         this.temperature = temperature;
     }
 
@@ -88,13 +92,16 @@ public class MCMCOptions {
         return evaluationTestThreshold;
     }
 
-    public final boolean useCoercion() {
-        return coercion;
+    public final boolean useAdaptation() {
+        return useAdaptation;
     }
 
+    public final long getAdaptationDelay() {
+        return adaptationDelay;
+    }
 
-    public final long getCoercionDelay() {
-        return coercionDelay;
+    public final double getAdaptationTarget() {
+        return adaptationTarget;
     }
 
     public final double getTemperature() {
