@@ -32,7 +32,6 @@ import dr.inference.markovchain.MarkovChainListener;
 import dr.inference.model.Model;
 import dr.inference.model.PathLikelihood;
 import dr.inference.operators.*;
-import dr.inference.prior.Prior;
 import dr.util.Author;
 import dr.util.Citable;
 import dr.util.Citation;
@@ -80,7 +79,7 @@ public class MarginalLikelihoodEstimator implements Runnable, Identifiable, Cita
         this.pathLikelihood = pathLikelihood;
         pathLikelihood.setPathParameter(pathParameter);
 
-        mc = new MarkovChain(Prior.UNIFORM_PRIOR, pathLikelihood, schedule, criterion, 0, 0, 0.0, true);
+        mc = new MarkovChain(pathLikelihood, schedule, criterion, 0, 0, 0.0, true);
 
         this.loggers = loggers;
     }
@@ -116,7 +115,7 @@ public class MarginalLikelihoodEstimator implements Runnable, Identifiable, Cita
             mc.runChain(chainLength, false);
 
             if (SHOW_OPERATOR_ANALYSIS) {
-            	(new OperatorAnalysisPrinter(schedule)).showOperatorAnalysis(System.out);
+            	OperatorAnalysisPrinter.showOperatorAnalysis(System.out, schedule, false);
             }
             ((CombinedOperatorSchedule) schedule).reset();
         }
@@ -374,7 +373,8 @@ public class MarginalLikelihoodEstimator implements Runnable, Identifiable, Cita
         /**
          * Called to update the current model keepEvery states.
          */
-        public void currentState(long state, Model currentModel) {
+        @Override
+        public void currentState(long state, MarkovChain markovChain, Model currentModel) {
 
             currentState = state;
 
@@ -388,16 +388,18 @@ public class MarginalLikelihoodEstimator implements Runnable, Identifiable, Cita
         /**
          * Called when a new new best posterior state is found.
          */
-        public void bestState(long state, Model bestModel) {
+        @Override
+        public void bestState(long state, MarkovChain markovChain, Model bestModel) {
             currentState = state;
         }
 
         /**
          * cleans up when the chain finishes (possibly early).
          */
-        public void finished(long chainLength) {
+        @Override
+        public void finished(long chainLength, MarkovChain markovChain) {
             currentState = chainLength;
-            (new OperatorAnalysisPrinter(schedule)).showOperatorAnalysis(System.out);
+            OperatorAnalysisPrinter.showOperatorAnalysis(System.out, schedule, false);
 //            logger.log(currentState);
             for (MCLogger logger : loggers) {
                 logger.stopLogging();
@@ -528,11 +530,11 @@ public class MarginalLikelihoodEstimator implements Runnable, Identifiable, Cita
             } else {
             	throw new RuntimeException("Either a number of path steps or predefined beta values need to be provided.");
             }
-            
+
             if (xo.hasAttribute(PRINT_OPERATOR_ANALYSIS)) {
             	SHOW_OPERATOR_ANALYSIS = xo.getBooleanAttribute(PRINT_OPERATOR_ANALYSIS);
             }
-            
+
             int burninLength = -1;
             if (xo.hasAttribute(BURNIN)) {
                 burninLength = xo.getIntegerAttribute(BURNIN);
@@ -542,7 +544,7 @@ public class MarginalLikelihoodEstimator implements Runnable, Identifiable, Cita
             if (xo.hasAttribute(PRERUN)) {
                 prerunLength = xo.getIntegerAttribute(PRERUN);
             }
-            
+
             // deprecated
             boolean linear = xo.getAttribute(LINEAR, true);
             // boolean lacing = xo.getAttribute(LACING,false);
