@@ -1,7 +1,7 @@
 /*
  * AdaptableVarianceMultivariateNormalOperator.java
  *
- * Copyright (c) 2002-2015 Alexei Drummond, Andrew Rambaut and Marc Suchard
+ * Copyright (c) 2002-2018 Alexei Drummond, Andrew Rambaut and Marc Suchard
  *
  * This file is part of BEAST.
  * See the NOTICE file distributed with this work for additional
@@ -26,9 +26,11 @@
 package dr.inference.operators;
 
 import java.util.ArrayList;
+import java.util.List;
 
 import cern.colt.matrix.impl.DenseDoubleMatrix2D;
 import cern.colt.matrix.linalg.SingularValueDecomposition;
+import dr.inference.model.CompoundParameter;
 import dr.inference.model.MatrixParameter;
 import dr.inference.model.Parameter;
 import dr.math.MathUtils;
@@ -48,7 +50,7 @@ import dr.xml.XMLSyntaxRule;
  * @author Guy Baele
  * @author Marc A. Suchard
  */
-public class AdaptableVarianceMultivariateNormalOperator extends AbstractCoercableOperator {
+public class AdaptableVarianceMultivariateNormalOperator extends AbstractAdaptableOperator {
 
     public static final String AVMVN_OPERATOR = "adaptableVarianceMultivariateNormalOperator";
     public static final String SCALE_FACTOR = "scaleFactor";
@@ -58,8 +60,13 @@ public class AdaptableVarianceMultivariateNormalOperator extends AbstractCoercab
     public static final String UPDATE_EVERY = "updateEvery";
     public static final String FORM_XTX = "formXtXInverse";
     public static final String COEFFICIENT = "coefficient";
+    public static final String SKIP_RANK_CHECK = "skipRankCheck";
+
+    public static final String TRANSFORM = "transform";
+    public static final String TYPE = "type";
 
     public static final boolean DEBUG = false;
+    public static final boolean PRINT_FULL_MATRIX = false;
 
     private double scaleFactor;
     private double beta;
@@ -67,6 +74,7 @@ public class AdaptableVarianceMultivariateNormalOperator extends AbstractCoercab
     private final Parameter parameter;
     private final Transform[] transformations;
     private final int[] transformationSizes;
+    private final double[] transformationSums;
     private final int dim;
     // private final double constantFactor;
     private double[] oldMeans, newMeans;
@@ -79,14 +87,15 @@ public class AdaptableVarianceMultivariateNormalOperator extends AbstractCoercab
     private double[] epsilon;
     private double[][] proposal;
 
-    public AdaptableVarianceMultivariateNormalOperator(Parameter parameter, Transform[] transformations, int[] transformationSizes, double scaleFactor, double[][] inMatrix,
-            double weight, double beta, int initial, int burnin, int every, CoercionMode mode, boolean isVarianceMatrix) {
+    public AdaptableVarianceMultivariateNormalOperator(Parameter parameter, Transform[] transformations, int[] transformationSizes, double[] transformationSums, double scaleFactor, double[][] inMatrix,
+                                                       double weight, double beta, int initial, int burnin, int every, AdaptationMode mode, boolean isVarianceMatrix, boolean skipRankCheck) {
 
         super(mode);
         this.scaleFactor = scaleFactor;
         this.parameter = parameter;
         this.transformations = transformations;
         this.transformationSizes = transformationSizes;
+        this.transformationSums = transformationSums;
         this.beta = beta;
         this.iterations = 0;
         this.updates = 0;
@@ -103,9 +112,11 @@ public class AdaptableVarianceMultivariateNormalOperator extends AbstractCoercab
         this.epsilon = new double[dim];
         this.proposal = new double[dim][dim];
 
-        SingularValueDecomposition svd = new SingularValueDecomposition(new DenseDoubleMatrix2D(inMatrix));
-        if (inMatrix[0].length != svd.rank()) {
-            throw new RuntimeException("Variance matrix in AdaptableVarianceMultivariateNormalOperator is not of full rank");
+        if (!skipRankCheck) {
+            SingularValueDecomposition svd = new SingularValueDecomposition(new DenseDoubleMatrix2D(inMatrix));
+            if (inMatrix[0].length != svd.rank()) {
+                throw new RuntimeException("Variance matrix in AdaptableVarianceMultivariateNormalOperator is not of full rank");
+            }
         }
 
         if (isVarianceMatrix) {
@@ -129,9 +140,9 @@ public class AdaptableVarianceMultivariateNormalOperator extends AbstractCoercab
         }
     }
 
-    public AdaptableVarianceMultivariateNormalOperator(Parameter parameter, Transform[] transformations, int[] transformationSizes, double scaleFactor,
-            MatrixParameter varMatrix, double weight, double beta, int initial, int burnin, int every, CoercionMode mode, boolean isVariance) {
-        this(parameter, transformations, transformationSizes, scaleFactor, varMatrix.getParameterAsMatrix(), weight, beta, initial, burnin, every, mode, isVariance);
+    public AdaptableVarianceMultivariateNormalOperator(Parameter parameter, Transform[] transformations, int[] transformationSizes, double[] transformationSums, double scaleFactor,
+                                                       MatrixParameter varMatrix, double weight, double beta, int initial, int burnin, int every, AdaptationMode mode, boolean isVariance, boolean skipRankCheck) {
+        this(parameter, transformations, transformationSizes, transformationSums, scaleFactor, varMatrix.getParameterAsMatrix(), weight, beta, initial, burnin, every, mode, isVariance, skipRankCheck);
     }
 
     private double[][] formXtXInverse(double[][] X) {
@@ -172,7 +183,7 @@ public class AdaptableVarianceMultivariateNormalOperator extends AbstractCoercab
 
     }
 
-    public double doOperation() throws OperatorFailedException {
+    public double doOperation() {
 
         iterations++;
 
@@ -406,7 +417,7 @@ public class AdaptableVarianceMultivariateNormalOperator extends AbstractCoercab
             }
             if (MULTI) {
                 if (transformationSizes[i] > 1) {
-                    double[] temp = transformations[i].inverse(transformedX, currentIndex, currentIndex + transformationSizes[i] - 1);
+                    double[] temp = transformations[i].inverse(transformedX, currentIndex, currentIndex + transformationSizes[i] - 1, transformationSums[i]);
                     for (int k = 0; k < temp.length; k++) {
                         parameter.setParameterValueQuietly(currentIndex + k, temp[k]);
                     }
@@ -539,14 +550,28 @@ public class AdaptableVarianceMultivariateNormalOperator extends AbstractCoercab
 
     //MCMCOperator INTERFACE
     public final String getOperatorName() {
-        return "adaptableVarianceMultivariateNormal(" + parameter.getParameterName() + ")";
+        String output = "adaptableVarianceMultivariateNormal(" + parameter.getParameterName() + ")";
+        if (PRINT_FULL_MATRIX) {
+            output += "\nMeans:\n";
+            for (int i = 0; i < dim; i++) {
+                output += newMeans[i] + " ";
+            }
+            output += "\nVariance-covariance matrix:\n";
+            for (int i = 0; i < dim; i++) {
+                for (int j = 0; j < dim; j++) {
+                    output += empirical[i][j] + " ";
+                }
+                output += "\n";
+            }
+        }
+        return output;
     }
 
-    public double getCoercableParameter() {
+    public double getAdaptableParameter() {
         return Math.log(scaleFactor);
     }
 
-    public void setCoercableParameter(double value) {
+    public void setAdaptableParameter(double value) {
         scaleFactor = Math.exp(value);
     }
 
@@ -558,38 +583,8 @@ public class AdaptableVarianceMultivariateNormalOperator extends AbstractCoercab
         return scaleFactor;
     }
 
-    public double getTargetAcceptanceProbability() {
-        return 0.234;
-    }
-
-    public double getMinimumAcceptanceLevel() {
-        return 0.1;
-    }
-
-    public double getMaximumAcceptanceLevel() {
-        return 0.4;
-    }
-
-    public double getMinimumGoodAcceptanceLevel() {
-        return 0.20;
-    }
-
-    public double getMaximumGoodAcceptanceLevel() {
-        return 0.30;
-    }
-
-    public final String getPerformanceSuggestion() {
-
-        double prob = MCMCOperator.Utils.getAcceptanceProbability(this);
-        double targetProb = getTargetAcceptanceProbability();
-        dr.util.NumberFormatter formatter = new dr.util.NumberFormatter(5);
-        double sf = OperatorUtils.optimizeWindowSize(scaleFactor, prob, targetProb);
-        if (prob < getMinimumGoodAcceptanceLevel()) {
-            return "Try setting scaleFactor to about " + formatter.format(sf);
-        } else if (prob > getMaximumGoodAcceptanceLevel()) {
-            return "Try setting scaleFactor to about " + formatter.format(sf);
-        } else return "";
-
+    public String getAdaptableParameterName() {
+        return "scaleFactor";
     }
 
     public static XMLObjectParser PARSER = new AbstractXMLObjectParser() {
@@ -604,7 +599,7 @@ public class AdaptableVarianceMultivariateNormalOperator extends AbstractCoercab
                 System.err.println("\nParsing AdaptableVarianceMultivariateNormalOperator.");
             }
 
-            CoercionMode mode = CoercionMode.parseMode(xo);
+            AdaptationMode mode = AdaptationMode.parseMode(xo);
 
             double weight = xo.getDoubleAttribute(WEIGHT);
             double beta = xo.getDoubleAttribute(BETA);
@@ -618,7 +613,7 @@ public class AdaptableVarianceMultivariateNormalOperator extends AbstractCoercab
                 burnin = xo.getIntegerAttribute(BURNIN);
             }
             if (burnin > initial || burnin < 0) {
-                throw new XMLParseException("burnin must be smaller than the initial period");
+                throw new XMLParseException("Burn-in must be smaller than the initial period.");
             }
 
             if (xo.hasAttribute(UPDATE_EVERY)) {
@@ -626,20 +621,173 @@ public class AdaptableVarianceMultivariateNormalOperator extends AbstractCoercab
             }
 
             if (every <= 0) {
-                throw new XMLParseException("covariance matrix needs to be updated at least every single iteration");
+                throw new XMLParseException("Covariance matrix needs to be updated at least every single iteration.");
             }
 
             if (scaleFactor <= 0.0) {
-                throw new XMLParseException("scaleFactor must be greater than 0.0");
+                throw new XMLParseException("ScaleFactor must be greater than zero.");
             }
 
-            Parameter parameter = (Parameter) xo.getChild(Parameter.class);
-
             boolean formXtXInverse = xo.getAttribute(FORM_XTX, false);
 
+            Transform.ParsedTransform pt = (Transform.ParsedTransform) xo.getChild(Transform.ParsedTransform.class);
+            boolean oldXML;
+            if (pt == null) {
+                throw new XMLParseException("No valid transformations have been provided in the XML file.");
+            }
+            oldXML = pt.parameters == null;
+
+            Parameter parameter;
+            Transform[] transformations;
+            int[] transformationSizes;
+            double[] transformationSums;
+
+            int transformationSizeCounter = 0;
+
+            if (!oldXML) {
+                // if there are no ParsedTransform elements then use the new parser syntax
+                if (DEBUG) {
+                    System.err.println("New parser");
+                }
+
+                CompoundParameter allParameters = new CompoundParameter("allParameters");
+
+                List<Transform> transformList = new ArrayList<Transform>();
+                List<Integer> transformCountList = new ArrayList<Integer>();
+                List<Double> transformSumList = new ArrayList<Double>();
+
+                for (Object co : xo.getChildren()) {
+                    if (co instanceof Parameter) {
+                        // parameters in the body of the object are assumed to have no transform
+                        transformList.add(Transform.NONE);
+                        Parameter param = (Parameter) co;
+                        allParameters.addParameter(param);
+                        transformCountList.add(param.getDimension());
+                        transformSumList.add(0.0);
+                    } else if (co instanceof Transform.ParsedTransform) {
+                        Transform.ParsedTransform parsedTransform = (Transform.ParsedTransform)co;
+
+                        transformList.add(parsedTransform.transform);
+
+                        int dim = 0;
+                        for (Parameter param : parsedTransform.parameters) {
+                            allParameters.addParameter(param);
+                            dim += param.getDimension();
+                        }
+                        transformCountList.add(dim);
+                        transformSumList.add(parsedTransform.fixedSum);
+                    } else {
+                        throw new XMLParseException("Unknown element in " + AVMVN_OPERATOR);
+                    }
+                }
+
+                parameter = allParameters;
+                transformations = new Transform[parameter.getDimension()];
+                transformationSizes = new int[parameter.getDimension()];
+                transformationSums = new double[parameter.getDimension()];
+
+                /*transformations = transformList.toArray(transformations);
+                for (int i = 0; i < transformCountList.size(); i++) {
+                    transformationSizes[i] = transformCountList.get(i);
+                }*/
+                if (DEBUG) {
+                    for (int i = 0; i < transformList.size(); i++) {
+                        System.err.println(i + "  " + transformList.get(i));
+                    }
+                    for (int i = 0; i < transformCountList.size(); i++) {
+                        System.err.println(i + "  " + transformCountList.get(i));
+                    }
+                }
+                int index = 0;
+                for (int i = 0; i < transformCountList.size(); i++) {
+                    if (!transformList.get(i).getTransformName().equals(Transform.LOG_CONSTRAINED_SUM.getTransformName())) {
+                        for (int j = 0; j < transformCountList.get(i); j++) {
+                            transformations[index] = transformList.get(i);
+                            transformationSizes[index] = 1;
+                            transformationSums[index] = transformSumList.get(i);
+                            index++;
+                            transformationSizeCounter++;
+                        }
+                    } else {
+                        //log constrained sum transformation
+                        transformations[index] = transformList.get(i);
+                        transformationSizes[index] = transformCountList.get(i);
+                        transformationSums[index] = transformSumList.get(i);
+                        index++;
+                        transformationSizeCounter++;
+                    }
+                }
+
+            } else {
+
+                if (DEBUG) {
+                    System.err.println("Old parser");
+                }
+                // assume old parser syntax for backwards compatibility
+                parameter = (Parameter)xo.getChild(Parameter.class);
+
+                transformations = new Transform[parameter.getDimension()];
+                transformationSizes = new int[parameter.getDimension()];
+                transformationSums = new double[parameter.getDimension()];
+
+                for (int i = 0; i < xo.getChildCount(); i++) {
+                    Object child = xo.getChild(i);
+                    if (child instanceof Transform.ParsedTransform) {
+                        Transform.ParsedTransform thisObject = (Transform.ParsedTransform) child;
+
+                        if (DEBUG) {
+                            System.err.println(thisObject.transform.getTransformName());
+                        }
+
+                        if (thisObject.transform.getTransformName().equals(Transform.LOG_CONSTRAINED_SUM.getTransformName())) {
+                            transformations[transformationSizeCounter] = thisObject.transform;
+                            transformationSizes[transformationSizeCounter] = thisObject.end - thisObject.start;
+                            //transformationSums[transformationSizeCounter] = thisObject.fixedSum;
+                            transformationSums[transformationSizeCounter] = thisObject.end - thisObject.start;
+                            if (DEBUG) {
+                                System.err.println("Transformation size (logConstrainedSum) = " + transformationSizes[transformationSizeCounter]);
+                            }
+                            transformationSizeCounter++;
+                        } else {
+                            for (int j = thisObject.start; j < thisObject.end; ++j) {
+                                transformations[transformationSizeCounter] = thisObject.transform;
+                                transformationSizes[transformationSizeCounter] = 1;
+                                transformationSums[transformationSizeCounter] = thisObject.fixedSum;
+                                if (DEBUG) {
+                                    System.err.println("Transformation size = " + transformationSizes[transformationSizeCounter]);
+                                }
+                                transformationSizeCounter++;
+                            }
+                        }
+                    }
+                }
+            }
+
+            //determine array length for transformationSizes = transformationSizeCounter - 1;
+            if (DEBUG) {
+                System.err.println("\nCleaning up transformation and size arrays");
+                System.err.println("transformationSizeCounter = " + transformationSizeCounter);
+            }
+            int temp[] = new int[transformationSizeCounter];
+            Transform tempTransform[] = new Transform[transformationSizeCounter];
+            double[] tempSum = new double[transformationSizeCounter];
+            for (int i = 0; i < temp.length; i++) {
+                temp[i] = transformationSizes[i];
+                tempTransform[i] = transformations[i];
+                tempSum[i] = transformationSums[i];
+                if (transformationSizes[i] == 0 || temp[i] == 0) {
+                    throw new XMLParseException("Transformation size 0 encountered");
+                }
+            }
+            transformationSizes = temp;
+            transformations = tempTransform;
+            transformationSums = tempSum;
+
             //varMatrix needs to be initialized
             int dim = parameter.getDimension();
-            System.err.println("Dimension: " + dim);
+            if (DEBUG) {
+                System.err.println("Dimension: " + dim);
+            }
 
             if (initial <= 2 * dim) {
                 initial = 2 * dim;
@@ -654,71 +802,6 @@ public class AdaptableVarianceMultivariateNormalOperator extends AbstractCoercab
             }
             MatrixParameter varMatrix = new MatrixParameter(null, init);
 
-            /*double[][] test = varMatrix.getParameterAsMatrix();
-            for (int i = 0; i < dim; i++) {
-            	for (int j = 0; j < dim; j++) {
-            		System.err.print(test[i][j] + " ");
-            	}
-            	System.err.println();
-            }*/
-
-            int[] transformationSizes = new int[dim];
-            int transformationSizeCounter = 0;
-
-            Transform[] transformations = new Transform[dim];
-            for (int i = 0; i < dim; i++) {
-                transformations[i] = Transform.NONE;
-            }
-
-            if (DEBUG) {
-                System.err.println("Transformations & transformation sizes:");
-            }
-
-            //TODO: add LOG_CONSTRAINED_SUM transformation to transformations array!
-            for (int i = 0; i < xo.getChildCount(); i++) {
-                Object child = xo.getChild(i);
-                if (child instanceof Transform.ParsedTransform) {
-                    Transform.ParsedTransform thisObject = (Transform.ParsedTransform) child;
-
-                    if (DEBUG) {
-                        System.err.println(thisObject.transform.getTransformName());
-                    }
-                    if (thisObject.transform.equals(Transform.LOG_CONSTRAINED_SUM)) {
-                        transformations[transformationSizeCounter] = thisObject.transform;
-                        transformationSizes[transformationSizeCounter] = thisObject.end - thisObject.start;
-                        if (DEBUG) {
-                            System.err.println("Transformation size = " + transformationSizes[transformationSizeCounter]);
-                        }
-                        transformationSizeCounter++;
-                    } else {
-                        for (int j = thisObject.start; j < thisObject.end; ++j) {
-                            transformations[transformationSizeCounter] = thisObject.transform;
-                            transformationSizes[transformationSizeCounter] = 1;
-                            if (DEBUG) {
-                                System.err.println("Transformation size = " + transformationSizes[transformationSizeCounter]);
-                            }
-                            transformationSizeCounter++;
-                        }
-                    }
-                }
-            }
-
-            //determine array length for transformationSizes = transformationSizeCounter - 1;
-            if (DEBUG) {
-                System.err.println("\nCleaning up transformation and size arrays");
-                System.err.println("transformationSizeCounter = " + transformationSizeCounter);
-            }
-            int temp[] = new int[transformationSizeCounter];
-            Transform tempTransform[] = new Transform[transformationSizeCounter];
-            for (int i = 0; i < temp.length; i++) {
-                temp[i] = transformationSizes[i];
-                tempTransform[i] = transformations[i];
-                if (transformationSizes[i] == 0 || temp[i] == 0) {
-                    throw new XMLParseException("Transformation size 0 encountered");
-                }
-            }
-            transformationSizes = temp;
-            transformations = tempTransform;
             if (DEBUG) {
                 System.err.println("\nChecking transformation array contents");
                 for (int i = 0; i < transformations.length; i++) {
@@ -728,6 +811,10 @@ public class AdaptableVarianceMultivariateNormalOperator extends AbstractCoercab
                 for (int i = 0; i < transformationSizes.length; i++) {
                     System.err.print(transformationSizes[i] + " ");
                 }
+                System.err.println("\nChecking transformation sum contents");
+                for (int i = 0; i < transformationSums.length; i++) {
+                    System.err.print(transformationSums[i] + " ");
+                }
                 System.err.println();
             }
 
@@ -746,7 +833,10 @@ public class AdaptableVarianceMultivariateNormalOperator extends AbstractCoercab
 					"\n If you use this operator, please cite: " + 
 			"   Guy Baele, Philippe Lemey, Marc A. Suchard. 2016. In preparation.");*/
 
-            return new AdaptableVarianceMultivariateNormalOperator(parameter, transformations, transformationSizes, scaleFactor, varMatrix, weight, beta, initial, burnin, every, mode, !formXtXInverse);
+            boolean skipRankCheck = xo.getAttribute(SKIP_RANK_CHECK, false);
+
+            return new AdaptableVarianceMultivariateNormalOperator(parameter, transformations, transformationSizes, transformationSums, scaleFactor, varMatrix, weight, beta, initial, burnin, every,
+                    mode, !formXtXInverse, skipRankCheck);
         }
 
         //************************************************************************
@@ -775,7 +865,8 @@ public class AdaptableVarianceMultivariateNormalOperator extends AbstractCoercab
                 AttributeRule.newIntegerRule(UPDATE_EVERY, true),
                 AttributeRule.newBooleanRule(AUTO_OPTIMIZE, true),
                 AttributeRule.newBooleanRule(FORM_XTX, true),
-                new ElementRule(Parameter.class),
+                AttributeRule.newBooleanRule(SKIP_RANK_CHECK, true),
+                new ElementRule(Parameter.class, 0, Integer.MAX_VALUE),
                 new ElementRule(Transform.ParsedTransform.class, 0, Integer.MAX_VALUE)
         };
 
