@@ -1,7 +1,7 @@
 /*
  * BitFlipOperator.java
  *
- * Copyright (C) 2002-2007 Alexei Drummond and Andrew Rambaut
+ * Copyright (c) 2002-2015 Alexei Drummond, Andrew Rambaut and Marc Suchard
  *
  * This file is part of BEAST.
  * See the NOTICE file distributed with this work for additional
@@ -85,9 +85,10 @@ public class BitFlipOperator extends SimpleMCMCOperator {
                 // }
                 sum += Math.abs(parameter.getParameterValue(i));
             }
-            if (sum > 103) {
-                System.err.println("sum: " + sum);
-            }
+// AR - removed a debugging printf
+//            if (sum > 103) {
+//                System.err.println("sum: " + sum);
+//            }
 
             /*
             for (int i = 0; i < dim; i++) {
