@@ -32,17 +32,19 @@ import dr.math.MathUtils;
  * A generic operator for use with a sum-constrained vector parameter.
  *
  * @author Alexei Drummond
- * @author Andrew Rambaut
  * @version $Id: CenteredScaleOperator.java,v 1.20 2005/06/14 10:40:34 rambaut Exp $
  */
-public class CenteredScaleOperator extends AbstractCoercableOperator {
+
+// AR - I don't see how this can work...
+@Deprecated
+public class CenteredScaleOperator extends AbstractAdaptableOperator {
 
     public CenteredScaleOperator(Parameter parameter) {
-        super(CoercionMode.DEFAULT);
+        super(AdaptationMode.DEFAULT);
         this.parameter = parameter;
     }
 
-    public CenteredScaleOperator(Parameter parameter, double scale, int weight, CoercionMode mode) {
+    public CenteredScaleOperator(Parameter parameter, double scale, int weight, AdaptationMode mode) {
         super(mode);
         this.parameter = parameter;
         this.scaleFactor = scale;
@@ -63,7 +65,7 @@ public class CenteredScaleOperator extends AbstractCoercableOperator {
      * This operator changes the variance but maintains the order
      * of the scalars.
      */
-    public final double doOperation() throws OperatorFailedException {
+    public final double doOperation() {
 
         double total = 0.0;
 
@@ -78,7 +80,8 @@ public class CenteredScaleOperator extends AbstractCoercableOperator {
 
             double newScalar = (parameter.getParameterValue(i) - mean) * scaleFactor + mean;
             if (newScalar < parameter.getBounds().getLowerLimit(i) || newScalar > parameter.getBounds().getUpperLimit(i)) {
-                throw new OperatorFailedException("Proposed value out of bounds");
+//                throw new OperatorFailedException("Proposed value out of bounds");
+                return Double.NEGATIVE_INFINITY;
             }
             parameter.setParameterValue(i, newScalar);
         }
@@ -96,11 +99,11 @@ public class CenteredScaleOperator extends AbstractCoercableOperator {
         return parameter.getParameterName();
     }
 
-    public double getCoercableParameter() {
+    public double getAdaptableParameter() {
         return Math.log(1.0 / scaleFactor - 1.0);
     }
 
-    public void setCoercableParameter(double value) {
+    public void setAdaptableParameter(double value) {
         scaleFactor = 1.0 / (Math.exp(value) + 1.0);
     }
 
@@ -108,21 +111,8 @@ public class CenteredScaleOperator extends AbstractCoercableOperator {
         return scaleFactor;
     }
 
-    public double getTargetAcceptanceProbability() {
-        return 0.234;
-    }
-
-    public final String getPerformanceSuggestion() {
-
-        double prob = MCMCOperator.Utils.getAcceptanceProbability(this);
-        double targetProb = getTargetAcceptanceProbability();
-        dr.util.NumberFormatter formatter = new dr.util.NumberFormatter(5);
-        double sf = OperatorUtils.optimizeScaleFactor(scaleFactor, prob, targetProb);
-        if (prob < getMinimumGoodAcceptanceLevel()) {
-            return "Try setting scaleFactor to about " + formatter.format(sf);
-        } else if (prob > getMaximumGoodAcceptanceLevel()) {
-            return "Try setting scaleFactor to about " + formatter.format(sf);
-        } else return "";
+    public String getAdaptableParameterName() {
+        return "scaleFactor";
     }
 
     public String toString() {
