@@ -36,11 +36,11 @@ import dr.math.MathUtils;
  * @author Andrew Rambaut
  * @version $Id: DeltaExchangeOperator.java,v 1.18 2005/06/14 10:40:34 rambaut Exp $
  */
-public class DeltaExchangeOperator extends AbstractCoercableOperator {
+public class DeltaExchangeOperator extends AbstractAdaptableOperator {
 
     public DeltaExchangeOperator(Parameter parameter, double delta) {
 
-        super(CoercionMode.COERCION_ON);
+        super(AdaptationMode.ADAPTATION_ON);
 
         this.parameter = parameter;
         this.delta = delta;
@@ -53,7 +53,7 @@ public class DeltaExchangeOperator extends AbstractCoercableOperator {
         }
     }
 
-    public DeltaExchangeOperator(Parameter parameter, int[] parameterWeights, double delta, double weight, boolean isIntegerOperator, CoercionMode mode) {
+    public DeltaExchangeOperator(Parameter parameter, int[] parameterWeights, double delta, double weight, boolean isIntegerOperator, AdaptationMode mode) {
 
         super(mode);
 
@@ -80,7 +80,7 @@ public class DeltaExchangeOperator extends AbstractCoercableOperator {
      * performs a delta exchange operation between two scalars in the vector
      * and return the hastings ratio.
      */
-    public final double doOperation() throws OperatorFailedException {
+    public final double doOperation() {
 
         // get two dimensions
         final int dim = parameter.getDimension();
@@ -117,7 +117,7 @@ public class DeltaExchangeOperator extends AbstractCoercableOperator {
                 scalar1 > bounds.getUpperLimit(dim1) ||
                 scalar2 < bounds.getLowerLimit(dim2) ||
                 scalar2 > bounds.getUpperLimit(dim2)) {
-            throw new OperatorFailedException("proposed values out of range!");
+            return Double.NEGATIVE_INFINITY;
         }
         parameter.setParameterValue(dim1, scalar1);
         parameter.setParameterValue(dim2, scalar2);
@@ -131,11 +131,11 @@ public class DeltaExchangeOperator extends AbstractCoercableOperator {
         return parameter.getParameterName();
     }
 
-    public double getCoercableParameter() {
+    public double getAdaptableParameter() {
         return Math.log(delta);
     }
 
-    public void setCoercableParameter(double value) {
+    public void setAdaptableParameter(double value) {
         delta = Math.exp(value);
     }
 
@@ -143,23 +143,8 @@ public class DeltaExchangeOperator extends AbstractCoercableOperator {
         return delta;
     }
 
-    public double getTargetAcceptanceProbability() {
-        return 0.234;
-    }
-
-    public final String getPerformanceSuggestion() {
-
-        double prob = MCMCOperator.Utils.getAcceptanceProbability(this);
-        double targetProb = getTargetAcceptanceProbability();
-
-        double d = OperatorUtils.optimizeWindowSize(delta, parameter.getParameterValue(0) * 2.0, prob, targetProb);
-
-
-        if (prob < getMinimumGoodAcceptanceLevel()) {
-            return "Try decreasing delta to about " + d;
-        } else if (prob > getMaximumGoodAcceptanceLevel()) {
-            return "Try increasing delta to about " + d;
-        } else return "";
+    public String getAdaptableParameterName() {
+        return "delta";
     }
 
     public String toString() {
