@@ -30,7 +30,6 @@ import dr.inference.distribution.MultivariateDistributionLikelihood;
 import dr.inference.distribution.NormalDistributionModel;
 import dr.inference.distribution.ParametricDistributionModel;
 import dr.inference.model.*;
-import dr.inference.prior.Prior;
 import dr.inferencexml.operators.EllipticalSliceOperatorParser;
 import dr.math.MathUtils;
 import dr.math.distributions.CompoundGaussianProcess;
@@ -124,14 +123,14 @@ public class EllipticalSliceOperator extends SimpleMetropolizedGibbsOperator imp
         }
     }
 
-    private double evaluateDensity(Prior prior, Likelihood likelihood, double pathParameter) {
-        double logPosterior = evaluate(likelihood, prior, pathParameter);
+    private double evaluateDensity(Likelihood likelihood, double pathParameter) {
+        double logPosterior = evaluate(likelihood, pathParameter);
         double logGaussianPrior = getLogGaussianPrior() * pathParameter;
 
         return logPosterior - logGaussianPrior;
     }
 
-    public double doOperation(Prior prior, Likelihood likelihood) throws OperatorFailedException {
+    public double doOperation(Likelihood likelihood) {
 
 //        System.err.println("Likelihood type:" + likelihood.getClass().getName());
 
@@ -159,12 +158,12 @@ public class EllipticalSliceOperator extends SimpleMetropolizedGibbsOperator imp
 
         } else {
 
-            double logPosterior = evaluate(likelihood, prior, pathParameter);
+            double logPosterior = evaluate(likelihood, pathParameter);
             double logGaussianPrior = getLogGaussianPrior() * pathParameter;
 
             // Cut-off depends only on non-GP contribution to posterior
             double cutoffDensity = logPosterior - logGaussianPrior + MathUtils.randomLogDouble();
-            drawFromSlice(prior, likelihood, cutoffDensity);
+            drawFromSlice(likelihood, cutoffDensity);
         }
 
         // No need to set variable, as SliceInterval has already done this (and recomputed posterior)
@@ -190,51 +189,80 @@ public class EllipticalSliceOperator extends SimpleMetropolizedGibbsOperator imp
         return r;
     }
 
-    public static void transformPoint(double[] x, boolean translationInvariant, boolean rotationInvariant, int dim) {
-        if (translationInvariant) {
-
-            double[] mean = new double[dim];
-            int k = 0;
-            for (int i = 0; i < x.length / dim; ++i) {
-                for (int j = 0; j < dim; ++j) {
-                    mean[j] += x[k];
-                    ++k;
-                }
-            }
-
+    private static void translate(double[] x, int dim) {
+        double[] mean = new double[dim];
+        int k = 0;
+        for (int i = 0; i < x.length / dim; ++i) {
             for (int j = 0; j < dim; ++j) {
-                mean[j] /= (x.length / dim);
-            }
-
-            k = 0;
-            for (int i = 0; i < x.length / dim; ++i) {
-                for (int j = 0; j < dim; ++j) {
-                    x[k] -= mean[j];
-                    ++k;
-                }
+                mean[j] += x[k];
+                ++k;
             }
         }
 
-        if (rotationInvariant) {
+        for (int j = 0; j < dim; ++j) {
+            mean[j] /= (x.length / dim);
+        }
 
-            final double theta = -Math.atan2(x[1], x[0]); // TODO Compute norm and avoid transcendentals
+        k = 0;
+        for (int i = 0; i < x.length / dim; ++i) {
+            for (int j = 0; j < dim; ++j) {
+                x[k] -= mean[j];
+                ++k;
+            }
+        }
+    }
+
+//    private static void rotate2d(double[] x) {
+//        final double theta = -Math.atan2(x[1], x[0]); // TODO Compute norm and avoid transcendentals
+//        final double sin = Math.sin(theta);
+//        final double cos = Math.cos(theta);
+//
+//        int k = 0;
+//        for (int i = 0; i < x.length / 2; ++i) {
+//            double newX = x[k + 0] * cos - x[k + 1] * sin;
+//            double newY = x[k + 1] * cos + x[k + 0] * sin;
+//            x[k + 0] = newX;
+//            x[k + 1] = newY;
+//            k += 2;
+//        }
+//    }
+
+    private static void rotateNd(double[] x, int dim) {
+
+        for (int d = 1; d < dim; ++d) {
+
+            final double theta = -Math.atan2(x[d], x[0]); // TODO Compute norm and avoid transcendentals
             final double sin = Math.sin(theta);
             final double cos = Math.cos(theta);
 
-//            System.err.println(theta + " " + sin + " " + cos);
-
             int k = 0;
             for (int i = 0; i < x.length / dim; ++i) {
-//                System.err.print(x[k + 0] + ":" + x[k + 1] + " -> ");
-                double newX = x[k + 0] * cos - x[k + 1] * sin;
-                double newY = x[k + 1] * cos + x[k + 0] * sin;
+                double newX = x[k + 0] * cos - x[k + d] * sin;
+                double newY = x[k + d] * cos + x[k + 0] * sin;
                 x[k + 0] = newX;
-                x[k + 1] = newY;
-//                System.err.println(x[k + 0] + ":" + x[k + 1]);
-                k += 2;
+                x[k + d] = newY;
+                k += dim;
             }
-//            System.err.println("");
-//            System.exit(-1);
+        }
+    }
+
+    private static void rotate(double[] x, int dim) {
+
+//        if (dim == 2) {
+//            rotate2d(x);
+//        } else {
+            rotateNd(x, dim);
+//        }
+    }
+
+    public static void transformPoint(double[] x, boolean translationInvariant, boolean rotationInvariant, int dim) {
+
+        if (translationInvariant) {
+            translate(x, dim);
+        }
+
+        if (rotationInvariant) {
+            rotate(x, dim);
         }
     }
 
@@ -258,70 +286,18 @@ public class EllipticalSliceOperator extends SimpleMetropolizedGibbsOperator imp
 
         setAllParameterValues(x);
 
-////        boolean switchSign = x[0] > 0.0;
-//        for (int i = 0; i < x.length; ++i) {
-////            if (switchSign) {
-////                x[i] *= -1;
-////            }
-//            variable.setParameterValueQuietly(i, x[i]);
-//        }
-
         if (signalConstituentParameters) {
             variable.fireParameterChangedEvent();
         } else {
-            ((CompoundParameter)variable).fireParameterChangedEvent(-1, Variable.ChangeType.ALL_VALUES_CHANGED);
+            variable.fireParameterChangedEvent(-1, Variable.ChangeType.ALL_VALUES_CHANGED);
         }
     }
-//
-//        if(!(variable instanceof CompoundParameter))
-//        {variable.setParameterValueNotifyChangedAll(0, x[0]);
-//        for (int i = 1; i < x.length; ++i) {
-//            variable.setParameterValueQuietly(i, x[i]);
-//        }}
-//        else{
-//            if(!drawByRow) {
-//                ((CompoundParameter) variable).setParameterValueNotifyChangedAll(0, current, x[0]);
-//                for (int i = 1; i < x.length; ++i) {
-//                    ((CompoundParameter) variable).setParameterValueQuietly(i, current, x[i]);
-//                }
-//            }
-//            else{
-//                for (int i = 0; i < x.length; i++) {
-//                    ((CompoundParameter) variable).setParameterValue(current, i, x[i]);
-//                }
-//            }
-//        }
 
+    private void drawFromSlice(Likelihood likelihood, double cutoffDensity) {
 
-    private void drawFromSlice(Prior prior, Likelihood likelihood, double cutoffDensity) {
-        // Do nothing
         double[] x = variable.getParameterValues();
         double[] nu = (double[]) gaussianProcess.nextRandom();
 
-//        double[] x;
-//        if(!(variable instanceof CompoundParameter))
-//            x = variable.getParameterValues();
-//        else{
-//            if(drawByRow){
-//                current=MathUtils.nextInt(((CompoundParameter) variable).getParameter(0).getDimension());
-//                x=new double[((CompoundParameter) variable).getParameterCount()];
-//                for (int i = 0; i <x.length ; i++) {
-//                    x[i]=((CompoundParameter) variable).getParameter(i).getParameterValue(current);
-//                }
-//            }
-//            else {
-//                current = MathUtils.nextInt(((CompoundParameter) variable).getParameterCount());
-//                x=((CompoundParameter) variable).getParameter(current).getParameterValues();
-//            }
-//
-//        }
-
-//        double[] nu;
-//        if(normalPrior!=null)
-//            nu = normalPrior.nextMultivariateNormal();
-//        else
-//            nu = treePrior.nextRandomFast(0);
-
         double phi;
         Interval phiInterval;
 
@@ -340,7 +316,7 @@ public class EllipticalSliceOperator extends SimpleMetropolizedGibbsOperator imp
         while (!done) {
             double[] xx = pointOnEllipse(x, nu, phi, priorMean);
             setVariable(xx);
-            double density = evaluate(likelihood, prior, pathParameter);
+            double density = evaluate(likelihood, pathParameter);
             density -= getLogGaussianPrior(); // Depends only on non-GP contribution to posterior
 
             if (density > cutoffDensity) {
@@ -353,7 +329,7 @@ public class EllipticalSliceOperator extends SimpleMetropolizedGibbsOperator imp
     }
 
     private void drawFromSlice(CompoundLikelihood likelihood, double cutoffDensity) {
-        // Do nothing
+
         double[] x = variable.getParameterValues();
         double[] nu = (double[]) gaussianProcess.nextRandom();
 
@@ -476,11 +452,7 @@ public class EllipticalSliceOperator extends SimpleMetropolizedGibbsOperator imp
         log[1] = precParameter;
 
         for (int i = 0; i < length; i++) {
-            try {
-                sliceSampler.doOperation(null, posterior);
-            } catch (OperatorFailedException e) {
-                System.err.println(e.getMessage());
-            }
+            sliceSampler.doOperation(posterior);
             for (int j = 0; j < dim; ++j) {
                 double x = log[j].getValue(0);
                 mean[j] += x;
