@@ -26,7 +26,6 @@
 package dr.inference.operators;
 
 import dr.inference.model.Likelihood;
-import dr.inference.prior.Prior;
 
 /**
  * An operator that requires both the prior and likelihood to calculate hasting ratio.
@@ -35,5 +34,5 @@ import dr.inference.prior.Prior;
  */
 public interface GeneralOperator {
 
-    double operate(Prior prior, Likelihood likelihood) throws OperatorFailedException;
+    double operate(Likelihood likelihood);
 }
