@@ -96,9 +96,9 @@ public class IndependentNormalDistributionSampler extends SimpleMCMCOperator {
 	}
 
     /**
-     * change the parameter and return the hastings ratio.
+	 * change the parameter and return the hastings ratio.
      */
-	public double doOperation() throws OperatorFailedException {
+	public double doOperation() {
 		
 		double logq = 0;
 		
@@ -123,7 +123,8 @@ public class IndependentNormalDistributionSampler extends SimpleMCMCOperator {
 				logq += (model.logPdf(currentValue) - model.logPdf(newValue));
 				
 				if (newValue < bounds.getLowerLimit(i) || newValue > bounds.getUpperLimit(i)) {
-                    throw new OperatorFailedException("proposed value outside boundaries");
+//                    throw new OperatorFailedException("proposed value outside boundaries");
+					return Double.NEGATIVE_INFINITY;
                 }
 				
 				variable.setValue(i, newValue);
