@@ -34,7 +34,7 @@ import java.util.ArrayList;
 /**
  * @author Marc A. Suchard
  */
-public class JointOperator extends SimpleMCMCOperator implements CoercableMCMCOperator {
+public class JointOperator extends SimpleMCMCOperator implements AdaptableMCMCOperator {
 
     private final ArrayList<SimpleMCMCOperator> operatorList;
     private final ArrayList<Integer> operatorToOptimizeList;
@@ -54,51 +54,41 @@ public class JointOperator extends SimpleMCMCOperator implements CoercableMCMCOp
     public void addOperator(SimpleMCMCOperator operation) {
 
         operatorList.add(operation);
-        if (operation instanceof CoercableMCMCOperator) {
+        if (operation instanceof AdaptableMCMCOperator) {
 
-            if (((CoercableMCMCOperator) operation).getMode() == CoercionMode.COERCION_ON)
+            if (((AdaptableMCMCOperator) operation).getMode() == AdaptationMode.ADAPTATION_ON)
 
                 operatorToOptimizeList.add(operatorList.size() - 1);
 
         }
     }
 
-    public final double doOperation() throws OperatorFailedException {
+    public final double doOperation() {
 
         double logP = 0;
 
-        boolean failed = false;
-        OperatorFailedException failure = null;
-
         for (SimpleMCMCOperator operation : operatorList) {
 
-            try {
-                logP += operation.doOperation();
-            } catch (OperatorFailedException ofe) {
-                failed = true;
-                failure = ofe;
-            }
+            logP += operation.doOperation();
             // todo After a failure, should not have to complete remaining operations, need to fake their operate();
         }
-        if (failed)
-            throw failure;
 
         return logP;
     }
 
 //    private double old;
 
-    public double getCoercableParameter() {
+    public double getAdaptableParameter() {
         if (operatorToOptimizeList.size() > 0) {
             currentOptimizedOperator = operatorToOptimizeList.get(MathUtils.nextInt(operatorToOptimizeList.size()));
-            return ((CoercableMCMCOperator) operatorList.get(currentOptimizedOperator)).getCoercableParameter();
+            return ((AdaptableMCMCOperator) operatorList.get(currentOptimizedOperator)).getAdaptableParameter();
         }
         throw new IllegalArgumentException();
     }
 
-    public void setCoercableParameter(double value) {
+    public void setAdaptableParameter(double value) {
         if (operatorToOptimizeList.size() > 0) {
-            ((CoercableMCMCOperator) operatorList.get(currentOptimizedOperator)).setCoercableParameter(value);
+            ((AdaptableMCMCOperator) operatorList.get(currentOptimizedOperator)).setAdaptableParameter(value);
             return;
         }
         throw new IllegalArgumentException();
@@ -112,7 +102,7 @@ public class JointOperator extends SimpleMCMCOperator implements CoercableMCMCOp
     public double getRawParamter(int i) {
         if (i < 0 || i >= operatorList.size())
             throw new IllegalArgumentException();
-        return ((CoercableMCMCOperator) operatorList.get(i)).getRawParameter();
+        return ((AdaptableMCMCOperator) operatorList.get(i)).getRawParameter();
     }
 
 
@@ -121,22 +111,22 @@ public class JointOperator extends SimpleMCMCOperator implements CoercableMCMCOp
         throw new RuntimeException("More than one raw parameter for a joint operator");
     }
 
-    public CoercionMode getMode() {
+    public AdaptationMode getMode() {
         if (operatorToOptimizeList.size() > 0)
-            return CoercionMode.COERCION_ON;
-        return CoercionMode.COERCION_OFF;
+            return AdaptationMode.ADAPTATION_ON;
+        return AdaptationMode.ADAPTATION_OFF;
     }
 
     public MCMCOperator getSubOperator(int i) {
         return operatorList.get(i);
     }
 
-    public CoercionMode getSubOperatorMode(int i) {
+    public AdaptationMode getSubOperatorMode(int i) {
         if (i < 0 || i >= operatorList.size())
             throw new IllegalArgumentException();
-        if (operatorList.get(i) instanceof CoercableMCMCOperator)
-            return ((CoercableMCMCOperator) operatorList.get(i)).getMode();
-        return CoercionMode.COERCION_OFF;
+        if (operatorList.get(i) instanceof AdaptableMCMCOperator)
+            return ((AdaptableMCMCOperator) operatorList.get(i)).getMode();
+        return AdaptationMode.ADAPTATION_OFF;
     }
 
     public String getSubOperatorName(int i) {
@@ -158,6 +148,10 @@ public class JointOperator extends SimpleMCMCOperator implements CoercableMCMCOp
         throw new RuntimeException("not implemented");
     }
 
+    public String getAdaptableParameterName() {
+        return "";
+    }
+
     public double getTargetAcceptanceProbability() {
         return targetProbability;
     }
@@ -206,4 +200,3 @@ public class JointOperator extends SimpleMCMCOperator implements CoercableMCMCOp
 
 
 }
-
