@@ -26,38 +26,37 @@
 package dr.inference.operators;
 
 import dr.inference.distribution.DistributionLikelihood;
-import dr.inference.model.DiagonalMatrix;
-import dr.inference.model.LatentFactorModel;
-import dr.inference.model.MatrixParameter;
-import dr.inference.model.MatrixParameterInterface;
+import dr.inference.model.*;
 import dr.math.MathUtils;
 import dr.math.distributions.GammaDistribution;
 
 /**
  * Created by max on 6/12/14.
  */
-public class LatentFactorModelPrecisionGibbsOperator extends SimpleMCMCOperator implements GibbsOperator {
+public class LatentFactorModelPrecisionGibbsOperator extends SimpleMCMCOperator implements PathDependentOperator, GibbsOperator {
     //    private double[] FacXLoad;
 //    private double[] residual;
     private LatentFactorModel LFM;
     private GammaDistribution prior;
     private boolean randomScan;
     private double shape;
-    double pathWeight=1.0;
+    double pathWeight = 1.0;
+    final Parameter missingIndicator;
 
     public LatentFactorModelPrecisionGibbsOperator(LatentFactorModel LFM, DistributionLikelihood prior, double weight, boolean randomScan) {
         setWeight(weight);
         this.LFM = LFM;
         this.prior = (GammaDistribution) prior.getDistribution();
         this.randomScan = randomScan;
+        this.missingIndicator = LFM.getMissingIndicator();
 
 //        FacXLoad=new double[LFM.getFactors().getColumnDimension()];
 //        residual=new double[LFM.getFactors().getColumnDimension()];
-        setShape();
+//        setShape();
     }
 
-    private void setShape(){
-        shape=this.prior.getShape()+LFM.getFactors().getColumnDimension()*.5 *pathWeight;
+    private double getShape(int i) {
+        return this.prior.getShape() + LFM.getRowCount(i) * .5 * pathWeight;
     }
 
     private void setPrecision(int i) {
@@ -68,11 +67,13 @@ public class LatentFactorModelPrecisionGibbsOperator extends SimpleMCMCOperator
         double di = 0;
         for (int j = 0; j < factors.getColumnDimension(); j++) {
             double sum = 0;
-            for (int k = 0; k < factors.getRowDimension(); k++) {
-                sum += factors.getParameterValue(k, j) * loadings.getParameterValue(i, k);
+            if(missingIndicator == null || missingIndicator.getParameterValue(j * LFM.getScaledData().getRowDimension() + i) != 1) {
+                for (int k = 0; k < factors.getRowDimension(); k++) {
+                    sum += factors.getParameterValue(k, j) * loadings.getParameterValue(i, k);
+                }
+                double temp = data.getParameterValue(i, j) - sum;
+                di += temp * temp;
             }
-            double temp = data.getParameterValue(i, j) - sum;
-            di += temp * temp;
 //            FacXLoad[j]=sum;
 //            residual[j]=data.getParameterValue(i,j)-FacXLoad[j];
 //        }
@@ -80,26 +81,13 @@ public class LatentFactorModelPrecisionGibbsOperator extends SimpleMCMCOperator
 //        for (int j = 0; j <factors.getColumnDimension() ; j++) {
 //            sum+=residual[j]*residual[j];
         }
-        if(pathWeight!=1.0)
-            setShape();
-        double scale = 1.0 / (1.0 / prior.getScale() + pathWeight*di * .5);
-        double nextPrecision = GammaDistribution.nextGamma(shape, scale);
+        double scale = 1.0 / (1.0 / prior.getScale() + pathWeight * di * .5);
+        double nextPrecision = GammaDistribution.nextGamma(getShape(i), scale);
         precision.setParameterValueQuietly(i, nextPrecision);
     }
 
-    public void setPathParameter(double beta)
-    {
-        pathWeight=beta;
-    }
-
-    @Override
-    public int getStepCount() {
-        return 0;
-    }
-
-    @Override
-    public String getPerformanceSuggestion() {
-        return "Only works for diagonal column precision matrices for a LatentFactorModel with a gamma prior";
+    public void setPathParameter(double beta) {
+        pathWeight = beta;
     }
 
     @Override
@@ -108,7 +96,7 @@ public class LatentFactorModelPrecisionGibbsOperator extends SimpleMCMCOperator
     }
 
     @Override
-    public double doOperation() throws OperatorFailedException {
+    public double doOperation() {
 
         if (!randomScan) for (int i = 0; i < LFM.getColumnPrecision().getColumnDimension(); i++) {
             if (LFM.getContinuous().getParameterValue(i) != 0)
