@@ -27,7 +27,6 @@ package dr.inference.operators;
 
 import dr.inference.distribution.DistributionLikelihood;
 import dr.inference.model.LatentFactorModel;
-import dr.inference.model.MatrixParameter;
 import dr.inference.model.MatrixParameterInterface;
 import dr.inference.model.Parameter;
 import dr.math.MathUtils;
@@ -47,7 +46,7 @@ import java.util.ListIterator;
  * Time: 2:23 PM
  * To change this template use File | Settings | File Templates.
  */
-public class LoadingsIndependenceOperator extends AbstractCoercableOperator {
+public class LoadingsIndependenceOperator extends AbstractAdaptableOperator {
     NormalDistribution prior;
     LatentFactorModel LFM;
     ArrayList<double[][]> precisionArray;
@@ -60,7 +59,7 @@ public class LoadingsIndependenceOperator extends AbstractCoercableOperator {
     double priorPrecision;
     double priorMeanPrecision;
 
-    public LoadingsIndependenceOperator(LatentFactorModel LFM, DistributionLikelihood prior, double weight, boolean randomScan, double scaleFactor, CoercionMode mode) {
+    public LoadingsIndependenceOperator(LatentFactorModel LFM, DistributionLikelihood prior, double weight, boolean randomScan, double scaleFactor, AdaptationMode mode) {
         super(mode);
         setWeight(weight);
 
@@ -270,18 +269,13 @@ public class LoadingsIndependenceOperator extends AbstractCoercableOperator {
 //        return 0;  //To change body of implemented methods use File | Settings | File Templates.
 //    }
 
-    @Override
-    public String getPerformanceSuggestion() {
-        return null;  //To change body of implemented methods use File | Settings | File Templates.
-    }
-
     @Override
     public String getOperatorName() {
         return "loadingsGibbsOperator";  //To change body of implemented methods use File | Settings | File Templates.
     }
 
     @Override
-    public double doOperation() throws OperatorFailedException {
+    public double doOperation() {
 
         int size = LFM.getLoadings().getColumnDimension();
         if (!randomScan) {
@@ -312,12 +306,12 @@ public class LoadingsIndependenceOperator extends AbstractCoercableOperator {
         return 0;
     }
 
-    public double getCoercableParameter() {
+    public double getAdaptableParameter() {
         return Math.log(scaleFactor);
     }
 
     @Override
-    public void setCoercableParameter(double value) {
+    public void setAdaptableParameter(double value) {
         scaleFactor = Math.exp(value);
     }
 
@@ -325,4 +319,8 @@ public class LoadingsIndependenceOperator extends AbstractCoercableOperator {
     public double getRawParameter() {
         return scaleFactor;
     }
+
+    public String getAdaptableParameterName() {
+        return "scaleFactor";
+    }
 }
