@@ -34,7 +34,7 @@ import dr.math.matrixAlgebra.Matrix;
 /**
  * @author Marc Suchard
  */
-public class MVOUCovarianceOperator extends AbstractCoercableOperator {
+public class MVOUCovarianceOperator extends AbstractAdaptableOperator {
 
     private double mixingFactor;
     private MatrixParameter varMatrix;
@@ -50,7 +50,7 @@ public class MVOUCovarianceOperator extends AbstractCoercableOperator {
     public MVOUCovarianceOperator(double mixingFactor,
                                   MatrixParameter varMatrix,
                                   int priorDf,
-                                  double weight, CoercionMode mode) {
+                                  double weight, AdaptationMode mode) {
         super(mode);
         this.mixingFactor = mixingFactor;
         this.varMatrix = varMatrix;
@@ -64,7 +64,7 @@ public class MVOUCovarianceOperator extends AbstractCoercableOperator {
         Iinv = new Matrix(I).inverse();
     }
 
-    public double doOperation() throws OperatorFailedException {
+    public double doOperation() {
 
         double[][] draw = WishartDistribution.nextWishart(priorDf, I);
 //		double[][] good = varMatrix.getParameterAsMatrix();
@@ -123,8 +123,11 @@ public class MVOUCovarianceOperator extends AbstractCoercableOperator {
 //				WishartDistribution.computeNormalizationConstant(Iinv,priorDf,dim));
                 0);
 
-        if (bProb == Double.NEGATIVE_INFINITY)
-            throw new OperatorFailedException("Not reversible");
+        if (bProb == Double.NEGATIVE_INFINITY) {
+//            throw new OperatorFailedException("Not reversible");
+            // not clear if this means a HR of -Inf or a RuntimeException
+            return Double.NEGATIVE_INFINITY;
+        }
 
         double fProb = WishartDistribution.logPdf(forwardDrawMatrix, Iinv, priorDf, dim,
 //				WishartDistribution.computeNormalizationConstant(Iinv,priorDf,dim));
@@ -156,12 +159,12 @@ public class MVOUCovarianceOperator extends AbstractCoercableOperator {
                 varMatrix.getId() + ")";
     }
 
-    public double getCoercableParameter() {
+    public double getAdaptableParameter() {
         return Math.log(mixingFactor / (1.0 - mixingFactor));
 //		return Math.log((1.0 - mixingFactor) / mixingFactor);
     }
 
-    public void setCoercableParameter(double value) {
+    public void setAdaptableParameter(double value) {
         mixingFactor = Math.exp(value) / (1.0 + Math.exp(value));
 //		mixingFactor = Math.exp(-value) / (1.0 + Math.exp(-value));
     }
@@ -170,41 +173,8 @@ public class MVOUCovarianceOperator extends AbstractCoercableOperator {
         return mixingFactor;
     }
 
-    public double getMixingFactor() {
-        return mixingFactor;
-    }
-
-    public double getTargetAcceptanceProbability() {
-        return 0.234;
-    }
-
-    public double getMinimumAcceptanceLevel() {
-        return 0.1;
-    }
-
-    public double getMaximumAcceptanceLevel() {
-        return 0.4;
-    }
-
-    public double getMinimumGoodAcceptanceLevel() {
-        return 0.20;
-    }
-
-    public double getMaximumGoodAcceptanceLevel() {
-        return 0.30;
-    }
-
-    public final String getPerformanceSuggestion() {
-
-        double prob = MCMCOperator.Utils.getAcceptanceProbability(this);
-        double targetProb = getTargetAcceptanceProbability();
-        dr.util.NumberFormatter formatter = new dr.util.NumberFormatter(5);
-        double sf = OperatorUtils.optimizeWindowSize(mixingFactor, prob, targetProb);
-        if (prob < getMinimumGoodAcceptanceLevel()) {
-            return "Try setting mixingFactor to about " + formatter.format(sf);
-        } else if (prob > getMaximumGoodAcceptanceLevel()) {
-            return "Try setting mixingFactor to about " + formatter.format(sf);
-        } else return "";
+    public String getAdaptableParameterName() {
+        return "mixingFactor";
     }
 
 }
