@@ -144,12 +144,7 @@ System.err.print("\n");
     }
 
     @Override
-    public String getPerformanceSuggestion() {
-        return null;  //To change body of implemented methods use File | Settings | File Templates.
-    }
-
-    @Override
-    public double doOperation() throws OperatorFailedException{
+    public double doOperation() {
         double[] draws=null;
 
 
@@ -180,8 +175,4 @@ System.err.print("\n");
         return 0;  //To change body of implemented methods use File | Settings | File Templates.
     }
 
-    @Override
-    public int getStepCount() {
-        return 1;  //To change body of implemented methods use File | Settings | File Templates.
-    }
 }
