@@ -41,7 +41,7 @@ import java.util.Set;
  * @author Marc Suchard
  * @author Guy Baele
  */
-public class MultivariateNormalIndependenceSampler extends AbstractCoercableOperator {
+public class MultivariateNormalIndependenceSampler extends AbstractAdaptableOperator {
 
     public static final String OPERATOR_NAME = "multivariateNormalIndependenceSampler";
     public static final String SCALE_FACTOR = "scaleFactor";
@@ -56,7 +56,7 @@ public class MultivariateNormalIndependenceSampler extends AbstractCoercableOper
     public MultivariateNormalIndependenceSampler(Parameter parameter,
                                                  SelfControlledCaseSeries sccs,
                                                  double setSizeMean,
-                                                 double weight, double scaleFactor, CoercionMode mode) {
+                                                 double weight, double scaleFactor, AdaptationMode mode) {
         super(mode);
         this.scaleFactor = scaleFactor;
         this.parameter = parameter;
@@ -67,8 +67,8 @@ public class MultivariateNormalIndependenceSampler extends AbstractCoercableOper
         this.setSizeMean = setSizeMean;
     }
 
-    public String getPerformanceSuggestion() {
-        return "";
+    public String getAdaptableParameterName() {
+        return "scaleFactor";
     }
 
     public String getOperatorName() {
@@ -78,7 +78,7 @@ public class MultivariateNormalIndependenceSampler extends AbstractCoercableOper
     /**
      * change the parameter and return the hastings ratio.
      */
-    public double doOperation() throws OperatorFailedException {
+    public double doOperation() {
 
         double[] mean = sccs.getMode();
         double[] currentValue = parameter.getParameterValues();
@@ -134,7 +134,7 @@ public class MultivariateNormalIndependenceSampler extends AbstractCoercableOper
 
         public Object parseXMLObject(XMLObject xo) throws XMLParseException {
 
-            CoercionMode mode = CoercionMode.parseMode(xo);
+            AdaptationMode mode = AdaptationMode.parseMode(xo);
 
             double weight = xo.getDoubleAttribute(WEIGHT);
             double scaleFactor = xo.getDoubleAttribute(SCALE_FACTOR);
@@ -179,11 +179,11 @@ public class MultivariateNormalIndependenceSampler extends AbstractCoercableOper
 
     };
 
-    public double getCoercableParameter() {
+    public double getAdaptableParameter() {
         return Math.log(scaleFactor);
     }
 
-    public void setCoercableParameter(double value) {
+    public void setAdaptableParameter(double value) {
         scaleFactor = Math.exp(value);
     }
 
