@@ -1,7 +1,7 @@
 /*
  * MultivariateNormalOperator.java
  *
- * Copyright (c) 2002-2013 Alexei Drummond, Andrew Rambaut and Marc Suchard
+ * Copyright (c) 2002-2015 Alexei Drummond, Andrew Rambaut and Marc Suchard
  *
  * This file is part of BEAST.
  * See the NOTICE file distributed with this work for additional
@@ -30,17 +30,14 @@ import cern.colt.matrix.linalg.SingularValueDecomposition;
 import dr.inference.model.MatrixParameter;
 import dr.inference.model.Parameter;
 import dr.math.MathUtils;
-import dr.math.matrixAlgebra.CholeskyDecomposition;
-import dr.math.matrixAlgebra.IllegalDimension;
-import dr.math.matrixAlgebra.Matrix;
-import dr.math.matrixAlgebra.SymmetricMatrix;
+import dr.math.matrixAlgebra.*;
 import dr.xml.*;
 
 
 /**
  * @author Marc Suchard
  */
-public class MultivariateNormalOperator extends AbstractCoercableOperator {
+public class MultivariateNormalOperator extends AbstractAdaptableOperator {
 
     public static final String MVN_OPERATOR = "mvnOperator";
     public static final String SCALE_FACTOR = "scaleFactor";
@@ -54,7 +51,7 @@ public class MultivariateNormalOperator extends AbstractCoercableOperator {
     private double[][] cholesky;
 
     public MultivariateNormalOperator(Parameter parameter, double scaleFactor, double[][] inMatrix, double weight,
-                                      CoercionMode mode, boolean isVarianceMatrix) {
+                                      AdaptationMode mode, boolean isVarianceMatrix) {
 
         super(mode);
         this.scaleFactor = scaleFactor;
@@ -74,22 +71,15 @@ public class MultivariateNormalOperator extends AbstractCoercableOperator {
             matrix = formXtXInverse(inMatrix);
         }
 
-//        System.err.println("Matrix:");
-//        System.err.println(new Matrix(matrix));
-
         try {
             cholesky = (new CholeskyDecomposition(matrix)).getL();
         } catch (IllegalDimension illegalDimension) {
             throw new RuntimeException("Unable to decompose matrix in mvnOperator");
         }
-
-//        System.err.println("Cholesky:");
-//        System.err.println(new Matrix(cholesky));
-//        System.exit(-1);
     }
 
     public MultivariateNormalOperator(Parameter parameter, double scaleFactor,
-                                      MatrixParameter varMatrix, double weight, CoercionMode mode, boolean isVariance) {
+                                      MatrixParameter varMatrix, double weight, AdaptationMode mode, boolean isVariance) {
         this(parameter, scaleFactor, varMatrix.getParameterAsMatrix(), weight, mode, isVariance);
     }
 
@@ -99,24 +89,29 @@ public class MultivariateNormalOperator extends AbstractCoercableOperator {
 
         double[][] matrix = new double[P][P];
         for (int i = 0; i < P; i++) {
-            for (int j = 0; j < P; j++) {
+            for (int j = i; j < P; j++) {
                 double total = 0.0;
                 for (int k = 0; k < N; k++) {
                     total += X[k][i] * X[k][j];
                 }
-                matrix[i][j] = total;
+                matrix[j][i] = matrix[i][j] = total;
             }
         }
 
-//        System.err.println("XtX:");
-//        System.err.println(new Matrix(matrix));
-
         // Take inverse
-        matrix = new SymmetricMatrix(matrix).inverse().toComponents();
-        return matrix;
+        double[][] inverse = new SymmetricMatrix(matrix).inverse().toComponents();
+
+        // Force symmetric
+        for (int i = 0; i < inverse.length; ++i) {
+            for (int j = i; j < inverse[i].length; ++j) {
+                inverse[j][i] = inverse[i][j] = (inverse[j][i] + inverse[i][j]) / 2;
+            }
+        }
+
+        return inverse;
     }
 
-    public double doOperation() throws OperatorFailedException {
+    public double doOperation() {
 
         double[] x = parameter.getParameterValues();
         double[] epsilon = new double[dim];
@@ -130,10 +125,9 @@ public class MultivariateNormalOperator extends AbstractCoercableOperator {
                 // caution: decomposition returns lower triangular
             }
             parameter.setParameterValueQuietly(i, x[i]);
-//            System.out.println(i+" : "+x[i]);
         }
         parameter.fireParameterChangedEvent();
-//                    System.exit(-1);
+
         return 0;
     }
 
@@ -142,11 +136,11 @@ public class MultivariateNormalOperator extends AbstractCoercableOperator {
         return parameter.getParameterName();
     }
 
-    public double getCoercableParameter() {
+    public double getAdaptableParameter() {
         return Math.log(scaleFactor);
     }
 
-    public void setCoercableParameter(double value) {
+    public void setAdaptableParameter(double value) {
         scaleFactor = Math.exp(value);
     }
 
@@ -158,37 +152,8 @@ public class MultivariateNormalOperator extends AbstractCoercableOperator {
         return scaleFactor;
     }
 
-    public double getTargetAcceptanceProbability() {
-        return 0.234;
-    }
-
-    public double getMinimumAcceptanceLevel() {
-        return 0.1;
-    }
-
-    public double getMaximumAcceptanceLevel() {
-        return 0.4;
-    }
-
-    public double getMinimumGoodAcceptanceLevel() {
-        return 0.20;
-    }
-
-    public double getMaximumGoodAcceptanceLevel() {
-        return 0.30;
-    }
-
-    public final String getPerformanceSuggestion() {
-
-        double prob = MCMCOperator.Utils.getAcceptanceProbability(this);
-        double targetProb = getTargetAcceptanceProbability();
-        dr.util.NumberFormatter formatter = new dr.util.NumberFormatter(5);
-        double sf = OperatorUtils.optimizeWindowSize(scaleFactor, prob, targetProb);
-        if (prob < getMinimumGoodAcceptanceLevel()) {
-            return "Try setting scaleFactor to about " + formatter.format(sf);
-        } else if (prob > getMaximumGoodAcceptanceLevel()) {
-            return "Try setting scaleFactor to about " + formatter.format(sf);
-        } else return "";
+    public String getAdaptableParameterName() {
+        return "scaleFactor";
     }
 
     public static XMLObjectParser PARSER = new AbstractXMLObjectParser() {
@@ -199,7 +164,7 @@ public class MultivariateNormalOperator extends AbstractCoercableOperator {
 
         public Object parseXMLObject(XMLObject xo) throws XMLParseException {
 
-            CoercionMode mode = CoercionMode.parseMode(xo);
+            AdaptationMode mode = AdaptationMode.parseMode(xo);
 
             double weight = xo.getDoubleAttribute(WEIGHT);
             double scaleFactor = xo.getDoubleAttribute(SCALE_FACTOR);
