@@ -42,14 +42,14 @@ import java.io.PrintStream;
  */
 public class OperatorAnalysisPrinter {
 
-    private final OperatorSchedule schedule;
-    private final NumberFormatter formatter = new NumberFormatter(8);
+    private static final NumberFormatter formatter = new NumberFormatter(8);
 
-    public OperatorAnalysisPrinter(OperatorSchedule schedule) {
-        this.schedule = schedule;
-    }
-
-    public void showOperatorAnalysis(PrintStream out) {
+    /**
+     * Writes ano operator analysis to the provided print stream
+     *
+     * @param out the print stream to write operator analysis to
+     */
+    public static void showOperatorAnalysis(PrintStream out, OperatorSchedule schedule, boolean useAdaptation) {
         out.println();
         out.println("Operator analysis");
         out.println(formatter.formatToFieldWidth("Operator", 50) +
@@ -58,7 +58,7 @@ public class OperatorAnalysisPrinter {
                 formatter.formatToFieldWidth("Time", 9) +
                 formatter.formatToFieldWidth("Time/Op", 9) +
                 formatter.formatToFieldWidth("Pr(accept)", 11) +
-                " Performance suggestion");
+                (useAdaptation ? "" : " Performance suggestion"));
 
         for (int i = 0; i < schedule.getOperatorCount(); i++) {
 
@@ -67,86 +67,88 @@ public class OperatorAnalysisPrinter {
                 JointOperator jointOp = (JointOperator) op;
                 for (int k = 0; k < jointOp.getNumberOfSubOperators(); k++) {
                     out.println(formattedOperatorName(jointOp.getSubOperatorName(k))
-                            + formattedParameterString(jointOp.getSubOperator(k))
-                            + formattedCountString(op)
-                            + formattedTimeString(op)
-                            + formattedTimePerOpString(op)
-                            + formattedProbString(jointOp)
-                            + formattedDiagnostics(jointOp, MCMCOperator.Utils.getAcceptanceProbability(jointOp)));
+                                    + formattedParameterString(jointOp.getSubOperator(k))
+                                    + formattedCountString(op)
+                                    + formattedTimeString(op)
+                                    + formattedTimePerOpString(op)
+                                    + formattedProbString(jointOp)
+                                    + (useAdaptation ? "" : formattedDiagnostics(jointOp, MCMCOperator.Utils.getAcceptanceProbability(jointOp)))
+                    );
                 }
             } else {
                 out.println(formattedOperatorName(op.getOperatorName())
-                        + formattedParameterString(op)
-                        + formattedCountString(op)
-                        + formattedTimeString(op)
-                        + formattedTimePerOpString(op)
-                        + formattedProbString(op)
-                        + formattedDiagnostics(op, MCMCOperator.Utils.getAcceptanceProbability(op)));
+                                + formattedParameterString(op)
+                                + formattedCountString(op)
+                                + formattedTimeString(op)
+                                + formattedTimePerOpString(op)
+                                + formattedProbString(op)
+                                + (useAdaptation ? "" : formattedDiagnostics(op, MCMCOperator.Utils.getAcceptanceProbability(op)))
+                );
             }
 
         }
         out.println();
     }
 
-    private String formattedOperatorName(String operatorName) {
+    private static String formattedOperatorName(String operatorName) {
         return formatter.formatToFieldWidth(operatorName, 50);
     }
 
-    private String formattedParameterString(MCMCOperator op) {
+    private static String formattedParameterString(MCMCOperator op) {
         String pString = "        ";
-        if (op instanceof CoercableMCMCOperator && ((CoercableMCMCOperator) op).getMode() != CoercionMode.COERCION_OFF) {
-            pString = formatter.formatToFieldWidth(formatter.formatDecimal(((CoercableMCMCOperator) op).getRawParameter(), 3), 8);
+        if (op instanceof AdaptableMCMCOperator && ((AdaptableMCMCOperator) op).getMode() != AdaptationMode.ADAPTATION_OFF) {
+            pString = formatter.formatToFieldWidth(formatter.formatDecimal(((AdaptableMCMCOperator) op).getRawParameter(), 3), 8);
         }
         return pString;
     }
 
-    private String formattedCountString(MCMCOperator op) {
-        final int count = op.getCount();
-        return formatter.formatToFieldWidth(Integer.toString(count), 10) + " ";
+    private static String formattedCountString(MCMCOperator op) {
+        final long count = op.getCount();
+        return formatter.formatToFieldWidth(Long.toString(count), 10) + " ";
     }
 
-    private String formattedTimeString(MCMCOperator op) {
+    private static String formattedTimeString(MCMCOperator op) {
         final long time = op.getTotalEvaluationTime();
         return formatter.formatToFieldWidth(Long.toString(time), 8) + " ";
     }
 
-    private String formattedTimePerOpString(MCMCOperator op) {
+    private static String formattedTimePerOpString(MCMCOperator op) {
         final double time = op.getMeanEvaluationTime();
         return formatter.formatToFieldWidth(formatter.formatDecimal(time, 2), 8) + " ";
     }
 
-    private String formattedProbString(MCMCOperator op) {
+    private static String formattedProbString(MCMCOperator op) {
         final double acceptanceProb = MCMCOperator.Utils.getAcceptanceProbability(op);
         return formatter.formatToFieldWidth(formatter.formatDecimal(acceptanceProb, 4), 11) + " ";
     }
 
-    private String formattedDiagnostics(MCMCOperator op, double acceptanceProb) {
+    private static String formattedDiagnostics(MCMCOperator op, double acceptanceProb) {
 
         String message = "good";
-        if (acceptanceProb < op.getMinimumGoodAcceptanceLevel()) {
-            if (acceptanceProb < (op.getMinimumAcceptanceLevel() / 10.0)) {
+        if (acceptanceProb < AbstractAdaptableOperator.MINIMUM_GOOD_ACCEPTANCE_LEVEL) {
+            if (acceptanceProb < (AbstractAdaptableOperator.MINIMUM_ACCEPTANCE_LEVEL / 10.0)) {
                 message = "very low";
-            } else if (acceptanceProb < op.getMinimumAcceptanceLevel()) {
+            } else if (acceptanceProb < AbstractAdaptableOperator.MINIMUM_ACCEPTANCE_LEVEL) {
                 message = "low";
             } else message = "slightly low";
 
-        } else if (acceptanceProb > op.getMaximumGoodAcceptanceLevel()) {
-            double reallyHigh = 1.0 - ((1.0 - op.getMaximumAcceptanceLevel()) / 10.0);
+        } else if (acceptanceProb > AbstractAdaptableOperator.MAXIMUM_GOOD_ACCEPTANCE_LEVEL) {
+            double reallyHigh = 1.0 - ((1.0 - AbstractAdaptableOperator.MAXIMUM_ACCEPTANCE_LEVEL) / 10.0);
             if (acceptanceProb > reallyHigh) {
                 message = "very high";
-            } else if (acceptanceProb > op.getMaximumAcceptanceLevel()) {
+            } else if (acceptanceProb > AbstractAdaptableOperator.MAXIMUM_ACCEPTANCE_LEVEL) {
                 message = "high";
             } else message = "slightly high";
         }
 
-        String performacsMsg;
+        String performancesMsg = "";
         if (op instanceof GibbsOperator) {
-            performacsMsg = "none (Gibbs operator)";
-        } else {
-            final String suggestion = op.getPerformanceSuggestion();
-            performacsMsg = message + "\t" + suggestion;
+            performancesMsg = "none (Gibbs operator)";
+        } else if (op instanceof AdaptableMCMCOperator){
+            final String suggestion = ((AdaptableMCMCOperator)op).getPerformanceSuggestion();
+            performancesMsg = message + "\t" + suggestion;
         }
 
-        return performacsMsg;
+        return performancesMsg;
     }
 }
