@@ -29,6 +29,7 @@ import dr.inference.model.Bounds;
 import dr.inference.model.Parameter;
 import dr.inferencexml.operators.RandomWalkOperatorParser;
 import dr.math.MathUtils;
+import dr.util.Transform;
 
 import java.util.ArrayList;
 import java.util.List;
@@ -40,28 +41,26 @@ import java.util.List;
  * @author Andrew Rambaut
  * @version $Id: RandomWalkOperator.java,v 1.16 2005/06/14 10:40:34 rambaut Exp $
  */
-public class RandomWalkOperator extends AbstractCoercableOperator {
+public class RandomWalkOperator extends AbstractAdaptableOperator {
 
     public enum BoundaryCondition {
+        rejecting,
         reflecting,
-        absorbing
+        absorbing,
+        log,
+        logit
     }
 
-    public RandomWalkOperator(Parameter parameter, double windowSize, BoundaryCondition bc, double weight, CoercionMode mode) {
+    public RandomWalkOperator(Parameter parameter, double windowSize, BoundaryCondition bc, double weight, AdaptationMode mode) {
         this(parameter, null, windowSize, bc, weight, mode);
     }
 
-    public RandomWalkOperator(Parameter parameter, Parameter updateIndex, double windowSize, BoundaryCondition bc,
-                              double weight, CoercionMode mode) {
-        this(parameter, updateIndex, windowSize, bc, weight, mode, null, null);
-    }
-
-    public RandomWalkOperator(Parameter parameter, Parameter updateIndex, double windowSize, BoundaryCondition bc,
-                              double weight, CoercionMode mode, Double lowerOperatorBound, Double upperOperatorBound) {
+    public RandomWalkOperator(Parameter parameter, Parameter updateIndex, double windowSize, BoundaryCondition boundaryCondition,
+                              double weight, AdaptationMode mode) {
         super(mode);
         this.parameter = parameter;
         this.windowSize = windowSize;
-        this.condition = bc;
+        this.boundaryCondition = boundaryCondition;
 
         setWeight(weight);
         if (updateIndex != null) {
@@ -72,9 +71,6 @@ public class RandomWalkOperator extends AbstractCoercableOperator {
             }
             updateMapSize=updateMap.size();
         }
-
-        this.lowerOperatorBound = lowerOperatorBound;
-        this.upperOperatorBound = upperOperatorBound;
     }
 
     /**
@@ -91,39 +87,71 @@ public class RandomWalkOperator extends AbstractCoercableOperator {
     /**
      * change the parameter and return the hastings ratio.
      */
-    public final double doOperation() throws OperatorFailedException {
+    public final double doOperation() {
 
         // a random dimension to perturb
-        int index;
+        if (parameter.getDimension() <= 0) {
+            throw new RuntimeException("Illegal Dimension");
+        }
+
+        int dim;
         if (updateMap == null) {
-            index = MathUtils.nextInt(parameter.getDimension());
+            dim = MathUtils.nextInt(parameter.getDimension());
         } else {
-            index = updateMap.get(MathUtils.nextInt(updateMapSize));
+            dim = updateMap.get(MathUtils.nextInt(updateMapSize));
         }
 
         // a random point around old value within windowSize * 2
         double draw = (2.0 * MathUtils.nextDouble() - 1.0) * windowSize;
-        double newValue = parameter.getParameterValue(index) + draw;
+
+        double oldValue = parameter.getParameterValue(dim);
 
         final Bounds<Double> bounds = parameter.getBounds();
-        final double lower = (lowerOperatorBound == null ? bounds.getLowerLimit(index) : Math.max(bounds.getLowerLimit(index), lowerOperatorBound));
-        final double upper = (upperOperatorBound == null ? bounds.getUpperLimit(index) : Math.min(bounds.getUpperLimit(index), upperOperatorBound));
+        final double lower = bounds.getLowerLimit(dim);
+        final double upper = bounds.getUpperLimit(dim);
+
+        if (boundaryCondition == BoundaryCondition.logit) {
+            // scale oldValue to [0,1]
+            double x1 = (oldValue - lower) / (upper - lower);
+            // logit transform it, add the draw, inverse transform it
+            double x2 = Transform.LOGIT.inverse(Transform.LOGIT.transform(x1) + draw);
+
+            // parameter takes new value scaled back into interval [lower, upper]
+            parameter.setParameterValue(dim, (x2 * (upper - lower)) + lower);
+            
+            // HR is the ratio of Jacobians for the before and after values in interval [0,1]
+            return Transform.LOGIT.getLogJacobian(x1) - Transform.LOGIT.getLogJacobian(x2);
+
+        } else if (boundaryCondition == BoundaryCondition.log) {
+            // offset oldValue to [0,+Inf]
+            double x1 = oldValue - lower;
+            // logit transform it, add the draw, inverse transform it
+            double x2 = Transform.LOG.inverse(Transform.LOG.transform(x1) + draw);
+
+            // parameter takes new value tranlated back into interval [lower, +Inf]
+            parameter.setParameterValue(dim, x2 + lower);
+
+            // HR is the ratio of Jacobians for the before and after values
+            return Transform.LOG.getLogJacobian(x1) - Transform.LOG.getLogJacobian(x2);
+
+        } else {
+            double newValue = oldValue + draw;
+            if (boundaryCondition == BoundaryCondition.reflecting) {
+                newValue = reflectValue(newValue, lower, upper);
+            } else if (boundaryCondition == BoundaryCondition.absorbing && (newValue < lower || newValue > upper)) {
+                return 0.0;
+            } else if (boundaryCondition == BoundaryCondition.rejecting && (newValue < lower || newValue > upper)) {
+                return Double.NEGATIVE_INFINITY;
+            }
+
+            parameter.setParameterValue(dim, newValue);
 
-        if (condition == BoundaryCondition.reflecting) {
-            newValue = reflectValue(newValue, lower, upper);
-        } else if(condition == BoundaryCondition.absorbing && (newValue < lower || newValue > upper)){
             return 0.0;
         }
-        else if (newValue < lower || newValue > upper) {
-            throw new OperatorFailedException("proposed value outside boundaries");
-        }
 
-        parameter.setParameterValue(index, newValue);
+}
 
-        return 0.0;
-    }
-
-    public double reflectValue(double value, double lower, double upper) {
+    public static double reflectValue(double value, double lower, double upper) {
 
         double newValue = value;
 
@@ -190,11 +218,11 @@ public class RandomWalkOperator extends AbstractCoercableOperator {
         return parameter.getParameterName();
     }
 
-    public double getCoercableParameter() {
+    public double getAdaptableParameter() {
         return Math.log(windowSize);
     }
 
-    public void setCoercableParameter(double value) {
+    public void setAdaptableParameter(double value) {
         windowSize = Math.exp(value);
     }
 
@@ -202,38 +230,8 @@ public class RandomWalkOperator extends AbstractCoercableOperator {
         return windowSize;
     }
 
-    public double getTargetAcceptanceProbability() {
-        return 0.234;
-    }
-
-    public double getMinimumAcceptanceLevel() {
-        return 0.1;
-    }
-
-    public double getMaximumAcceptanceLevel() {
-        return 0.4;
-    }
-
-    public double getMinimumGoodAcceptanceLevel() {
-        return 0.20;
-    }
-
-    public double getMaximumGoodAcceptanceLevel() {
-        return 0.30;
-    }
-
-    public final String getPerformanceSuggestion() {
-
-        double prob = MCMCOperator.Utils.getAcceptanceProbability(this);
-        double targetProb = getTargetAcceptanceProbability();
-
-        double ws = OperatorUtils.optimizeWindowSize(windowSize, parameter.getParameterValue(0) * 2.0, prob, targetProb);
-
-        if (prob < getMinimumGoodAcceptanceLevel()) {
-            return "Try decreasing windowSize to about " + ws;
-        } else if (prob > getMaximumGoodAcceptanceLevel()) {
-            return "Try increasing windowSize to about " + ws;
-        } else return "";
+    public String getAdaptableParameterName() {
+        return "windowSize";
     }
 
     public String toString() {
@@ -246,8 +244,5 @@ public class RandomWalkOperator extends AbstractCoercableOperator {
     private double windowSize = 0.01;
     private List<Integer> updateMap = null;
     private int updateMapSize;
-    private final BoundaryCondition condition;
-
-    private final Double lowerOperatorBound;
-    private final Double upperOperatorBound;
+    private final BoundaryCondition boundaryCondition;
 }
