@@ -43,24 +43,24 @@ import java.util.logging.Logger;
  * @author Andrew Rambaut
  * @version $Id: ScaleOperator.java,v 1.20 2005/06/14 10:40:34 rambaut Exp $
  */
-public class ScaleOperator extends AbstractCoercableOperator {
+public class ScaleOperator extends AbstractAdaptableOperator {
 
     private Parameter indicator;
     private double indicatorOnProb;
 
     public ScaleOperator(Variable variable, double scale) {
 
-        this(variable, scale, CoercionMode.COERCION_ON, 1.0);
+        this(variable, scale, AdaptationMode.ADAPTATION_ON, 1.0);
     }
 
-    public ScaleOperator(Variable<Double> variable, double scale, CoercionMode mode, double weight) {
+    public ScaleOperator(Variable<Double> variable, double scale, AdaptationMode mode, double weight) {
 
         this(variable, false, 0, scale, mode, null, 1.0, false);
         setWeight(weight);
     }
 
     public ScaleOperator(Variable<Double> variable, boolean scaleAll, int degreesOfFreedom, double scale,
-                         CoercionMode mode, Parameter indicator, double indicatorOnProb, boolean scaleAllInd) {
+                         AdaptationMode mode, Parameter indicator, double indicatorOnProb, boolean scaleAllInd) {
 
         super(mode);
 
@@ -84,7 +84,7 @@ public class ScaleOperator extends AbstractCoercableOperator {
     /**
      * change the parameter and return the hastings ratio.
      */
-    public final double doOperation() throws OperatorFailedException {
+    public final double doOperation() {
 
         final double scale = (scaleFactor + (MathUtils.nextDouble() * ((1.0 / scaleFactor) - scaleFactor)));
 
@@ -99,12 +99,16 @@ public class ScaleOperator extends AbstractCoercableOperator {
             for (int i = 0; i < dim; i++) {
 
                 final double scaleOne = (scaleFactor + (MathUtils.nextDouble() * ((1.0 / scaleFactor) - scaleFactor)));
-                final double value = scaleOne * variable.getValue(i);
+                final double offset = bounds.getLowerLimit(i);
+
+                // scale offset by the lower bound
+                final double value = ((variable.getValue(i) - offset) * scaleOne) + offset;
 
                 logq -= Math.log(scaleOne);
 
-                if (value < bounds.getLowerLimit(i) || value > bounds.getUpperLimit(i)) {
-                    throw new OperatorFailedException("proposed value outside boundaries");
+                if (value > bounds.getUpperLimit(i)) {
+                    // if bounded then perhaps this could be reflected.
+                    throw new RuntimeException("proposed value greater than upper bound");
                 }
 
                 variable.setValue(i, value);
@@ -123,13 +127,14 @@ public class ScaleOperator extends AbstractCoercableOperator {
             // Must first set all parameters first and check for boundaries later for the operator to work
             // correctly with dependent parameters such as tree node heights.
             for (int i = 0; i < dim; i++) {
+                // For scale all we scale by the same factor (i.e., not relative to their individual
+                // origins).
                 variable.setValue(i, variable.getValue(i) * scale);
             }
 
             for (int i = 0; i < dim; i++) {
-                if (variable.getValue(i) < variable.getBounds().getLowerLimit(i) ||
-                        variable.getValue(i) > variable.getBounds().getUpperLimit(i)) {
-                    throw new OperatorFailedException("proposed value outside boundaries");
+                if (variable.getValue(i) > variable.getBounds().getUpperLimit(i)) {
+                    throw new RuntimeException("proposed value greater than upper bound");
                 }
             }
         } else {
@@ -162,7 +167,8 @@ public class ScaleOperator extends AbstractCoercableOperator {
                     final int rand = MathUtils.nextInt(nLoc);
                     index = loc[rand];
                 } else {
-                    throw new OperatorFailedException("no active indicators");
+                    // this used to throw an exception
+                    return Double.NEGATIVE_INFINITY;
                 }
             } else {
                 // any is good
@@ -170,21 +176,22 @@ public class ScaleOperator extends AbstractCoercableOperator {
             }
 
             final double oldValue = variable.getValue(index);
+            final double offset = bounds.getLowerLimit(index);
 
             if (oldValue == 0) {
-                Logger.getLogger("dr.inference").warning("The " + ScaleOperatorParser.SCALE_OPERATOR +
+                Logger.getLogger("dr.inference").severe("The " + ScaleOperatorParser.SCALE_OPERATOR +
                         " for " +
                         variable.getVariableName()
                         + " has failed since the parameter has a value of 0.0." +
                         "\nTo fix this problem, initalize the value of " +
                         variable.getVariableName() + " to be a positive real number"
                 );
-                throw new OperatorFailedException("");
             }
-            final double newValue = scale * oldValue;
+            final double newValue = ((oldValue - offset) * scale) + offset;
 
-            if (newValue < bounds.getLowerLimit(index) || newValue > bounds.getUpperLimit(index)) {
-                throw new OperatorFailedException("proposed value outside boundaries");
+            if (newValue > bounds.getUpperLimit(index)) {
+                // if bounded then perhaps this could be reflected.
+                throw new RuntimeException("proposed value greater than upper bound: " + newValue + " (" + variable.getId() + ")");
             }
 
             variable.setValue(index, newValue);
@@ -211,11 +218,11 @@ public class ScaleOperator extends AbstractCoercableOperator {
         return "scale(" + variable.getVariableName() + ")";
     }
 
-    public double getCoercableParameter() {
+    public double getAdaptableParameter() {
         return Math.log(1.0 / scaleFactor - 1.0);
     }
 
-    public void setCoercableParameter(double value) {
+    public void setAdaptableParameter(double value) {
         scaleFactor = 1.0 / (Math.exp(value) + 1.0);
     }
 
@@ -227,21 +234,8 @@ public class ScaleOperator extends AbstractCoercableOperator {
         return scaleFactor;
     }
 
-    public double getTargetAcceptanceProbability() {
-        return 0.234;
-    }
-
-    public final String getPerformanceSuggestion() {
-
-        double prob = MCMCOperator.Utils.getAcceptanceProbability(this);
-        double targetProb = getTargetAcceptanceProbability();
-        dr.util.NumberFormatter formatter = new dr.util.NumberFormatter(5);
-        double sf = OperatorUtils.optimizeScaleFactor(scaleFactor, prob, targetProb);
-        if (prob < getMinimumGoodAcceptanceLevel()) {
-            return "Try setting scaleFactor to about " + formatter.format(sf);
-        } else if (prob > getMaximumGoodAcceptanceLevel()) {
-            return "Try setting scaleFactor to about " + formatter.format(sf);
-        } else return "";
+    public String getAdaptableParameterName() {
+        return "scaleFactor";
     }
 
     public String toString() {
