@@ -36,7 +36,7 @@ import dr.math.MathUtils;
  * @author  Joseph Heled
  */
 
-public class TeamOperator extends SimpleMCMCOperator /*implements CoercableMCMCOperator*/ {
+public class TeamOperator extends SimpleMCMCOperator /*implements AdaptableMCMCOperator*/ {
 
     private final MCMCOperator[] operators;
     //private final ArrayList<Integer> operatorToOptimizeList;
@@ -96,9 +96,9 @@ public class TeamOperator extends SimpleMCMCOperator /*implements CoercableMCMCO
 //    public void addOperator(SimpleMCMCOperator operation) {
 //
 //        operatorList.add(operation);
-//        if (operation instanceof CoercableMCMCOperator) {
+//        if (operation instanceof AdaptableMCMCOperator) {
 //
-//            if (((CoercableMCMCOperator) operation).getMode() == CoercionMode.COERCION_ON)
+//            if (((AdaptableMCMCOperator) operation).getMode() == AdaptationMode.ADAPTATION_ON)
 //
 //                operatorToOptimizeList.add(operatorList.size() - 1);
 //
@@ -165,7 +165,7 @@ public class TeamOperator extends SimpleMCMCOperator /*implements CoercableMCMCO
          }
      }
 
-    public final double doOperation() throws OperatorFailedException {
+    public final double doOperation() {
 
         choose();
 
@@ -173,12 +173,7 @@ public class TeamOperator extends SimpleMCMCOperator /*implements CoercableMCMCO
 
         for(int k = 0; k < nPick; ++k) {
             MCMCOperator operation = currentRound[k];
-            try {
-                logP += operation.operate();
-            } catch (OperatorFailedException ofe) {
-                nToReject = k+1;
-                throw ofe;
-            }
+            logP += operation.operate();
         }
         nToReject = nPick;
 
