@@ -39,7 +39,7 @@ import dr.util.Transform;
  *
  * @author Guy Baele
  */
-public class TransformedRandomWalkOperator extends AbstractCoercableOperator {
+public class TransformedRandomWalkOperator extends AbstractAdaptableOperator {
 
     private Parameter parameter = null;
     private final Transform[] transformations;
@@ -56,17 +56,17 @@ public class TransformedRandomWalkOperator extends AbstractCoercableOperator {
         absorbing
     }
 
-    public TransformedRandomWalkOperator(Parameter parameter, Transform[] transformations, double windowSize, BoundaryCondition bc, double weight, CoercionMode mode) {
+    public TransformedRandomWalkOperator(Parameter parameter, Transform[] transformations, double windowSize, BoundaryCondition bc, double weight, AdaptationMode mode) {
         this(parameter, transformations, null, windowSize, bc, weight, mode);
     }
 
     public TransformedRandomWalkOperator(Parameter parameter, Transform[] transformations, Parameter updateIndex, double windowSize, BoundaryCondition bc,
-            double weight, CoercionMode mode) {
+            double weight, AdaptationMode mode) {
         this(parameter, transformations, updateIndex, windowSize, bc, weight, mode, null, null);
     }
 
     public TransformedRandomWalkOperator(Parameter parameter, Transform[] transformations, Parameter updateIndex, double windowSize, BoundaryCondition bc,
-            double weight, CoercionMode mode, Double lowerOperatorBound, Double upperOperatorBound) {
+                                         double weight, AdaptationMode mode, Double lowerOperatorBound, Double upperOperatorBound) {
         super(mode);
         this.parameter = parameter;
         this.transformations = transformations;
@@ -101,7 +101,7 @@ public class TransformedRandomWalkOperator extends AbstractCoercableOperator {
     /**
      * change the parameter and return the hastings ratio.
      */
-    public final double doOperation() throws OperatorFailedException {
+    public final double doOperation() {
 
         //store MH-ratio in logq
         double logJacobian = 0.0;
@@ -144,9 +144,10 @@ public class TransformedRandomWalkOperator extends AbstractCoercableOperator {
         final double upper = (upperOperatorBound == null ? bounds.getUpperLimit(index) : Math.min(bounds.getUpperLimit(index), upperOperatorBound));
 
         if (condition == BoundaryCondition.reflecting) {
-            newValue = reflectValue(newValue, lower, upper);
+            newValue = RandomWalkOperator.reflectValue(newValue, lower, upper);
         } else if (newValue < lower || newValue > upper) {
-            throw new OperatorFailedException("proposed value outside boundaries");
+//            throw new OperatorFailedException("proposed value outside boundaries");
+            return Double.NEGATIVE_INFINITY;
         }
 
         //parameter.setParameterValue(index, newValue);
@@ -163,78 +164,32 @@ public class TransformedRandomWalkOperator extends AbstractCoercableOperator {
         return logJacobian;
     }
 
-    public double reflectValue(double value, double lower, double upper) {
-
-        double newValue = value;
-
-        if (value < lower) {
-            if (Double.isInfinite(upper)) {
-                // we are only going to reflect once as the upper bound is at infinity...
-                newValue = lower + (lower - value);
-            } else {
-                double remainder = lower - value;
-
-                double widths = Math.floor(remainder / (upper - lower));
-                remainder -= (upper - lower) * widths;
-
-                // even reflections
-                if (widths % 2 == 0) {
-                    newValue = lower + remainder;
-                    // odd reflections
-                } else {
-                    newValue = upper - remainder;
-                }
-            }
-        } else if (value > upper) {
-            if (Double.isInfinite(lower)) {
-                // we are only going to reflect once as the lower bound is at -infinity...
-                newValue = upper - (newValue - upper);
-            } else {
-
-                double remainder = value - upper;
-
-                double widths = Math.floor(remainder / (upper - lower));
-                remainder -= (upper - lower) * widths;
-
-                // even reflections
-                if (widths % 2 == 0) {
-                    newValue = upper - remainder;
-                    // odd reflections
-                } else {
-                    newValue = lower + remainder;
-                }
-            }
-        }
-
-        return newValue;
-    }
-
-    public double reflectValueLoop(double value, double lower, double upper) {
-        double newValue = value;
-
-        while (newValue < lower || newValue > upper) {
-            if (newValue < lower) {
-                newValue = lower + (lower - newValue);
-            }
-            if (newValue > upper) {
-                newValue = upper - (newValue - upper);
-
-            }
-        }
-
-        return newValue;
-    }
+//    public double reflectValueLoop(double value, double lower, double upper) {
+//        double newValue = value;
+//
+//        while (newValue < lower || newValue > upper) {
+//            if (newValue < lower) {
+//                newValue = lower + (lower - newValue);
+//            }
+//            if (newValue > upper) {
+//                newValue = upper - (newValue - upper);
+//
+//            }
+//        }
+//
+//        return newValue;
+//    }
 
     //MCMCOperator INTERFACE
     public final String getOperatorName() {
         return parameter.getParameterName();
     }
 
-    public double getCoercableParameter() {
+    public double getAdaptableParameter() {
         return Math.log(windowSize);
     }
 
-    public void setCoercableParameter(double value) {
+    public void setAdaptableParameter(double value) {
         windowSize = Math.exp(value);
     }
 
@@ -242,38 +197,8 @@ public class TransformedRandomWalkOperator extends AbstractCoercableOperator {
         return windowSize;
     }
 
-    public double getTargetAcceptanceProbability() {
-        return 0.234;
-    }
-
-    public double getMinimumAcceptanceLevel() {
-        return 0.1;
-    }
-
-    public double getMaximumAcceptanceLevel() {
-        return 0.4;
-    }
-
-    public double getMinimumGoodAcceptanceLevel() {
-        return 0.20;
-    }
-
-    public double getMaximumGoodAcceptanceLevel() {
-        return 0.30;
-    }
-
-    public final String getPerformanceSuggestion() {
-
-        double prob = MCMCOperator.Utils.getAcceptanceProbability(this);
-        double targetProb = getTargetAcceptanceProbability();
-
-        double ws = OperatorUtils.optimizeWindowSize(windowSize, parameter.getParameterValue(0) * 2.0, prob, targetProb);
-
-        if (prob < getMinimumGoodAcceptanceLevel()) {
-            return "Try decreasing windowSize to about " + ws;
-        } else if (prob > getMaximumGoodAcceptanceLevel()) {
-            return "Try increasing windowSize to about " + ws;
-        } else return "";
+    public String getAdaptableParameterName() {
+        return "windowSize";
     }
 
     public String toString() {
