@@ -36,20 +36,20 @@ import dr.inference.model.Parameter;
  * @author Guy Baele
  */
 
-public class TwoPhaseOperator extends AbstractCoercableOperator {
+public class TwoPhaseOperator extends AbstractAdaptableOperator {
 
     public static final boolean DEBUG = false;
     public static final boolean PROVIDE_SAMPLES = false;
 
-    /*private AbstractCoercableOperator[] phaseOneOperators;
-    private AbstractCoercableOperator[] phaseTwoOperators;
+    /*private AbstractAdaptableOperator[] phaseOneOperators;
+    private AbstractAdaptableOperator[] phaseTwoOperators;
 
     double phaseOneTotalWeight, phaseTwoTotalWeight;*/
 
-    private List<AbstractCoercableOperator> phaseOneOperators;
+    private List<AbstractAdaptableOperator> phaseOneOperators;
     private List<AdaptableVarianceMultivariateNormalOperator> phaseTwoOperators;
-    //private List<AbstractCoercableOperator> phaseTwoOperators;
-    private List<AbstractCoercableOperator> currentOperators;
+    //private List<AbstractAdaptableOperator> phaseTwoOperators;
+    private List<AbstractAdaptableOperator> currentOperators;
 
     private SimpleOperatorSchedule phaseOneScheduler;
     private SimpleOperatorSchedule phaseTwoScheduler;
@@ -65,7 +65,7 @@ public class TwoPhaseOperator extends AbstractCoercableOperator {
 
     private boolean switchOperators;
 
-    public TwoPhaseOperator(List<AbstractCoercableOperator> phaseOneOperators, List<AdaptableVarianceMultivariateNormalOperator> phaseTwoOperators, List<Parameter> parameters, int initial, int burnin, double weight, CoercionMode mode) {
+    public TwoPhaseOperator(List<AbstractAdaptableOperator> phaseOneOperators, List<AdaptableVarianceMultivariateNormalOperator> phaseTwoOperators, List<Parameter> parameters, int initial, int burnin, double weight, AdaptationMode mode) {
 
         super(mode);
 
@@ -125,7 +125,7 @@ public class TwoPhaseOperator extends AbstractCoercableOperator {
 
     }
 
-    public double doOperation() throws OperatorFailedException {
+    public double doOperation() {
 
         if (DEBUG) {
             System.err.println("\nTwoPhaseOperator: doOperation() called");
@@ -192,7 +192,7 @@ public class TwoPhaseOperator extends AbstractCoercableOperator {
             }
             currentOperatorScheduler = phaseTwoScheduler;
             //TODO: fix Java type safety problem below
-            currentOperators = (List<AbstractCoercableOperator>)(List<?>) phaseTwoOperators;
+            currentOperators = (List<AbstractAdaptableOperator>)(List<?>) phaseTwoOperators;
             //an extra draw is needed here
             currentOperatorIndex = currentOperatorScheduler.getNextOperatorIndex();
 
@@ -245,26 +245,26 @@ public class TwoPhaseOperator extends AbstractCoercableOperator {
         currentOperators.get(currentOperatorIndex).reset();
     }*/
 
-    public double getCoercableParameter() {
-        return currentOperators.get(currentOperatorIndex).getCoercableParameter();
+    public double getAdaptableParameter() {
+        return currentOperators.get(currentOperatorIndex).getAdaptableParameter();
     }
 
-    public void setCoercableParameter(double value) {
-        currentOperators.get(currentOperatorIndex).setCoercableParameter(value);
+    public void setAdaptableParameter(double value) {
+        currentOperators.get(currentOperatorIndex).setAdaptableParameter(value);
     }
 
     public double getRawParameter() {
         return currentOperators.get(currentOperatorIndex).getRawParameter();
     }
 
-    public String getPerformanceSuggestion() {
-        return currentOperators.get(currentOperatorIndex).getPerformanceSuggestion();
+    public String getAdaptableParameterName() {
+        return "windowSize";
     }
 
-    @Override
-    public double getTargetAcceptanceProbability() {
-        return currentOperators.get(currentOperatorIndex).getTargetAcceptanceProbability();
-    }
+//    @Override
+//    public double getTargetAcceptanceProbability() {
+//        return currentOperators.get(currentOperatorIndex).getTargetAcceptanceProbability();
+//    }
 
     public String getOperatorName() {
         return "twoPhaseOperator(use at own risk)";
