@@ -30,17 +30,21 @@ import dr.util.Attribute;
 import dr.util.FileHelpers;
 import dr.xml.*;
 
+import java.io.BufferedWriter;
 import java.io.File;
 import java.io.FileNotFoundException;
+import java.io.FileWriter;
 import java.util.*;
 
 /**
  * @author Marc A. Suchard
  * @author Alexander Alekseyenko
+ * @author Guy Baele
  */
 public class PathSamplingAnalysis {
 
     public static final String PATH_SAMPLING_ANALYSIS = "pathSamplingAnalysis";
+    public static final String RESULT_FILE_NAME = "resultsFileName";
     public static final String LIKELIHOOD_COLUMN = "likelihoodColumn";
     public static final String THETA_COLUMN = "thetaColumn";
     public static final String FORMAT = "%5.5g";
@@ -146,6 +150,10 @@ public class PathSamplingAnalysis {
         public Object parseXMLObject(XMLObject xo) throws XMLParseException {
 
             String fileName = xo.getStringAttribute(FileHelpers.FILE_NAME);
+            String resultFileName = null;
+            if (xo.hasAttribute(RESULT_FILE_NAME)) {
+                resultFileName = xo.getStringAttribute(RESULT_FILE_NAME);
+            }
             StringTokenizer tokenFileName = new StringTokenizer(fileName);
     		int numberOfFiles = tokenFileName.countTokens();
     		System.out.println(numberOfFiles + " file(s) found with marginal likelihood samples");
@@ -164,8 +172,17 @@ public class PathSamplingAnalysis {
                     if (!file.isAbsolute()) {
                         parent = System.getProperty("user.dir");
                     }
-                    
-                    file = new File(parent, name);
+
+                    final String fileNamePrefix = System.getProperty("file.name.prefix");
+                    final String fileSeparator = System.getProperty("file.separator");
+                    if (fileNamePrefix != null) {
+                        if (fileNamePrefix.trim().length() == 0 || fileNamePrefix.contains(fileSeparator)) {
+                            throw new XMLParseException("The specified file name prefix is illegal.");
+                        }
+                        file = new File(parent, fileNamePrefix+name);
+                    } else {
+                        file = new File(parent, name);
+                    }
 
                     fileName = file.getAbsolutePath();
                     
@@ -225,6 +242,14 @@ public class PathSamplingAnalysis {
 
                 System.out.println(analysis.toString());
 
+                if (resultFileName != null) {
+                    FileWriter fw = new FileWriter(resultFileName, true);
+                    BufferedWriter bw = new BufferedWriter(fw);
+                    bw.write(analysis.toString());
+                    bw.flush();
+                    bw.close();
+                }
+
                 return analysis;
 
             } catch (FileNotFoundException fnfe) {
@@ -254,7 +279,9 @@ public class PathSamplingAnalysis {
 
         private final XMLSyntaxRule[] rules = {
                 new StringAttributeRule(FileHelpers.FILE_NAME,
-                        "The traceName of a BEAST log file (can not include trees, which should be logged separately"),
+                        "The traceName of a BEAST log file (can not include trees, which should be logged separately)"),
+                new StringAttributeRule(RESULT_FILE_NAME,
+                        "The name of the output file to which the path sampling estimate will be written", true),
                 new ElementRule(THETA_COLUMN, new XMLSyntaxRule[]{
                         new StringAttributeRule(Attribute.NAME, "The column name")}),
                 new ElementRule(LIKELIHOOD_COLUMN, new XMLSyntaxRule[]{
@@ -271,5 +298,4 @@ public class PathSamplingAnalysis {
     private List<Double> mlContribution;
     private final String logLikelihoodName;
     List<Double> orderedTheta;
-    //private final String thetaName;
 }
