@@ -25,18 +25,25 @@
 
 package dr.inferencexml.distribution;
 
+import dr.inference.distribution.CauchyDistribution;
 import dr.inference.distribution.DistributionLikelihood;
 import dr.inference.distribution.MultivariateDistributionLikelihood;
 import dr.inference.model.Likelihood;
 import dr.inference.model.Statistic;
 import dr.math.distributions.*;
+import dr.util.Attribute;
 import dr.xml.*;
+import org.apache.commons.math.distribution.CauchyDistributionImpl;
+
+import java.util.ArrayList;
+import java.util.List;
 
 /**
  */
 public class PriorParsers {
     public final static boolean DEBUG = false;
 
+    public static final String TRUNCATED = "truncated";
     public static final String UNIFORM_PRIOR = "uniformPrior";
     public static final String EXPONENTIAL_PRIOR = "exponentialPrior";
     public static final String POISSON_PRIOR = "poissonPrior";
@@ -44,16 +51,21 @@ public class PriorParsers {
     public static final String DISCRETE_UNIFORM_PRIOR = "discreteUniformPrior";
     public static final String NORMAL_PRIOR = "normalPrior";
     public static final String LOG_NORMAL_PRIOR = "logNormalPrior";
+    public static final String HALF_NORMAL_PRIOR = "halfNormalPrior";
     public static final String GAMMA_PRIOR = "gammaPrior";
     public static final String INVGAMMA_PRIOR = "invgammaPrior";
     public static final String INVGAMMA_PRIOR_CORRECT = "inverseGammaPrior";
     public static final String LAPLACE_PRIOR = "laplacePrior";
     public static final String BETA_PRIOR = "betaPrior";
+    public static final String CAUCHY_PRIOR = "cauchyPrior";
     public static final String UPPER = "upper";
     public static final String LOWER = "lower";
     public static final String MEAN = "mean";
-    public static final String MEAN_IN_REAL_SPACE = "meanInRealSpace";
+    public static final String MEDIAN = "median";
     public static final String STDEV = "stdev";
+    public static final String MEAN_IN_REAL_SPACE = "meanInRealSpace";
+    public static final String MU = "mu";
+    public static final String SIGMA = "sigma";
     public static final String SHAPE = "shape";
     public static final String SHAPEB = "shapeB";
     public static final String SCALE = "scale";
@@ -62,9 +74,64 @@ public class PriorParsers {
     public static final String UNINFORMATIVE = "uninformative";
     public static final String HALF_T_PRIOR = "halfTPrior";
     public static final String DIRICHLET_PRIOR = "dirichletPrior";
+    public static final String ALPHA = "alpha";
     public static final String COUNTS = "counts";
+    public static final String SUMS_TO = "sumsTo";
 
 
+    /**
+     * A special parser that reads a convenient short form of priors on parameters.
+     */
+    public static XMLObjectParser TRUNCATED_PARSER = new AbstractXMLObjectParser() {
+
+        @Override
+        public String getParserName() {
+            return TRUNCATED;
+        }
+
+        @Override
+        public String[] getParserNames() {
+            return new String[] { getParserName(), "trancated" }; // was misspelled, keep compatibility.
+        }
+
+        @Override
+        public Object parseXMLObject(XMLObject xo) throws XMLParseException {
+
+            double lower = xo.getAttribute(LOWER, Double.NEGATIVE_INFINITY);
+            double upper = xo.getAttribute(UPPER, Double.POSITIVE_INFINITY);
+
+            DistributionLikelihood dl = (DistributionLikelihood)xo.getChild(DistributionLikelihood.class);
+
+            DistributionLikelihood likelihood = new DistributionLikelihood(new TruncatedDistribution(dl.getDistribution(), lower, upper));
+            for (Attribute<double[]> data : dl.getDataList()) {
+                likelihood.addData(data);
+            }
+
+            return likelihood;
+        }
+
+        @Override
+        public XMLSyntaxRule[] getSyntaxRules() {
+            return rules;
+        }
+
+        private final XMLSyntaxRule[] rules = {
+                AttributeRule.newDoubleRule(LOWER, true),
+                AttributeRule.newDoubleRule(UPPER, true),
+                new ElementRule(DistributionLikelihood.class)
+        };
+
+        @Override
+        public String getParserDescription() {
+            return "Truncates the enclosed distribution to the given bounds.";
+        }
+
+        @Override
+        public Class getReturnType() {
+            return Likelihood.class;
+        }
+    };
+
     /**
      * A special parser that reads a convenient short form of priors on parameters.
      */
@@ -103,8 +170,8 @@ public class PriorParsers {
                     }
                     likelihood.addData((Statistic) xo.getChild(j));
                     if (DEBUG) {
-                    	likelihood.calculateLogLikelihood();
-                    	System.out.println("likelihood: " + likelihood.getLogLikelihood());
+                        likelihood.calculateLogLikelihood();
+                        System.out.println("likelihood: " + likelihood.getLogLikelihood());
                     }
                 } else {
                     throw new XMLParseException("illegal element in " + xo.getName() + " element");
@@ -162,8 +229,8 @@ public class PriorParsers {
                 }
                 if (xo.getChild(j) instanceof Statistic) {
                     if (DEBUG) {
-                    	System.out.println("scale: " + scale);
-                    	System.out.println("offset: " + offset);
+                        System.out.println("scale: " + scale);
+                        System.out.println("offset: " + offset);
                         //System.out.println((Statistic) xo.getChild(j));
                         Statistic test = (Statistic) xo.getChild(j);
                         System.out.println(test.getDimension());
@@ -174,9 +241,9 @@ public class PriorParsers {
                     }
                     likelihood.addData((Statistic) xo.getChild(j));
                     if (DEBUG) {
-                    	likelihood.makeDirty();
-                    	likelihood.calculateLogLikelihood();
-                    	System.out.println("likelihood: " + likelihood.getLogLikelihood());
+                        likelihood.makeDirty();
+                        likelihood.calculateLogLikelihood();
+                        System.out.println("likelihood: " + likelihood.getLogLikelihood());
                     }
                 } else {
                     throw new XMLParseException("illegal element in " + xo.getName() + " element");
@@ -435,6 +502,49 @@ public class PriorParsers {
         }
     };
 
+    public static XMLObjectParser HALF_NORMAL_PRIOR_PARSER = new AbstractXMLObjectParser() {
+
+        public String getParserName() {
+            return HALF_NORMAL_PRIOR;
+        }
+
+        public Object parseXMLObject(XMLObject xo) throws XMLParseException {
+
+            double mean = xo.getDoubleAttribute(MEAN);
+            double stdev = xo.getDoubleAttribute(STDEV);
+
+            DistributionLikelihood likelihood = new DistributionLikelihood(new HalfNormalDistribution(mean, stdev));
+            for (int j = 0; j < xo.getChildCount(); j++) {
+                if (xo.getChild(j) instanceof Statistic) {
+                    likelihood.addData((Statistic) xo.getChild(j));
+                } else {
+                    throw new XMLParseException("illegal element in " + xo.getName() + " element");
+                }
+            }
+
+            return likelihood;
+        }
+
+        public XMLSyntaxRule[] getSyntaxRules() {
+            return rules;
+        }
+
+        private final XMLSyntaxRule[] rules = {
+                AttributeRule.newDoubleRule(MEAN),
+                AttributeRule.newDoubleRule(STDEV),
+                new ElementRule(Statistic.class, 1, Integer.MAX_VALUE)
+        };
+
+        public String getParserDescription() {
+            return "Calculates the prior probability of some data under a given half-normal distribution.";
+        }
+
+        public Class getReturnType() {
+            return Likelihood.class;
+        }
+    };
+
+
     /**
      * A special parser that reads a convenient short form of priors on parameters.
      * <p/>
@@ -457,19 +567,54 @@ public class PriorParsers {
 
         public Object parseXMLObject(XMLObject xo) throws XMLParseException {
 
-            double mean = xo.getDoubleAttribute(MEAN);
-            final double stdev = xo.getDoubleAttribute(STDEV);
-            final double offset = xo.getAttribute(OFFSET, 0.0);
+            double mu;
+            double sigma;
+
             final boolean meanInRealSpace = xo.getAttribute(MEAN_IN_REAL_SPACE, false);
 
-            if (meanInRealSpace) {
-                if (mean <= 0) {
-                    throw new IllegalArgumentException("meanInRealSpace works only for a positive mean");
-                }
-                mean = Math.log(mean) - 0.5 * stdev * stdev;
-            }
+            if (xo.hasAttribute(MEAN_IN_REAL_SPACE)) {
+                // if the meanInRealSpace attribute is given then respect the old
+                // parser choices (i.e., specify mean and stdev but change their
+                // meaning to mu and sigma).
 
-            final DistributionLikelihood likelihood = new DistributionLikelihood(new LogNormalDistribution(mean, stdev), offset);
+                final double mean = xo.getDoubleAttribute(MEAN);
+                final double stdev = xo.getDoubleAttribute(STDEV);
+
+                if (meanInRealSpace) {
+                    mu = Math.log(mean / Math.sqrt(1 + (stdev * stdev) / (mean * mean)));
+                } else {
+                    mu = mean;
+                }
+
+                // in the previous version, the stdev (or 'Log(stdev)') parameter is sigma.
+                sigma = stdev;
+            } else {
+                // decide parameterization by whether mean, stdev or mu, sigma are given.
+                if (xo.hasAttribute(MEAN)) {
+                    final double mean = xo.getDoubleAttribute(MEAN);
+                    if (!xo.hasAttribute(STDEV)) {
+                        throw new XMLParseException("Lognormal should be specified either with mean and stdev or mu and sigma.");
+                    }
+                    final double stdev = xo.getDoubleAttribute(STDEV);
+                    if (mean <= 0) {
+                        throw new XMLParseException("If specified with a mean in real space, the value should be positive.");
+                    }
+                    mu = Math.log(mean / Math.sqrt(1 + (stdev * stdev) / (mean * mean)));
+                    sigma = Math.sqrt(Math.log(1 + (stdev * stdev) / (mean * mean)));
+                } else {
+                    if (meanInRealSpace) {
+                        throw new XMLParseException("Lognormal with 'meanInRealSpace' should be specified with mean and stdev.");
+                    }
+                    mu = xo.getDoubleAttribute(MU);
+                    if (!xo.hasAttribute(SIGMA)) {
+                        throw new XMLParseException("Lognormal should be specified either with mean and stdev or mu and sigma.");
+                    }
+                    sigma = xo.getDoubleAttribute(SIGMA);
+                }
+            }
+            final double offset = xo.getAttribute(OFFSET, 0.0);
+
+            final DistributionLikelihood likelihood = new DistributionLikelihood(new LogNormalDistribution(mu, sigma), offset);
 
             for (int j = 0; j < xo.getChildCount(); j++) {
                 if (xo.getChild(j) instanceof Statistic) {
@@ -487,8 +632,14 @@ public class PriorParsers {
         }
 
         private final XMLSyntaxRule[] rules = {
-                AttributeRule.newDoubleRule(MEAN),
-                AttributeRule.newDoubleRule(STDEV),
+                new XORRule(
+                        AttributeRule.newDoubleRule(MEAN),
+                        AttributeRule.newDoubleRule(MU)
+                ),
+                new XORRule(
+                        AttributeRule.newDoubleRule(STDEV),
+                        AttributeRule.newDoubleRule(SIGMA)
+                ),
                 AttributeRule.newDoubleRule(OFFSET, true),
                 AttributeRule.newBooleanRule(MEAN_IN_REAL_SPACE, true),
                 new ElementRule(Statistic.class, 1, Integer.MAX_VALUE)
@@ -705,9 +856,89 @@ public class PriorParsers {
 
         public Object parseXMLObject(XMLObject xo) throws XMLParseException {
 
-            double[] counts = xo.getDoubleArrayAttribute(COUNTS);
+            List<Statistic> data = new ArrayList<Statistic>();
+            int dim = 0;
+            double sum = 0;
+            for (int j = 0; j < xo.getChildCount(); j++) {
+                if (xo.getChild(j) instanceof Statistic) {
+                    Statistic statistic = (Statistic) xo.getChild(j);
+                    dim += statistic.getDimension();
+                    sum += statistic.getValueSum();
+                    data.add(statistic);
+                } else {
+                    throw new XMLParseException("Illegal element in " + xo.getName() + " element.");
+                }
+            }
 
-            MultivariateDistributionLikelihood likelihood = new MultivariateDistributionLikelihood(new DirichletDistribution(counts, false));
+            double[] counts;
+
+            if (xo.hasAttribute(ALPHA)) {
+                // alpha is for when the Dirichlet distribution is symmetrical
+                double alpha = xo.getDoubleAttribute(ALPHA);
+                counts  = new double[dim];
+                for (int i = 0; i < dim; i++) {
+                    counts[i] = alpha;
+                }
+            } else {
+                counts = xo.getDoubleArrayAttribute(COUNTS);
+                if (counts.length != dim) {
+                    throw new XMLParseException("Counts attribute in " + xo.getName() + " should have the same dimension as the data.");
+                }
+            }
+
+            double sumsTo = 1.0;
+            if (xo.hasAttribute(SUMS_TO)) {
+                sumsTo = xo.getDoubleAttribute(SUMS_TO);
+            }
+            if (Math.abs(sumsTo - sum) > DirichletDistribution.ACCURACY_THRESHOLD) {
+                throw new XMLParseException("The starting values of the data should sum to " + sumsTo + " (actually sums to " + sum + ").");
+            }
+
+            MultivariateDistributionLikelihood likelihood = new MultivariateDistributionLikelihood(new DirichletDistribution(counts, sumsTo));
+
+            for (Statistic statistic : data) {
+                likelihood.addData(statistic);
+            }
+
+            return likelihood;
+        }
+
+        public XMLSyntaxRule[] getSyntaxRules() {
+            return rules;
+        }
+
+        private final XMLSyntaxRule[] rules = {
+                new XORRule(
+                        AttributeRule.newDoubleArrayRule(ALPHA),
+                        AttributeRule.newDoubleArrayRule(COUNTS)
+                ),
+                AttributeRule.newDoubleRule(SUMS_TO, true),
+                new ElementRule(Statistic.class, 1, Integer.MAX_VALUE)
+        };
+
+        public String getParserDescription() {
+            return "Calculates the prior probability of some data under a Dirichlet distribution.";
+        }
+
+        public Class getReturnType() {
+            return MultivariateDistributionLikelihood.class;
+        }
+    };
+
+
+
+    public static XMLObjectParser CAUCH_PRIOR_PARSER = new AbstractXMLObjectParser() {
+
+        public String getParserName() {
+            return CAUCHY_PRIOR;
+        }
+
+        public Object parseXMLObject(XMLObject xo) throws XMLParseException {
+
+            final double median = xo.getDoubleAttribute(MEDIAN);
+            final double scale = xo.getDoubleAttribute(SCALE);
+
+            DistributionLikelihood likelihood = new DistributionLikelihood(new CauchyDistribution(median, scale));
             for (int j = 0; j < xo.getChildCount(); j++) {
                 if (xo.getChild(j) instanceof Statistic) {
                     likelihood.addData((Statistic) xo.getChild(j));
@@ -724,18 +955,17 @@ public class PriorParsers {
         }
 
         private final XMLSyntaxRule[] rules = {
-                AttributeRule.newDoubleArrayRule(COUNTS),
+                AttributeRule.newDoubleRule(MEDIAN),
+                AttributeRule.newDoubleRule(SCALE),
                 new ElementRule(Statistic.class, 1, Integer.MAX_VALUE)
         };
-
         public String getParserDescription() {
-            return "Calculates the prior probability of some data under a Dirichlet distribution.";
+            return "Calculates the prior probability of some data under a Cauchy distribution.";
         }
 
         public Class getReturnType() {
-            return MultivariateDistributionLikelihood.class;
+            return DistributionLikelihood.class;
         }
     };
 
-
 }
