@@ -1,7 +1,7 @@
 /*
  * WorkingPriorParsers.java
  *
- * Copyright (c) 2002-2015 Alexei Drummond, Andrew Rambaut and Marc Suchard
+ * Copyright (c) 2002-2016 Alexei Drummond, Andrew Rambaut and Marc Suchard
  *
  * This file is part of BEAST.
  * See the NOTICE file distributed with this work for additional
@@ -37,6 +37,7 @@ import dr.xml.*;
 
 import java.io.File;
 import java.io.FileNotFoundException;
+import java.util.StringTokenizer;
 
 /**
  * @author Guy Baele
@@ -55,6 +56,7 @@ public class WorkingPriorParsers {
     public static final String GAMMA_WORKING_PRIOR = "gammaWorkingPrior";
     public static final String PARAMETER_COLUMN = "parameterColumn";
     public static final String DIMENSION = "dimension";
+    public static final String UPPERLIMIT = "upperLimit";
 
     /**
      * A special parser that reads a convenient short form of reference priors on parameters.
@@ -404,6 +406,14 @@ public class WorkingPriorParsers {
                     throw new XMLParseException("Column '" + parameterName + "' has dimension smaller than 1.");
                 }
 
+                double upperlimit = 1.0;
+                if (xo.hasAttribute(UPPERLIMIT)) {
+                    upperlimit = xo.getDoubleAttribute(UPPERLIMIT);
+                }
+                if (upperlimit <= 0.0) {
+                    throw new XMLParseException("Positive upper bound expected for logit transformed normal KDE distribution.");
+                }
+
                 LogFileTraces traces = new LogFileTraces(fileName, file);
                 traces.loadTraces();
                 long maxState = traces.getMaxState();
@@ -433,7 +443,7 @@ public class WorkingPriorParsers {
                     Double[] parameterSamples = new Double[traces.getStateCount()];
                     traces.getValues(traceIndexParameter).toArray(parameterSamples);
 
-                    DistributionLikelihood likelihood = new DistributionLikelihood(new LogitTransformedNormalKDEDistribution(parameterSamples));
+                    DistributionLikelihood likelihood = new DistributionLikelihood(new LogitTransformedNormalKDEDistribution(parameterSamples, upperlimit));
                     for (int j = 0; j < xo.getChildCount(); j++) {
                         if (xo.getChild(j) instanceof Statistic) {
                             if (DEBUG) {
@@ -452,26 +462,42 @@ public class WorkingPriorParsers {
 
                     //dimension > 1
                     LogitTransformedNormalKDEDistribution[] arrayKDE = new LogitTransformedNormalKDEDistribution[dimension];
+                    String[] newParameterName = new String[dimension];
+
+                    upperlimit = dimension;
+
+                    if (xo.hasAttribute("parameterNames")) {
+                        String temp = (String)xo.getAttribute("parameterNames");
+                        StringTokenizer token = new StringTokenizer(temp);
+                        for (int i = 0; i < dimension; i++) {
+                            newParameterName[i] = token.nextToken();
+                        }
+                    } else {
+                        for (int i = 0; i < dimension; i++) {
+                            newParameterName[i] = parameterName + (i+1);
+                        }
+                    }
 
                     for (int i = 0; i < dimension; i++) {
+
                         //look for parameterName1, parameterName2, ... if necessary
-                        String newParameterName = parameterName + (i+1);
+                        //String newParameterName = parameterName + (i+1);
                         int traceIndexParameter = -1;
                         for (int j = 0; j < traces.getTraceCount(); j++) {
                             String traceName = traces.getTraceName(j);
-                            if (traceName.trim().equals(newParameterName)) {
+                            if (traceName.trim().equals(newParameterName[i])) {
                                 traceIndexParameter = j;
                             }
                         }
 
                         if (traceIndexParameter == -1) {
-                            throw new XMLParseException("LogitTransformedNormalKDEDistribution: Column '" + newParameterName + "' can not be found for " + getParserName() + " element.");
+                            throw new XMLParseException("LogitTransformedNormalKDEDistribution: Column '" + newParameterName[i] + "' can not be found for " + getParserName() + " element.");
                         }
 
                         Double[] parameterSamples = new Double[traces.getStateCount()];
                         traces.getValues(traceIndexParameter).toArray(parameterSamples);
 
-                        arrayKDE[i] = new LogitTransformedNormalKDEDistribution(parameterSamples);
+                        arrayKDE[i] = new LogitTransformedNormalKDEDistribution(parameterSamples, upperlimit);
 
                     }
 
@@ -513,6 +539,8 @@ public class WorkingPriorParsers {
                 AttributeRule.newIntegerRule("burnin"),
                 //optional to provide a dimension attribute
                 AttributeRule.newIntegerRule("dimension", true),
+                //optional to provide an upperLimit attribute
+                AttributeRule.newDoubleRule("upperLimit", true),
                 new ElementRule(Statistic.class, 1, Integer.MAX_VALUE)
         };
 
