@@ -1,7 +1,7 @@
 /*
  * MarkovRandomFieldMatrixParser.java
  *
- * Copyright (c) 2002-2013 Alexei Drummond, Andrew Rambaut and Marc Suchard
+ * Copyright (c) 2002-2015 Alexei Drummond, Andrew Rambaut and Marc Suchard
  *
  * This file is part of BEAST.
  * See the NOTICE file distributed with this work for additional
@@ -39,6 +39,8 @@ public class MarkovRandomFieldMatrixParser extends AbstractXMLObjectParser {
     public static final String DIAGONAL = "diagonal";
     public static final String OFF_DIAGONAL = "offDiagonal";
     public static final String AS_CORRELATION = "asCorrelation";
+    public static final String NUGGET = "nugget";
+    public static final String DIM = "dim";
 
     public String getParserName() {
         return MATRIX_PARAMETER;
@@ -46,6 +48,10 @@ public class MarkovRandomFieldMatrixParser extends AbstractXMLObjectParser {
 
     public Object parseXMLObject(XMLObject xo) throws XMLParseException {
 
+        String name = xo.getId();
+
+        final int dim = xo.getIntegerAttribute(DIM);
+
         XMLObject cxo = xo.getChild(DIAGONAL);
         Parameter diagonalParameter = (Parameter) cxo.getChild(Parameter.class);
         Transform.ParsedTransform tmp = (Transform.ParsedTransform) cxo.getChild(Transform.ParsedTransform.class);
@@ -58,7 +64,15 @@ public class MarkovRandomFieldMatrixParser extends AbstractXMLObjectParser {
 
         boolean asCorrelation = xo.getAttribute(AS_CORRELATION, false);
 
-        return new MarkovRandomFieldMatrix(diagonalParameter, offDiagonalParameter, asCorrelation,
+        if (diagonalParameter.getDimension() != 1  || offDiagonalParameter.getDimension() != 1) {
+            throw new XMLParseException("Wrong parameter dimensions for GMRF");
+        }
+
+        cxo = xo.getChild(NUGGET);
+        Parameter nuggetParameter = (Parameter) cxo.getChild(Parameter.class);
+
+        return new MarkovRandomFieldMatrix(name, dim, diagonalParameter, offDiagonalParameter, nuggetParameter,
+                asCorrelation,
                 diagonalTransform, offDiagonalTransform);
     }
 
@@ -85,7 +99,12 @@ public class MarkovRandomFieldMatrixParser extends AbstractXMLObjectParser {
                             new ElementRule(Parameter.class),
                             new ElementRule(Transform.ParsedTransform.class, true),
                     }),
-            AttributeRule.newBooleanRule(AS_CORRELATION, true)
+            new ElementRule(NUGGET,
+                    new XMLSyntaxRule[] {
+                            new ElementRule(Parameter.class),
+                    }),
+            AttributeRule.newBooleanRule(AS_CORRELATION, true),
+            AttributeRule.newIntegerRule(DIM),
     };
 
     public Class getReturnType() {
