@@ -26,9 +26,9 @@
 package dr.inferencexml.operators;
 
 import dr.inference.model.Parameter;
+import dr.inference.operators.AdaptationMode;
 import dr.inference.operators.CenteredScaleOperator;
-import dr.inference.operators.CoercableMCMCOperator;
-import dr.inference.operators.CoercionMode;
+import dr.inference.operators.AdaptableMCMCOperator;
 import dr.inference.operators.MCMCOperator;
 import dr.xml.*;
 
@@ -52,7 +52,7 @@ public class CenteredScaleOperatorParser extends AbstractXMLObjectParser {
         CenteredScaleOperator op = new CenteredScaleOperator(parameter);
         op.setWeight(weight);
         op.scaleFactor = scale;
-        op.mode = CoercionMode.parseMode(xo);
+        op.mode = AdaptationMode.parseMode(xo);
         return op;
     }
 
@@ -71,7 +71,7 @@ public class CenteredScaleOperatorParser extends AbstractXMLObjectParser {
     private XMLSyntaxRule[] rules = new XMLSyntaxRule[]{
             AttributeRule.newDoubleRule(MCMCOperator.WEIGHT),
             AttributeRule.newDoubleRule(SCALE_FACTOR),
-            AttributeRule.newBooleanRule(CoercableMCMCOperator.AUTO_OPTIMIZE, true),
+            AttributeRule.newBooleanRule(AdaptableMCMCOperator.AUTO_OPTIMIZE, true),
             new ElementRule(Parameter.class)
     };
 
