@@ -26,8 +26,8 @@
 package dr.inferencexml.operators;
 
 import dr.inference.model.Parameter;
-import dr.inference.operators.CoercableMCMCOperator;
-import dr.inference.operators.CoercionMode;
+import dr.inference.operators.AdaptableMCMCOperator;
+import dr.inference.operators.AdaptationMode;
 import dr.inference.operators.DeltaExchangeOperator;
 import dr.inference.operators.MCMCOperator;
 import dr.xml.*;
@@ -47,7 +47,7 @@ public class DeltaExchangeOperatorParser extends AbstractXMLObjectParser {
 
     public Object parseXMLObject(XMLObject xo) throws XMLParseException {
 
-        CoercionMode mode = CoercionMode.parseMode(xo);
+        AdaptationMode mode = AdaptationMode.parseMode(xo);
 
         final boolean isIntegerOperator = xo.getAttribute(INTEGER_OPERATOR, false);
 
@@ -105,7 +105,7 @@ public class DeltaExchangeOperatorParser extends AbstractXMLObjectParser {
             AttributeRule.newDoubleRule(DELTA),
             AttributeRule.newIntegerArrayRule(PARAMETER_WEIGHTS, true),
             AttributeRule.newDoubleRule(MCMCOperator.WEIGHT),
-            AttributeRule.newBooleanRule(CoercableMCMCOperator.AUTO_OPTIMIZE, true),
+            AttributeRule.newBooleanRule(AdaptableMCMCOperator.AUTO_OPTIMIZE, true),
             AttributeRule.newBooleanRule(INTEGER_OPERATOR, true),
             new ElementRule(Parameter.class)
     };
