@@ -26,8 +26,11 @@
 package dr.inferencexml.operators;
 
 import dr.inference.distribution.DistributionLikelihood;
+import dr.inference.distribution.IndependentNormalDistributionModel;
+import dr.inference.distribution.LatentFactorModelInterface;
 import dr.inference.distribution.MomentDistributionModel;
 import dr.inference.model.LatentFactorModel;
+import dr.inference.model.Likelihood;
 import dr.inference.model.MatrixParameterInterface;
 import dr.inference.operators.LoadingsGibbsOperator;
 import dr.inference.operators.LoadingsGibbsTruncatedOperator;
@@ -44,6 +47,12 @@ public class LoadingsGibbsOperatorParser extends AbstractXMLObjectParser {
     public static final String LOADINGS_GIBBS_OPERATOR = "loadingsGibbsOperator";
     public static final String WEIGHT = "weight";
     private final String RANDOM_SCAN = "randomScan";
+    private final String WORKING_PRIOR = "workingPrior";
+    private final String CUTOFF_PRIOR = "cutoffPrior";
+    private final String MULTI_THREADED = "multiThreaded";
+    private final String NUM_THREADS = "numThreads";
+    private final String PATH_PARAMETER = "pathParameter";
+    private final String UPPER_TRIANGLE = "upperTriangle";
 
 
     @Override
@@ -53,16 +62,36 @@ public class LoadingsGibbsOperatorParser extends AbstractXMLObjectParser {
         LatentFactorModel LFM = (LatentFactorModel) xo.getChild(LatentFactorModel.class);
         DistributionLikelihood prior = (DistributionLikelihood) xo.getChild(DistributionLikelihood.class);
         MomentDistributionModel prior2 = (MomentDistributionModel) xo.getChild(MomentDistributionModel.class);
+        IndependentNormalDistributionModel prior3 = (IndependentNormalDistributionModel) xo.getChild(IndependentNormalDistributionModel.class);
+        DistributionLikelihood cutoffPrior = null;
+        if(xo.hasChildNamed(CUTOFF_PRIOR)){
+            cutoffPrior = (DistributionLikelihood) xo.getChild(CUTOFF_PRIOR).getChild(DistributionLikelihood.class);
+        }
         boolean randomScan = xo.getAttribute(RANDOM_SCAN, true);
+        int numThreads = xo.getAttribute(NUM_THREADS, 4);
         MatrixParameterInterface loadings=null;
         if(xo.getChild(MatrixParameterInterface.class)!=null){
             loadings=(MatrixParameterInterface) xo.getChild(MatrixParameterInterface.class);
         }
+        DistributionLikelihood WorkingPrior = null;
+        if(xo.getChild(WORKING_PRIOR) != null){
+            WorkingPrior = (DistributionLikelihood) xo.getChild(WORKING_PRIOR).getChild(DistributionLikelihood.class);
+        }
+        boolean multiThreaded = xo.getAttribute(MULTI_THREADED, false);
+        boolean upperTriangle = xo.getAttribute(UPPER_TRIANGLE, true);
 
-        if(prior!=null)
-        return new LoadingsGibbsOperator(LFM, prior, weight, randomScan);  //To change body of implemented methods use File | Settings | File Templates.
+
+        if(prior !=null || prior3 != null){
+            LoadingsGibbsOperator lfmOp = new LoadingsGibbsOperator(LFM, prior, prior3, loadings, weight, randomScan,
+                    WorkingPrior, multiThreaded, numThreads, upperTriangle);
+            if(xo.hasAttribute(PATH_PARAMETER)){
+                System.out.println("WARNING: Setting Path Parameter is intended for debugging purposes only!");
+                lfmOp.setPathParameter(xo.getDoubleAttribute(PATH_PARAMETER));
+            }
+        return lfmOp;
+    }
         else
-            return new LoadingsGibbsTruncatedOperator(LFM, prior2, weight, randomScan, loadings);
+            return new LoadingsGibbsTruncatedOperator(LFM, prior2, weight, randomScan, loadings, cutoffPrior);
     }
 
     @Override
@@ -71,14 +100,26 @@ public class LoadingsGibbsOperatorParser extends AbstractXMLObjectParser {
     }
 
     private XMLSyntaxRule[] rules = new XMLSyntaxRule[]{
-            new ElementRule(LatentFactorModel.class),
+            new ElementRule(LatentFactorModelInterface.class),
 
             new XORRule(
-            new ElementRule(DistributionLikelihood.class),
-            new ElementRule(MomentDistributionModel.class)
+                    new XORRule(
+                            new ElementRule(IndependentNormalDistributionModel.class),
+        new ElementRule(DistributionLikelihood.class)),
+                    new AndRule(
+            new ElementRule(MomentDistributionModel.class),
+
+                    new ElementRule(CUTOFF_PRIOR, new XMLSyntaxRule[]{new ElementRule(DistributionLikelihood.class)}))
             ),
 //            new ElementRule(CompoundParameter.class),
             AttributeRule.newDoubleRule(WEIGHT),
+            AttributeRule.newBooleanRule(MULTI_THREADED, true),
+            AttributeRule.newIntegerRule(NUM_THREADS, true),
+            new ElementRule(WORKING_PRIOR, new XMLSyntaxRule[]{
+                    new ElementRule(DistributionLikelihood.class)
+            }, true),
+            AttributeRule.newDoubleRule(PATH_PARAMETER, true),
+            AttributeRule.newBooleanRule(UPPER_TRIANGLE, true)
     };
 
     @Override
