@@ -27,7 +27,7 @@ package dr.inferencexml.operators;
 
 import dr.inference.distribution.DistributionLikelihood;
 import dr.inference.model.LatentFactorModel;
-import dr.inference.operators.CoercionMode;
+import dr.inference.operators.AdaptationMode;
 import dr.inference.operators.LoadingsIndependenceOperator;
 import dr.xml.*;
 
@@ -47,7 +47,7 @@ public class LoadingsIndependenceOperatorParser extends AbstractXMLObjectParser
 
     @Override
     public Object parseXMLObject(XMLObject xo) throws XMLParseException {
-        CoercionMode mode = CoercionMode.parseMode(xo);
+        AdaptationMode mode = AdaptationMode.parseMode(xo);
         String scaleFactorTemp = (String) xo.getAttribute(SCALE_FACTOR);
         double scaleFactor = Double.parseDouble(scaleFactorTemp);
         String weightTemp = (String) xo.getAttribute(WEIGHT);
