@@ -25,9 +25,10 @@
 
 package dr.inferencexml.operators;
 
+import dr.inference.model.Bounds;
 import dr.inference.model.Parameter;
-import dr.inference.operators.CoercableMCMCOperator;
-import dr.inference.operators.CoercionMode;
+import dr.inference.operators.AdaptableMCMCOperator;
+import dr.inference.operators.AdaptationMode;
 import dr.inference.operators.MCMCOperator;
 import dr.inference.operators.ScaleOperator;
 import dr.xml.*;
@@ -42,6 +43,7 @@ public class ScaleOperatorParser extends AbstractXMLObjectParser {
     public static final String DEGREES_OF_FREEDOM = "df";
     public static final String INDICATORS = "indicators";
     public static final String PICKONEPROB = "pickoneprob";
+    public static final String IGNORE_BOUNDS = "ignoreBounds";
 
     public String getParserName() {
         return SCALE_OPERATOR;
@@ -52,8 +54,9 @@ public class ScaleOperatorParser extends AbstractXMLObjectParser {
         final boolean scaleAll = xo.getAttribute(SCALE_ALL, false);
         final boolean scaleAllInd = xo.getAttribute(SCALE_ALL_IND, false);
         final int degreesOfFreedom = xo.getAttribute(DEGREES_OF_FREEDOM, 0);
+        final boolean ignoreBounds = xo.getAttribute(IGNORE_BOUNDS, false);
 
-        final CoercionMode mode = CoercionMode.parseMode(xo);
+        final AdaptationMode mode = AdaptationMode.parseMode(xo);
 
         final double weight = xo.getDoubleAttribute(MCMCOperator.WEIGHT);
         final double scaleFactor = xo.getDoubleAttribute(SCALE_FACTOR);
@@ -63,6 +66,45 @@ public class ScaleOperatorParser extends AbstractXMLObjectParser {
         }
 
         final Parameter parameter = (Parameter) xo.getChild(Parameter.class);
+        Bounds<Double> bounds = parameter.getBounds();
+
+        Boolean negativeSpace = null;
+
+        for (int dim = 0; dim < parameter.getDimension(); dim++) {
+
+            if (parameter.getParameterValue(dim) < 0.0) {
+                // the parameter is in negative space
+
+                if (negativeSpace != null && !negativeSpace) {
+                    throw new XMLParseException("Scale operator can only be used on parameters where all elements are strictly positive or negative (" + parameter.getId() + ")");
+                }
+
+                negativeSpace = true;
+
+                if (bounds.getUpperLimit(dim) > 0.0) {
+                    throw new XMLParseException("Scale operator can only be used on parameters constrained to be strictly positive or negative (" + parameter.getId() + ")");
+                }
+                if (!ignoreBounds && !Double.isInfinite(bounds.getLowerLimit(dim))) {
+                    throw new XMLParseException("Scale operator can only be used on parameters with an infinite upper or lower bound (use a RandomWalk) (" + parameter.getId() + ")");
+                }
+            } else if (parameter.getParameterValue(dim) > 0.0) {
+                if (negativeSpace != null && negativeSpace) {
+                    throw new XMLParseException("Scale operator can only be used on parameters where all elements are strictly positive or negative (" + parameter.getId() + ")");
+                }
+
+                negativeSpace = false;
+
+                if (bounds.getLowerLimit(dim) < 0.0) {
+                    throw new XMLParseException("Scale operator can only be used on parameters constrained to be strictly positive or negative (" + parameter.getId() + ")");
+                }
+                if (!ignoreBounds && !Double.isInfinite(bounds.getUpperLimit(dim))) {
+                    throw new XMLParseException("Scale operator can only be used on parameters with an infinite upper or lower bound (use a RandomWalk) (" + parameter.getId() + ")");
+                }
+            } else {
+                // disallow zero starting values
+                throw new XMLParseException("Scale operator can only be used on parameters where all elements are strictly positive or negative (" + parameter.getId() + ")");
+            }
+        }
 
         Parameter indicator = null;
         double indicatorOnProb = 1.0;
@@ -106,8 +148,9 @@ public class ScaleOperatorParser extends AbstractXMLObjectParser {
             AttributeRule.newBooleanRule(SCALE_ALL, true),
             AttributeRule.newBooleanRule(SCALE_ALL_IND, true),
             AttributeRule.newDoubleRule(MCMCOperator.WEIGHT),
-            AttributeRule.newBooleanRule(CoercableMCMCOperator.AUTO_OPTIMIZE, true),
+            AttributeRule.newBooleanRule(AdaptableMCMCOperator.AUTO_OPTIMIZE, true),
             AttributeRule.newIntegerRule(DEGREES_OF_FREEDOM, true),
+            AttributeRule.newBooleanRule(IGNORE_BOUNDS, true),
 
             new ElementRule(Parameter.class),
             new ElementRule(INDICATORS,
