@@ -161,6 +161,13 @@ public class GammaDistribution implements Distribution {
                 return 0.0;
         }
 
+        if (shape == 0.0)  // uninformative
+            return 1.0 / x;
+
+        if (shape == -0.5) { // Gelman 2008, hierarchical variance, -1 degrees of freedom
+            return Math.sqrt(x);
+        }
+
         final double xs = x / scale;
 
         if (shape == 1.0) {
