@@ -35,4 +35,8 @@ import dr.inference.model.Likelihood;
 public interface GaussianProcessRandomGenerator extends RandomGenerator {
     // Only implemented by Gaussian processes
     Likelihood getLikelihood();
+
+    int getDimension();
+
+    double[][] getPrecisionMatrix();
 }
\ No newline at end of file
