@@ -1,3 +1,28 @@
+/*
+ * NormalKDEDistribution.java
+ *
+ * Copyright (c) 2002-2015 Alexei Drummond, Andrew Rambaut and Marc Suchard
+ *
+ * This file is part of BEAST.
+ * See the NOTICE file distributed with this work for additional
+ * information regarding copyright ownership and licensing.
+ *
+ * BEAST is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ *  BEAST is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with BEAST; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301  USA
+ */
+
 package dr.math.distributions;
 
 import dr.math.ComplexArray;
@@ -5,6 +30,8 @@ import dr.math.FastFourierTransform;
 import dr.stats.DiscreteStatistics;
 import dr.util.HeapSort;
 
+import java.util.Random;
+
 /**
  * @author Marc A. Suchard
  */
@@ -260,4 +287,27 @@ public class NormalKDEDistribution extends KernelDensityEstimatorDistribution {
     private double up;
 
     private boolean densityKnown = false;
+
+    public static void main(String[] args) {
+
+        long start = System.currentTimeMillis();
+
+        Random random = new Random(1234);
+
+        Double[] samples = new Double[10000000];
+        for (int i = 0; i < samples.length; i++) {
+            samples[i] = random.nextDouble();
+        }
+        NormalKDEDistribution nKDE = new NormalKDEDistribution(samples);
+
+        for (int i = 0; i < 100; i++) {
+            nKDE.evaluateKernel(random.nextDouble());
+        }
+
+        long end = System.currentTimeMillis();
+
+        System.out.println("Time: " + (end-start));
+
+    }
+
 }
\ No newline at end of file
