@@ -44,21 +44,23 @@ public class XMLParser {
     public static final String ID = XMLObject.ID;
     public static final String IDREF = "idref";
     public static final String CONCURRENT = "concurrent";
+    public static final String VERSION = "version";
 
     private Vector<Thread> threads = new Vector<Thread>();
     protected boolean strictXML;
     protected boolean parserWarnings;
 
-    public XMLParser(boolean parserWarnings, boolean strictXML) {
+    // The software version
+    private final Version version;
+
+    public XMLParser(boolean verbose, boolean parserWarnings, boolean strictXML, Version version) {
+        this.verbose = verbose;
         this.parserWarnings = parserWarnings;
         this.strictXML = strictXML;
         addXMLObjectParser(new ArrayParser(), false);
         addXMLObjectParser(Report.PARSER, false);
-    }
 
-    public XMLParser(boolean verbose, boolean parserWarnings, boolean strictXML) {
-        this(parserWarnings, strictXML);
-        this.verbose = verbose;
+        this.version = version;
     }
 
     public void addXMLObjectParser(XMLObjectParser parser) {
@@ -105,7 +107,7 @@ public class XMLParser {
 
     public void storeObject(String name, Object object) {
 
-        XMLObject xo = new XMLObject(null /*, objectStore*/);
+        XMLObject xo = new XMLObject(null, null /*, objectStore*/);
         xo.setNativeObject(object);
         objectStore.put(name, xo);
     }
@@ -139,7 +141,7 @@ public class XMLParser {
         if (e.getTagName().equals("beast")) {
 
             concurrent = false;
-            return convert(e, target, false, true);
+            return convert(e, target, null, false, true);
 
         } else {
             throw new dr.xml.XMLParseException("Unknown root document element, " + e.getTagName());
@@ -161,9 +163,16 @@ public class XMLParser {
 
         Element e = document.getDocumentElement();
         if (e.getTagName().equals("beast")) {
+            // If the 'version' is attribute is present then check it is not an more recent version...
+            if (e.hasAttribute(VERSION)) {
+                String xmlVersion = e.getAttribute(VERSION);
+                if (version != null && Version.Utils.isMoreRecent(xmlVersion, version.getVersion())) {
+                   throw new XMLParseException("The version of BEAUti that generated this XML (" + xmlVersion + ") is more recent than the version of BEAST running it (" + version.getVersion() + "). This may be incompatible and cause unpredictable errors.");
+                }
+            }
 
             concurrent = false;
-            root = (XMLObject) convert(e, null, run, true);
+            root = (XMLObject) convert(e, null, null, run, true);
 
         } else {
             throw new dr.xml.XMLParseException("Unknown root document element, " + e.getTagName());
@@ -201,7 +210,7 @@ public class XMLParser {
         return root;
     }
 
-    private Object convert(Element e, Class target, boolean run, boolean doParse) throws XMLParseException {
+    private Object convert(Element e, Class target, XMLObject parent, boolean run, boolean doParse) throws XMLParseException {
 
         int index = -1;
 
@@ -217,7 +226,7 @@ public class XMLParser {
             }
 
 
-            XMLObject restoredXMLObject = (XMLObject) objectStore.get(idref);
+            XMLObject restoredXMLObject = objectStore.get(idref);
             if (index != -1) {
 
                 if (restoredXMLObject.getNativeObject() instanceof List) {
@@ -266,7 +275,7 @@ public class XMLParser {
                 repeats = Integer.parseInt(e.getAttribute("count"));
             }
 
-            XMLObject xo = new XMLObject(e);
+            XMLObject xo = new XMLObject(e, parent);
 
             final XMLObjectParser parser = doParse ? parserStore.get(xo.getName()) : null;
 
@@ -284,7 +293,7 @@ public class XMLParser {
 
                         // don't parse elements that may be legal here with global parsers
                         final boolean parseIt = parser == null || !parser.isAllowed(tag);
-                        Object xoc = convert(element, target, run, parseIt);
+                        Object xoc = convert(element, target, xo, run, parseIt);
                         xo.addChild(xoc);
 
                         if (target != null && xoc instanceof XMLObject) {
