@@ -25,6 +25,8 @@
 
 package test.dr.app.beauti;
 
+import dr.evomodel.substmodel.aminoacid.AminoAcidModelType;
+import dr.evomodel.substmodel.nucleotide.NucModelType;
 import dr.app.beauti.generator.BeastGenerator;
 import dr.app.beauti.options.BeautiOptions;
 import dr.app.beauti.options.PartitionData;
@@ -39,8 +41,6 @@ import dr.evolution.io.Importer;
 import dr.evolution.io.NexusImporter;
 import dr.evolution.tree.Tree;
 import dr.evolution.util.*;
-import dr.evomodel.substmodel.AminoAcidModelType;
-import dr.evomodel.substmodel.NucModelType;
 import dr.evoxml.util.DateUnitsType;
 
 import java.io.*;
@@ -353,7 +353,7 @@ public class BeautiTesterConfig {
 
                     } else if (block == NexusApplicationImporter.ASSUMPTIONS_BLOCK) {
 
-                        importer.parseAssumptionsBlock(charSets);
+                        importer.parseAssumptionsBlock(charSets, null);
 
                     } else {
                         // Ignore the block..
@@ -458,7 +458,7 @@ public class BeautiTesterConfig {
                         }
                     }
                     if (partition.getPartitionSubstitutionModel() == null) {
-                        PartitionSubstitutionModel pm = new PartitionSubstitutionModel(options, partition);
+                        PartitionSubstitutionModel pm = new PartitionSubstitutionModel(options, "default", partition);
                         partition.setPartitionSubstitutionModel(pm);
 //                        options.addPartitionSubstitutionModel(pm);
                     }
