@@ -5,13 +5,13 @@ import dr.evolution.datatype.GeneralDataType;
 import dr.evomodel.operators.ExchangeOperator;
 import dr.evomodel.operators.SubtreeSlideOperator;
 import dr.evomodel.operators.WilsonBalding;
-import dr.evomodel.sitemodel.GammaSiteModel;
-import dr.evomodel.substmodel.FrequencyModel;
-import dr.evomodel.substmodel.GeneralSubstitutionModel;
-import dr.evomodel.treelikelihood.TreeLikelihood;
-import dr.evomodelxml.sitemodel.GammaSiteModelParser;
-import dr.evomodelxml.substmodel.GeneralSubstitutionModelParser;
-import dr.evomodelxml.treelikelihood.TreeLikelihoodParser;
+import dr.oldevomodel.sitemodel.GammaSiteModel;
+import dr.oldevomodel.substmodel.FrequencyModel;
+import dr.oldevomodel.substmodel.GeneralSubstitutionModel;
+import dr.oldevomodel.treelikelihood.TreeLikelihood;
+import dr.oldevomodelxml.sitemodel.GammaSiteModelParser;
+import dr.oldevomodelxml.substmodel.GeneralSubstitutionModelParser;
+import dr.oldevomodelxml.treelikelihood.TreeLikelihoodParser;
 import dr.inference.loggers.ArrayLogFormatter;
 import dr.inference.loggers.MCLogger;
 import dr.inference.loggers.TabDelimitedFormatter;
@@ -105,7 +105,7 @@ public class GeneralSubstitutionModelTest extends TraceCorrelationAssert {
         operator = new UniformOperator(internalHeights, 10.0);
         schedule.addOperator(operator);
 
-        operator = new SubtreeSlideOperator(treeModel, 1, 1, true, false, false, false, CoercionMode.COERCION_ON);
+        operator = new SubtreeSlideOperator(treeModel, 1, 1, true, false, false, false, AdaptationMode.ADAPTATION_ON, AdaptableMCMCOperator.DEFAULT_ADAPTATION_TARGET);
         schedule.addOperator(operator);
 
         operator = new ExchangeOperator(ExchangeOperator.NARROW, treeModel, 1.0);
