@@ -8,10 +8,10 @@ import dr.evolution.io.NewickImporter;
 import dr.evolution.tree.Tree;
 import dr.evomodel.tree.TreeModel;
 import dr.evomodel.tree.MicrosatelliteSamplerTreeModel;
-import dr.evomodel.substmodel.AsymmetricQuadraticModel;
-import dr.evomodel.substmodel.TwoPhaseModel;
-import dr.evomodel.substmodel.LinearBiasModel;
-import dr.evomodel.treelikelihood.MicrosatelliteSamplerTreeLikelihood;
+import dr.oldevomodel.substmodel.AsymmetricQuadraticModel;
+import dr.oldevomodel.substmodel.TwoPhaseModel;
+import dr.oldevomodel.substmodel.LinearBiasModel;
+import dr.oldevomodel.treelikelihood.MicrosatelliteSamplerTreeLikelihood;
 import dr.evomodel.branchratemodel.BranchRateModel;
 import dr.evomodel.branchratemodel.StrictClockBranchRates;
 import dr.inference.model.Parameter;
